(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    951839,      16915]
NotebookOptionsPosition[    937986,      16580]
NotebookOutlinePosition[    941632,      16658]
CellTagsIndexPosition[    941589,      16655]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["---Preamble", "Title",
 CellChangeTimes->{{3.706931445955883*^9, 3.7069314469474945`*^9}, {
  3.7069315103240986`*^9, 3.706931510692077*^9}}],

Cell[CellGroupData[{

Cell["Path to the fast marching code binaries", "Section",
 CellChangeTimes->{{3.706931453875929*^9, 3.706931484005084*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"binDirectory", "=", 
  RowBox[{"FileNameJoin", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"NotebookDirectory", "[", "]"}], ",", "\"\<bin\>\"", ",", 
     "\"\<hamiltonfastmarching\>\""}], "}"}], "]"}]}], "\n", 
 RowBox[{"libraryPath", "=", 
  RowBox[{"FileNameJoin", "[", 
   RowBox[{"{", 
    RowBox[{"binDirectory", ",", "\"\<libMathematicaHFM.dll\>\""}], "}"}], 
   "]"}]}]}], "Input",
 CellChangeTimes->{
  3.696921828515355*^9, {3.6969250538716993`*^9, 3.6969250540962667`*^9}, {
   3.6972150701368217`*^9, 3.697215071896489*^9}, {3.7003678311568394`*^9, 
   3.700367836798877*^9}, 3.700456503070724*^9, {3.7069482107541428`*^9, 
   3.7069482263215632`*^9}}],

Cell[BoxData["\<\"D:\\\\wrkLocal\\\\Projects\\\\_Exercises\\\\bin\\\\\
hamiltonfastmarching\"\>"], "Output",
 CellChangeTimes->{3.7069482304344845`*^9},
 ImageSize->{397, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData["\<\"D:\\\\wrkLocal\\\\Projects\\\\_Exercises\\\\bin\\\\\
hamiltonfastmarching\\\\libMathematicaHFM.dll\"\>"], "Output",
 CellChangeTimes->{3.7069482304364843`*^9},
 ImageSize->{551, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Load the LieAnalysis package", "Section",
 CellChangeTimes->{{3.706931491012723*^9, 3.7069314951086545`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"Load", " ", "the", " ", "package"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"<<", "LieAnalysis`"}]}]], "Input",
 CellChangeTimes->{{3.6410154104951763`*^9, 3.6410154160801105`*^9}, 
   3.6410310392915277`*^9, 3.641032396402068*^9, {3.6503340712929506`*^9, 
   3.650334129995751*^9}, {3.650334175812951*^9, 3.6503342426433506`*^9}, 
   3.673067942046812*^9, 3.6732305405642557`*^9, 3.673230697625856*^9, {
   3.674893555081876*^9, 3.6748935790415688`*^9}, {3.7009954874623823`*^9, 
   3.7009955009231725`*^9}, 3.706931364150257*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["---Functions", "Title",
 CellChangeTimes->{{3.7004503893612385`*^9, 3.700450391266301*^9}, {
  3.7069315075236464`*^9, 3.7069315142445345`*^9}}],

Cell[CellGroupData[{

Cell["HFM FileIO (The old approach using disk writing)", "Section",
 CellChangeTimes->{{3.700451378609577*^9, 3.7004513812325325`*^9}, {
  3.7009987678432198`*^9, 3.700998777092843*^9}}],

Cell[CellGroupData[{

Cell["Data IO (hard-disk <> RAM)", "Subsection",
 CellChangeTimes->{{3.706931545950878*^9, 3.706931587765154*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"--", 
      RowBox[{"--", 
       RowBox[{"--", 
        RowBox[{"--", " ", "Copied"}]}]}]}], " ", "from", " ", 
     RowBox[{"FileIO", ".", "nb"}]}], ",", " ", 
    RowBox[{"in", " ", 
     RowBox[{"JMMCPPLibs", "/", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Output", " ", "--"}], "--"}], "--"}], "--"}]}]}]}], "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"RulesToRaw", "[", 
      RowBox[{"l_List", ",", "fileName_String"}], "]"}], ":=", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
        "lStr", " ", ",", " ", "lNum", ",", " ", "lArr", ",", 
         "\[IndentingNewLine]", 
         RowBox[{"str", "=", "\"\<\>\""}], ",", 
         RowBox[{"data", "=", 
          RowBox[{"{", "}"}]}]}], "\[IndentingNewLine]", "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"!", 
           RowBox[{"And", "@@", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"Length", "@", "#"}], "\[Equal]", "2"}], "&"}], "/@", 
              "l"}], ")"}]}]}], ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
           "Print", "[", 
            "\"\<SaveToFile Error : Elements of l are not pairs\>\"", "]"}], 
           ";", "\[IndentingNewLine]", " ", 
           RowBox[{"Return", "[", "True", "]"}], ";"}]}], "]"}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"!", 
           RowBox[{"And", "@@", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"StringQ", "@", 
                RowBox[{"First", "@", "#"}]}], "&"}], "/@", "l"}], ")"}]}]}], 
          ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
           "Print", "[", "\"\<SaveToFile Error : Keys are not strings\>\"", 
            "]"}], ";", "\[IndentingNewLine]", " ", 
           RowBox[{"Return", "[", "True", "]"}], ";"}]}], "]"}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"!", 
           RowBox[{"And", "@@", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"StringQ", "@", "#"}], "||", 
                 RowBox[{"NumericQ", "@", "#"}], "||", 
                 RowBox[{"ArrayQ", "[", 
                  RowBox[{"#", ",", "_", ",", "NumericQ"}], "]"}], "||", 
                 RowBox[{"#", "===", "Null"}]}], ")"}], "&"}], "/@", 
              RowBox[{"(", 
               RowBox[{"Last", "/@", "l"}], ")"}]}], ")"}]}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
           "Print", "[", 
            "\"\<SaveToFile Error : data format should be \
string|Numeric|Array\>\"", "]"}], ";", "\[IndentingNewLine]", " ", 
           RowBox[{"Return", "[", "True", "]"}], ";"}]}], "]"}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"lStr", "=", 
         RowBox[{"Select", "[", 
          RowBox[{"l", ",", 
           RowBox[{
            RowBox[{"StringQ", "@", 
             RowBox[{"Last", "@", "#"}]}], "&"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"lNum", "=", 
         RowBox[{"Select", "[", 
          RowBox[{"l", ",", 
           RowBox[{
            RowBox[{"NumericQ", "@", 
             RowBox[{"Last", "@", "#"}]}], "&"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"lArr", "=", 
         RowBox[{"Select", "[", 
          RowBox[{"l", ",", 
           RowBox[{
            RowBox[{"ArrayQ", "@", 
             RowBox[{"Last", "@", "#"}]}], "&"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"Do", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"str", "=", 
            RowBox[{"str", "<>", 
             RowBox[{"(", 
              RowBox[{"First", "@", "eStr"}], ")"}], "<>", "\"\<\\n-1\\n\>\"",
              "<>", 
             RowBox[{"(", 
              RowBox[{"Last", "@", "eStr"}], ")"}], "<>", 
             "\"\<\\n\\n\>\""}]}], ";"}], "\[IndentingNewLine]", ",", 
          RowBox[{"{", 
           RowBox[{"eStr", ",", "lStr"}], "}"}]}], "]"}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"Do", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"str", "=", 
            RowBox[{"str", "<>", 
             RowBox[{"(", 
              RowBox[{"First", "@", "eNum"}], ")"}], "<>", 
             "\"\<\\n0\\n\\n\>\""}]}], ";", "\[IndentingNewLine]", 
           RowBox[{"AppendTo", "[", 
            RowBox[{"data", ",", 
             RowBox[{"N", "@", 
              RowBox[{"Last", "@", "eNum"}]}]}], "]"}], ";"}], 
          "\[IndentingNewLine]", ",", 
          RowBox[{"{", 
           RowBox[{"eNum", ",", "lNum"}], "}"}]}], "]"}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"Do", "[", 
         RowBox[{"(*", 
          RowBox[{
           RowBox[{
           "Dimensions", " ", "are", " ", "reversed", " ", "because", " ", 
            "we", " ", "want", " ", "the", " ", "first", " ", "index", " ", 
            "to", " ", "be", " ", "the", " ", "fast", " ", "index"}], ",", 
           " ", 
           RowBox[{"like", " ", "Matlab"}], ",", " ", 
           RowBox[{"and", " ", "contrary", " ", "to", " ", "Mathematica"}]}], 
          "*)"}], "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"With", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"dims", "=", 
               RowBox[{"Reverse", "@", 
                RowBox[{"Dimensions", "@", 
                 RowBox[{"Last", "@", "eArr"}]}]}]}], "}"}], ",", " ", 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"str", "=", 
               RowBox[{"str", "<>", 
                RowBox[{"(", 
                 RowBox[{"First", "@", "eArr"}], ")"}], "<>", "\"\<\\n\>\"", 
                "\[IndentingNewLine]", "<>", 
                RowBox[{"ToString", "[", 
                 RowBox[{"Length", "@", "dims"}], "]"}], "<>", 
                "\"\<\\n\>\""}]}], ";", "\[IndentingNewLine]", 
              RowBox[{"Do", "[", 
               RowBox[{
                RowBox[{"str", "=", 
                 RowBox[{"str", "<>", 
                  RowBox[{"ToString", "[", "d", "]"}], "<>", 
                  "\"\<\\n\>\""}]}], ",", 
                RowBox[{"{", 
                 RowBox[{"d", ",", "dims"}], "}"}]}], "]"}], ";", 
              "\[IndentingNewLine]", 
              RowBox[{"str", "=", 
               RowBox[{"str", "<>", "\"\<\\n\>\""}]}], ";"}]}], 
            "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
           RowBox[{"data", "=", 
            RowBox[{"Join", "[", 
             RowBox[{"data", ",", 
              RowBox[{"N", "@", 
               RowBox[{"Flatten", "@", 
                RowBox[{"Last", "@", "eArr"}]}]}]}], "]"}]}], ";"}], 
          "\[IndentingNewLine]", ",", 
          RowBox[{"{", 
           RowBox[{"eArr", ",", "lArr"}], "}"}]}], "]"}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"StringLength", "[", "fileName", "]"}], ">", "0"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"With", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"formatFile", "=", 
               RowBox[{"fileName", "<>", "\"\<_Format.txt\>\""}]}], ",", 
              RowBox[{"dataFile", "=", 
               RowBox[{"fileName", "<>", "\"\<_Data.dat\>\""}]}]}], "}"}], 
            ",", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"Export", "[", 
              RowBox[{"formatFile", ",", "str"}], "]"}], ";", " ", 
             RowBox[{"(*", 
              RowBox[{
               RowBox[{"Mathematica", " ", "adds", " ", "one", " ", "\\n"}], 
               ",", " ", 
               RowBox[{
                RowBox[{
                "so", " ", "we", " ", "must", " ", "remove", " ", "one"}], 
                "..."}]}], "*)"}], "\[IndentingNewLine]", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"Length", "@", "data"}], ">", "0"}], ",", 
               RowBox[{
                RowBox[{"BinaryWrite", "[", 
                 RowBox[{"dataFile", ",", "data", ",", "\"\<Real64\>\""}], 
                 "]"}], ";", " ", 
                RowBox[{"Close", "[", "dataFile", "]"}], ";"}]}], "]"}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"Return", "[", "False", "]"}], ";"}]}], 
           "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Return", "[", 
            RowBox[{"{", 
             RowBox[{"str", ",", "data"}], "}"}], "]"}], ";"}]}], 
         "\[IndentingNewLine]", "]"}], ";"}]}], "\[IndentingNewLine]", 
      "]"}]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"RawToRules", "[", "fileName_String", "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"formatFile", "=", 
         RowBox[{"fileName", "<>", "\"\<_Format.txt\>\""}]}], ",", 
        RowBox[{"dataFile", "=", 
         RowBox[{"fileName", "<>", "\"\<_Data.dat\>\""}]}], ",", "data"}], 
       "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"RawToRules", "[", 
       RowBox[{
        RowBox[{"Import", "[", 
         RowBox[{"formatFile", ",", "\"\<String\>\""}], "]"}], ",", 
        RowBox[{"BinaryReadList", "[", 
         RowBox[{"dataFile", ",", "\"\<Real64\>\""}], "]"}]}], "]"}]}], 
     "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"RawToRules", "[", 
     RowBox[{"str_String", ",", "data_List"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"l", "=", 
         RowBox[{"{", "}"}]}], ",", 
        RowBox[{"pos", "=", "0"}], ",", 
        RowBox[{"newlineCharacter", "=", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"$OperatingSystem", "\[Equal]", "\"\<Windows\>\""}], ",", 
           "\"\<\\r\\n\>\"", ",", "\"\<\\n\>\""}], "]"}]}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Do", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Module", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"format", " ", "=", " ", 
              RowBox[{"StringSplit", "[", 
               RowBox[{"s", ",", "newlineCharacter"}], "]"}]}], ",", "dim", 
             ",", "dims", ",", 
             RowBox[{"oldPos", "=", "pos"}], ",", 
             RowBox[{"oldLen", "=", 
              RowBox[{"Length", "@", "l"}]}]}], "}"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"Length", "@", "format"}], "\[GreaterEqual]", "2"}], 
              ",", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"dim", "=", 
                RowBox[{"ToExpression", "[", 
                 RowBox[{"format", "[", 
                  RowBox[{"[", "2", "]"}], "]"}], "]"}]}], ";", 
               "\[IndentingNewLine]", 
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"IntegerQ", "[", "dim", "]"}], " ", "&&", " ", 
                  RowBox[{"dim", "\[GreaterEqual]", 
                   RowBox[{"-", "1"}]}]}], ",", "\[IndentingNewLine]", 
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{"dim", "\[Equal]", 
                    RowBox[{"-", "1"}]}], ",", "\[IndentingNewLine]", 
                   RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Length", "@", "format"}], "\[Equal]", "3"}], ",", 
                    RowBox[{"AppendTo", "[", 
                    RowBox[{"l", ",", 
                    RowBox[{
                    RowBox[{"format", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "\[Rule]", 
                    RowBox[{"format", "[", 
                    RowBox[{"[", "3", "]"}], "]"}]}]}], " ", "]"}]}], " ", 
                    "]"}], ",", "\[IndentingNewLine]", 
                   RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Length", "@", "format"}], "\[Equal]", 
                    RowBox[{"dim", "+", "2"}]}], ",", "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"dims", "=", 
                    RowBox[{"Reverse", "@", 
                    RowBox[{"Table", "[", 
                    RowBox[{
                    RowBox[{"ToExpression", "@", 
                    RowBox[{"format", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", "+", "2"}], "]"}], "]"}]}], ",", 
                    RowBox[{"{", 
                    RowBox[{"i", ",", "dim"}], "}"}]}], "]"}]}]}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{"pos", "=", 
                    RowBox[{"pos", "+", 
                    RowBox[{"Times", "@@", "dims"}]}]}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Length", "@", "data"}], "\[GreaterEqual]", 
                    "pos"}], ",", 
                    RowBox[{"AppendTo", "[", 
                    RowBox[{"l", ",", 
                    RowBox[{
                    RowBox[{"format", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "\[Rule]", " ", 
                    RowBox[{"ArrayReshape", "[", 
                    RowBox[{
                    RowBox[{"data", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"oldPos", "+", "1"}], ";;", "pos"}], "]"}], "]"}],
                     ",", "dims"}], "]"}]}]}], " ", "]"}]}], "]"}]}]}], 
                    "\[IndentingNewLine]", "]"}]}], " ", "]"}]}], " ", 
                "]"}]}]}], " ", "]"}], ";", "\[IndentingNewLine]", 
            RowBox[{"(*", 
             RowBox[{
             "Allow", " ", "for", " ", "a", " ", "final", " ", "blank", " ", 
              "line"}], "*)"}], "\[IndentingNewLine]", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"Length", "@", "l"}], "\[Equal]", "oldLen"}], " ", "&&",
                " ", 
               RowBox[{"s", "\[NotEqual]", "newlineCharacter"}]}], ",", 
              RowBox[{"Print", "[", 
               RowBox[{
               "\"\<RawToRules error : could not import \>\"", "<>", "s"}], 
               "]"}]}], "]"}], ";"}]}], "\[IndentingNewLine]", "]"}], 
         "\[IndentingNewLine]", ",", 
         RowBox[{"{", 
          RowBox[{"s", ",", 
           RowBox[{"StringSplit", "[", 
            RowBox[{"str", ",", 
             RowBox[{"newlineCharacter", "<>", "newlineCharacter"}]}], 
            "]"}]}], "}"}]}], "]"}], ";", "\[IndentingNewLine]", "l"}]}], 
     "\[IndentingNewLine]", "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.696873107708523*^9, 3.696873280372493*^9}, {
   3.6968735175848227`*^9, 3.696873544038447*^9}, {3.696873883092235*^9, 
   3.6968738866873617`*^9}, {3.696932632863077*^9, 3.696932683915284*^9}, {
   3.696943072071027*^9, 3.696943090021679*^9}, {3.696943371703699*^9, 
   3.6969433796839247`*^9}, {3.697743684182283*^9, 3.697743700937011*^9}, {
   3.699379911773041*^9, 3.699379915829468*^9}, {3.699379954174136*^9, 
   3.699379957148058*^9}, {3.699379996216611*^9, 3.699379998377261*^9}, {
   3.699380091805086*^9, 3.699380121229937*^9}, {3.699380157431526*^9, 
   3.699380189663466*^9}, {3.699380289139727*^9, 3.699380310301757*^9}, {
   3.699380469782707*^9, 3.699380572745825*^9}, 3.699380604092313*^9, {
   3.69938068985175*^9, 3.699380771922076*^9}, {3.699380818902176*^9, 
   3.699380839220717*^9}, {3.6993869743422413`*^9, 3.6993869795148697`*^9}, {
   3.7004504286136*^9, 3.7004504288692784`*^9}, {3.7004505119742374`*^9, 
   3.700450512037407*^9}, {3.700450546660462*^9, 3.7004505596199417`*^9}, {
   3.700450611683378*^9, 3.7004506396507034`*^9}, {3.7004508260033283`*^9, 
   3.700450834595139*^9}, {3.700450917577772*^9, 3.7004509202709637`*^9}, {
   3.700451168289363*^9, 3.700451292044406*^9}}]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
HFM WLL (The new approach using a direct Wolfram Library Link)\
\>", "Section",
 CellChangeTimes->{{3.696925024527689*^9, 3.696925026351544*^9}, 
   3.700455276831668*^9, {3.7009987846930237`*^9, 3.7009987940669394`*^9}}],

Cell[CellGroupData[{

Cell["The library link functions", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**", "**", "**", "**", "**", "Load"}], " ", "HFM", 
    " ", "wolfram", " ", "library", " ", "link", " ", 
    RowBox[{"functions", ":"}]}], "*)"}], "\n", 
  RowBox[{
   RowBox[{
    RowBox[{"LoadHFMWLL", "[", "lfmwllLibraryFile_", "]"}], ":=", 
    RowBox[{"Module", "[", "\n", "\t", 
     RowBox[{
      RowBox[{"{", "}"}], ",", "\n", "\t", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"**", "**", "**", "**", "**", "The"}], " ", "main", " ", 
        RowBox[{"functions", ":"}]}], "*)"}], "\n", "\t", 
      RowBox[{
       RowBox[{"hfmRunModel", " ", "=", " ", 
        RowBox[{"LibraryFunctionLoad", "[", 
         RowBox[{"lfmwllLibraryFile", ",", " ", "\"\<RunModel\>\"", ",", " ", 
          RowBox[{"{", "}"}], ",", " ", "Real"}], "]"}]}], ";", "\n", 
       "\t\t\t\t", "\n", "\t", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"**", "**", "**", "**", "**", "Get"}], " ", 
         RowBox[{"functions", ":"}]}], "*)"}], "\n", "\t", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"**", "**"}], "*", "GetScalar"}], "*)"}], "\n", "\t", 
       RowBox[{"hfmGetScalar", " ", "=", " ", 
        RowBox[{"LibraryFunctionLoad", "[", 
         RowBox[{"lfmwllLibraryFile", ",", " ", "\"\<GetScalar\>\"", ",", " ", 
          RowBox[{"{", "String", 
           RowBox[{"(*", "key", "*)"}], "}"}], ",", " ", "Real"}], 
         RowBox[{"(*", "keyval", "*)"}], "]"}]}], ";", "\n", "\t", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"**", "**"}], "*", "GetString"}], "*)"}], "\n", "\t", 
       RowBox[{"hfmGetString", " ", "=", " ", 
        RowBox[{"LibraryFunctionLoad", "[", 
         RowBox[{"lfmwllLibraryFile", ",", "\"\<GetString\>\"", ",", " ", 
          RowBox[{"{", "String", 
           RowBox[{"(*", "key", "*)"}], "}"}], ",", " ", "String"}], 
         RowBox[{"(*", "keyval", "*)"}], "]"}]}], ";", "\n", "\t", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"**", "**"}], "*", "GetVector"}], "*)"}], "\n", "\t", 
       RowBox[{"hfmGetVector", " ", "=", " ", 
        RowBox[{"LibraryFunctionLoad", "[", 
         RowBox[{"lfmwllLibraryFile", ",", "\"\<GetVector\>\"", ",", " ", 
          RowBox[{"{", "String", 
           RowBox[{"(*", "key", "*)"}], "}"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{"Real", ",", "1"}], "}"}]}], 
         RowBox[{"(*", "keyval", "*)"}], "]"}]}], ";", "\n", "\t", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"**", "**"}], "*", "GetArray"}], "*)"}], "\n", "\t", 
       RowBox[{"Quiet", "@", 
        RowBox[{"Do", "[", 
         RowBox[{"(*", 
          RowBox[{"Quiet", " ", "overload", " ", "messages"}], "*)"}], "\n", 
         "\t\t\t", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"hfmGetArrayBase", "[", "d", "]"}], " ", "=", " ", 
            RowBox[{"LibraryFunctionLoad", "[", 
             RowBox[{
             "lfmwllLibraryFile", ",", " ", "\"\<GetArray\>\"", ",", " ", 
              RowBox[{"{", 
               RowBox[{"String", 
                RowBox[{"(*", "key", "*)"}], ",", " ", "Integer"}], 
               RowBox[{"(*", "Dimension", "*)"}], "}"}], ",", " ", 
              RowBox[{"{", 
               RowBox[{"Real", ",", "d"}], "}"}]}], 
             RowBox[{"(*", "keyval", "*)"}], "]"}]}], ";"}], "\n", "\t\t\t", 
          ",", 
          RowBox[{"{", 
           RowBox[{"d", ",", "1", ",", "6", ",", "1"}], "}"}]}], "]"}]}], ";",
        "\n", "\t", 
       RowBox[{
        RowBox[{
         RowBox[{"hfmGetArray", "[", "d_", "]"}], "[", "key_", "]"}], ":=", 
        RowBox[{
         RowBox[{"hfmGetArrayBase", "[", "d", "]"}], "[", 
         RowBox[{"key", ",", "d"}], "]"}]}], ";", "\n", "\t\t", "\n", "\t", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"**", "**", "**", "**", "**", "Set"}], " ", 
         RowBox[{"functions", ":"}]}], "*)"}], "\n", "\t", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"**", "**"}], "*", "SetScalar"}], "*)"}], "\n", "\t", 
       RowBox[{"hfmSetScalar", " ", "=", " ", 
        RowBox[{"LibraryFunctionLoad", "[", 
         RowBox[{"lfmwllLibraryFile", ",", " ", "\"\<SetScalar\>\"", ",", " ", 
          RowBox[{"{", 
           RowBox[{"String", 
            RowBox[{"(*", "key", "*)"}], ",", " ", "Real"}], 
           RowBox[{"(*", "val", "*)"}], "}"}], ",", " ", "\"\<Void\>\""}], 
         "]"}]}], ";", "\n", "\t", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"**", "**"}], "*", "SetString"}], "*)"}], "\n", "\t", 
       RowBox[{"hfmSetString", " ", "=", " ", 
        RowBox[{"LibraryFunctionLoad", "[", 
         RowBox[{"lfmwllLibraryFile", ",", " ", "\"\<SetString\>\"", ",", " ", 
          RowBox[{"{", 
           RowBox[{"String", 
            RowBox[{"(*", "key", "*)"}], ",", " ", "String"}], 
           RowBox[{"(*", "val", "*)"}], "}"}], ",", " ", "\"\<Void\>\""}], 
         "]"}]}], ";", "\n", "\t", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"**", "**"}], "*", "SetVector"}], "*)"}], "\n", "\t", 
       RowBox[{"hfmSetVector", " ", "=", " ", 
        RowBox[{"LibraryFunctionLoad", "[", 
         RowBox[{"lfmwllLibraryFile", ",", " ", "\"\<SetVector\>\"", ",", " ", 
          RowBox[{"{", 
           RowBox[{"String", 
            RowBox[{"(*", "key", "*)"}], ",", " ", 
            RowBox[{"{", 
             RowBox[{"Real", ",", "1"}], "}"}]}], 
           RowBox[{"(*", "val", "*)"}], "}"}], ",", " ", "\"\<Void\>\""}], 
         "]"}]}], ";", "\n", "\t", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"**", "**"}], "*", "SetArray"}], "*)"}], "\n", "\t", 
       RowBox[{"Quiet", "@", 
        RowBox[{"Do", "[", "\n", "\t\t\t", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"hfmSetArray", "[", "d", "]"}], " ", "=", " ", 
            RowBox[{"LibraryFunctionLoad", "[", 
             RowBox[{
             "lfmwllLibraryFile", ",", " ", "\"\<SetArray\>\"", ",", " ", 
              RowBox[{"{", 
               RowBox[{"String", 
                RowBox[{"(*", "key", "*)"}], ",", " ", 
                RowBox[{"{", 
                 RowBox[{"Real", ",", "d"}], "}"}]}], 
               RowBox[{"(*", 
                RowBox[{"val", " ", 
                 RowBox[{"(", 
                  RowBox[{"d", "-", 
                   RowBox[{"dimensional", " ", "array"}]}], ")"}]}], "*)"}], 
               "}"}], ",", " ", "\"\<Void\>\""}], "]"}]}], ";"}], "\n", 
          "\t\t\t", ",", 
          RowBox[{"{", 
           RowBox[{"d", ",", "1", ",", "6", ",", "1"}], "}"}]}], "]"}]}], ";",
        "\n", "\t\t\t", "\n", "\t", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{
          RowBox[{"**", "**", "**", "**", "**", "Additional"}], " ", 
          "front"}], "-", 
         RowBox[{"end", " ", 
          RowBox[{"functions", ":"}]}]}], "*)"}], "\n", "\t", 
       RowBox[{
        RowBox[{"hfmSetVariable", "[", 
         RowBox[{"key_", ",", "val_"}], "]"}], ":=", 
        RowBox[{"Switch", "[", " ", 
         RowBox[{
          RowBox[{"Head", "[", "val", "]"}], "\n", "\t\t", ",", "String", ",",
           "\n", "\t\t\t", 
          RowBox[{"hfmSetString", "[", 
           RowBox[{"key", ",", "val"}], "]"}], "\n", "\t\t", ",", "Integer", 
          ",", "\n", "\t\t\t", 
          RowBox[{"hfmSetScalar", "[", 
           RowBox[{"key", ",", "val"}], "]"}], "\n", "\t\t", ",", "Real", ",",
           "\n", "\t\t\t", 
          RowBox[{"hfmSetScalar", "[", 
           RowBox[{"key", ",", "val"}], "]"}], "\n", "\t\t", ",", "List", ",",
           "\n", "\t\t\t", 
          RowBox[{
           RowBox[{"hfmSetArray", "[", 
            RowBox[{"TensorRank", "[", "val", "]"}], "]"}], "[", 
           RowBox[{"key", ",", "val"}], "]"}]}], "\n", "\t\t", "]"}]}], 
       ";"}]}], 
     RowBox[{"(*", 
      RowBox[{"end", " ", "of", " ", "switch"}], "*)"}], "\n", "]"}]}], "\n", 
   "\n", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
     "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
       "**", "**", "**", "**", "**", "**", "**", "**", "Unload"}], " ", "HFM",
      " ", "wolfram", " ", "library", " ", 
     RowBox[{"link", ":"}]}], "*)"}], "\n", 
   RowBox[{
    RowBox[{"UnloadHFMWLL", "[", "]"}], ":=", 
    RowBox[{"Module", "[", "\n", "\t", 
     RowBox[{
      RowBox[{"{", "}"}], ",", "\n", "\t", 
      RowBox[{"(*", 
       RowBox[{"The", " ", "main", " ", "functions"}], "*)"}], "\n", "\t", 
      RowBox[{
       RowBox[{"LibraryFunctionUnload", "[", "hfmRunModel", "]"}], ";", "\n", 
       "\t", 
       RowBox[{"(*", 
        RowBox[{"Get", " ", "functions"}], "*)"}], "\n", "\t", 
       RowBox[{"LibraryFunctionUnload", "[", "hfmGetScalar", "]"}], ";", "\n",
        "\t", 
       RowBox[{"LibraryFunctionUnload", "[", "hfmGetString", "]"}], ";", "\n",
        "\t", 
       RowBox[{"LibraryFunctionUnload", "[", "hfmGetVector", "]"}], ";", "\n",
        "\t", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"LibraryFunctionUnload", "[", 
           RowBox[{"hfmGetArrayBase", "[", "d", "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"d", ",", "1", ",", "6", ",", "1"}], "}"}]}], "]"}], "\n", 
        "\t", 
        RowBox[{"(*", 
         RowBox[{"Set", " ", "functions"}], "*)"}], "\n", "\t", 
        RowBox[{"LibraryFunctionUnload", "[", "hfmSetScalar", "]"}]}], ";", 
       "\n", "\t", 
       RowBox[{"LibraryFunctionUnload", "[", "hfmSetString", "]"}], ";", "\n",
        "\t", 
       RowBox[{"LibraryFunctionUnload", "[", "hfmSetVector", "]"}], ";", "\n",
        "\t", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"LibraryFunctionUnload", "[", 
          RowBox[{"hfmSetArray", "[", "d", "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"d", ",", "1", ",", "6", ",", "1"}], "}"}]}], "]"}], 
       ";"}]}], "\n", "]"}]}]}]}]], "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Back tracking via LieAnalysis`", "Section",
 CellChangeTimes->{{3.7069400292440944`*^9, 3.7069400372434063`*^9}}],

Cell[CellGroupData[{

Cell["Back tracking via LieAnalysis`", "Subsection",
 CellChangeTimes->{3.706940048892398*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"BackTracking", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"g1d_", ",", "g0d_"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"A1WInt_", ",", "A2WInt_", ",", "A3WInt_"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"beta_", ",", "epsilon_"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"sTheta_", ",", "sx_"}], "}"}], ",", "periodicity_"}], "]"}], ":=", 
  RowBox[{"Module", "[", "\n", "\t", 
   RowBox[{
    RowBox[{"{", "\n", "\t\t", 
     RowBox[{"(*", 
      RowBox[{"Some", " ", "parameters"}], "*)"}], "\n", "\t\t", 
     RowBox[{
      RowBox[{"\[Delta]t", "=", "0.001"}], ",", 
      RowBox[{"(*", 
       RowBox[{"Step", " ", "size"}], "*)"}], "\n", "\t\t", 
      RowBox[{"minimumspeed", "=", 
       RowBox[{"10", "^", 
        RowBox[{"-", "1"}]}]}], ",", 
      RowBox[{"(*", 
       RowBox[{
       "Backtracking", " ", "stops", " ", "if", " ", "the", " ", "minimum", 
        " ", "speed", " ", "is", " ", "lower", " ", "than", " ", "this"}], 
       "*)"}], "\n", "\t\t", "\n", "\t\t", 
      RowBox[{"(*", "Initialization", "*)"}], "\n", "\t\t", 
      RowBox[{"direction", "=", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], ",", "\n", "\t\t", 
      "curved", ",", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"The", " ", "output", " ", "curve"}], ",", " ", 
        RowBox[{"d", " ", "stands", " ", "for", " ", "discrete"}]}], "*)"}], 
      "\n", "\t\t", "currentPoint", ",", "newPoint", ",", "\n", "\t\t", "\n", 
      "\t\t", 
      RowBox[{"(*", 
       RowBox[{"Gradient", " ", "descent", " ", "variables"}], "*)"}], "\n", 
      "\t\t", "A1", ",", "A2", ",", "A3", ",", "\n", "\t\t", "u1", ",", "u2", 
      ",", "u3"}], "\n", "\t", "}"}], ",", "\n", "\t", "\n", "\t", 
    RowBox[{"(*", 
     RowBox[{
     "Initialize", " ", "track", " ", "with", " ", "end", " ", "point"}], 
     "*)"}], "\n", "\t", 
    RowBox[{
     RowBox[{"curved", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"g1d", "/", 
         RowBox[{"{", 
          RowBox[{"1", ",", "1", ",", "sTheta"}], "}"}]}], "+", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]}], ";", "\n", "\t",
      "\n", "\t", 
     RowBox[{"it", "=", "1"}], ";", "\n", "\t", 
     RowBox[{"While", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Norm", "[", "direction", "]"}], ">", "minimumspeed"}], "&&", 
        RowBox[{"it", "<", "5000"}]}], ",", "\n", "\t\t\t\t", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{
         "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", 
          "Last"}], " ", "point"}], "*)"}], "\n", "\t\t", 
       RowBox[{
        RowBox[{"currentPoint", "=", 
         RowBox[{"curved", "[", 
          RowBox[{"[", 
           RowBox[{"-", "1"}], "]"}], "]"}]}], ";", "\n", "\t\t", "\n", 
        "\t\t", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{
          "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", 
           "Gradient"}], " ", "direction"}], "*)"}], "\n", "\t\t", 
        RowBox[{"(*", 
         RowBox[{"left", " ", "invariant", " ", "vector", " ", "frame"}], 
         "*)"}], "\n", "\t\t", 
        RowBox[{"A1", "=", 
         RowBox[{"1", " ", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"currentPoint", "[", 
                 RowBox[{"[", "3", "]"}], "]"}], "-", "1"}], ")"}], "*", 
              "sTheta"}], "]"}], ",", 
            RowBox[{"Sin", "[", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"currentPoint", "[", 
                 RowBox[{"[", "3", "]"}], "]"}], "-", "1"}], ")"}], "*", 
              "sTheta"}], "]"}], ",", "0"}], "}"}]}]}], ";", 
        RowBox[{"(*", 
         RowBox[{"xi", " ", "direction"}], "*)"}], "\n", "\t\t", 
        RowBox[{"A2", "=", 
         RowBox[{"1", " ", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"Sin", "[", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"currentPoint", "[", 
                  RowBox[{"[", "3", "]"}], "]"}], "-", "1"}], ")"}], "*", 
               "sTheta"}], "]"}]}], ",", 
            RowBox[{"Cos", "[", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"currentPoint", "[", 
                 RowBox[{"[", "3", "]"}], "]"}], "-", "1"}], ")"}], "*", 
              "sTheta"}], "]"}], ",", "0"}], "}"}]}]}], ";", 
        RowBox[{"(*", 
         RowBox[{"eta", " ", "direction"}], "*)"}], "\n", "\t\t", 
        RowBox[{"A3", "=", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], ";", 
        RowBox[{"(*", 
         RowBox[{"theta", " ", "direction"}], "*)"}], "\n", "\t\t", 
        RowBox[{"(*", "controls", "*)"}], "\n", "\t\t", 
        RowBox[{"u1", "=", 
         RowBox[{
          RowBox[{"1", "/", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"sx", "^", "2"}], " ", 
             RowBox[{"beta", "^", "2"}]}], ")"}]}], "*", 
          RowBox[{"A1WInt", "[", 
           RowBox[{"Sequence", "@@", "currentPoint"}], "]"}]}]}], 
        RowBox[{"(*", 
         RowBox[{"division", " ", "by", " ", 
          RowBox[{"cost", "^", "2"}], " ", "is", " ", "included", " ", "in", 
          " ", "A1WInt"}], "*)"}], ";", "\n", "\t\t", 
        RowBox[{"u2", "=", 
         RowBox[{
          RowBox[{"1", "/", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"epsilon", "^", 
              RowBox[{"(", 
               RowBox[{"-", "2"}], ")"}]}], " ", 
             RowBox[{"sx", "^", "2"}], " ", 
             RowBox[{"beta", "^", "2"}]}], ")"}]}], "*", 
          RowBox[{"A2WInt", "[", 
           RowBox[{"Sequence", "@@", "currentPoint"}], "]"}]}]}], ";", "\n", 
        "\t\t", 
        RowBox[{"u3", "=", 
         RowBox[{
          RowBox[{"1", "/", "sTheta"}], " ", 
          RowBox[{"A3WInt", "[", 
           RowBox[{"Sequence", "@@", "currentPoint"}], "]"}]}]}], ";", 
        RowBox[{"(*", 
         RowBox[{"Convert", " ", "to", " ", "discrete", " ", "angles"}], 
         "*)"}], "\n", "\t\t", "\n", "\t\t", 
        RowBox[{"(*", 
         RowBox[{"Gradient", " ", "direction"}], "*)"}], "\n", "\t\t", 
        RowBox[{"direction", "=", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"u1", "*", "A1"}], "+", 
            RowBox[{"u2", "*", "A2"}], "+", " ", 
            RowBox[{"u3", "*", "A3"}]}], ")"}]}]}], ";", "\n", "\t\t", "\n", 
        "\t\t", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{
          "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", 
           "Get"}], " ", "new", " ", "point", " ", "and", " ", "update", " ", 
          "curve"}], "*)"}], "\n", "\t\t", 
        RowBox[{"newPoint", "=", 
         RowBox[{"currentPoint", "+", 
          RowBox[{"\[Delta]t", "*", "direction"}]}]}], ";", "\n", "\t\t", 
        RowBox[{
         RowBox[{"newPoint", "[", 
          RowBox[{"[", "3", "]"}], "]"}], "=", 
         RowBox[{"Mod", "[", 
          RowBox[{
           RowBox[{"newPoint", "[", 
            RowBox[{"[", "3", "]"}], "]"}], ",", 
           RowBox[{"periodicity", "/", "sTheta"}], ",", "1"}], "]"}]}], ";", 
        "\n", "\t\t", 
        RowBox[{"AppendTo", "[", 
         RowBox[{"curved", ",", "newPoint"}], "]"}], ";", "\n", "\t\t", 
        "curved", ";", 
        RowBox[{"(*", 
         RowBox[{
         "Used", " ", "as", " ", "a", " ", "global", " ", "variable", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"s", ".", "t", ".", " ", "the"}], " ", "curve", " ", 
            "can", " ", "be", " ", "inspected", " ", "even", " ", "if", " ", 
            "the", " ", "code", " ", "was", " ", "aborted"}], ")"}]}], "*)"}],
         "\n", "\t\t", "\n", "\t\t", 
        RowBox[{"it", "++"}], ";"}]}], "\n", "\t", "]"}], ";", "\n", "\t", 
     "\n", "\t", 
     RowBox[{"curved", "=", 
      RowBox[{"Reverse", "@", "curved"}]}], ";", "\n", "\t", 
     RowBox[{
      RowBox[{"curved", "\[LeftDoubleBracket]", 
       RowBox[{"All", ",", "3"}], "\[RightDoubleBracket]"}], "=", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"curved", "\[LeftDoubleBracket]", 
          RowBox[{"All", ",", "3"}], "\[RightDoubleBracket]"}], "-", "1"}], 
        ")"}], "*", "sTheta"}]}], ";", "\n", "\t", "\n", "\t", 
     RowBox[{"Return", "[", "curved", "]"}], ";"}]}], "\n", "]"}]}]], "Code",
 InitializationCell->False,
 CellChangeTimes->{{3.706939932684207*^9, 3.7069399742367845`*^9}, {
  3.7069409077743*^9, 3.7069409079487963`*^9}, {3.7069464094947853`*^9, 
  3.7069464189028482`*^9}, {3.7069465711543107`*^9, 3.7069465790894403`*^9}, {
  3.706947167474739*^9, 3.7069472062488976`*^9}, {3.7069472948024774`*^9, 
  3.7069474175379972`*^9}, {3.70694772136934*^9, 3.7069477420663614`*^9}}]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["---Retinal Vessel Tracking ", "Title",
 CellChangeTimes->{{3.6364482051751328`*^9, 3.636448206597025*^9}, {
  3.7009988189480953`*^9, 3.700998820196412*^9}, {3.706931390355955*^9, 
  3.7069314037486043`*^9}, {3.7069315934292326`*^9, 3.7069315937811537`*^9}}],

Cell[CellGroupData[{

Cell["0. Detect images/test data", "Section",
 CellChangeTimes->{{3.7009988061470566`*^9, 3.700998811620635*^9}, {
  3.7069316152512407`*^9, 3.7069316165015726`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"directory", "=", 
  RowBox[{"FileNameJoin", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"NotebookDirectory", "[", "]"}], ",", "\"\<TestPatches\>\""}], 
    "}"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"filesIM", "=", 
  RowBox[{"FileNames", "[", 
   RowBox[{"\"\<*.png\>\"", ",", "directory"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.6364482313941517`*^9, 3.6364482593789787`*^9}, 
   3.636779843926099*^9, {3.6962410319581423`*^9, 3.69624103440464*^9}}],

Cell[BoxData["\<\"D:\\\\wrkLocal\\\\Projects\\\\_Exercises\\\\TestPatches\"\>\
"], "Output",
 CellChangeTimes->{3.706948235349579*^9},
 ImageSize->{306, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"D:\\\\wrkLocal\\\\Projects\\\\_Exercises\\\\TestPatches\\\\01_\
h_patch_1.png\"\>", 
   ",", "\<\"D:\\\\wrkLocal\\\\Projects\\\\_Exercises\\\\TestPatches\\\\5_img_\
1.png\"\>"}], "}"}]], "Output",
 CellChangeTimes->{3.7069482353515587`*^9},
 ImageSize->{843, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["1. Import image", "Section",
 CellChangeTimes->{{3.6364523434266033`*^9, 3.6364523465548534`*^9}, {
  3.7069313830916147`*^9, 3.70693138381153*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"imNr", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"imfilename", "=", 
   RowBox[{
   "filesIM", "\[LeftDoubleBracket]", "imNr", "\[RightDoubleBracket]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"imIn", "=", 
   RowBox[{
    RowBox[{"Import", "[", 
     RowBox[{"imfilename", ",", "\"\<Data\>\""}], "]"}], 
    "\[LeftDoubleBracket]", 
    RowBox[{"All", ",", "All", ",", "2"}], "\[RightDoubleBracket]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"imIn", "=", 
   RowBox[{"Rescale", "[", "imIn", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Image", "[", 
  RowBox[{"imIn", ",", 
   RowBox[{"ImageSize", "\[Rule]", "Medium"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.636448276066623*^9, 3.6364483143445387`*^9}, 
   3.6364501576333647`*^9, 3.6364502871208005`*^9, 3.6364503988253336`*^9, 
   3.6364505033797665`*^9, 3.6364506012872944`*^9, 3.636452214660018*^9, {
   3.6368869160420637`*^9, 3.636886918290217*^9}, 3.636887924774019*^9, {
   3.63688819728817*^9, 3.636888249375743*^9}, {3.6368923244458923`*^9, 
   3.636892329590246*^9}, {3.6368931137053747`*^9, 3.6368931168415775`*^9}, {
   3.6380722253032913`*^9, 3.638072232790292*^9}, 3.6380733213735733`*^9, 
   3.638073446781209*^9, {3.6381081661833544`*^9, 3.638108167166453*^9}, 
   3.638109800768546*^9, 3.638110582032321*^9, 3.6381108243314238`*^9, 
   3.638152421694768*^9, 3.6381526914612246`*^9, 3.638154070703513*^9, 
   3.638155764664729*^9, 3.6381567133663497`*^9, 3.63815851194034*^9, {
   3.686569404328326*^9, 3.6865694299534855`*^9}, {3.6868912661235266`*^9, 
   3.6868912694623995`*^9}, {3.686891865756962*^9, 3.6868918872841887`*^9}, {
   3.6868935197529736`*^9, 3.686893521304096*^9}, {3.6868943377772474`*^9, 
   3.686894339386543*^9}, {3.686894576697294*^9, 3.686894578216333*^9}, {
   3.6868982408857365`*^9, 3.686898243077529*^9}, {3.686898453213067*^9, 
   3.6868984545827093`*^9}, {3.686898741517413*^9, 3.6868987428880243`*^9}, {
   3.686898916450378*^9, 3.686898917951374*^9}, {3.6871545472202797`*^9, 
   3.687154548871419*^9}, {3.6875953115196624`*^9, 3.6875953157990704`*^9}, {
   3.68759582339544*^9, 3.6875958249826913`*^9}, {3.6876007165332785`*^9, 
   3.6876007180011845`*^9}, {3.6876014474628167`*^9, 
   3.6876014488114047`*^9}, {3.6876015017261767`*^9, 3.687601503164003*^9}, {
   3.687603960558995*^9, 3.6876039622906017`*^9}, {3.6876706832546363`*^9, 
   3.6876706914167156`*^9}, {3.687682029664799*^9, 3.687682036777729*^9}, {
   3.6962410289802585`*^9, 3.696241038291972*^9}, 3.699677440536069*^9, 
   3.6996776348233595`*^9}],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJxk3enXbWld3nvPOW/Oy/MijRlKJ1BYguLRgKDYIRIUiFDS2dAjikYEqtm1
965dRaGIioAiooIiKth3UaJGUQSBkkbFqJiYZiT5S873rM+Y15iWc4xnjfWs
Ndds7nn/rvv69Q95yffc8vL/8zM+4zNu/b97ueXFV776Na958dVv/H/659mv
vPUV3/7Kb3vZ173ytm/79m97zeNe8n/14bP+j8/4jO/o7/9//+EPf/j3fu/3
fvqnf/qNb3zjnXfe+eIXv/hpT3vaV37lVz7h2Hr/xCc+8d/+23/bV3ffffcP
/MAPvOIVr3juc5/bbl/zNV/z5Cc/+eu//uuf8YxnvOxlL7t69eoP/uAPvu1t
b3vnO9/5i7/4i7/zO7/zh3/4hx/72Mf+8rJ96lOf+pvL9ulPf/q//Jf/8g//
8A9/+7d/+8lPfvK+++774Ac/+Cd/8id/9Ed/9B/+w3/oYn7/93+/H/7pn/7p
Rz7ykT//8z9vhw7y55ftz/7szz7wgQ/01R//8R//4WX7j//xP/ZvO7RbH/bz
zvu7v/u7ff7Hl603v3fZ+vB973tfb3r9ncv2W7/1W7/2a7/2y7/8y+95z3t+
/ud//md/9md/7ud+7r3vfe+v/Mqv9Hmv3cUv/MIv9NW73/3uvv2Zn/mZn/iJ
n3jrW9/6Yz/2Yz/1Uz/Vv++9bO3T/r/927/dKX7jN36jPdunoXjDG97wfd/3
fQ3aHXfc8Z3f+Z0vetGLnvWsZ33d133dV3/1Vzduz3nOcxq0b//2b3/5y1/+
3d/93VeuXGn/n/zJn+ykHaor79F0v3/wB3/Qvx2/z3/pl36pq+p6el5dwI/+
6I++9bL1pkv68cv2tsv2Y5fNpXbNXeovXLZupPfvete7utP+7YAdudc+7Jid
vSP8yI/8SJPhh37oh9542Xri3cVrX/vauy/bXXfd1YO+fv16n7z+9a9vtze/
+c3t9qY3vakf7rxtXcbb3/52B/zhH/5h+/zoZetNh/3e7/3ejvD93//9Hf/1
l+11r3vdvffe25sfuGwdvNc+2Q79a//vv2yvP7aGrn/fcNn8+6bL9pa3vMW5
7G+3/dxZ+rcr2Sm+77J50+f9xGV0Cx2qm+2TrrNBeOUrX9kz/cZv/MZ/82/+
TQ80ifimb/qm7/iO7+iZ9nC/4Ru+Ibn45m/+5uSl4Wo+9NvuvdcO6Do7fkPa
DfZvOziFb11hX91zzz0bgfM97grvvWzfe9l6KF2bN9euXeu8Pa/rl60T+bbN
0+zD9ulGmnvJ/t63+WHbtcvW57ddtttvv709+zyBff/739+c7I461Ld927eF
A//6X//rm2+++XM+53Me+tCHPuIRj3jYwx72uZ/7uV/xFV/RsNx6662NQ2P1
VV/1VV/0RV/06Ec/up2/5Eu+JAzpw0ayS2qQmy0JVIKZaH/oQx/66Ec/Gm78
3WULMf7X//pf//t//+//9t/+29///d//9V//9Sc+8Ylkf9CRmCTayUsf9sPg
oh1Chl7794OXrWv+3cvW8ft3qNLn/TBM+Pf//t8HEf0bCk3u3nPZEpNf//Vf
/83f/M1fv2z9mxAlSu+8bIkPQAhP+omv+jDpSxBMG1O6930ON371V3+1s7j4
TpEANmN7sg1pY/7qV7/aXGp2Pe5xj2tsP+/zPq83YcizLluzKwzpuXTkThQ4
dBfdV3fUDXapXUki3+m6woQx2UwY27nJljz26pJ+8LJN5MlOb7ryd7zjHW4t
wAEsXWT/QsW+3WGbvU0t07WneePGjW4h6HvVq14Vvn3Xd31XT7k7aiY0i5pC
zVJT0bQkAmSToLmGPumAE97eNyHN6jsvm7OYt33VBXRqMGVit/WJz/tVZ7/j
spnJfUg0eu19x+9NJ93+147t6rH5VV/5l6D1xpH7t9ceCgnqyN1pV949dsaG
opX06U9/+pd92Zd94Rd+4aMe9aik4ClPecrznve8Hmji8NjHPrZlt0fcItug
deR+28gQ8K6q43ecWy9bJzUCXY8xd8udvWFvh4n2bsQ193kX6eLtb+fe/LvL
1sP6rsvWcQACEOgJ9knftqLBuuS69yHAS1/6UstZr/3bbT7/+c//lsv2rd/6
rb3vNaFuZrZKNoV6vp09CP3ar/3a0OCRj3xkoBF6fPZlCzoaon77kpe8pMEJ
XYOOdvt/L9tjHvOY/g1YOnUX1jRuEnbMRADxSK7/4rL91V/9VXDxD5ftv/7X
/xqSBB2xhVCi3do5GUzME5ZgYdwjxGj9TZTiG63FidX7Llui2g6jHz7vdn7t
snUQpCK5S2q6JItg0hcrSMAxioFGF5w0BaG9JlCBxs9etr7qt8njFsdem/+B
Q2KY3HWbnaiL6fo7XcdMEi2s7dyA9Iwa/xag+NsXfMEXNLYNXbOrVemZz3xm
M62Bbega/6ZW1xOgufH4Ugd3YfhAJ7XEb21947FtJbIqWePa+kk33m/PBCBK
0L+IUzfYDlsNTWxQkPR1VU25JmTzsNmVyLzysjX3EjGzffO5/f28DXpYsomM
Y/YVRJ1s3n7agNJkhFwkFBNnl+TffttXltQbly0Zv/PYet/OLqYd3MVrXvOa
Hsf3fM/39HNoY2HtW8LYkdunPUlWu7VDR4AbIVI79LCSgiQl/O9pJh1JQQ+0
Rxw5Txa++Iu/+Eu/9EtDktaLBLCDBzgNyNZxCOksnc6994lb6D3pNtpQGnp0
Pb41AmB2l93mV9CA+Pe+Z9dXkLbfdvuBSV+1YAUULzm2ZmkI8MIXvjB86DWI
ePazn91NoU/N1ehBYk4YW+ib9k3XplMX1s5Rr8c//vGh6AMf+MDP/MzP/Of/
/J9/1md9VsQjCO04TfIGrfGJhDRc7dYo9VVcpd92Pd17U6Wp2HKcFLf0B1Af
//jHQUdAEXT8j//xP/77f//vQUdqS5/EKKIc8QSMuuU+JhCGhB7Rhr5KiDpI
r6Cjaw5VktOAIuHqPX2kfxEMnOG3LpslO+lITBKW1vRkMCTplt992bxv6/PE
KpnqzTsuGzxJ3Maue/pW9iSiz/tVlwo3KERJfaAU7HTkztWoNtmaHi94wQua
SGHs53/+5zdujVjj3Cd0vVhHQ9f87OyNQEMRDHbA7iXs6jhdeaKNezs7st0F
oxD7fIQcL+oCBiDtDBxw737YmBgZQNeHbhPj7dXyZ1q+6rKZ55Myom1WW5ot
9zSRLgYD77BWf7Sh3UgQpgExms9kpEPh8GMCmElnwROckTTdjzAAjf5tN8Le
1un6EBQ0zgl+v3UxmJVTWLi7wXbrYizZXVhf0Rp60+eJW4KQyhnr/pzLNg6Z
XIQYrQ7928NNyhLPjtCFjUQNN7rxzgXERh66cVSkq3Wp7TCphzCeRa+BgA9R
lz7pmvtVCB8ONOWCgpAh5uBe3BfQCE/6vHvptZ0DihcdGwzp58+7bLGmQCP0
aI3r82hA4pw8JnoJaQLSstVltH8jEPUKKyIb//Jf/st/9s/+2b/4F/+i0Wgo
AofO1ZE7TiQk3EhhiZi1mMbcQpXuqAfRLE36kt8EOdmPM3zyk5/8q8v2N3/z
N/hG6NGbT3/60xGPICV8mM2BGk4FGG8PN95/2fqEXhAuJWK9p7l404e/etmG
G1SSsX16B2tMW9fZayhBPNswkzbrcp9b66nVltHGKmnth11trMBlAK7+nUmh
w/bDBqRH1ixqVQpmQUfAG3Q005761KdG4XpwDV1TPSkO6H7zsnXlDUij0ZVg
/lNDkseO3DUgEgCB2gLZgMCUYlgxq0Vb7/ErrKPb7N/2mT2BfpGwbKnqCi3B
dGSLZnJhDuP/FBCaSKfuwphNujXkBOuYqkLkSVBH6/jTyqdo9DpWQPSQEAJo
Caa2gJR+gmlQMSBD+8CNVuR27tvXHZvjoytdA6WM2CaD7UwDaoe+Teh6lE96
0pNSUh7ykIc8+MEPjnIgGD3H3pCIdkjoWvTxFprU0BISAgekovdd4UwKuwwi
/5pjQxj6sG/BbK990j590umSzSSU4EOD3r/i2ByTbtLOfUWck2t7vuyyvfiy
veCydZDkultun9DmE5/4RFLcWk9hScQSq2ZL1xZRiYZ1+0FHIxN6xDpuuumm
UDTk6Zq72s7eoZ74xCd+0WULZxKEhq7TdWtNuWZ1B2zat27GEz7ykY8EHX/5
l38ZwfjbyxZ0/M//+T+xjkhI0BE+JPgzV7JMhgMBReAWzaCPtMUxQAelhprA
4Pnbl61fJXShR0cLjgYdaP/UliTFes3AeDYttlnfGR7BCIWdzPbhcKPTDab6
d1bTzhgOtH/zoXGLuALbVqgGrfdPfvKTG+qAuq96fM2lBC0RjmZ0HLcQhM4E
wYIBQ1gazzZJEopmBB0gLhBgPfMvDQIAdrR+FbghSDSsgQ/bRVN9stncsCZa
3C3BUzdmoBj/Z/Rga+107X9W1e1DxkkuKm7xna6BGFCF8I2p+VuFp+/4Of0F
t8F8nJroUYWYHNuYZCEeQwGq3/NiYdjVAp/ApCU4zA8cbr755gSk19STHmIf
9kxbFFodeqzhRsdhV+xqAeaZ23TByTuSkOy7ZZCCg/VVMt4Zu6TvPLY+xEPc
KeLHatHnVI9ekQey/22XrW+ZNUKGvkrMm3VJ8WAhiKDd2DrIlJfedy+dIjlt
6f9P/+k/0RSSyuSrSd6caaw6DibWmIQekbGHP/zh4Wq8IlLds2jqdsEdtpmf
XtNANVxp7v3b9XRHzZOEq9mYNAUd0YlYRyf91Kc+xc8SdPzn//yfQ4xwozf9
G5SFMMwUrbmBBm0iGcQ9yCbniA1WAI0W/fP7RLhfJX1eA5CkY74Dkthd8Ep4
0/bmY0sG4QbNJcBhKYU2HcEnHZZ0d8HOElzwWVCXuguW555sD6hRTVv5gssW
MjfNmnLNsfhbzxdbS+p7EI7QBkV5Urpm9kYIRvsYL3JTLpu0epPw0jtAASsN
n0g/dy/dWmDVEfyEj4OVw8wcMky6R7xHRcj7ZBwmzEvSSbEU8EJO0QPax+SF
7WKKCavI9WNzImynbYI5CwDk6Q3sorh1EAs9MkMVmnLnW4elCMBJdpXxn46Z
+CQCKZhN+0c+8pHxjZbU5OJpl63nG54kOHHLpDIxnEJhQAxmnxgH5AHrOA+L
cRhc/LvThghROtw4CzwdpDNCCRoK3HjpZQOGAQLQCChoIr1J3vukfeIhyExv
2EmoLb1hXw0rQox0hAQ2Kf7whz/cIh50tIY2jF1DSlx0IkAIOgKNhz70oQ98
4AMbqHhF3+L8PdNkIaY9o1+D1r9dQCPARpoQJc7hUpQjzSjWET6kJX3ssnXq
eWkpLKAjSUxkiCrjf4SBbPKJgIjeJJu0En7YwIS1geLQh+3/i5eNyxV00EeS
OB7MrdGJDCcmDGEHCLsYXjo7w0U/7zhdXoft+AFd0t0+vbZDJ+pzVKc30Lgx
7xE84xnPaGqFGI1VIxZPe8ITnvDlX/7l4W36YwtBE6Ap2mV0lk4BNtt+/rI1
5qEQysGTMjco6OjND1+2aS7+5eKZvCRNs6x2wA4LojsjrWdEpa2nfF4KrZV8
HMR5xn/rvsk89ODTxH/4H2HCfCV2m1BPftldZ4U4mz1ZTeEGIy0E86FXl4Fy
cKFa8RlhemV+gRu0FZc9awOjwdQHGkTCmKz1vFolW0lbUh/xiEeE/wzdLQE9
zaQg2YmWJAgQFQZSo1592egXhLQ3vfahW4OEsykhCbDFRoFqowTBDXhC+6B0
YB2xBX7/8RYwwgZCQ9k+WBYUotR0v37b511eBCCsoK3EAXqTwpK4JYNJSmPY
r0KhVsP0uEDjQQ96UApL3KPhCmy72tb05nMPOugIXfu8PVPew+HU9q6fjbT5
nDQl1+kaYULKyIcvWzDC1MlX+/eXLf7Tv3/8x3/MvZIk/sxlmxmTs6PzJo9b
i9sS0oQ3oGADYSwFIMwO82kGHR3tbNA4Ry+0WPvE+t7Wm34YAnR85ouO0M+Z
T7uYcGPoNEcMPeuXL1vvO35LXiNPB2w9SlVJYYmkNceadanDjSoLfDOqoQsQ
upJOwdrjZnvPTotFYNqJ5CgH6w2/yRzHnKHzfWwR5zAVccHT1PjQ4zrCLMDY
NSZPsryhs/QvW+L0dJKCmcMojlqKUm/mqRlFOccb4CRoA47kNpkpiN4W5fET
dzTZxFgYSPuhIzBvUkz61+AMN2a55bJpI0FQkaT3pgfUhE8lb8KLVWgJCCvC
jaZ9i0Lve6AtrxaCMTFDBxXBQiPWmk7psPGl2r8zIhVEeGSDgQKv6JXFhumm
fwOBoIBRdEZOSgoTK3Xm5ZeNKcNx6CYdxC3Df8SDoxbfSKDiAGFFiBHxCD1i
Agl1nzfhW3F6BF1MM/lLv/RLG5/0uM/6rM8KQEKGRqzPm2xBR6tVx2+IGq7I
SWPYDv2kYWxMmiHNzPZM+pK7xDlM+LPL1qk7XdDR++gHytFrlOO+++4TpyE2
icP0LMgApFd4AjoS204ROs12SluZ5kJVIdf9UDyDpTZh6d9E0sLde+5azh2g
FGhQi1g+AVoHbIcO3rcBXe+7ktH+3vP59klD2rRvTL7xG78xjoGeNVaB7eMe
97gnXbaoWnOyh9hTa26zviIebnA2EwFmC41gcul2upH2T+qnqszKISLoHMPQ
QoyZdDRn4ZjuIB0KUeF/xCtAB+ECQbNLEASuQBOvz9kW/HyeFBtPzbQM6sC4
x+wYDJtEm1tkbgWS1RF8ODDETOZoQGP6CsViJhWjMijDhfqXEsQSwt7L9jhR
IunJ49Of/vQAP7LxgAc8oCWAgywSEmKkh/ZAWx0Sipb13eP8yKADU0IkDNqc
OH7S2cEF3Fi4Ra8MFGFCr71HJFzbCy+bzzs70wRX7Py/O+AgCGj08z6f+0bo
DkaEh3TxgqyS4tb9oCPQSGDTIxLkBDZxaMp1lo4c+2oomuSBRujaKtlUj4d0
IoaOHoTdggtKTetpUpCm0xlpkc3MJnxSnDiHV9hOZ0xV6QJ63wUEGhGPQKzP
+1C0RqJKO2jlXQzknKdJUJ+DAiI8AwgnCwOpuI4pPnbuIKyj1JYO1cG5JjtF
8i4OZDEh3Dc2hlYRZR223UAHywyUw2o6GntsAJuY98jSjqeqhBuBbZNNdG5z
b6GGzMv9aqwj6EC0EI9GAxnoKTAggOg5bblcF+yBn1j6z5ZS1tHFeXJVc68E
KfsJD8X9Yke999WI/dypM076FbSZz4Uj8tZjmzl0pGgxXS4YsMwvPCXibFcB
CGdf7Rb33s81w7uBDjG/zArEpIOxzOjKi7FlPUlsWYxXN9Uf/OAHJxEtml93
2XqO6Z7JS494Nquz19gtuKpuARp02Lm5z97V7z625sPMlb2fBQNo8L32ClJ8
5duwhR+WIrlQEGSGQ8cGlNqzr3aphs7O7MktjqS41Xmh3Qlv0JHukBQ01RvP
ft7ZWwfDhOAiaI17oBzpJikyndrk6Tqb9u0W927P3gS/iUCn62mydTTbRZN2
XpbSBZPTmNJT/u7v/i4A6TL4XuMPyWMrfsJONWBaoSmY5+Ihxz2S6OS3u2NK
5ZZddOhPH9u0FW4U0CFwdAZPDppGA3r07xy+4spmdRFPAlKSa+DWBtbEgSSh
jWfPMXBo1jWMsY5GsrH6isvWZGvu3XLLLS0TzRauTGZYt0lhwYJg0QLSxIsm
6bPYWElR8dlIRaFgArOdiihj7XEu6NFx5rdl67BY3w83FmF1DhXjPWTrW3QW
qRksEM+xYkSCLWXmkTkunXThChZo4jZb6AjVbB32HxcCUJgMtYUWQ6cTvuIu
JuCsE+wMPZSEK2UzPSXAv+mmm1pJe4hhvhCpcKMHGm60FqS2eI5zEpFH73cL
FnRSzDgzBxa55tqgkkAJ9g0wMl+Jz1GRNnbR6SAUDcefmYguRhtyQO7dxeQM
peEJ3LAQE4Q4QHKaICfFrf6COpo8Tct5ZiNmTXWxLo1Yy2WDE6loh4a963nu
c5/beCYR8Y3QQ/xt19/ZBQxQWCRHJGixgsWKs5QGHX992SSwdCVC0FkPsA52
CaDBf4rGM0smWVQDOR2cKbJOcIy5VHoFNaIXOvKYzPQL6snvX7auduwFmMAl
H4pvBx19AqYoRPP/pj40Dj0IGCtwLoxtBsZsH3/Zgo5Qmim+mdOsTrRpE11z
l8fz2331RijsOeiC4zgEYNPANFhHOYmWIuErOv5bLhvXTM8IqWPG6UOqyjmc
e55TJg62VsdkhTAnzdJrp43f8NqRQLEAaXABfP6pHjS5OweXzuzA92GSz+I6
L+1WduR/h4JjQG8Ki3wWbtk5aAZunatF+cUvfvHznve8Fs0eXFLQMtrjQxS/
/uu/Hm5wsqfLtDNAmH0DiZrblzKyiBE7T21pEwHehlFwwlIc7O8T/4rm6qRc
sYwbTSQ/WeRbbxYGw04LxGYUha7nIHZcqF8J6mZta/1KBP7wD/+Q+vChD32o
N7SVJlKPsnM1kwPVoCPK8aDLFno07Vsl+6ozdpZ2E4LbAtpgYmup891O3/Y4
mtWCExLMZA3b6XRi0aWi8NL2JtyIBTFyiovompPB4KLJLHTBm6Y3l8cvXTY3
ZUv2+xXRZmfAARAVBIPmghXADfBCQkFcSlM0LGRAM2hDDRETyqCjjRkWw5kZ
lu7TeRNeYWApv02tlqqgOAQWsc+90jg3A7/lW76lceupYdGUDr4Pj4zPl3O2
2S5KU/xGIBBQLG9FxFcbe2nHIePT7u0MQLiTumY2nN4LFJ8gMy1iHZQUZkaH
srPIrrOF4eyBBTiLPaBQd6jxGc5fqoefiMjiIgEFUILNYT6Lsxd4Hs/5LwAU
YjNzynCDN63B6d/xnJkaLP2t41FoTjHWvLaeWp9867d+awSjZ9cSQPd82tOe
1oJL4thhZqdF3njnkQ1mz7ONiEsUVgCK4QMZ71cgcYaRqRtsnsiG4xgloSm8
MBsrT6cxYZh1y9MTZwMXD8zch6s3PQRmE2T5pOKc+0oIemcPE4LTZnjQwcMS
dDTtOaG6KYF/DWBkuw8bQMFgyUj30hXy+omY6gKoEp00sEoxCSXmbZETCsFQ
Dm7WxDNJXBiDzFAWgISUq5QPVHoa1sE00enIcjsj837eIPCisq9yR46BhEKN
A4tuFyPE3cUI9Orgztu9LOLdh1NYHArr6MobitaCRonhyLLVGxF0bRGPlrC4
XMPesxOIxW2a7HeQLnIpNl1qx2TcI7moRbcGQMSJeXOO5eCqOLsV2Ff7Ictw
F9zY9tuOTGDnkG2b0WPZo4v9mA0WSbjfFJ2XdnwYhWC9ZDWdYgJA6Bo8s/af
XHPldBy0Z+aUhZ1M8Ekov+1UJztzyxqHrgFeMWsQpd7wpLQONtuFKCz0N9Wy
r3pe8lbavvzLvzzwj4EnF6CAMnUOm59ON8PjUmPamDLmqGWbNQ6zCU/Mx6ba
c9lqXC0AB+aw0jB+LgDPIPitqPiFuMg4QI0MfuKAS1tbz6mdiUZ6ioBMeWFy
7bsYkfmNWPP8gQ984L/6V//qAQ94QO8bpVAFKHV5YqobvTibuKY4SbdGARfr
aEGHV3/wB3/Qah5QyNJNQv/0T/9UAqzcect9X8mAc1UiwAlI75MgiGHp5/sQ
rS32jKS7a+mlcCMZ6RMZagJCREosFY6QypeRSUcf6RRsob9y2dhOmUR8OM/s
vMmsNILrAlg+2QZw0PHFly08CTqe/OQnN+DYWgL+pmMT5tpx0CTOU3EdgxcR
rSLkeUZAiqAvlsa5Ry21dvOMxIMxIvWvVFAKPhsjZ+giu8Y35HfPZzqbJI1m
FJ2yw8SxWA7sBW5MD/KGwXDu2kVTjMyb8MMB/hqyOb9AI2mxnnlwigPIWkrv
tSOLZCYaTslW8GZy7IKe0vN69KMfHUVMJXnmM58Z31g+bE+23V74whd2xuWV
wKs5kYGnhZ6TFEDZRkWoGENseDiNbB7tAYg7FbgFOuarBSMe4jibwbyfVWoc
w3gOYeSVcxpSZnvfVOe4tL7zOfZ5k6e5cfslGTC8jUs0XM3zB1y2iIdQ0kaJ
0bXd8PDQuPmf2tJ4hr19e/b9IR5BVicVji6iow2ABF8JaXwDqsxSugyyJvbb
jq33QibYH5Td4FsJlwg7ie7Gwc6PHluXEWyyUQgd6a7hEmNsIh8sqO/RoRof
TAPUcLgILRNjJliL1XTxZssjiy81Dk2MALY51rJ1880333TZWDzoLKFx61oD
jsspLoE5QIYZS5cRz4JBQ+m+2ILEsK0YxcpWeGN/bATyLJCeKtfY9mESTRee
Dn77kcWJujj4kusnICgHk8LCrnhzaDTW3xvHNgPsiA2/KrEy2+eRoZhj4xyF
8/4QdiJ2dim68gnOnDjSeFlHhabjM0w08tMj/+kp+EZzu2kv6kDYXgSy9+FG
Dy66iGbfeuTCL8gWrM3IA9lcz9lVJHXXxikzX/OMRXM/zVUE32YJWWTp0ucx
rm1YyjLj2Jl9OHP0AL+x/bnLxpu5ZYtpcUsn0eBYbPL0oLv4IDfFrdkuCv3h
D3+4kLmoRZ93wSZDIxYIN7xwIwyRIdilIrRYhwgKJIGWJAE2oKCeEHnQwWML
OuStu7YFcC6wkwlCutl+3uvS7QEmv0Nb4AC+JMKEHr2XFD8lyMg4bK/Cyw3U
rx4b0wqHb9djVFGODjKolCrLf90iJSObU48Xu0ELNxo0Dr44cI++hyjK61xP
BmB2CmH5y7inrUiWh66MG6T7h46N8YRe/4ZjcwpkDHIKIk2amqhs70S1mbb0
VQYTARum2VQGFonrl8TSc/GcmVIZN4SE2WeVPegsV44cOsI+jj0TB+FiAJlg
kgir5/y2xBP0zXDqh53agMimcVLAYh1/6UtfGm4oJSF4rwfXw0oliW+EFclF
/0rzjIEnBS4YSZh5Z9rB7o5czzEkVW1b/+Js0yCWWjjvM/4mfW/RYtt8OAuP
QZiyM7CaQrRoXrjhtcfBlUkcRBMJxRQFATpEdDMLNCebjV1bx+e/Tq0LK1of
m+rhRgwkFaax6lzNt84S/Wit7MMvu2wxt6c+9akvetGLOogqEEpDcBNgO6GB
wK0/vWzqepHl8ORDl036v/CMVb04Qx9/DX2hfeSk98pUkhaW4LdDN578ckE2
FP3K2ZX16Br6l88CAgAEpgwGWCHu0JVplF3Ft2gGLueNpDkh7p23KXrnpdJa
iBpKNJLygFg5Wraagc1DtR1e8pKXNK8ETrNnUj26+A64s6gZIoCNicawIDkz
d0iCO+fPfv+xzViBdWCGGF3vm59mNVcg0bMUynyR2DLPrGgr+giJhlrKW51x
4+wYxTdWBmQRpOcpTfQAAjFh/ZsnVwA8wZ+kzI1LMAcLdx3bsv/cxV1HhR+M
pVsOw4P6kKEJH258wRd8Qdj+nMsWwvc+oZBHH8EON5hlGB7Rg/OtzYDDscJ8
uus86yzufbH3c4jMwnnnUbmL+uYBnUFj0WtjbiMbCCG+MX/KnUdtBOiNyFFM
THiOFQlZEiLMf54IMQkiKFqDmledTqqF0bv5sj3sYQ9TwCS1XcGlLiChYGT+
qsv2pCc9KcBpMJsYWDTj5KCjM45jKAVGkCkvSvQowQEK2GGSXAIuNX6pcHBP
hixPxwoGcnlI90gckqnOLnxL+YvOLmGHorEjs7UuxH0pbPPaCOpw9j5nFJ0/
xS2T69a1nkuUownWEMV4pRA+9KEPnX9WFHrf3nLLLS94wQvaeeEHDBGy6Vl4
oMf8Qfw4fcJ8ylghp4+OJtiJmCzjHnPAOqa2BDJ+JcyPEG1bEbBpGewnCzLn
XaVKd65ZaOd4XRTrFmJSfI6jQBLmnhCBiZmfl9fN+XNw6SwMPLadaHU2aNbz
E410KVQIf1gS2j+y3cOKS7Roivhtzvd0ItIkgj+FbSpBcD3nIHOCP3qwCCvL
/ZUjqw5QeINyzN08wESWprstOARtEAw26+jIxgLhpmkuO2CxHM4+S/UyHLvs
5lhSYGVUNy9BWKVNGjpzBxVeoEIzkNcPdETYAtiU8YC3hTL0aKqHD2l2XV7T
r6sKOlA42jrnVFfVNTC+MT9aGTlZVpOHa7iNfWOulv7FQ1ZKVBi5anjSV89h
YOecOADCesNCggAwj7SDSFrpLeBFgPrcK+cN0gJhp8DQYAjTqHh42oroEcEn
iXxP5I5LDdJgIY7B2txG9Qs9mpzRj0Y4yMU6VHrhzmACVbQnYeyYC4WVYnM2
ybqAtx+bkcdA4IMwbAyBNjEeIjJE5R/KDo/JOUZiRcDY4W0EZJU0MOpV1BHa
vVAoi+wsEucFkcgzFTJTyD2fl3ZWxIHYHacyenccpa7ADn/Ewsas8hzZbpaJ
mPfZCg61Gv94BdyYP6VHI5y7NbF1k3appoqgr6tHutzsvaMxU1tmBdq53Ms5
dH/wcu2oUzSv9FDRcC1UQ2wYT4ph2bYw3X646hzjJ84izt+sQAZEaNN/OVMw
igmaRZM6ry6fZbrdmpMdoYtUnTWgaHqjHL02z1NJGjSusek1KSwqgz372c8W
t9/1NBUtlPJe2RCEhNEvVq84rLjvvvtEd6gpKhCdXhO29L7fdoQW2eVqnQn8
0s2mgkl+QePFRcANqSjS4tQQc2T2n2W4GyIFN4SKIR6DWWYQ5G27EWTco9tP
SHtAL3/5yxuZJmGI8eAHP/ghD3lIgyn3Tfpb1K4dUq6/4zu+Y0tkw0tVgR6c
LI5PD/UK8SgsaizjPPJnV+mL1jDngn/5R6z+SsiyCPUTte/uFx0kSnm1Lxx2
EQum341TMS6lge7HDXCMc/DkcruWVC6LnBUFDthWnActOceMDStI1t7Ts6yn
rooGx1Bz/aho2mt8g54SOEjkbItayD81yRdk3vrYxVw7KqbOYcQ6AU7vOooX
zexwNjVs6Uc2ZrtgVrrrqH62eLbZSZAWWfPKXxvAc9oyexFutmhY3Aa07oJF
F4s0VqtB8AM2y0wqhiHREGfFNwE0EiJFwpv/sdwO2OlCAOXRhJI+6EEParb3
b5gcT+va7rpUSWpgFfRO73vqU5/aqPYIumU1fhejlYRyB88PAjoU7ensH/nI
R8INQWIf+tCHxFQoQ9oWgPTDhDShoAfRL0Sny6jF27ld6GiL7Vz+uxtnU3UN
v/u7v6ugx9QT2SJMo6K8JNELWGUvRTlmJvIJ0wetakGkQFgQaUyjYQw6GklF
YJjoY2sN3fOe9zyuPcu3mlpcIQwXnCB4lxtfXURONFZuBk+1R1gCibZ5ODUc
R51nofc8tudQjUm9fayw3BNozFBo8eqrIi7Bf+r59IvZ6Gb/N7EBAqlnzVjs
JYThTExk6CO3HaXAzgTmypHedfbRMDvzOg0wV50M+DTyaYtxiZSREKPlstcm
tpDOaHYzPDzpScWxw432v/NUVNlFninZwqtm5p3WYATc6Uy4i0hZuP4qhzC9
glMD2DiIHhdZej8+duUoF2DcnHQcDHTQqoA87VX6J/vYKs6xlKL3yxynNVh/
RVy3jCZlTZ5uvytRlTSaHXQ89LIp8twkj9dh1O0WzWiEIydxvF4b2JCwR9Nl
dDTF8agPimkMOhT4cg0BhZjSj3/84zopiPRQOx0PUb4soYYeTK9aGPCousFl
rq3mOQuPTZA5ruUaQAdbEOiY7gMNRLmzJDjFTLXbTTxYR2B8kAbStTVje5rq
ID360Y9OVVGALtwIhONp2G/fBrntxvbORkqKF9ohSY0dY1UQrQui2hZzu6dP
upemKtLgHOU1j0CvDKec6Z2xK0c2iLAwSDq7R38OM1v1fgxkpQgXmLGEiNkr
tvzdfmSakCwe1duO+oTX/knW20JDp0yN2O/DK0e9YrLG4+OCl707b3InbcZ+
0zd9U8QvJH/kIx/ZPH/84x/fEkk8Fa4X8RsPZ4+64yhuPHg0MoszmTeEtfOM
mTN03HaUNFlk/vJb7/rHZRvPsWEOtfwXXAX3WOAcqBkyz1Z85aintMJoDUvz
ZG1BVp2Sy370I0FYAKRYiJXxbGuFFQ8m0EsF+JC2Od9sb63stQHUIsGKo/0K
6EgKNFCIdTdinVTkubNIH2PABFYrphEmBBeyd6XSLOQj9OiroKMPg5d+lbS6
QSV6KC9S5rV6Wcar4FL2CkqEERCYIUWlC6B9CAyDP3LoRHnNh3I+qfgQuTDU
HAA1QyXDKV+VkQwoeKkaxkA4vS8l5cnH1ixtGCMnTSqCiVevZBlLr5vlVdH7
YMWZXdvqFC2LnMniTJhZxugRXhEJJAdGqdzeb81bSrE12sI6AcR4LbKzdQCr
xXXzJrgA4LBwgiunZh9T6ucQ4bMYvCzOhARdOTLU/HBHO8PIIlrnIZ2Lhx4k
gz6+pwlCZAOqN42lrLYy9oB6WJLBg3cWGCMwoLh6FEFdPAZDEEIyAwXjxiyW
C5Bb1IrdMM8rpwTes69kR1v013cfZdI3ILOpGvkpbvfzwLKncditAO8ikwVe
WkxlYSSqAjVJ9PJDk7ImZEe77VIEqXWwMWyS33TTTU34XiPYAW/6YOdVY5NS
o5ZaQN23PYKXvexl9KYECqvp+Iva6g2DAyTpMlJV4APKMUNHukwY0idyW6gw
HTAhXY0v4RPMKbP6CgZDA1COZcXyniiuvmLIs1QYqHlP+Hb7oQK/i4hQRsOp
2SopKSuxvtLHzZz095at5l7QEWjEOm6++eaG62u/9mu//rI1M2N3zVUxRTyb
cIMgrwDRqhavliDldG2ApH8uxRVVNgPnjNvnY9QSSM+F0Zyxg5iu14+ywH6y
kCpMQ1zEjITn0NBl2Y+xnxV8U31hSFePKhYkBbKNY0yLP3sNvL/9KHi4aAoW
QjAy6R5uUMT6bRM1stE87xE85jGPSUPpubRWKror1pFdtBnOiJeQ9tvB5gI2
rh41nBdPNRsy9NgjOGfWoFKsNAvSmGFnNhCUZi4nOuYspR0Bztx5KlmAZxqN
K0fqLhRdFg/dyrwdh3/LsZ2jKcgUx2gyy0cpZEKYU4LThLl66RJCW2HoSEPn
XlEfvgGH4V1ziC0rn4excVamozWrZTfhXfMUiokAzt88tq6HQSN2waYhbVal
DpFjIsQElyonwuQr9FFinfp+tLBez7UEWUrlu3EqLQF2xYfZOuzJpiHopSNI
n6H780qEIVjHfKDsD6MlCgv3PkHuSTUaEu2bmUYyDDFWjXAAosJPc1iFn57m
wi0cigahfiC5Hm6sKRua8dqjT8qQYT5K85B8bUFHsOGGtUY95069ymD3497s
nBMNckHrx72nC0CYJeMv4oKJb2r+DBpT+UHc9Kn99tVHewXREbjH2a1wPxsI
oZs4330UWB5uIBsp2ghhi2MAws8l5ED8Rkp6u7FvYGg7ptd5kYxtI8CPsxRC
dGtBJmfQ8ApIaWSGhcPojIru5epRd9Exhw+Dx5VPGRFaLhLYWWhrj281/00t
C9DKdK+e9ggG3VxK1yr9Cp3qfjtyz0W91oZOCG6jGpezVnKvoHyNv9gPjE7v
lW6/qZgMdnAkR2+U9x2bsMwEU3xF+BAyBBpBR+DQJzLX6DiL8hIj2i2wB/KB
dne8Hgyw/dCR6SkMngBhyfgspauXLu0F8UAhlkzXmDSGw41liyzObTWExWWt
MgDKIdFe281Q1/xsMJuNxkrjlYa0V9krDf7rj8aL4qlsIqxGKUEKxWSrP9GA
BpP3u45qe1eOCjPm7Swe/A49d0XGJNBN3+E3cYobRwMyXHelw6wjy5aCA5xE
Z2MFtWVFKtg0lho29+WVUw1zetDtRzrbDKqvOgrX3Hps/9T6AXl2y9dODRC7
AB0BJMPGq3suD3vYw5S26/NYYk8kHTzAD1j6sCUSbswZPcoBrscK5lWHGwoH
Tb9g6lwYmJ/MaTK30dmRDVqvHDVJ7jzaww0whxI3jvKt9/yTapCzqIzpdZHi
Fkwnq560dD4IFfDOizLjhtXWJ8CkNTdJ7H67hqhaCKAEh2r/AuoE4qbLmC18
B8lFekrQ0VDrQtu1KYHeYUMM0V/8sII8V6jcNczPMtsp+4M9Z5CBDIvBEJHO
LoFNUUB4WhkfYMhsiRysYmiZO2TTQ5sVTxYV1p5Cys/ljkVIbukHIFEODiz0
hgek3WgrjWTjo/h5zC0W12yMvD31soUe0Q+so6nVT4RwrPMjRWlxuVQYxTpk
OE4ruXI0HFmtD2ZSNgq2teWyLd1p2oppI46LE3NmtAVCMwzeuCT2juRMnR9V
Xvj09aOCx+g6CnSuYjeqMAH3eteRivXao22K0A7LtxuZ7n/HkZphEFCds1Qu
xjIE0MKsRxCe91Ca2xHCeKCWjhGMnkiLpuan6SyRkNDGcskgfMYNLOu2o/Hi
7adWUIqbjWOwGuE8M5bOiTwf8UjFlSPr9uqpgebIya1H5qyxuufoIwPS7zna
21051e1x3muX4vB4u4pwtBUVLbTxmudOeS5iyDC4Lq4sHsl4gtOEvPfSmCwu
EfDKCuSoevRl69+GN43PxBMkGcI84QlPCLGXPMgz23nBggBR4RlcwGJIOC9k
tfDCsFsuVQQ7Qj8WRCFOQ10vXCLZl8OyEC8xb8ykE+eh6BJSRHQsqjzZFwyz
UCtWCyzCcsyqcC6PA8E4fxlVOEYTwB5WOkhDtHJJkTcp2yFwU5ShY7aOxhPh
X0GeRU1woi3LFW6cST4/gkTyFfBRC8g8n1HxbJq7dpTM0htuwWN4jhyl2Tdo
JbI/1qt6NGMa0KCD/J4Nd2c3waRjMZNDv7uOcHfYdeNotnLbUYVjlTomsCtk
scSWGUMwHBiy/uANeGAeAxRg05rYNG7ha3rLxurb3rTnC17wgvWGQ72mFEDR
iSdqYU3f0u/uBtq3HdUA5kudo9ZzvHrkDjuR8dzqgEQt4eW2I7nYtU2FvOOI
shs5mVXZQxRVKLzhHO/N4yBkiMKSKC1ge0u5zHdui6Sp3Zps1y7dhUR5KVMc
65D7lp7eeDa2gQN1qYuP3TXzz57ZYKeL7FAt+gMoFk7VhvukK2HAPCfUIA/U
h187bQBkxcYXNYEb0FbWe0Xy7xLTiL9hUaNDaMcy2nhvvcpI5er96aNrvBgJ
nlBGJC4P4qlSGS+tIjksTgl4M+fVlzRPIQGx4iZqg5m20r+BRkyjoWt+Grpb
brmlnWcGP7N9q/m6HrDWsvWNhJtyybvYDAZVlQYXMzkld7r/IjEwDYXT5cot
wnAmi5nlERt9B6bmj8aQqekLI9XE3273s20OecCOICX3u7OMwM9iM4PAUkRv
P0JMWXjYGG89quLElsMNFTZ0QFgl85a8oLuH0oNQeSlsafVsf02Tz3bR1x5V
ke8+1VRcTMUMs689ypzOOsq8s/Q9yI+DudRrl0LQ1MyzAfa2o2Q0kFwDuNuP
YgjLPZlDCm4gG4Os2y5F41V9EUW5puRrw2Hp5JFc/fA1JkvWkt8lmsUE+lxE
R9fZjcTo1HbW9E00gty3qEiXrdClpm+qFjT/098Tk+Z/95LQ8cyGSxLqlShX
5Bwr4NEQxwUERLeu+taixNkozintwum5QgYymIOw8HVeYMNEvdax2rYUNgrO
KoZR9DaMbK2QhAnCawCyWqYst/0EsOgT1CNuzYpdNBVjHfENlV1l+qTiUaVD
j3U/v+NUPfL6UdLz1ZeeLEI9Z/04hzatVYE6pdxqrJ3tyVIBBGamIJ4Mvwx6
Z7vKsuPP9MA6aK4uU36+V/z5zlOFn6kq07t9OKY93PCTO4+WLrjTdKJzIPc2
0MH8SxjPiv9iGIikyhsqevUslK4KOrDoJq0igUuGndWafWNBLHPQzHty5dJ6
acbbGYL4ueS7jXfdfZRDH5AOA+84Ug9E7hmxgZJTqAa24hvTgG4ctUcWzYvn
DDQgp1lEoFa005o4LVgMWLOa7ZQyvsqW8r+kkAicSJvoww6lyewrXvGKxq3R
Czqa6jLEZWw17fuq+2I57HpiHTENDqzEofnf0+wWupgOyAoqhIOWhBiwJMz9
IV+V8WFa1Vw/iAdthad1vIKndRUzMIfBESSRhPLuS/f53zi2c/arQ21P0WVL
0YU5y9znMGVW4rLBWM49KNunOd+j7yk///nPb3z0xWuBkwSUctdKJyRMq9n2
icuhoJtp85JQY6WZcO6co0xXLuwNRy97l7ccFtVKAZHocUCBnyzyfHku91xa
m1GKuwzuyPn7WCTAyF1Hq+WZHaa2XD2qf18/CmR5Pdszbz+KiZ0NpEK7KWjM
pM5LVRnxvnLESXJS3H4U0pk3YQtu16/yhikdbvQgtD9o2DVbb+qK7O1xqEjs
WRixc6rOwkJEea0sBmfH3Uet9e2w2/Tb8bcbR9vc209pQQvCWUGPAeY0r3EJ
oCRQlotNkuONo6jabUc7BnU8OvJoNmshW8fcgvyVVJi3HhvKLb9jZoTEU3mu
P/qjPwo62qGzd9JORA3R8U0cqbo0KvzIa+uaA5mQvCfSU2AjbZHtghvtTtrl
8eNo4savsaBNm1iUFUufKZUPd1e7iiJr4YpysIhyo5xb06IxwxmYQC3icFlL
Bd8u4lSDBorecsp8K2ZmdS1WolDmCKCew7StyaDwvljEBlMaptZ4cebwtkET
R6qRMUJL+eXjWzkL0LGiSa5kxYvAyPpWyzpU1Xy9oUc2VkTofiFnst46Y1d+
+yl8gh7dD68dJUMXWXTjKGI5R8bVU+Wuc5Dn1tbbT9FNgGLunqtHkYo1WprF
YAx8IVLLFFusyDBtwVSvvpT6bMampLDIfeEXfmFTOvRo5GMa6SMthc3qnkhI
HoCkNvbIhMFPK7nn6FbpCmdztpqvxQnQe+2pCfXMUFS5G0c1xbuPhhRDFWTm
2qU82qtOXRW24U6vOlpBzaos8JidSq3a208NINYtrsvbQknxx6tFJoMOGVLI
8zwv8AT3JkfCw9TGSYnomIlGF3DtUvUr8tCyuKw3rqvmPPeKcaDIh9sNeMp7
z6Kno7V949NJeVhYNlgYGAQWO0FB4JuYtXPuGEAxEw1Xsshw6bftv3Lo5zpd
SMgwxP1KGRNIxha0QO6xDtoNyJ2d+Zypyii6cmdKedB0ADh7dT/HOoSgp0Qz
k2IdKruGGE972tNCXYFhQYcZu6p0VAlWiFUC5GdZD4j54gn+HEByfATDcxP3
OT9Fr2voxiSiyxvKgb00w2+7pJ6ttzXkmenj7qM3ykyFQ5WJAw391UdlqjuO
UM/bThm4dxwtBmZ+YWC8cWq/suPPXUIZGRW3FnNiLv7Katv8bC2Ttva4xz1O
5Y0eRIMfRMRD6JKrs6Rij2BRJG0xqNMdlsW/NX0pqwOWhY8umO32o4jH8gQp
O+Ix7jmqLE6FOatmnCl0ltuPoP39tueFgrKoU9ZefXRqUFC9UxOQs9xtpVuC
g1AHiyBT3nyIrB/iFhJMvg/BV0lBP+wyOAXiDyr8NNv1UHjEIx5BMeR7vfNS
uHIxuiH2WEfPt+N09gT/7DDFENSaOGe8Kj3RV0vGl/BCKeNLPVf2YwZhaF31
AIjhLGwjfruMNhEXkGGD1ofaTVJtUA7ZHytPtFivocq5tuG8uty4653Uc2ye
9OwarmbpKk2FwGol6fgTbjSAwW/Ln8VriW9U12R2jg8pLarB8w7z8qweqRD0
XfyZmXQckrvsGKrKdB90hYEUXCi+tyqCK3XbDGfA5H+5cfRqJPVXj3Qtq+cS
0KbdE/nFa919NGjYmj5/Af6zgLGzv8A2K8dtR8LLbCmkJr7R4D/xiU9sJrcO
RvyUFY1ptDg28uHJl3zJl0xJadG87UjXXaDsNAg0Y6oEGrDKn9eOeiCudjHz
QsThJyBairEBuXFqird4NuI/JeVce3BsELabGMxTcwQbHP0ou5j71cvlc9xK
RxYEJvlcLPqoLBLbV7qVCbew9e9KkjYIZnt0Wn0JmxZXcbz4D/tP+NycH9mT
ifySl7ykG2/KdRmCvSW2M1OwUcj1cBe2Xzg25gjUAqfCCtCPxXGt/9rQQ00S
wLKi5ZwySMXqoq98R6utIqXql+JpcIN46jxr+Va4T4FQl7ScPj4dQbx+Djr4
qpql4hU179iqxy0bdPRty19wzbZw96k5yFwqnMIE3HJA6gdoFBNqyFYKVLM3
TS1T2gJ6bvmkQIcjCyUVR4qTqBOyokBcpcyqfWJ9JwtnBJj8mvx3HmmzV4/m
SguEXoGgxYpfO/UdeN3RAfaf2kjncVggOmLzmqMKenM4PVHEUYjR4DeZex+v
aIpyzjafH//4x8u6Qvk6wj2Xos0Gn7cCTTr7axCDBZCz0HIMUdOwkXP1Hpc3
7/Z6Rc1qDTcW3GUAV7REwPkrj05PbCOOw8rBlTMbyBCmh0775ixQoPKcN7Gg
DnEdWKiViE3M9GtPtW4k2gsR58VIfhX855kNOprYTXLV8ForWzT7pMfRZTc5
GwGVS7Xl1YGoJxLQ3bg0We7ahJIK4WCWnInmbIdc8oi0cc4OuoM8Mi6M5dFz
kfCu8rksvFx818yhYykCzFYaHc/v4I4s3VVYu9XcSi10ZHV7yCl31ZkIqem6
JlOCtaSdNhrBghACbSJb+1r4lvUW8bAIKr/f0C3Rnu7AvtGzwwpmGrUQnBkU
gjEXG4plGjS7WAzEAvGtqMzpRGeW1XulR604rsH8RGz4PjoIPr9ixQs/uHpU
2z4nmPAZjZMMGYAGwrCg7nuOekHSbycOQwxie7/0WxS9MQcOcl21vJHuHZ68
7GUvCyg4BHlgox/NZLShSwKqPT6aF5FfvNb8wj4ZdqFztDls5JyQ4pahKw0U
oVp4vzfzcTNyvvrSs35VjwZEC/XHTnsWI3udWkOo+XqsKahpm3BHyrtAgmaI
usGorBVzhePMgQkLGykbAvlK+mS9YXoxt3WrWSnjBj+gCFVoQF1qD6Jp325K
a/akgvRurSfeBSSMnYiBQrTGHCuslKscIgBDgZ3ZOVeEWRwX1rFMWMGxczMp
lrgIEPe1V24dLEW/lXPwBnUJAi8QV8DGTxwbXic5l73INShbtILtDi4erEHo
8QFhkXWB8Od+7ufGOhrJEKPBlMCytk0NqU6Rg30TA5dACVCLKaFrsuAKXaTU
Xaiypm9zVdxztGm2piwlxylm9LhfAWSXwa22coILxp6jFj0g4N9zNPjw+RzN
55gxF3P9KMS9GLNZGO481biYocNar1srZeEMGtJgG+Hm5OIYewoKfaRiIxup
KoHJ85///OmJDQWpufdSl3WWituPcLtF1DO2nDkPZc3Sv7pkZ7fRJF29RzA7
dWwF2a4e1cbc43cfPSUXiwtX/QQ1Zb6mH+kROVOS50v2KdoMeiP8oONHjs0K
xePm6eOZPfQ+4csQwGlpXgNTtllJ9OGAxDcG0qZ9DyIkb7isON1Ow67OvAfR
T17wghd0BD2sO6agiyWMTA0ZwVBFZ31UV8pv1TBYQuw846ciPDJeV8Xr3F3a
q/Pq1CZgTBossEXVSBlxA8WiueaTAl+gZvF1Qkq6HcYiziDkTae5BrO5gTY3
aE960pMY9hvMZnIDlWYddAQaQUezWinjJsM8I1ztUtLgw2qwnANLhA1P/5pp
d/XBkARTaHaJEY91Y2lPlg1nlDvjc9aPRZKsRCFKsEPxBJnDtx4VhuczvX4k
+F879RRA3a8f27UjPf/KUYXsrKrMKXMuDTT5Wr2sVj1lh+FGlKOZGVxwoeoM
Ik9TL+l+KOwE2ev17ktRd/sv9/acRTIHx0IyGD+FY53dpkK8hthr3MBevfu9
fpQ0ufOoqoQznO3Jw97F+UssEuxnQFg2AGw/H3HtwUlLURHip49W770x21dp
YZmz+IYVR1ivJmLLMxW3qUlBJ2JJ6xGcoeNzLxvLXty7q+L3F19tt56FJrPz
zHb2ZZegB7QM6/7ZprGSwiyopHWRG2MjC9sAerYl7sm1ByZ0k984GkzLrdOD
UhC7AWQjFdAOJWZbBilMysBk4rw6ft1IWKSwqh5PGuchHo1zz1fVqYiZkQw6
0lmayZENAc+xkd40jAL7e1I9PiOw9rj0Ds/0/GR5YNfqZSoVzcW0wRyWUTu+
YX1cRXRhZtNq19SJpjN46f2q+qwBJWgSiarrEzvGvCF8AddPBXDuOjookZdZ
Qa8cNUjvOZrP3n1UFmI8HHR899FElQkR30jpaH4+85nP1IuNM6tFLdzQ+T2s
CDEY5TR87Fd3XILGxUWIiGDEsNwT22UJuc6z0eb2o54bMnb1aIiJKpwD8FaF
XoDN7MbXj8Rkys6dR+XzeXWvHdnxrmE2pRtH/fZZQlb5p4MzcFGOdE9bfSph
otyL1iNOWOvp6lKuqeg69aiLCzqa6mtg2jzs3jtp42mhbPyV7w46tOVttNmK
u8KEIr6XwthuKfKRQKXD+vaeSw+Fd17aRDoFdUNW++qGkXFajOJ+Lv5cBRQt
WbaaT2DCHC7DpdUAEbP6vve9T1c7LiQemXPjA7m3eD6/LU1wzaZXxGD7kFNF
5jvyhz70IaUAQo/OqOBJB0nueqw9zTSRIEIXb1HoEt+C2XCjN81hDsHmQE+Z
F2yOp9UgnWPIs15mNEDrcxRl/SLpNeTajD1HNC1Mugk/WyhyMnsszQUJwV1H
OfwQFfmBY+PG5RkkX2en5I0jB/bOoyLf3Uf++1JduFfmZJmEXjkKcgKN9VWk
+/e+T5qNkTf1puQKrS2y9Pk4XqDRg2hiCy8XJjoIVQvRWj/L5znY1dUuBPRM
qACCALBbLyUQX3V0qaZZnF1R14804aHQjaN2+izM4zbnsLq7j3qnV/9xjWjj
AE5dkpbBOKRECalbLAOW41633PCeoCKrjI3ESohb41eLPkFj6OjgzZCurbMr
b9KwxzQi2A996EM5BVinpQw37GkrutugHF/5lV8pwKYhbZI0A7lyFpQ1Kwe3
5uryUSs0o1+FwPVqoXpwxa4K6Bo4crWs6ghvjjLI0vMVVF+q/syqLsONgwV5
KOc6gbOK2HCANrgRKH34wx9Wu0yVAAH2CrA3FXuyEbOWvCCXoaPxTG3Rk7qV
sbVPcTA20p54krsiCeJ2dg2e8korSIo/Wz8opBRbMR60YM6CNVM41/1bDtfq
rs9KNs+vBLpBEIbsPcQgdPDEIriIqZkLBJMwezLo3bhU9rh+VClcTAgkcYRF
Y+IA+jU3pOcGzciGiK/1mm+ce21sQ4x2FkQaUPdtiN2/gUk/l3W+1nj0lFuP
moSvOaqUz8y7ENY7Tklqdx01QBCJ1d+YP2ja2czIoxN3nuqaeiJDp6X2LO5l
DtwxEMd/5dHQihmkQZ5/YeEHbBQsgVZqdjl+2LUUXGzkKt0t5INhLURarTDF
OjqsEuii8aMWYUJE4qabbpLypg9Fz6IxZ7a9dinoIY3oKy6bxnnKTTQJOynx
XMSF4uTTPlCFtUSRrsJqIcQLYvBfTPtYwu856FTNMRULAwo9ryGGMPsl6bCo
zNC6pBVosDqlKn6AaLYO8tureJhOpLrIRz7ykU4hN8evuuvETeJbJFklE3Gk
oYfk4kBDf+qoWtAR3jbs/SQEaNwsCujZshq5zGYRBSDEXI68IIQ3nPpHk2tg
wp8LBF57NFlb8PPUE1GpvcFzbFz8o68QyTo7Y+l8r3eeKp8TPSsmdJLqu7X4
dUeX6nmNbZORBUgwaMTN9FTVmrnXl73sZfENPRwbzKhd48ye30+6qpSU4ELI
InN0P5GevJ6557roK9kHoODArUdd0Ik8DjATzeJp7zgqf44tjFcsvPYMGj5Z
5iDd5/ql/zu2Ngvt9LsF+c+UulID3Y54BhyVqqsNwSIWBh08Eci2mtiiJhBd
OgvDKVObshL0BbV8OxSCfc+llFyPI2qhM29kI9yIZqczcgqE+TSRJqSc2WZ+
z0WUgo6HTY9O9LOnnrYLzaKGsHlSMegUwkfboAeisiZK01awDoUKgwWN2xQF
4mUOJT72sY8pUajv5LmF3EgODchVATFtqekdvZFuI4CN2RaXQ9U6UXtqiavh
lPZSKE1C12ykrTSrZVSpXNerqEVW5V4lGocwPfckvYc1kuOZzuDJWbwWCata
jH5YuYjnLOTUkDauIpqO2AzzEAmhpLz1tLVzN97t9BRWi3VwhHisgtD1Iz12
6sbiLsRr3Xopmy8nBeW46ygFvDioZXac3SuDjgVtJvUKgOtb1LhFfdNTVN5W
GqLhVVO0S+pNuBFoKIcS31h5QNEpIHfxZto9r23r/covL3Je2An+MB1kcHHP
0axqMOJ25o06e6IXe7+s4bm2Z4ZdYuyZmVw5OlAsX7iDgwWmDEsMP+b6Mp8L
fTMkjoFb2fGQRSihtWeFnZXPEiwetVkh9jj612RuSsteCT3iHnqvhOTtE1Hp
511/IxzrgBvCeuONjXBTEQVKKhGGrfKu07SEXQk15YJOoaM9/6xtXVHcPqIS
hSC8EvcEoOIbf/EXf/E3f/M3f/3Xf50q4ZiS75Q2klrr3ocDOs11tHAGFKhm
RvtgVm2UVilxzS41mcJS8KL2V+FHREf8rVVvLFo0o7a8vTbJdebt6d99KfQ6
NUEoF0sLO+ey3iDG8me5NkxXtcVQCIErjB4a1qg8sLBDsZqrDGZzCpG9a38J
McY31mbx2tFjaAHbrKMLeDjHWK5iv3X22tE7dZ0X7jlK9g1AtkwLb7ChBAFI
MNJS1fA2AzVEjhs3b5/73Ofapzc6mUbzFP7qJ99zNPMdAN44iiIublPopvj5
pZPM0czOLGhzbGGeFwTj+lFPFYtYj7zVY3d3EODOo5fl9aNG0/WjqtLAZ+UR
DMjiSSAzhxSXATohOWV5WKIlqfyLrZoKIMZgHYv6iRAFLJfXQLDQ7IG4uryM
HmuXJKJDn80wnGe2rYfSbA/hm8DJUTs3nnwHPZcwv7VVhfmGq2870RpJL5ic
+UX5HT5TQr3GryqD0VkIrOs8Q8dQQnuFXjGKfvsnf/In8Y2/+7u/+/SnP/2J
T3yiz7GRtabCf6TS9G9nXJuGXtUgWhXEfrumTiwPFKi+BXQrKd8lzVWkqpgy
a1hH4KA4WGMYekQ2QgwqXnibOtM62ExoJvO6LlKUbUrpjOXqrvrffKYM+2rv
CBrv83nZFj8scU+414JUaTerd/rWo+EsBZmeu1DS1x0dpc1koU2TPoJ/66lx
0quPHisLfRe5NBLOrAE6HGe+A8BiE1G5niN6Z3N5N7ZNy1RpDVMa2NavvjKH
pSRHNpqZfdKvuqobp/p79x59H+4+agOu6MeMFYtQhRuUrHuO1i2L3rz11LkV
JvjtjaOGGMOyYXRfIsdec/S4NKQrOHZONJ5+xwq9isd806JYkfzld0jGRF9n
N6CqDzoY0+5Xs8IEXjacJQxrPcejQqR3XvqxdmHiSVoow4EWR93YZ+sITATV
gER6TfzkGy5bTyeQ7+k0aM1qAaL8JowG/BoUFtEXDJsWcaUFE1gFNNaSgNXU
sPQ5HSeB1dQplYSO03F60yeRjb/927/9q7/6q6AjXHKitcWEGOoqBxqpNlGU
dg46UAgmC80d4DMQW6EkX6kGADqYOFZiqPHUPaEpEX8LGdSTf9SjHgU6HvvY
xz7hsjWrQ93nPOc5IcyNS7G+c9PGaRzLICD4jBvClnAAzIGAr6IpPxpbGe8t
wqlM4or5rH8iZsIIPCcOL7Bs/bN1jnZ/76Vl7aqhLoV8hg6sI2lt/ttZ/KSI
qXO2OBBbFXdCfeModrqMM2TjJS95iZy1CEZcLtwINLSlCC5kpgQXYpubmX0S
2YghsyLS1NZzaqUXFy4yxJva9eqjLPn1I3NtGXYLGJuesrCx247agFgH5WiU
g7KzLDYIwwszC/Msq1N25nUCp7MjscIxeBJqIY5WXiZQBH4eyZWbWCTDuZnI
cMP8MXlWEG8dnYSTdWt3XMp0qPmvSdnnfM7nfPZlC9X7sAcROHCHKUEfmKTF
9Mj61bLeOouG1LQSBXAWdu4WmBd4Ti3i6gpygtC5hmyiSVfNQ5kRVQrJLOig
rQQFf/mXf3nfffcJ5EA2VttnIPOpT30qkOk1opLWE41BTtha2S6EoAhIY7QB
HRBDSXmeX6yGtVkDgp5s4xM46GsfnW48FeqPQgcd0ezwNkFo4iW/E17dEFQl
ZedMtLllgYbYLcyfXZRBY25ZwWwsYIsyhQbcrCsCRrvhsh/VYRbDWFzMvJa3
H7UjrpzqmFkTUfHJzhLTGDrIDjldPHkHee2lTyWE5PrZorwqeRydIr6EiapS
rn96gByp0zWP3UMtYkF3fdKv2D3uutQmWonmmXmJ6rlM6DqsLaN/OLB4VxaJ
2XUXBDtU4STFIqasDaaWPbeUlnmp/HzHXG0QPtnlwiyNZUkontdMmucKgWtl
uEo1AGSgYWE9mztmVVurDin5K6TJ+NAnqqDHJUDH533e52kTKQS9x5QISG1T
naCH2JLa/OdYge3dcnOg083IuXDQJbutO5JGCdpVE0aOkhknF/Pph7Oy0oPY
FrxX/jTmEA5EPIKOSAVCwv6zUJDtprPtJz/5SVEZ7BtcveMSvFRjSjgS44bW
dTPRqEaimjpDRzO2MWnhE0Qqpq7FUY8PkbcNdXLRxOi5sA4J46FQ0ESa3kLi
V5RjGbWmHLvoeme89ehmtWya5dSv5wK9xjpIZ1m9oM29ha0KA/unNTfQ6S2X
uPTVf9yddis1eiObbEdgpxWLMusrYo/MLAsmzsAi2kxrqQp4hRuFG71/9rOf
LYg0KG5UtaVgeUM2ZKaIWLufsEMApox5OW87OjMupI2cLvyVg+neo7LxsE7g
yhzNFBC0arhx5dQQh23EPhsKICwUZ0zvylFMfol4Vy+t+havaALQPRfiaNlV
omdNQ85YsfgoTttlUoxyLOqD5W2tD5XIeM+l+/Nbjk5DPZ0gvQmvjNLDLlsz
XxO9qAUPe2/SVkKPsL3HJKC3e2TP3ykElsMNGxvIMmiUE2QxYGxkJaaziJgV
+M0ajLRQf84ZtUl9UhzxSIvBItRMXladgop93g6pKoFGSk2qSvwknBntWSAZ
C4bEfzRPYOqMIYgHA+zi+RtebSKb6g2XmEZ5K0GH/M0YncCksKU9F8vBvCAC
cGUDBw5TUtbU4O5LPRyFeti1knQW0eVNw5NV8wAOVkAb7rF8OkaSaTf9th3u
uZSVuP2otGPOTzTuPvqr3nt0fOOfnaxJ3ufLwF6oKosnQbFWiWguSx6E9L5m
V3p0M1NFqcZw4c0tYYl8O6iIEt9I3VbAXFDlay+V4TU1uOtoKjFFYLjR7F1N
8gW9n7Nirx7l2Rd7f8aN5ctfO4oHcngtxfjeS110XyE5rBxUv3bw+GbB5ve5
drRqWo0CN4XISfRGDGiys2oCDXR9vRfFP9BQFkLpXzoChcX8MRvFAACiRUsy
R9B33nvp+MafmKqonc1NN90ENx7+8IensKSz9+CiFkxhMpqTjmkrQcr1SwIR
6FhzgfENQZKMBpwdMOTcRwmkSH1lzFlQ+qLgcCqZGgviWogICyeRp5FhJiyc
73//+8VxhRtpNzrKRTzYW7iJRYwgHusi55pn6KA3ybhfHWYdW3qm2kQqWBdn
sz7SygFIFK71MaEQA4NZSVoBGtMRek8ZUdicDc2kkhPRfLPoYAvM4AKMBxrL
qO0TuLGALtCx9itIqRy6/oVjWyh5T1596Zxy91FGj5dzGzvqnAJwjz5yz1Ee
fAFOak0sTv6uo3UCVp/YRoPxjZDh677u6xiOGkYN0/s2UWqHqEhqIJ2aB1Y6
W3cHMyV6iA9n0hR5xbhxVh92s+curmdLJjuJq2UmhZCrRrJAUHoctrMY0XOt
gH4rqEbAv4ZZdx+Z+9eOUmzDnBlPGkz1YSiks1NxpJpO1IqmJZI85dr7mThW
2WaNlefbNSVGOUjxyghbTPtJuzVLG66gQ32DoCNtRbPIHlZ40lcKobQb9tgD
7an1GpLoz95QKDzFBSxCYyV9qA8svTykTL7L4V0bpt5ou7ZCQLP5LLqyr+ax
5Rh1U2tH5XSK/6ynw9pQIh69p7AwkLJ5QmnIMM0IBKFJ64F1LnDa/TbUPdwA
NkrW9G5xfMADHtAYBh3DjaiIEv1BRxOj5QYZY2JdxCZujA8soOu1R4Ff650y
pOwbq0mLZNJTpr8omrqA82WdmLd2gxWcMjCns3PFzra5ddk0tgQjD+LNXPmy
RJUBYQVdHBrkgRuS+s+oQniV00wT0WVJTR6xMV/zNV+DsKnA9pSnPCU1MAYS
+42EhCf9/O5LCeg1+pRcM1/n9SNJbdYb5X2mbfHpCHfHEKz187TOnnn7UQ8N
7IyeXT06PS3/xc5UFYWJbhzljJaJvNA4l3HbUZt0OYOs4jj5SlJYqdk2MdjF
bCPbQiUFSWqmliyw5mH4q9WpmchCOyw6rPTrCC/ATCC6aIQeZQAbPrRcKi6h
JGmUI/VcI5tXvOIVHvGrL0336CxBR883Qejn3TjzfmcR/bX6gTCN9sFDuois
lehhO6UCuBEWAEvnrt8xxY24BU4cCo7EOhiFvUj8T+o7uB6UgQZzBzeNvjDo
BCIhBn7maEcDF+NL3izaTc/NHndaduDQ+hj2fuZnfmbQEfdIPY94KEgVqW6c
m5kJVHe3wNGekeDGBV2s5JfYG7ORajAzxdk/Mi/JchBWMUCxZenziyRf8TEK
ERRa2WTxY/KpzeF1D1mI49ZBegF7AmcivsSOcU7s2nI8g7Ag8MWgSmcLFkRu
pIk0IWPCSiRFcakSy740OcON5mdHMDjjV210pYVjzXSwrPkFvd92lBnn/Vxv
F07SaSiCoBhzHPMcrE7Sl/ayLBj2k9uPAqrzmyxG9Jy9Ylv6zG6KEI3Yr7oC
SZ8HhFsBVYYYUetFPM6baQJbcCU+YB2LJh1uvO3o0NpPqAlIi+723VRKpQzx
VszQ41GXTe5bTKP7Zb3spvo3bUUcaQ+ufxvqJgkLv/DXpb6eKwyL5SZ3S2db
CydNWyIAfctFu4QvyX00OPGoLCR0EzebAK7NiiQX/ao6hSML/6CzfPSjHz37
ZBlb5pFZ4PrqBtAKf+m0rZmFjKHmanPjec97Xvw5PeUhl02HoJlJm+dBrlpq
NHGKZI9GQR6mQkmpVBWkgtGSvVF4+SjH4GLa7srSeuIasljg+EmX89WhWDmW
sfLGY1tS2IIYJ2vLY73zUnt5F7wUXZSGzfMcXXnnUcJ3ceCLsOrgOkQrKNow
piPz9wW8j3/84/s3ZSTQ0NqmifqEJzwhYOGrElkHD1eiZGEVAHmaxSDitkvN
8xlhXn30fl1hwBUdXTjo3NDA5PopZc8NutNVL2F05SoSYX6/SBgqzCy0Yzh3
n3rIspwAjZWcYpGY115xKk6QRSawy8U0tF4V6ZTgaI5gDq9Kp/V3cLTyL3LJ
FTQ+J5FJKe28jUAI0Nxe9OPNl01J0p5pU6sj99BbFHpeUgNijMmCpoc8AnLE
hKid8+VpEBPMhYXbWCQ4XiXXMNpMm2u4mEaT6HaguHWcX7h0vRfO9LOX7rpC
3G3OBUbkugYXDKpyW1QwAw4zJa3jA91q5Q13tSuVzIfe2Lam98SVdY1dKAet
omAzX+7blkjp3k1m6fxCPRd/hRusBiAiOm8p3FhZY3Bh3fnxoweuEI6zMsJY
N3q8df9sEmFZnf2BF4aZ4q5TO2ncA+vuK0Frs2msmsfMp5M1Jtbrl1RTlhbW
SzKrmmggENnQ2Ydru6FTvbyxZYKOivRJqJK+HMJQUjoR/Yv/+nVHt1wXM/Py
bBQ4xvVTvZ07jt4lLC23Hr1fZ1ZlgpjVYqrKfs7EseiO+8EUfAAyV48e4iqW
ozdLNF5o3E7dI2sqUjz5UKaqjB5IImhOSt8QyLT6w031FQr+taPp4VLMVr5P
mChEmvVs3grFu3gY+RY7SOftmkP7ZQRgHZqGRC16QLTa7jpyqMp0jy/YD1gW
UN0tzKc5NFtdr988tuXgr3SP0HRmHHHgQmopXzQ4LhWB6EGotteCWFA1d7fj
iD/HH5RjZSmFG72fX3VFxqTMeDPWsTIg50plsudcnhznZk40u8WxQdMhSOxB
w9jSqWG64HN5gg0my6QjcJ5yyy6+y1KCehFP9VFX2WyN6pCNkbS9qr3AanHv
0bnpB49tIWdTamaCwCUWtLCkTmn1Y9H4j8iQN1x60iEezricOKYMLl24RLvp
E5EbTaqmnz7R0Ta5bA1asyswScS49mTIBiyByYxsnZGR7S1Ho20gtjxfo/q6
ox/rWTuYI0PJYrDgHq8cVcfHE1CCRcddOTprS5uFPFePAu+2K0c1wjuOhhFz
l4ioV+uMaQWaLcFtJKTppwymR8/fsboQCwZm0uRcaN4y3BEorkwM3GZxZ3WU
gYVFT+jW0Ul8CBG2Lq8jW8dpmnXjetk87nGPwxIDEB6BnqaQ6e6CI0ZiV1/p
3HTLLbc0Dvde+rMoGG6xXljFKnqRx+Hesu9Fp/OQcljMq7u2uR2hHQINPSh7
L3TWsiv5gjcKzAobwx9AR+peoBF0BD79fA3uZ18F19CDrUOqC5rnFu7Xr0F5
hCZnSyfs1TfhnHqcFGg1K34pQWgkm+QN++oSKwrKw3KuKIs0Ig+6JLA5Szqw
UrByMHXSYlhKMYoOuNAjiDFc+vFTyffFjAkpaZ9znPmirO86igG+7mg2J1T+
jZduL/eeGsGz6xJA0srWNzJz+6UqXWQjEPjmb/7m1iNkY15szTQT6nYIK3Su
mZICNzqj4BbGnKGEYWQyQrp2I6wT64VET+EwncDOInH3UdtkZY6m+/hKsNa6
OF37x/0Rrh6duGfBQNs4haXytU1hMUqLde8IFASGzfccmzjn6RcoKElf0yWC
tiK9s9rNG3sOkQIdJj+7/YpHIR7rIKkqjrz1fsU70APiBevB4diB/2Me85ie
1wtf+EIKaRhCW9HJut20CO9RCkTvyqkV5xX8rL/4yiccPf4lrauFvm3GVRrc
/bQVuhiqplUleAlbuE6wBXaPMOfDl603Eu42sAPkxaCiSYsdnYboaLSbrr/H
99ZL45UmQ1O90QgohOMGHdEPuCFzNshtoJq0vFEUVdoHG+kKcHFbzNR5drKv
FvTsWsqdna3i0KM3q9Kz9nC8um87uvaMt5A+aCBRbqHXMyTedTRMmY1UHxBF
UOdJWdjV9sTelwbC2C4hRYM8hXrCjVauZuATn/jEcJhYxTrU/lo0nULENy5V
oJmDuDjXuWbx9ky19x6tnGkTgtZ4ZtdRTl2+JaNdPaqOs5/MwrwstrND5Naj
5+x+xZp9zlVZcLttCkvbEu6M8IwkHXwlu3khzdJZDpk+ZiNdBV0JCFwtVIDx
/x2N6eC8Gi4rVqTotGDo1DGV1pSCau1u/3ZrNHoize1meEQRLOiRmm7y7Gc/
W4WE+DZthUkkbGl/dtTunaV0ZlJcCFqu45t7wY7WuO29R9tHTOydx4Yv+ZW7
WxEP9pCz4ah9QIQiP7LylRdgSAlMPvjBD9533329+neRYHs0PLCMHtPsRKcb
cyRQ7LrKYF1A86RJnvbd5A8uHnzZBC/pSLj62601VjES56EvMc0mF34pz6R7
JYmE83Xec7Auu9AChFY+nXbw+qMhAtxQrHLUVzn3zrWqp8Ih0H5iYuHYuozS
C95Yjv+yXWZUHAMZgMyyEW4s1kuWq64c6SNPf/rTm4qtyMGslkABb8Ooxhdj
aQcEcUBSSuCcR5jVgnIZh1f1QpEc0fIQY17ju089HdYEBxAx6uJL9K+7jkod
CAxcGjxeP3WaPltQbzv6uJ17NNx2tN1c7G4/PzsFOP5WYrc5AO0RznOJFSSc
PcQRlopOfIRR8TySI7ljlnXGUrhh7q1IXe/bocnPX5MIBDudqPtt8scowEKg
oV6HWvStC1HK8EFjkZ5vS0C7aZwak4yHNw7Koa/F87Du3EXaLcAWoaErHWAH
pGtDgZ+fy5P+xtE7aQm2ONV82d2XqqFthojPt69SVdJZpMp275yz58i0XoEJ
xecDH/gAuwrokO1r6DoCS1ErOM4WOCgjL6IjvpE4SLFva+lMWEx7AUsT9nk0
0GwOU1EW/EoSmowDhmmgFnF39u/Tbt54aujGMsllk5R1WJUqma/h0puObfHw
a/p2/Wg0z9xHqeckWngJZ+6W43uO7HKCNjuhpmwjG002ycWPetSjVPeKY0ha
Ua2uAWwHNV2bY3pddYr5mJYzODvtcOOeo+bnjaO3i4Arwr7axdePEqnLo+dB
ZsnZgMBSyTW8sdeObblp56yTO472jmd/qwSfRaCxhNhNyUHY0qHYsmTNL4GL
5V8VXIEWq1G8kIx52USW0jUW9YTbWx8R/lkmrUozlqLx5yqXzRm2REYDFbQ6
dSPTY41RsHW0dDb5k4KeaZ+0nkYgpS62EMQtk4Wvumw936c85Skql/a8mrrQ
YGTJxbiLBYZRWExguEH1WFkzIyAMlci4fRTLz88lNYTBzJcdRHR3osoXf7vu
M0JzV9F0jV0WpisORCBNb9R/7lUyi4PP3pKYNyua2AlCUtC4PehBD5LyphpY
6CrcMZFRGlogKJ8yv4a1EsG+ny1iyEBVwTdWFGgFgkY5ZrUQpjU9SLoZL5hp
OVBiIyWGgjGssNj+srrO1c6b3oLhEWa2jmWBEcYtyqtbrh6g0l6aRzfBuF8b
H4wi9EhhET4aFOvqKH0+ep9wketzIL3rvPcoIKzvw3AM8RCxSVtZddOFZBDe
K6eW2RQf8CvEZWV2bj96TEMnmLPSAQHI/DUQY1bi/XvtqHE6yuEyAMgesfWi
id0sVaNbAe1zy0I28zXRYLlaNBQjp4NQt0facYxfOPom00fY/xlaVwMEv2Xr
SIia/OpqJib9sKmSSqJsYPiv+L8gau32Ao3QQ3GwVofEJNBQbFONTVXCNGGZ
v1j9EPxB+ts5mhQ7Qrbl6J1bmJ2jaucYZULhKrVogkp0q3thnUAqFnMLbKcz
Mqrw287csVFFDjmzeiP/F8r1XunClfrpOF1zs7GhSxZmINUWWZOaBipipjp3
kxkyzB+67irWboZHxGPjsO63nqPAWn5hfhYaB9AQ28lYsVJ+eI5KII65YrYD
7dlGZmYkDteOBiuz/zMGKg/CxktaX3t0Cpg7ppGJzabqBputL7fccksTphWn
kUmbE2qrW3G4sVhcKT/NwyBX2Y1+u8jDVRuggjHjMHT0CknmZ2HYnIx3Pfyh
bR3tjqOeKkMuk+ldRxU1NiIEbIob/LxxKhIovmVnETOm5sDMrXcdddVs6AfE
GJeT2PIbR7VegKBlWFN6BaZMbCX1VgATg93i61lboeSABAUrMwgTtr5Pjt57
9ELaMqpr/EoH93lXotBWONYO6xrJJJUI9Ow+/7I1/1kzenzhg358aZ2BhuTZ
ZkKPuzW3GdIAulRgNcPFTx1N69579HnkSuY7QLBthIieNW2F4jOKMovxouCQ
MXdKMZSKuzB1PB9szkwENIYnkHweH4MsJtYT6UR9SItBPDpL3zZRm4fNcL4V
gbhWUtpKkqIbcjNTqyABFW89OjHJtji3pV7CWjuIPSbpeMK5lcw7jtYPbCZr
wEF9QLMFfgs9ZW6dg4/XXvwMS6PJ/7qjLyrmQGG/ejQX6JWB9G1HC+/142Bs
nMcznkA96fbV9WpMggU+ayV6Ao0ILQcf/SW+EeSqItWa1RFiLA2y4jaqOjPm
TF3ik4K68y+fnbOMGMqOrW3cnacNLLh3VI0z6LVHg0uU48rRKcZtwo3lLd5z
FGtdqv6CPfxKcJ3BBMizurQbF+qS0Twma/2KVFiz5IbPJLgIKEhuHFjCe8TT
es62x5k9laaxbYmkmKSecw3LiFcmy9IZgnWonn7DpWxgaBDsSxjvIdI0m/yq
+mhbJh5s0CEPrsfRQfQHmf1tjepsKwQE9Nwv7xLMFMlgHeR8ZE82wxk0gOdq
pkHR2Ypl1VHlVsQVjqkaNHYh/X/hHxJneHLnGNpFkrjGiploVda72WZOM7/R
QL/bWI8VI0U5EpCG9+5La3JSPBuXJRvdslh4Ty50WPBMZS4AVVRk7jmoO3UD
boCOuVCXVj8z2ruOFntwA804OxavnRq6LQpCltZS5zw1JhF8Y6mv3XJUIcKg
UiiDJ5cTZNBvV+xon3zRZWvQgEafp6Q0tqqSKloo8hAlm8Y3i4eqI7N7ICc4
A0cqE+WiU+YwmhH1rqNf9vywNprFGQE4dld/YCn5oyKgg7ayoDKKyYoELsmu
80qIoE0gA56OvFHoIQ+Fif49RxvWlWdZaZcVCeQZwbEXEb14qmXcEy6rUpMt
2VHvV5HwZISIaT+EcvS+43SubkceYk+QrUM0KftVcpFW0tMMQHrTqxr1cY/Q
o/dsHQ0OKxxFY/dF/9piBxMUHJhr1SfnXJtVM0PJVm8Q9TLIS6kjXAspYTTu
mIg9J+Y58X9NW+CMgHwExjivVNHw3EOkM2I+Ha0H1NDFx0JX6T+ajn3ZsWlS
07op7dRiTQ9lYUC0BNsTAUjCa/DWS18nl7E0t+4FkpzD1G00DlLwuksTVaye
WWB9adcFTAaNzH0puksqX2aH1XY95aWKOxrGyPvA0sgXox+Z6NCmjfbQUdmU
lFhHzPZZz3qWwl/K4QolagDThdu/lUhB0aisxBmFQ8XDrPOdRfYcEKsyCZeK
e6e1rbCPaztHfgr8Vl4APgiUXZ4+9+vy4Ja3MtfJSggKikNg7jwa3m1z8AWl
dztaQgQdHdCEZHZbWe8p/k02ZjpVYnSBHyuewmJAlgpN6NZPYVn2tHIRI06n
WAcISmr6imL+0Y9+VNy1SNTeaCCCjag42k0l/iiHQmEPe9jDpG4pMfGMZzzj
OccWzeiTFhFUvGkgtK+hVtz7zIcX3epZzzKMWtDizWFqmugFMU5Hzd23nasl
q1VCJUSl3PiCQHxoRV7fNMs3Hw03CmuG59XnAGoK0Q5OyhgqV7iAEtQnzZbm
QKQiuBA+GmEDGiqf66UunEMe/cK/8YSFjDKWrozwjKX8TSYD1QnrMETY6SqA
rV6fYhp8snBDbuyqW4PW1bMd/zn7MW1I9e1HV6Zrl2YEzK2C3okM6Vg7NsWH
hXKxbCgi2vKU/qLEaBjiq6ZcPBZ91Vc60LAcXzk6skk5Gdt5+2lbAIygfRRL
qMm5qmqIIR92hsorR8nxO04Vfu48ejm1MXUuUnSV0HCwZcaJ87/3qBU/CIK9
EEPlIkXXZQdr9dhxloO22qGMD2ISll4hTHp2fnFioxw8sx7KqvT0ra7Ng4uB
Bu1eR9f3HD1ViYC+qPfdd9/HPvax0COawYT4J8fW+/ZZ6lZLZ4DQnBeIrii6
0L4gQppbDFMlt/hGU6I3/fvc5z43bhlpaaAawJ6aBXo5NR6olWLexj1uRv5z
CgajvTmAl7bPe46OErQMFk4p9ngduV4ATO+5p2kBAE00O1Vl4RmaWi73djn1
IzODDk8EP5Hu2nOPVFPSNaHoTfCrfLE0n4ZOn6bXXxquzSKhcZLn5WZX+0Ka
SSO5risrMwt+f/LSF3tdFXDUtxz9VparMp/sTNAdECdkRFpLGqxGZbDlmDvO
9aPdPLVFyj+VQew3tLnt0t5LnxQhQFoELqq80YhjvOhFLxJw3igJ2HjsYx/b
vynLTbCFVl49NpIrdoKBdCH6cysowomJAcBz5eeFoF89yvQ5MmPv6m+gFrcf
XdW6F6rNyo9TQBahMSClwlBVbjuaZnK5Xjk1PujWWkFS0IS6KX7YD+dEO3dF
WV1cIc0rp8lFuyZEFG32UshpOs0O9s5T17bldvntFPOFc3igHaeTqtsZdAQg
q/utPh7fikIT3XJzW5W2VoGwYpWNlexQEuGbLlu7pbOkjbZzc6OVIv1Fkz4G
8B7rygxCM3RiEVAk2kxeYTG7EZCz8v62S+epxcaoIMrNCnXh85kMkAjuLbqw
MNfVOJIy0+NwNArL6ocI+Fc2xKMUe8YAJRqcR6OZ3AQIGRTaDWwjadLcGpyv
uWzcB+z2DB0/eLQgX9aSR7Z4xbFfOycFFI2V5hgpXezoav7wLyyiQzS7kcQ9
2u3sAgOzEiLmY2XrkLDZ+zkZBSTgTlvZWTmkvnKmaCTR4sLRz+YZ2WjdCWab
SE2nEEOEbUPXdOonAQ7QEFi1YBJeDwZS2T0SeVaCcsEtnERLnl3DO1aIlVae
Lfds4jgX8YMb6MdcKtwlK+mzRkurboSNoBOrPOZoYs7l973gBS8IIWX7dmFb
F/i85kejYmC/ciIQDzNWfJGIR0GhZjsTwTtObalVAxYqucLdjCriEGRy9fOJ
ZJchhCnFRM7X+9//fgaWtU7rktqtoQ76ut9gQSOtVgG5n/yzPfqeb088EegR
CyiNarJ1JCPNCt0uGq4mktAOTlWBW4OOtxx9tEUaLJ/L8oE2nEXJKsnVcq5r
KqOHrWM6y8LMlrF7rvjh+GLaz3GhYj/WVptGOVSHIR1K0NSbj7bgFmiUo6Gg
4kU5EhbtaZKOBq3xaZ2V3blqLee4rxkZTHh57tBj6auMFRR8NEwIBxix/i5L
znGW/Sr/faFTvX/7pcfcwpLRM4kwns7y8b2hiaxqx12XAnerD8xEsH4H6RpS
nCIbX3zZGhARgxJV+opG3FfhicDyeIhSokt4WUEe0dp8K12J25kD7l3/uMuh
i188hssDgEAYOxKrJsB1FolzPDlyxSPjks44w+MsSw6BYSSZ+SKI+PbL1pUj
GJhYt5nsJEENhRTIWTWx2Z88OqcvVWQ55r95apXYvA03NPXgqKXgLBVl1Tg5
Vs7hHFt81w0E5TYBOGX6rTq9girV1VxJXnGknauf6FUte4tmmu4plLTXRz3q
UYxXPWLmboYvrbX0TlWDup9zsrz9aIrN+yniiMuA+29ZFUv97idqj8xdK8Zy
NnwqGA+sUC7QwRbN0LEaaCuDLNKsI4ii7CwWXDgsfky2y/JtRYJ94AMf+NCH
PqTMqdBNk9MKbmVvyjUBBJ+jZ0mEQBdjEnTEyhq0ZhRtZRW6rJ5vPdq8vuXo
rmKhXFnLxRUsc+2NRyPIpceCRIoqQGMklLixeukr7IPeW4/YSClibzna3L/x
6DtJ+pbAheqjBAv2QOYtqVJfu2UWYyknSqJFRXrT1FLvK4bWQDXZOF6XOC/U
k2CO57MSiEBjm5V6w36uGolwXMBy7lJH7zuHzcxXy3y66sFLITk3QLn71JAO
33C/6+u0rigcQEoH2Lop0SOUuKZBghN6uN/OZVFb251ZApu3dJPVqSPyQIPN
gYvW5FwDAtFK82D66ux/7NsdQa0wFW84giU9dQEqBa1U7+8dG/+OhbUfdqIG
v/FsuLpfPjKW8M+7bFiH+v/Nje69x62QbHsKKO298vUNY0+NNk3DUjlZUvni
dubJUoauCb9aphvPc7ldjlHhIuqJrcKz5P2FSMk4Prt0kwuSLgiB78mo9nTC
jQ9+8IMsP4al13Aj/S6qtnaWoGMaQZfdvGqGNx/iaZE0+T7iHhvDXmGIPNkm
3qp/ryIHEEAk5h95w9Fxfn2aIICh8y0LCdPQGPu6TNL0z3krS4pf9wTmGla1
tx59Fs6xVX6uHq9FVprY+LlkeeUm1CRvPY1fsZXJ2VEsFBVJJVlUuQxioCEB
Fq4uPYQxQdw7CVWjWK4xiuXGmxVqqILiRYyv+LP8NeI55/X3Htu6zDDGLmiW
pWVpblSVRbgJw2DqpNo0DitLyGmi4RTcMz5w46UvfSl+pRrtumCsw5oZbn2k
U2xjplh0h1RuX632Dt/rWPfaIdlo4mtHYn++yKXKcuYSEGDFtIiid17y0ocJ
bD9ZuYm0Enn3CUI6SyvpOXSnB929x7iaCfENcZLJiII/jc86LzMsoE/S0hcX
vWeKRiIDOCfqPi/DDx793Lsj2ELeRYMv+4xxbMmziy9lO7UqWXcQGP6FcDX4
DSV0jVTBA57/+Z//OcNy73si3DdLjefBTHz0W2klTSJkyKof2NYYGpPAVijC
8rO2LVd9GVuMG+uAADqsoViHfxP2Za+csxjmBO/n2B3KwZ7JBSNu3G5tquKs
RvGqbFmX7zoaRq/B2Rk3ko7Wmi0lqg0ohtaU6JO+0leir5oqstv4Xptp1JDb
jlKiChmxNDI+zA7ZG/EwwP9tR5cQ8SQA4U1HV9zFjipHhnKAR6bp6WJrr3Dl
aPFw+9EtV9zsSnnYYS0sJb+cW0wyqwKQNavdblQVnbK5bJjgVEmaS1HmF4Fd
uNHaB2ALujOrAsG8LwCSIiOIUQ0fDPxc/tdSu0bP+gf11RJYlt3A5qyHCOPq
eq7JDutNh2qfZilndPcYPpAFTpa2dJaEgq3jWy/bs5/97KSDoUM74MREs61G
pkMp9P2uo1uuLD8xDHD+XKjqzaeGiVuXidKbjp6JIvkFs2EFIjk7+KJBWKfP
UWRT4YnhgEhZAFUHO1QoylVNp5Mfpy9Dn2A1s+R3PcppBggK+4DZoCOp4U9J
OmIdoWsUXVO87zv6Iy+8mZrGeyjqe1yCIYX9U8HSKS/SVFlWF/Sy0Lu5wpUe
2lq80qNuf7n5zIaexdDJwk3fuX50YWZ/4FzoxgWIhopAo8mg6YxG8914/JO+
3wj0VYjRjFLXSwwYEWO+sOaCjpUEtNw772uPZk9uYcFObz0aRoi4Bgvsqwyq
P3C0t3O/SgqYdbwtEm1YOdaiuldJwey0Pqc0sXz6d0yMrWNVOKgwGjGs/5T6
7cozMvrhlj9+KUT8rqN2N+hYtd71CJgvFQewLZPlXKgKu2DxW8obQ+svHz1b
zwW1Rk4EpnL9Iz+/djRq5MekwmAsLKs/c+l0z4oeMIYPLZ3ihNdzVi5GQtFz
t9A0JQT5tDUlwhAKiyI2TVRh20vSefel09yKbN97NBOknFLDf+DUXWhWxFGO
jtNdhBiRBI3su32qyjtOXSbffXSZ4d4CWVb2hUmoltOAqJEeUGhbv6aQOtJq
XCsqzFkcSoXtc7M8rSGj4o1J4/D0y4ZymIc3jm6ndLTFbpnnCmfJk512No/J
m48ubDT9Hzk22rH5tgmgRJLyPjyz48MrBwSU4AP+c64e9saj4cvdp20RYgkO
tV1KAmt5jCLQCD/Tc5/xjGe87LJ17+FqykvDEp6oB9WHydE6FKhPSJVbaqpL
UnsQbmyeIE4DkCm2mzkezfVLS0oTic5LWzGGQlBQ37Pm1QNdoAXVjJG2z2ML
K2aOmawYILoSdLB4gBRu3LP1dQ2v+Q0ti0x8ZuySpKx6c36xy1Fe5pkly/Lo
F/uxilXLh12i/RJRO5QjMJIwq/rJ0lTFWb3n1GiS41LuJweNxK527nYa1SuX
ZrI9X35GSfdBh7z71tYWF3kErTh6uDdnmhutKWJN1fQQFcajOtzrjTQHRJo2
iiqz1Z9BYyRzmpdbDjeoEpqnNJ6SgnlzVkLZmLD8LCMMbjh4E6md+7kE249c
NljK5vz+y6YTbqdm6GCEYeVokqwtsq6ySY0Qlz586mULOhqo5ozQxBXpQpVJ
okUfJix+YwqF+BbrqVzyt5yawYluFaayMrYChOiGMxZBITFU3BBjMkxP1JP+
Hfd7w9EBgVODkwVjb+1IbQ83Qgkp8wK6WlxEvlF7W4CaM5GNFYHv837b0Cnt
u/qEgHRRr8w7106t3mkrLJyAl5X4zUdHKrfgIvmUWUFnbd6wA425YllUFA+R
oLdQNLoG4+e60FJhrhwbhPFmfmQ8ZDWOFonah9R2UMlPtLRWBrop+PSXGQy5
RabCTKhXjtg2zAEa+AY66ixCy5bhheGYOb989JxdyyTY9ctHh+sVOxXIKjWs
idogNyxBLp9706B1JNC46aabbr755kiIjsCNcHOjaSP5McHhmk9nkXTQyDfU
PaCerEqDKwgMo0yMlac7q/krj3COAROgtQJfGlX3XlNpfMCyuwAn4ZEMpKP9
W7sFu7aDaPzYRXDUq6odzFPKn8ZD1kx24dbN0iaDOplWVS7I2FfjE1zEycOQ
Vdy9cjRXhVp8JeuY4JapKlBC0gplxHnPKfnn9ISGyDrCViZAztXOAw5hmJJo
WybtlukhDHvI2czyuqMDbBMD8Vau/NyLTSGj1o64RzwEG+n2G40+7LU1hde+
iaFncaM3akFrQ+ApFJaVTiqe05ouen801Qxxka8/CryvhurqC62m8dJYBHWM
URB2hojotNTd2SsoLxiI4DFosOwVytQi1c8BYLMnXzuaKfRJN4hgo0BvO4rV
/8zRVXnp7UtTkmeEeKxdkbgjFlTFqZg43ntpp2IxxdKXHssOptoGXk0NWTq5
XDA2PUEOy0OXCHaOKmH66CedS328BqFhbHVQSAHxEOPUe9XsA40kIoKRhtLE
UJtUqR+9Phv/pkcjPHMHd3MX079K+ou725o4VyxxWF0jIRzsRSoV8CnPl8qp
JIRm1QjPrQSYzkzLtQngfmpU2Ujvu+++4CisEKC7qghOIcNIcAie2fU3UC1M
GlI3LAan94oPNHrJDm+UpJ65LQCXdXNBGlwtq5WBrTHwLtTcjRDwRZGpYLDi
9kopNkMch5nox48+CzbWQtcwJobdbU/kqq8s4utxoDdKEyB41FMppqECT0Nx
dqN86WUzJYyDkl/IxqgXZYrpyZ1OV6LHLWgTDrCBzGG0uNnVMhpWiA6959Jg
bjWL7r00xh3TAIYBWnDXlD5bYBgr6B1LWxPR4ThL0mcnOast02Vkt/HF9LlC
r65/xuqlV1A6VhZjdu/5Dc+Lo9X/7DlVPUwZXt72dx2lxc/9W+V1qkXDjTte
scioZYHJ1MAuJHypDuRcgKuDy5pscBq6ZL8VM47RasLcEfGQeh9WNDeaD+3Q
5AkxTJI+FzwptEMMQwdElVXDY7tT8dJao68K/Y6KJ3zOdSp+OKAwRDynAQgx
IdTL3hrBWAADCV0spfnWRIVLNKCgIxrjmPPdsJcqsNzOQr4dsKfflFD4rrtm
7VmX5HCjcWAgTV6ssJR0fENBPBoHW9mIh6tlNzunlnR2KV2DDsaQ9hHAFtbJ
ReonLIeEa1CwCuphph3EhICLc2XLnzjapotMk5AiuilkUEG0++VGUe4Ppe+5
B5ghiTrY4Yk6DK3jwSwav2DaYZfUgHNEymR/iWPLTVso6Ti/6Pr5rdg6uHf7
4XooLI+PzUHIa3fUtYUbfB/ySkg9R+3Agc2WgW5lx3heVAhcX7w7joYRs6zq
KtUPHZaaBjOnS77j1Aaa7WLGK2viuy6tmhZTvco/0tMWryVVfLWLmUxFL9CG
gA+7x4qfv/voJLv2rLJ0BUNywSyqBFdhcqHjdPGsf91d45kUqEod5XjEIx7x
4Ac/+LM/+7NTXnjkGQDFLTzhsjWFhHYkO89//vN7KI3eXGmQUw2rZQEDUsWZ
t25qAM1EycfBzcFnStezJSaCVIGzVXKBE/P5rnoDUzZRmuOp2+db0eF6jwCe
L8r9py+9v5F88VFaZ6bpA4qGq/dwA+UIWnU+5XZc5RlXMk8HoJs+AmxdofXl
nFoyirI0/L4VLaw1T1OFgrboxKGB7BvoMd+9r1wG4uf9Wy5VUpvhYkTnge0e
V2ojqpka0jJtNFpuMFUBotIhBZavbfS5zif1jUo7+zNtZYU1uFfm2WEXQi3e
cClljPnPhf36U6FyAV2L/GRqYAJVgL3bCTRedmzKdyAMNBSeFxkudx2tWxx2
NGNOWKU/1m9lUeh9hW8sqJVRi1o6h9EWixWIoHqsCJ64BWK+NKvkRfa9V7Kz
BiJiQSWbcLB2NMKy4qWmwVZtwQwwZCEQklyoRWj5OZZb+PrbL60Je0zNB4E9
LSuqXSEesrqCiySFB6E3YtH1gGtrdqXvaLvArKd2x4rguU4eW34inuJUho9/
/ONJcYghFgt6MDis5Yrr73aYkqxWyMyU98VBQfUF27z9aI6GIffbX7z0lGQp
XYj+KhtjdHy7bzoap1KWm2ktso2SoZD9172rQkDrb/40zfrJuexMF7liJhD1
x4/eTGeDw9J733u03lgcmpgot9AgYJUImIV7AQ8/frTgORc6YDde6TmjMVsQ
W+US2Zr5SZkSPQJEmT27wbDC6tCDTgz7JPJJawtS2j9WlpD+f2Td6+99Z33m
9yfBEGNCwMbm5BhjgwNETA4dTSdRO31QJXQSQdskWGqAEIFCEqpRos50lFYZ
pEkD1LExYGwItn82B3NQmuRJpemDiSB1DJZtDMY2iCh/TN/aL61LK+56sLW/
+7sPa93rvq/7c7g+16d1pFBuRgIk392R91lSfnV/Hzl1VFSIukSqeTWrUqyD
OzO3gkyohCk+J374714OVM8QgzVl4QtTTLRZ9mRyglMW/eOj0RulDoyvPzwO
YeRlavrTrNsesVpFZuGSX7azla6MaCHVPqleJgrDQOKAc43QyERfeQs6NEZ0
8xzBYLsDjpNS9AkVTqhTkek4ZounkeDDfgcdCNt9bfelEWi/CA0QSskM3nrr
rSIezZBs0d/8zd9setDuaFL1ytgd/au70yA3zz95NKw8K/wAjb+6tFrrGiVb
0Sp6zsYgmkr8c/XFjuEnM4Ylv5TNMoxbj+MAeLQ8zeFOjBSSoe5GSKMLXGPt
otD/+SGd13TSuBDdWulfO2xXTYWgcQtDWk1NGyYHc9pZ9VUDT36W71+KQcGO
+DZOoDcsKrj8ci+qiGSZsDfWl8H0GIF/5DG0XjNn8oZ3He3SJoQ15WES1krm
mw899mewoBgnZAhYVDyRAQxF9Zpvta5MWHCGm6Y8X3gcL9T+O3miQcF6LZ0B
hIyA6O7IXTJBq4RdBoTLcM6VWObLm3T+wIEzAnNWqvPvjmMixjsNtLEzi2MN
avl34UZwtPJwFuAU/xgeIJTXdu+p3Yk9ZRz7aZLMwTSFWsiY4VaNTdaS6ehP
RMcee94Mlyi0DbEzp36zNA3DQ0hE4J3hPVVPxszIqHI0fereS0eALp88aSgR
XAQat9xyy62XIxjJkQkxjFszpBXUYskUIW4MVUJdgj8ulvkNr7hOlqeALXub
dDC7y6P4BhtjvNxR+ikTrtqLnzsLFjVCdPTclERmHwO5exeSn20ziPHl09GY
tCStWcExyyqTgzprR+AJOlo12SE9acVZOEzr4UaLVNx44a+1Phk7/c5LZ5Yr
J9F4LFZcUJYPhsMMXWRsrFQ2iSf8muncCrBzvj556tKCpCccak21O6vSQhCl
LUzrqf2i96DDaValUEVqXpCcfKgOKVM0mvzyTEQulZlMIUQudZkXtoeKeyMv
baHHwRi5cAMBg/DONIqxufgOQIMEx9hoXCFKHSNsTLJj0IHOwSCRSRH8XBJ2
Qh8gtwHsU2utNbmYSUmcia8micro1QIbq3P/nbkYV45e89xqAhrDDXqAsgn9
ie5Ilqel12yfaINMysRIFyN9+Gh1LYyg8FOiU2IXK4xeh5Bjb2B1NCZZHbTC
sjo4LKFHj29/+9ubJA0Rlz905dq040x+s21IhoVx3ql2sf0iPESdfeToiTCi
C4vCE3GGs2jzcGOFb2ha69Iy7dPJ8yI/zDCDJOwTN6vb59wkzXtks42MCjoM
tUBQk6QZEjC2gkQ5srIsGYmn3JY86Fbfvz1aoK4gi57P547D2aqaXEGWyKFB
W5hUHEAwZ/sykLQHcUAIdMwRWKWw35q569jg3HVREx0nqmkfaLT8u5DuLFJx
c0D7v/5lWw8c9PkKNzSM5qjCzN4zatmEMWXB0GNGZvNcpGK1ruKH8iyrKJnC
IZLnmufOMrFs2QaIFsrTrHrEzpXETmRD6kT4AtoswSq/43vGGj3zu4Y8U/lQ
a89NsxIXWeJjMh7uOo5u+lrLrVgAtgiDT7jmrO9EpxQj1LYbMixSt513ucge
lyvk5o/07pFRuszOqlbVx6mIkfmVxQgu+k5ESoiED9Ata4ia/xo5ybDcdDl+
+qd/uv2lZSKBEj6EMBjI2Rt0v1tNyAwyLOIwnUnnwAEJFvpzBfIqgkegRbY/
93slMgxGhjOr8ZGo+uujgy1Sui2YLzm6slfmHassZvBLbX/paMJozfppFkJf
2I1ullpiraAGofUisZKfIrXXo25lvec/XBobzZCYS8tuv+8QqLEBbZ9d0l+k
9MGjF3Z/skzGfZJo2NXJjskC33m0NFqGl07aciiMDY5DF9XtpgSIWN5VZER1
UcRpUeszpbrpXT6LtJ0iIyRUaQQUpLRfZIK2vtaAgF2EtevgownIGJMpobnw
1eitTJJI8hq4WL9UEx0imWsXCxNmJwxGgMNkwRa7+N9PfajHSGfYsHYg0tIo
gIVNslYI/+Y42DO94eGjm6etbRp3w4F7DhnJqSCuLHHGpJTKqvyEtTn+zXP9
yEQ54IY6ek0PvShpuxbV6z4wQexl32CI28SkETA590aU0VBEo3FzrhC6Neho
fjYg5CLNkNtuu+3mm28W68iuoEMrRp1NK+pOSQ/ZmOAkStj0UUmIa26LKc1U
WPc3IcFHjiYyq/hDmQMv68smD8U+AbNLpGKeiwy4C4boU0dDtBkA8sLrBjXZ
CiqOAh1QGimridqs6NICzPbcf3U58L46WlCNhu5C4vOM6sUGrYs5U/ccSrzC
hjZiZoCk6tmagjAfP3qjaCXga11Uf2IrNRVZU2uoIa9339E8lPXVXFVCLhaq
nlHdK0eM3Fk3tCv94Ac/GCC0GLs6BW4/93M/12M2SW9maDUstBPPgEnByV4m
4bhc2JlSvhzr3YdM4tizVIgtSWEERAsszXkxKyo5a+8Ici6x+wJFDigkcuJX
vH8II/fK00FrEdYY4PhpYViKHFmbvTIF76Uz5LamSLMaz9198WEWVzdIOoz2
rCKsqUn4wqYl9hFpCHZFR09yTzIGZBbkInG3FgjdObBqRheEHgpm6V/1WYT2
swa4El15jccff1yRV6+LlDYPG4QwoXmSLZHhMcGfdiKddAhLnvdfRZFajdA+
Ws2a6Ap5tEcu3aU5cSs8YYQ8fLTfXfcEuIFHx08RG1n9ILeOVlL/ol4u98Qk
9ivqQc5afD1vrBhgnDi4YZef1BgaXt/WbW22NDMz6bvAFleGVo9dfqPRWL3r
Xe/qddAhJytBPKRaTFIiYxJhdx9tI5iyszrcTQt/wl9T9Wex42MLVvDZewWn
jiaS/PUu3/e0JM35s4fSJeSSBIbq5bUg79L4nnTy2zh+4Rd+4dwYJbQJWFpT
2J5iLHO7ACANBBprq1Ybq2QiBjM2zmoDApJk1RtYu/+aLY5zJUSDwcWtGKFU
MneluKASDrBeVED/u1Mrt4nA80GgFiX2FQ4DGe0v4UZP+ob7jr7AU+gaf0CI
8jNH44lVGZx1GFD42OrGTUR05Y2TDpNiYGBAjwU36IgKY6oux2TgksjXrPPC
rCDbDWYa5rlAvSww3QmMjpbbY4899tRTTwUdsqL9iqXd3W9sZerbfVgdt9xy
C8EfmlfhRsNFKU7TlkAm6FBd232k9rNaTomVdWtijz1wNAhgj8G9B44uqLZ+
nJYpesnIiAhpF6uWZ9Lo7Bm3D9r7ctGP4bwE6G7KZNsZcgwSmN+LQpSt2WZm
5laX3yU3Do1PNliGB314xW4txmZUb54RzvI5C3Chj84OGS9r1DUqBA+c+vJ8
8tJZ6aNHLyGJJBu36A2iEXE2RGUFTdMMtDBFFJvnGZYt/GwGgm96HGQ6YmW8
+93vzpCQTmqb6DJ7XRs7dTpZnoGGFkUS0J88uqI4/08eFcqGUWBnxJ4FbwHm
EpfMQujKGFjbOPxwECFKKevKKsDmmsiGGIiM27ybP740yNa2CdXE0M162cEy
QRuTLtEkDhMMCql8ydFTLtc3fOZo/83FOHdH4ixspq1bn3Fwf919uQ/Zlolq
rrxi2pjnaAZehyyDlIp46XhKoAMsKDPnw54zPosHcpEAl5Nn87P2LUB1ZE9f
Du2bO5/eCTqaPJkQCKXkwt7ylrf0J3Fj5lmTqoWjkuVfXI4+0qRqnLspytYM
14rU1JVwukcHWv04IwGMoMwt4gHx/p/LwfAgh25gPTmHFieE5Wv7886jI5J4
lOzDLOoHDhn59W6YwYl40M7evtMl663cVbcvq6wn00qDoukkuWDn/f9bDpP0
XNXG1s5dh6ax9Otydp8+dYj76KW/Eok/7FNZBgyrRlhs3OD0p6Iha0RYoBun
0kRYQ8BT7KItIPOjm8vlb130hoyrtZLpdmd+dItJ36NVz9uaSzim6NzqMdDG
TxO8XaHfxLLOISlNHoUR+A6DiPU8WgXrZA+nDMYtGrNdFob9gKA1GZ9zSSzF
M8wxEsTEh/+3SytJHxEgok4MN1zgVEYxc8xMnuNU+s85lPuPgxe5DQUTyZ7L
AJA2FZrjp6+Xk6CExMd/Pg4RCY78JAqZ1jaj0QVxDxa8hfnTc+DRK3vBFcmq
CTe+973vff/73//u5ejPQKy3dfJBrkip/Gy48da3vjUPt40pY7VZJ383kfyf
//mfDzeI05Inbbpim4weP09tfveiNGcEhn6CJHi5oNslSM4CigVG1oOSlcKt
c9AfkNw80xhYhisNWIMnUGbcgIa4Yh9pwTZP9LfqSrvwFl37dY9I1w2IAHJT
F4yD7iuHXPDqSkZUu+dQkR0j6+NH29mRNyxM9u1sDMzMM9NMPgXBvnmC7LGU
rvIN4jzvec97xGem6BVutClkR3UJVkfvDCS5MAONYESBW/DYe4ZmZ+9DGssq
sHuO1WDJGNsrRzcu9jMHE2Iww1gj4G7VqSKlauIwP0UvdUMwLGv1OK1XBbNd
vljr0qxEfnzV+h2sHS1x5sBBzkgeRNUteIFC3CgKOagC3A3rbvK8k7uUFlw8
5FysdPfRxsv6HX1UUa0A5oiU0qMoDctOag7ikQtPolBeUkkFTqB90wz/zNEq
zsQbz0SFlHqZvkoqJ/ckMyNv5Tvf+U4mx7PPPvvcc88FI73Yb/WdTYwPfOAD
IUPmRNCBSqqXU6+wzJt7SFDhSXMvW5cL3MxsMJvMTQxOhMHhO2yebL5tA7LG
h8mLrc1weuToOLkub1IhwjhenNIaIqj8wmdOXSnvPlqGsQYdsjNXjsbxS3/c
e3Q5aUJaTWEjb6XHEKNLzgJpWRHmbbdqkncLxrgY5XW+7RQz/MrsRg7+WRJw
BIz7jkaiduetiEmYfvrSjuH+oxs4O0fek+oFJ0VkQ7F8+4LqRYXP3dMusN/t
/Lv1WVB0I7u/SMJkaYVDW4ljzgjLMPP4XDz3SWoYxgX9Hjo6j5ObmFm4EPHi
Pz0KRIiLkhhqaolInNMotFA4cet0P+iQAx3fA/j0tfhv6xc5A0a+qUGgL/Hv
jx6RrJQ1Z+Gt9GZXcTauFgY3DXa9Au+7aumSlXhvX5vPggbMd7YNPXJp8hhu
iGxM1ph/Kio4daAV1covmOFWmaz9Z09ta0y5aV87c4naKfyIqEwIK/R45pln
go4f/OAHQUc/1FU0RHRsZPbf/va333rrrdkeSu/bfZpF+g43u5p+2qr2r7bg
rNluQdgllQ835gWsFNRxVooT/VgS6pzUG+dtSuZyRsw5o6SWcM1Z1n3p/qMV
1L1HV6zpogvGQp51z5GjmZSWBahUtgHBmxVO7Ko1Auiqs0YybpuWzeHVogL2
0XvuPRpkbC/ecltgkBWhWF440dk+cPSq7iOfPHTDJjY4uoh5K2jQ+sU6aJ5r
sqbFPMDv5Luz3btgUCdccWBOKJYOa2q9Ufj7raC7j0YGzmqpw88c6ovnQn6e
l2XChp/W7hTtPnkIwjO3NuyY/9a46OUI52vNNmY4+Reh0Y8fvSQmGjZ+COSR
W5HbxT6FHiInvBXcNsAlCn2WPe89PbGozxwJPsvCPm46evBC8eSn3NkrR3+f
vzhadG2XgbdbRDqLBRTUdDHMNZ8VSJx3Y1GsuSr2gkip2ySaYWlsnvMZ7zp0
OO872hAgvS/iwW3RnyX0yG3J6hAs7Tsb+eZSMyro0CG0Qz/EZh0p+CBCoEOj
IlZHBnz/CjpaAgjVLnyhZlvMBodPN7qLMOk54QJ1+SwGZLgx7VZ4Igm11ngc
pVWejiYxl8S9WINIn8U9sLrd0M6zGShh3V7cgAjstO6kG7QXaUyaS70N42LV
7ltc88gm/7X42Lz7Pz+ORWOA/8NHL8sGkGbIZJGEfGEUZ4Hpsr7MFGx++3IE
Ahoq/fPL0ZPuV9sry7+VknXRDe0+Ao3bL0dvEGrQPgmBn8fhGHSwi85J8BXw
uoQdXE53R5aBqfyJo2/s6mGnDz8ZKA4RlHiBHBBI4bkADdaIIM8Su2Kn50I2
wdhpfHFG0MY+chzr3CRA2ogtUsf7ht5M3E8c3T9Vas9BWx20/OOVowX5laMT
4nmDU4zPSvFmdStBB3o5mmVmtojfVL+EUifuMWqlFWFJMntWoDGi+2g/dx8t
Th44GhOjohFVlggOPYKO3JYnnngi6OhUG/YGJ6OiWdT2BD3yVloyv/zLvywL
SbVDv4Bf/MVf1FKhmZk73Mh3d5DkXTurbBwnhvpZrANiwDem7JyyiQ9ID9Ek
eeRozI1UNuLKyOprOLs47bDIQlvexzReHFt0wgnbIJqozZPAId+ftNE/uxzU
KgKTFiA9Z41HZVVstWwb/JDPno4FCT91HG4i8wOZyseXL1PgxoyfR79quGn2
Ei0c8VUXtnCvu6k5V2ce7mUpAQ3h0O5m/6X2JhYqjkq4SQd2GjtqZx46Gn1O
l8YxgigM3Puh9MhFyHsLQeORjugCOhYzOSOqPR3rQ7gSdKx1C2bXGiUowsUr
w0QdcX0k1VWjiKUgkomujLl6xh+sVGdy99EAdLSNZdN2zoDFTmTT//TREsgY
mpwsloVJl4J88OhrpnpU3QT+eetXjHTTfqXocMMxL8biUo1rOeyYObTqyBke
HFILEC1TLCXb4+mnn/7h5cjwyBrpRv/HS8t7neAIWQcdNH8CCiyglpLefwwP
XPTe33/b6fqGfpqvNProQ0dvR5GE5feNydRFuurebxLy9OGe3erLR2vv5Y9Q
T9nAYMT4jGPmOSRZ+fl4+47RSPikXzk68d13aTPR1MpN6wLhRgZYQKoTouZE
XfKUNpdcU0YtDMvwYIp8/tRZWAh3Jb32315ha1mhYj4PHh12ODU2Ynv0nYey
q2wL174ZTmRDbx2N2LKUulmdsMqvlk//1abN7aMeQJzH3tp6XPRAUnviEsPD
Tx66EwJZM9eHG/xuuEEs4sGjY9Say/z5oTQoVDhO6ccOjesFZgnNCTusynUt
mdS2818w3wYUE+zyyiBisQ4hWTHYRV9Xyy8L0xum5yCes73AGj+rKHDM7ewc
Z1GsEQBsDePZLtDBGrcHsVFX7t0C+U+nQ2hUuAMDyk769dNhi2RaW49rl+CQ
vZ3zdf/RlOQvTo0GdJWS4gwoHn/88UyOf/iHfwg6et4JdIaNGC1ribl1vdeN
hSQUw2NdnOTvSNc26/qGT1zazm7ZTlrEIM/JcmK9bT1ryKXakY28ap1Jkezb
Vo3LcjB0GzRG/pwa2dt5T0IQDxwKrkKsa5fj43zD5kCLSNBYKfE6W/XKO9/5
zgakrRkja4XknzvaeI1ICSvMhHsPMY1PHY177jn6p3RwkMcNnkH7maMN1ix5
vv9IYkz0Bj+sy2BA98o4ZCw5217n8ndRerFJoyBsdC18fMK8in0cvMtV/tqk
mN+L05p4znO1vQqpNDe0lTx0lPpOuULcZiU/k3PHKVU7MFJfb1jHpdWgsTr4
LHCDMk8vAg3kDY8iJGKw/+upS/ULOr+sIBeRA2/kY4ccNL+Sq2KJsUPYUedD
ck3sRW3Xee6xLRX47KvmBwGcc81ak5nYjqIVa5lS8cpFwYK60ZXML3zKSScS
ha8+icItMfak6SpbStYYkypH6dvf/vZzzz33ox/9KOjIYenben8jhvtEteNn
f/ZnWzKtlzCkHYoyfOZuZm12b7iRI9P+K3Wbz5J53LA3w3l5WwIMD0UZA1jl
q5OOV04iyLBKbSh9Vk+aqTA41frq3P1qT+DA0uvDjXGke4P0ltuBYCb01B1s
6rZ3NxQUF+m1hqWNSRZXtllj1byyNYvyfeZo48V4mODkQGP4yT5cpBS3avKk
S2UOPdTiMS3O8UPBDctEYjHc6AZ12iIznWpWYsYkb52xoeFOsK8RRh/JfCID
SPwZFW1yysLdZ9/TzshutE0ASbwaxmSDaWeEybzRKQOs2E3205LnbhDfwLpn
cgioinCyFly+EUAj9yXzWc4qxD6iqsXB3liyde0PxHZmosATbFJIotiQuWWb
WHms82SZMKVW9bxe2/Ivm8azzHkooyss9DHWseqJNZCdEDd1uw7Mzy2KvzkO
K4WEZrP9zAxBG1uNGyuIkcwEQlMh3wdzvvnNbwYXzz//fFbHM8888+ijj/Z6
H2nMm0JZHXTym3sZ5y0Wot/vfe97NzPJzVGAIdrQJNQDrrG1BKQVFp+ZXBgn
UTSV2UYiSVrks0cBLMvE2pk8BWAclnLoQISAKtxYO5vhxtJh7DEBpTVQ+Lu/
+ztKfVCojzR0TZh2Z9DRIODkhxtdNR5LKNoEUyo7HYzRiQGm5YbWwnmEn6IT
rF+m+0qwubdQdxu9GhAm9PZEkX8V37oh6x0M0ruDv/Irv9L9YrQHLKpiw3y9
t7qPeaBkANdNyRY/hZARpMU2RQg5XISbMGr47BBPjee2qrU1dAfPVcMEDdYc
SjCT94HBgmR759G4jRuiloS9AUWXZxGdEOhYj+kz9Ws6ogHCKlD0SREvPTNU
8d6VihNZ5c5g5S2asYD/0ug2BeHrcwdht5gVZ0Of12Bwpslw7z8V+vj0IQPF
opD4wEtXzKXwZBxymhtgATHbK6IlE/CkcMWXmZLMmZ95rm2hzfXYY489/fTT
I4Z94xvf6Jub4Q17o9cm9Wu/9mtUBPn4QUdg0j7belnDL2xS+Vm6De95z3sa
ea0S7znaCg9Iz0MhJsbcFdAQMnrwaIPIrpNL3XU9fLSeX64WgMxPcQhcsDeW
oxk37wViKXq7qDeU5O2b+4luffOkocikbwSID+ik2fU2PrfffntbuSiiJWYz
RWwQ2TjXX9936nP38aNR4x1Hv8jVgAgJQh656Y6+5FOXBiv8+rVcJwMojdJ9
meywTsGqiprnzfbMp8450PilX/qlQCMvrFvZ+bM0pHrnYuOQ3H10Uuaez+U0
r1arONkHZon4BltuIi3m+VRQwKZUyDrYWtpsiXVg2bpz7auXX6HKzDAfmSTp
+gyKqepirxU1c2Jt6KeCzgLBeF8lfr8oKdCINb01u9QfoZ8eL24VsiO0LPhz
59HTkBX38aMPOwIwK3c569WpSd+vEnxLabsnXpNSUOUqIIiNYcBXlk4kR02H
LElHGLJQycJQovSfP9rALcBCz1BuJeh47nL0JCOkL2muNnVbL81D8puhR/sX
vZdQQhol04JSVnCBmC1YSv1mKVqDabIZCpsy6Jie/8q+2OfQw2a9YIgQx1I2
Xz668aqMY5UZojOGfPnoAM444RD1zRpCNYA0yiiUEjCZ69evtKjbkjRNCDGC
jre85S1KR7twJNKmELaDC+xC+MJS5FL24/2OWP6Jo1vZyu2FQFVhN1s4evL1
4sO9YsWxw22InV7GBpKernzINsh7zXBFrO256pK6WbQCAr32UB1GWl+dksHf
zVqt1og3o6ks0OQQWP7y0XFsqE5P2w64wadjwOqwHZ/7zG6LV/QqXiHcQRhH
eGdWB++G1bFOClwVYMICIVKKu441Cj3G5cByl05ik+yU+mx3PEeV8moDCHL1
vuxr6S3feQhWC4AsqLWENcNSPKdjaeulRUxjvdtWyDldhdHUpR03PabMI4gx
agdUmVIWDPnLSy/IgcACrWNDffHSqJHduLQsqS5ip3QL81YwOjI5nnrqKU2R
QEfTiQhYcwwDqi2MxFy7Va8HvKGHjkUq4HDDBNxC5u5Od62pzmxgAt13ahbP
WOXhLvH3+ZN+6RePjhKUPSbfYWz9adDWUE998bnaSHjHTZHgNtslqRs9Ikt/
dzkwe/XU62sbtKZN+3gXyFuhDI9JpRV1K7dp3Ih99tB0Gqd3W89fnGSItqEL
pq2FvQSl4ouzzCBTFoe5z6oLk3Ac71G9PHOCAk9POu2+rYHqq7oXVJc77VyV
nvNQ+O+9TcUEr+rBo3/QWTPEYS4tezXDeDKq4htfOfqcmpDTYKHXLUzKhSeB
zvMaQZSLMaOCyAB8kFplP5x5nsuDSL8OTBDI1+VtYh0LkLJDVl43g8ebWT5v
fvObX/va1/7UT/1UBqdkgabkU0XLPkFX417dfajWL14hzul2M7Q+dnRp/9xF
2V5TDJRv8hGrU7v30G6d+Bs3n+HHm7AWEBKEXscKI58FN/pTZJWA54pchE34
6azHudiiW325JgVnMthTlyPo6BW9s/vdrr1x++AHP9jGRARMz1BMhvksLZxG
T6WDylnQkWnH6mgkBZPnOgnI33X0gFsSjdU3+iszeN4f6+JsTvBBwIKaPq0Q
XPvyLyts4d8ZqAWTIfBZMgW/t6MX+2+n2uJqVdK9EeIIQ8JJYh1cMwUdgw6k
mnNyfDVfC5jzgtfODJ98HabYKgs8SsQjp40HpTlyuIFgg7xHfkenrUb1U5eu
skFEdiAdSD1TaIA34VtBssnuzsouFtpd4A6MsJMfOfS6N2N7BeaAa7dMRG7y
/jLvzFrWy+SG+CBbrWKeLIo1bXFMQHXdlM6HBBOrg5OC0+VTiuV9cAEiQVHx
DeUwjJlJgtx0000/+ZM/ee21115//fUAhOWpJXcjP/YLROpaiNAy4cx8EfKV
KSGqARk3WjBZF3vQ0Rjiy33qaLpxx9FfVbJpoZItcz83pgHfZEQawWqlKJkN
JrnlQPL3HIwa/8FNJ/Kjh9q3v/1t5fYdSmh7zHRv7fTxLryha1q2OsafbO3o
VdQrWmz8xm/8hjkZXDRj/+XlaL/LvA9YuhEN0V2XlvezeO01WD0TwNdAcBI3
5rCIroknHGQGgg7z+ZGjYcTsBP9lxX39aN0rGS2SjHq3MKncCrMNFHNberE3
NN8Ch643wAw3Mll/5md+ZmWADU52ly72I/ncd9Hp3TG67PL+i6FtK4EerPF1
Zv/M0UyWhW/EVLGt0WGWQxjeaHcy6l471ZChFcEF+NCHPpR9GPgzBWkAavna
Om3YId44S2bd0oUcQzwcUTunxMyYMzi6o9gpIodbZguj2WIm9ylfiCo/BwQg
qH+37xMOGqf9z4/GsjYaY8Vr85Gx033ntL8YLXycdWeQoOGtUPCQjQU12lZ2
3HjjjS972cte/vKX9xiA3HDDDa9//et7sccARI/dZn7250LNtCVxWlibI6if
GTiiN/M+OB1CFvC2kR9/TEaeiS4af44Qfv6QBnKbxhtfqRcjhNQG3Mh4oDr4
fx19sXn9rESEvZmdynVbO31qUskan/WY+fHkk0/2RKS0E27cmmZEwNpzWy9v
f/vbQ48WUVjBYREM6c9zTUc4IwvTHekucNDuPfUgY4DhEts4ePcTEW1MUF+W
mxa9t/8+cojMS3AvS7V+3C+wUoBqbwAd2Oarr5emgcYkU7SuYHI0r2hZZKN2
+Rik6tN7sTXbZTZVmgnqHMdVuPPUtJHh6haPlM5zsRmR+TLb9UulvDF9GOnL
9VLMYAjV80cafO3n6LM1e0WnWwK9IXhH2CPnFQaqA21zpLBx76VlrcjDSpWv
HHL6TJ2RRe89+kAJcYylM3WCzWEb35eOJqrMSPeie2onFeJYzZpr50QwP2zf
hoKDj9w+ddZFSEQkrPezjwMfzibHKlZW7zblQBW1OGDTC73tttte9apXvfKV
r3zFK15x3XXX9TzDI/To8dWvfvVrXvOaAOTmm29uQ2l6iAGyQPrCyRF89iQo
IWUvXrq81WjDMqe2/ukT2nM5Oy6EgWp2rSpZXIU6yqrtZp/jgSCg2hk55gur
IuwtO+DWL+mpzkugg3EOfxYs7ehJL4KOJpjplxWBTRrGgo6GqPHJxWs2Nid5
K8Gv0nsVEDkyvac7BVpX/gk30HrlzYWYqFgsXTu7a57+w4eYmPyIGP7KkIm6
o4C+QJ/QHdFjdyODICGxTuZxgtKNTG/rxnX33/e+91GG7+qAxhCSiFaLscmG
/CkqPotCfHhEiHNQcdu0oLH0Ci9+0MGlveuQK5cL0Ogw0MjeQ+XqZDKbw7ff
+73fk1zIopCZ7QwJDvdnOE/fpl9haazAkKOhEhBWyKFLEWIUTEGiC5xijLsw
0pr3iwouF78QPdgHU13y7A3HskXrvmQJU0KbtgnAOVtoPriK+LP1omnUuR3t
2sKeVX3OJFIT0jC+9a1vzbp43eteF26wOq655hq2RzASeoCOjje+8Y2SboSw
8hbbUtt0kMcUMI6lOat7IQvYYslPTHuqmyQi77v0SFrySJ2UuLqRkcecuf7I
0Wl6VfMyquduaMhjI6vrrkKj+OFD2dtd5vX3L11OJp7ckgkxhEk78mX6wqZK
Y9gsbU4K17fhZqs3nj0PLpqNuSR2ZKLZbJKeK2ZpAEMeqatggT0PPz926RQ/
YXwkGQnKFU4icoiFLtxxrmEZSWOSa8IXqzE0gGf59yw0oqa6qzAUG1h5lka1
oQg5G5Y+2Gk0o1R2dFEzTdtcBDpkkZqKnfbqgsfWwGGb2MuyYw5BbNOmW7+1
YL/jjNuIV6opIjoPhQ/VmQQgAXhvU1oetnR3ugUa4EoA9cG+oe/kPI6h99DR
N9A+JS4tvrGKYzEZSbFRgxaIHm6Y7RLQnz9EBWHmFoKrvvfQTeJQWOxb2spG
EDNsr3cdba361GrqxxkTvvBVohzL1YIdkef5JvgYfkhhy2Q6MMzhdjda76HQ
I4gIKwKQn/iJnwg9gpGfvBxZI9khYiDCIH2k/aWboi8A0SfQIS3lpksvGk9I
Mn0Yfgck5+L12Bj2JQJikFZScqR9IbXVJH7p6EsrOq2JyXqhDjRGLh3pVMsV
VrENZXoX9IVYKYjBFMnEPUKP3JZ23sU6gg4OS7MUATtobeelrUcsS+ZlNomc
YK/3hrbsdrquVFRnZZUm+cxLkwHCSH9TiVlCubX2l5cmj2s7da5kaUIiHXHc
JGWghzFhckxqXmNW1iCOGTLYctyNTN9MKk2AVMlwl+nqwo1WZS5b49Myv+do
3XWOS//FIXrvNi29vvgA6tQ9R5sGa2GJhnUDoSB6FpEOyRUkNr1ph4oiNu0b
8EZe63DsUApXfWGrrLG1qDkXFvU5PzL2y+r1zikheSJ3ZBq5q3QQW1uw7lxs
OGWbBZAndHYObwpg/h/HQWNtKtCfvmidnUnmIiRnGXMkT+knsUqheOr9CKL/
y3FseOVkJWuk1PP7GsDmue0ShmRdhA8BRaARjPQYhlx99dUvfelLM0V6JUcm
nOmdfQSkt7fqRyMcKhbtOHOJFwfj2372JC0rW6qe6+5LN08mx7m/uU1qNZ7M
DNul9SJ4AkMUeiwoOjaUHW158wXMQcdy6+NQ9bVElR977LEnnngi3PjWt77V
K72z8+mOZDbkd+R9NEv/i8vR/stcby+mXJHVIYKqIiyfxW7YG7KrKbkhhk2T
XGKFX2/vEBsUOGV+LGFhWmKwSEPj2TLnBqpaPlEdNLdt9OvbQpOtSxapQ2rF
hOxLAha2XN/fG5rnnV5GPkKmMje6HL92OdStNDE6275HgIvTxCxXaej05Ist
z68cXcVlGZgcdk+pSVih8yD3RCaLEuDq/d/xjnd0eg1gA9vHe1tI3m0aO1Tn
X0q861f1+dMh2rlybCM2tcZl6NhRc8kBMia5CeYGuaLPH32aRmJRDnyuxRC0
eQEHQ6hH/FOUeARs3mt/rq3kospoYEu8MmJnzCw6iiB6xo1eGfNcR5VgB929
CU/7ThZ7O+Ob3/zmkOHVr351LkyP4caP//iPv+hFL7rqqqte/OIXv+QlL8kg
yQjpPbfddlvv17kmu3QiqPec2lsIHQsX33eSpb3naPDh1tCRkMgGg6wp6Xt2
C57nuTIFNVppPLoXWx1fve88t1TGIF0SjSE0btUQab2Q/upo3jpWQz7Lk08+
2ZO+vFPtQoKO9qwmra73jSEFSyXbIQalrCVfQIfmkpiKQUemcndz6YYzJcZN
NxQ72KjolIJID196MZA3ERYW2HH+ItL7Lz9OBcq4HNNRp/6qO6Rdkr9vHKRl
MVv63aYTDfBM0NCSUlbzqhVKE76V21zt9vVtok9S2391aYY14i4j8EvHMQ8L
E1s5BvVgM7kRCzd6/PCHPxwg6HGQCUGZR41hN0XxZssnhBnxBhkv24OiJi2s
dWZZadWCw3BjZGZjYgOCHrxsm2PzaqQavFZgwkqRsVrtJ2LDxDrm+Kg9cdgv
xC6scZu+4Mb4VHCYHME05DEcRhKbpTENQNGSNaMXzVg3NzCCG4b9JSKnSJzZ
3I3upjfazeemt0KMYOGWW24JOnJego4Q48WXI9ujV3Jhclve8IY3ZKhQ8W3C
aE8jLeIWUKX74kUifv7LAkrnkKl9sBHgrFkyfdWYqJDc9GZdrJ20pOHqhqyC
2e2jTGOQPnRoiTCBxsZcbe/QyYLy2dZa0z7Dg+gQSlgn1qxrJrflBR1TsAw3
VvYVOMjb9jo1DwEBmj+YllnaTfIudl29JvgmNW8omKDz4BQN4ZKxwbR+CBxE
ctaQxSVQaR6tq7eBCImVNcmajjolMTETpgtuWN/Q2xrn1hpvBce+yzSRMrS6
ri68FdrybIga3sbtqaeeCnj//u//vt9dyTNs16JiUXTG0heOPlNU1lVMUKbK
VGjVK5Zv8Fl9fKWAulPqnQ1RH2/mq6zpDKV7skzkXkOhzs10RXueCsSkMxZ7
Ya/y/iaKYkZxwIVHkIK6OoqRvB7FDqIlcONcDIvFeq5VWaYDboxbDjRsK2iZ
q1DAqfO1vh89XuWLBM1iHX96HDyg0cxENjg16yG7ShmK0NkVWRQ333xzT2x/
iEztmBoSNb3bH3tD+JB7kpPyssuxGAjP5TWveQ3yWO9Xqixp24Wb0niMX7o0
j54ctANUCpGxUbsvmQFwwxVRvm0o2I3Wssk8BqldlTPC9xlT3bG+TqtbWUKN
XQQ3OKFTxFJTIN0phtB6af4//vjjPfavPtiN6zybhLa8DAyUMOFQUf0OGh02
ROlLnAcdz7H9VaODDlFi9Uo8U8FwkTHGBoQxYe4/mlwLEVNwhRtQlErzskXQ
g1+zqsB1tyHKClh4N5kEbHVsnFBUX87u1FwAKka0s4goLn/UBG4wH330UXVA
OHWCKsP8vl98bNkuu3kX2ORXyr3e0H1nm5TitXAA187UVSzfElMfQT8k3OiU
KHqFM6FZiIfUoSvKxC7uOFqaTllRymOSuaOOqzo55wd9xKZzTng5cESB4T2n
vlQLbzI/FB0shbRABMuBCy/mA0Y656lA33P01+b+SDypfPGR1bv5wtHG9KiC
G+wQbFLJX74S+hbe13XXXZdF0XNymhoBvO1yCOWFKkFHyHD99ddfdxx9MPSA
IQFItge/prfp0awlYpjPvYXPhJvOJgcze8RdE2bEORosEkAMGAVE412f9Xsh
hk1hSil417Iq1tE56QAo3FnOi9DHePKL19lu4AZyqWYKPH094DKbqT1wTAIH
FXB6RHawn8PnXvzZ42DhY3e0La40TDp7+844e2spYvRwIdQyT49RmfA0WkHo
Om7r6y0/Iu8s6YykQVVegVuX6V9qVSRqxYLETHqFtzKJTrEFrSK60gBTWrZN
vykXOOTr/ehHP3ruueeeeOIJfbgWkm0Nfv3S0WDKnFcugsOio+tESSC3I6sj
3Lj99tsDClIGKmUaxma+zG8j1nvIpAiHNi0DjXAeOxRNcSpbPIJPHs0oVcRM
zgg+CMsLDa3T1vgeAQ4KjTTfmXP49UOCvo9/7iTRfO4T8Ymjpfuq2AS1Rs9Y
QsTzcw9NdoutWejDn/s4hPQRW/O0CKbwszZw6ByoINrzkUZpmV999dWt+muv
vbZVHxqcqV+6poYYPUq4nKkdPemDP3E5esL8CD36kv7bp1RKqifKLe26BOdX
XC87vxJ+/h2GxpWjDYeqpUkPoclJPdiVVvJ5LvOcBA32AhsD1G/TlO9bCuzh
oykAIab7L23OmMqgw96Bv70Cuua8Bmp9sNudJdDWJhvYFFX+FiwEDnr9KJXl
sCB19MQbrLXmdrtzszrk73qR6MRFR92ZAP6koj51NKaXDR+5ZZkm2+IkRzoY
FfCBafHY5eC86MLZc69/61vf6rF3LmQ67nRj0vOmK19AWrZLoyfwS5fDLt9q
zejtrgUR2RuDjn5CmgZkGU9JN9WIq79WDK7JiFLujIowgbEhLt0Y5iX1eh/p
G1om4TAaGIfx3e9+d1aKEk6JxeW4JaqQt5FMJIvNnK4UaIiMccD5biigK/U1
hx85Ogdxq3vCvlVX2LeR7qGQcPfR/3ECAhMaFchajtVMYGnMQFpZujqgaZj4
znFgcK4k7MQP5wJjdCh1gRUytiIhYETat8nW6m6li11IuXaADhHR8ORVl0Ni
BamjfwUjPBdplz6V4REEYZ/2ZvyxbI+sl+5md62NuOXf5dx3NEq4/9KBBXhS
mkVigR6svv5sxLhabQ2rfxHueODUsF5dgCLEESPXSWFV5O7y4lrn7NhqzbBE
eCt7z0rG1rAVzVIAFt+vIe0WtBu+//3vpxWmqIqeDxtDQKnXFXfzx+kQSrUE
HcFOc1thqay0TNwUnM4uKmIYj+9zR9tEJ//IIfLM/JDO4Lmg/Ysnhw+5XVra
rSlVR5aGmp0nn3zSv0IYcYmvHA31hDEJ+7SWW6GSR7SLMe3VBYeH+Rfdys6z
Lwk6nn/++WeffbYnfX+49I3L0e+uiMmyuuvo8ChS1x6keE2xfMZGQBFK90O4
AYEGB7kZ1ZPQ7L87Ds4gSrkSLQ67N68n1AiHTQPLfAQYTOPpaq6E6uun3rtn
ur74G+UH+9QKBCQLVtgovInB5WS4TrMrbBbszxXF2ziYE/aUwciZfI4H4pIn
niPVslAAvhlOu3eOM4OFPg2QJmq2QWv/pS99aes9WAgBmB9hBToHNilYEMp4
wxvekAUSJvQYegCW0KMvkXZ58YtffM3lEDjtbXk6rYhc4O54p4FgY3gbLhe4
IA9fzxKQy+606baxOkYGY5nPv2BFTMJRpmbkDY7JVy5d7Kek99WjsTJKyTkR
j87nXrOZV2pq+z47AmNVdd+7p/ngZMBx0UWNKIbxXHQSFEvkttAvRfDQYrKl
0d7KD52xaqz+5DiWoRMdNZmtuFEmeG1/dfS7PwdIVQEHDu37LV6PLWG+Q/9l
cjiCDrocGmVOt0qCICRv+unLjEQqYtY1BhptHPomSLo1UEHQd7/73R/+8IcM
j+985zsBVL8ibGJzbw5wV11yE2AVryIbgUZf20/8V5ejn27YGxDOQkMX9gbg
mkb1JNBQv/ZHf/RHtiEjZsHedXTGRCE4Szyp8eFuYJh/6mjbfQ6QnqWiqBPA
DZmpVQSImSB4UHXDhebmeOWTR19CVsQioj0q/mUSiHHN6VD1Zp5I4kvKYH9t
+S9CMgbptqGJov/HownUhNNnrnR/3/SmN2VdhAZZF2fTQvgiKMDiEMoIScKB
jA0uTIZHf/bYN2RdDDpe8pKX/Pjl6CMMmEDm1ltvbck0kXL/A/xOWCoW1U00
2wEWhIn4KTwvMIivsqD31A9YgMuwc4jghtUN5EUzRuf46tEHbemVs8bC/acO
U0IH6j6UjInm2U1WKtLbOu1GviXfboidqMVbR8igmqNHVbTNeeHoEMN7Wm7d
l/6lO0mLpRGYVP5KRNECpWgpUoqnqTnFrVWAI8bbJcs6MZaYGRBDBV9PMjkw
6rkqss/CIDBkh4TLqCAPXXql6Q5pf8/SQGLp8t9xOfA6FJF15t2dvp9wAa2k
oGPWjq/tPehMFovKtRDjve99b7+Sx9Hwwl5N1nqxecXN1MRBCVu/3k/332CN
UBWCqIgZx1m1i1eWLX3g6Bh+Zv5cOXpYL/s2R4aJa5pN/FYgaJF8vLsvnhp/
PHj0U1idvi1srSKWml/pKOZ5gMD8xvx0MFFkbNE2HIuxMyReIP7zJ0cjJwfX
WIhjJQ+27M6qwezmEt295ZZbbr4cACSTI7jIZlC6gvSlgKU3hAMhhudwg18T
SgCcQKOPvOJy8Fz6QnGP1o6uN7//+7//J5fuogzsT186AxoBFyXJeF4jEFW4
e5UdI9KgGfAp3N+RQ1Y/KzaLazrcmI/zwNEdRrCR1XHlaAogoS+roke8zZfS
xbCo72kOdP5NzvbE5rY2K7kkcAN0zORAKlg4Ueij9/ev7GrQsfDXMrBsM57v
hssU2n9XVmzTRJDTQebRRx/91re+xQ3hiYQYOmCGHi3nVfZ5VGXsqjXl1P5G
LW3rpV/pR7lp+aTI3qhBIcY73/nO/+E4+q/Kvga28wmUtNLr0U+IBjA5FC51
09v1eCha2OT1NLAU2Bre0KmfCBDuufSb7iN5NL1Thqt/YXmFG2QAUZgQvWw3
MMpOxGNFe2a2sU7PFgKVS8t/DXpwimbcTtZgmwsLbdPPhMQwX+sQmxQfbXTQ
VQVCUZiwQIdihAl4jtaFm8GpGedcYncbNExehT7DZtUxHBlRghVoaxyce6im
uBn7tre97Y1vfGO2RFAgUgpAhEC5LR3CGguEqokLFl57OcQ9OsAInyUY6RWx
kdtuu62NtXWh4QgFTsENQ6RrlW3UeulaBHAsEPDCVZlw6Fmn4pFDQnwGxvTS
u31yN9PLOsu7jd4srIQYNuKfRKciuNaOmOHY12Onyyd25k11zUcaXrGO6YEr
wGfJ/6vjaBUE40S0er+CzeyWprqAttu9wh/S1iyQaestSsZ5sZQ4aLQ19L2a
9xFoBBfPPPPM906Hlna9zn+hJ6Byh7lFlKNB6Asb28YE8abZdS4f6xL4KT1R
EtKW0cT73d/93eZkA0t1bQaMvA9KCV3TLkpLlD/4gz/QtzHcoCe8cph+ou/s
C/HDyR30WyGGTq99Sh/DRlKVqLIgTIzROx84epCN+z3C56rblH4veM7OBA62
D4bHsnX+K/XPCDnvXN6pqgtMDTdwMO49tTSVZyF3YznYSZclWT0setjiqOP/
IB6LCWAm8332HkGShWEBzvwU9cjYSpmO2XIBOABpuraom7p5FmHIAGTGgxwK
3JBM8aT39OZMEbkYKRgBE+la+RpE0ze/+c2aGak8apMK1jggozzNlHIV7Ksx
3zj16/AFNxasZliCjm6uJOw0HrF3VnlkH2FVysO6a6LHQmTTw7xyaWWiAi7Q
sDULGIIm5aXNn+ZYV8RhMc+FQHW9D6IlYSUdWPU4Y71BGCSrQ1u0VkobZXvu
MN/2tIz/GiYONJae08biwUu7bRpKCtk6Z7in5jeseO6555599tm8BhhC+gxu
uEyMDqt7ORfowU5QubPK084cYhBODD9//dd/va2/hawhWgu8qxAHQLDp3GzN
4zkIb65vYwjQhNF/rfGZT5eB0f1SHdlA0ToIdfvFICXMaYcKfMDvRy9C5dNM
tl94XHmmVb9C+MkzjvmMiH4WJXDy0w4Vo1aHhfsxWNj3K8lRHss1VokvkbQ6
6HGJbZqIYasA5b3KsIh2riqBLAP+mMDFQiXyC2ZO82qllGcpj/9wtHoUKZWH
7XboiNcgr5eQDrxZgJvDb3rTm7ITkDeyGZC+lM3KwGZL9AgZWB0hA8qH7C3D
g0ZQuNEr45u1dpan0998jLgNBfSAtF2Lq1hNn6W9RQ3JJ4S1zPvXjxbMYoPY
X5NTcDc5tqvqRZCY+DwaniybehDMc7szeR/LR6qiN/T93Z2ma/is7j6g0E8h
37CxDT2WtSQOhq+L+6FYrAXSHWmhffCDHwyFQIeA3gJo24nm6PFfRkfvbbPJ
lQbLwKray00YXIQenoch4Qm3RciUN4HRgfuBMNYTuiU9aeE0Pv1iU2uNBjIJ
gg70NrpGrWgZZyx0DuCCA8LRRDa6ut4j96p4LStCUAhNqBezxs2ELpleN1HH
fq5xCzeI14mFYsqBgulUzwxAEmC3nGHk/lMnKXNGOg/n0LyyN2H4S9r6tpnB
Xzj616xubrqv0rIyONgg8iy2LXa4vM+5/MQat0fYOLbkmessCmmRZWGWwVxs
hMjYTHr7DpBBm8E87F+LOvYiKWP3JQBpnFUJES7uHjWHW+NveMMbJFDYGEHH
mOdXXXXVi170ov6Ulwlk2B7SLkKvtD4EQKRaxEtbQaSimkidA/mUpbCxqffn
skviP3dcGv1MwmLT4CtHT9W/OTraszqUG6wCbgqEI43YHR46GkhBJHdQcHL2
ZF+VXdEWLC/QWmN44E2JH4Yh/URn2CC3RnRjCRyUx3ZAj/5ED8N2CEBaEW2m
quR6EnR0I4gN5mySTtKogsmx5B2nVQ6ChTbvZgpsU0ijWKJkL6BYfLLHEINk
IieFhFGvs0N6M1UBgQ7duh+/HKFHV91oz9ZSFxxuqAIONIJBscoGpN2qOUmm
Y0tSrFu4EjEmeyMo0Ne770HVCIh6pU0ET4wMrOYUvd4cDmR09VUs3/IR05jm
5MNHv/iHjy5saMN+fZIm9x+9ZiaMTGlNppUBRh9pfKEvXvo10JuaBz0w2TEN
MSAJ24VHPn/pPS3+Px3FbRALZYxQ+gKD0/YBTyY8SFgYb9Ce6KtWU79QydK7
K2zpsxSbVQzZxHXjzV/48Ic/jFGjtyaEp9aow2Z7ZaZCFkXGw9VXX/2Sy6Hk
rQMmgI6AAv+8I8zJxlipPo4HNkjQYdttdTSXmmltDZ0hw0xxyhiz0usCRMjn
wqpSIQLgotl0J1AlV27J/AApXEt38yyxwiGdHrg72A+tE5+5J1wWdLSmwo1/
/Md/bINu4diLhQ5EP/760u++wQ+cpRtaRIjoQcdbLkfPA09Wd8fCHUSrevSK
cEf3KPDvRt93tE285+jozfyYaNh0w/gsjPPVbLZFos0LkDKcFOAInBIQwPsS
Ow00fvCDH8DJXtHnt0smksYayZdp7XRWzUNtSpgcULGrI+wZdAQp/beZFnR0
2mB/gQXKq83qLrahCwFyOho9UkhUPrJRmSsNRVfayDRd9XjtMTOPwgah8m7B
Zy79N2mPLHtuAswYkJ67cupTA0/8C0FoZbyj1W1XAh0U4NeQTnZmAZMpVfqh
c0G9aBvLx/yXxVjycWzS7aHAYSSxxbg4JjaRifOoiF9UBD7sG0Yn+9jRNHOt
34RVe9vSBxjs0i5aWTXOODY9Kj8MtLVM7e5nbOehZ0WgeWRCBCBKZRWwjATC
qAhn3vjGN4KODrYH3OgJn6UvBB1NjG53CAYYGZYGzQ47ABliTB97QiuzNwIN
9GmqGsuqLOHOu3zo6MLQK72tbZTcaEugWbHCRnpcfEMK231VX96ie/7551tN
rTulKy006QllXJQ5mdztmzoP5ozkkvz05fiZyxGYhM8Sl7Q7Jm6sqZPmQd2I
1mNrrdNw+SOcYDPSIpiK9WhjbNdGEnQ07ekEsjrIMmdgBBQT6oEJsIVH05We
SRdKXSau2PPpwPdbXIZOWNJZR8Ue6Rd1LYKlvSdwYEQJJU1wtenaDJyEWiOA
HCIW2tXhpaP6Nyzys3komoBnwTaXWi8Yj9NFX3ZVCcy0dFbkyKcTY5cmgxg2
mq8eTb3ZtJwULGVBJM/xydeNaJTC1UP5LWF8eDUJ024lsUSyzCOGLbFidSwG
+H8e/akXHlcIKaBBdxST3GjgyrJR596ufh+vY7I/TA57EPRbaR5fBlcEKR3l
gw6be9d22e1oVjelm/OZCqyIsELutSceZVukcW+44Ya8laAjZ4ftIdy6zEtf
0otBh/5fTSeKpgGX0DfZH2lu4zbN2zN6WzhyB8pStHCSOhR8WIk9gZqp2Y+e
EQ4gNrT/tsO2FlpZ5JQ7DfcLCbwTUMDeG9a5ScmnfIRIYy/23ywT4Q7VHF0j
PliggSw6aQ65S2kI23QvNtripSTXWol8FsUUiENrLjBxzpF5VkM93OtaGjHK
OY2M9EoXS5m5SyDLjN2hHidkYHJ0XUEiU4R9BXZCj8aZcFCLS3olB0F2o9P+
by5HF6VuRcUfShgxgbVLQJhsQnaNWREhQJfcm4U11OwHCE31VlMzhLvdFCUp
n5etqUe40cebyXSS5U+l2Nbr+cFDDvRsbEiFyMcJkc1eHZj4knMnwXH7Mb56
/0OnDk0Dpc3bqTcs/beKCfIjrOsXxNnGJmVjLMphP53VcSaDSZooOaE2/KdH
U8714PjTS2sVDWRXqzINELmY3gM3PnUcd5y62U6icHIf9AZbyAHIdHeb0nno
WRSZDZImci7XXHNNFsiP/diPZYSADqwPJeQSCh1kgvoXsyToYHhgiGlp1HTq
WtTVYmcNuqf9xWAYhi+lzmik0YHFtJheK51g4KiV5lKvZ580//GgJChbES2H
3t+Xo7AK3gopdD4yLH2QYS9D0QfbmgUNWob9LtWO7njjqV9Ym284ABOoZrWZ
ZmBMMUwBPprN+T041S2NDPiPXBrBc9lkkM2x2a7zUjF/yFMzUz93aU3bcMkE
cVsCgS6kqzACHfIp6GFI6XNqvnk5eiIu2jhLoTaw7Ng2oCYq6GjO4ITjXSj3
W+VIs6tTxfdWuwQ0KJx0vWL1jRiWVxcixcCKIy4KNELmRjhHmyB/k7nvXL0q
q5IaM3vD62NyTkZy5ZPqTQTElpaVOlmHzWkvrG0QoteVi7yqdMmI6Kar79kX
er70LnNl8t2cdEaFC5/2O5qTqiXeh2QKxIAwNEzYG9mBUieril3KlS6xo+dr
lLAsrWs5S4jssKeDLJFYrDNgJQbSrekGtW+2G4Ye2Qy8D/HPcOOqq67CHVXD
knsilBEs2Fh7xBi58cYbBVF70p+auZBYaZfp1gt3MPPWYEVAexrRDx6CjY8c
HZoc7iw1vJa2Wi0BTOa0r4IbGSSsbua6FcTlD1IIgwPbcw2UAijaF49eDotu
msa9Qk4HRaql0b0IEpvkJDs4LGKkI2/IYE64A9i+9XL0fgrAfUN7cStOsbNC
WnT9SeWPAUghXwuw7qnUjFSLrOI8F4Vv7C4W1CBx/NIee3FejIxSg9xG3L1o
trN5mnjYF+973/vofzZnlK50aU0DFDjNuHuzLIBCcpOtC2yfmrHRZ9/1rnfl
ktjjtDbQa6lDqrffCm1oZooFdY0zMyZnNHlbHE5hzyXopyY66Jj6ohKnSUiJ
sZ+NkF5kpfBBpi9n0vqSh4+OWtwT8epVzmJ3KA9fdk9Yfm24QYSIhwJ5c1KO
dYVy8ER59aTOV6fAFmUbaLDb0dAJU6y1tGYoDfj9R1d0tooCByzrqQ/N3FUa
I8kl+kFBRZubbnpzoGkvZJr9gPEl7tEjpkeo0n9zVVoFTYNgoXXR7im/0KJ4
w+XoS0KYXqFjHzq1xDrtRkCIY8rzrDuxaxbIF44mOBCbBYjbIw+b5TBvve21
O6s0oLd113rlW8dhAx3jWi25KOsXL13aof2Uc8iqq+wAFNkY1h059L6qbV29
Z5/qLgS/LDdcdFlvAvKkOQQ3EMaCC06NkEiQqwZ/VbQY1N0muVe5lSWhJNok
1CatL/VGBbqBbUiZauc20w0XCO2ADzwaAQ219qyOBip87hagHwjRC8UjYEiI
SPQjdYgPMyFa700t0f4etVJqmvWphihskZUm6NEldJldQlfdDAxJslh6IoES
aMBSXnyTvEvrolBeBbuWT5nLwHZdrNLzhw4J/W1GJtUkBLFAhVkevDSqmFaq
ybmIK4doguezOrzeLBUV8VkwIqU7+uhsjzOdQ06Et+JYFtLuNqHvnqN4rThu
vFCGaGMuuyq8SQHMksf+6nvE0876IXcfneJho/g87BIzgTzmHj+Ifuk80OYw
yY7MD2QPNXFhSLaHP/Vqac735rYetYpNJK0D+6yexSQrybD0zbfffrs8AvLJ
oqDugrglpu7uqd3EZrF8ShOm5U+ovIXQpjPeV59qXg0xeg4o/vrStp5yBbEI
5d79qJsoTyH5zgAm1Nk3tKbO/ZsI4JA1w2hqhndp+jR1vQBBipbtoSZOWZzx
aXCIouCP9QYt4djnco62FRCx+iZwse7t0723+9DYlDRcVSAkRO46d8QzGpw+
kWfMt67ugUvn1qmkcpH6xc4q6NDfZJpgAJOGQK/3BhVbHe19WSlBhMiGileE
DfLjUlQNYBeuqUFHUGy77AJVJWhLLZKjNqfzRM1aTGMxB9NpfsqiDbKuq5Hc
3uT5lw4h5fUa+9qpkfcYZeIbCBvL7V75p0LNy+Se6YsqZ5dVHCYADa6oMLjb
PeqOTV/41JvdjvVx86+xvCb8JbtKKlCsg3vb+9EgmRl3H33Dz+3SzpLCFsjH
DpHDUVinTs8z6i43gbu/zfw8DughWJrDwvzIf+nP6667LqOiaUOIkj6nCi91
o7PYf/lyEF1B8gEdi2+MS4Ofg4Mx0hfb8mtHryILAWGJMz7dnt7ZYicGCDoU
d2sQYPNlRSBF920Mcm4L+rFMrh0H4DD4+0LqmhOoUZFNn7/VpOsHiVfEMLEg
zkvPGxMSjv0XbkhUId8KjLQSs/0sot/6rd8KRn77t39bXyGESUrgvJVzhx1B
MIm2qb+OoM62F23GihQ7koIkMeH1xvnKRaFrElXrA2KXyUZldaztnRAHVlj+
RadKAqL3h4FdyBp2Bx29p8lstve2UKILxEFtDHsuECplQKUcIRzNHvRNvow5
MQX1NUuaph9LwwEoVqtiUilPGHSA3FW/zkqRz1VhvZpZI3zOyapiMNpfvXTQ
s+V94WisPDbRBEPuuDRdms1gC1g5xtQFRUHPFS7rRDy2GI6HuSGSyVuBG7Ik
vXOeiByur+UUByDgF3SctZcFu5ba4zrNIlJF3r3uRrd7tiHedNNNr3nNaxYs
zeqY2xKkgI6RFv7ry6H2vIOa/Tve8Y5wg3HS4tL0vGvsbHFEz1p/bgHHBGi7
ietxb/dkS9AjHUWnz/aRlsDqxwUD21IVTfgXg4QnQiuv00AMm8z4poGQ4/pI
LtCh6vOhi7hxg4naoVarC8+K4JWQX9NhQSfW8CGUYJXRNGgMZWTIHZMiJKtu
0Oh8trgybFpZrc2WW1t5qzJIoZ3Val2DcsUIyszX6Qm0igCw4rbolCGfmy9I
e9nyTEsCGqS66JOoa1hmVrV7vkYLv8nfqu981BTLwpAc7Mwbrr65mUZgrYtC
8Qok27ZcEU7+x4/+bpNZoKRKTJXo0Fa6KAQnfUomghs7pomkKHKSLyCFYzK4
WNrFyACKldkuKKd8fhywRfXxi6SMBfAtQ/ENYU/503NzGUamgOe4Gat8HNcL
KwO7Y5ncXgkZtD8gAW2vsb/QOe9XbArgaJx29gx5AY7/up94ZUGPFdZR61pD
LoVIYb5sYzM5u5o8qdp8ssYd1MZW6dYBQ4QKiduoWlJvLkjYn8263PnmhozA
OYq1GNeyZnwWdRlUd5SyLpyuHAA7VLlEb5N8Qd9S0qWPQM/XeLpHBI8vXlSX
sTtMV2OimKVf77eQwWAOUXHpXfQeVkeroLUTVAKHACFwgB4T6GCJiXKIlHJb
+pPSow5QkCSDDY+dah/hPpEldM3WaXjV77ZCW3QwpEkSeozzLzcq22sy2ERs
f5v29x+dsldMuposXVxxC6kKs68mnSGMo6w1WBOoCUCoZ3TTFaFgrSBD9iSI
6MxdAn1yCufkNTp5d4E/vmw79WauCjqomBizc5dDTHghju1HvJXpQcGNXiRs
gk94tjS+djSNBR1IR/5cVf6Sg4MpOx0nxbdhW1mP1v6qCdbWjaTkOf2BFXbH
cUi8CjuMAXLncfSGPivb0vhnABhMEQ/Or+7GcINGh9IVhgSWGobhpGxGy0QP
gGmMEzusBA087Bs6h269agJ5k9yW1apoy0JgMJ+FrEdvw4psVrdLNsPPlaSt
AvOfTatQtPPHx2NvzHIYXfmRozEZdeJpUOgzQrFt8eo7L61vu3HaLmv1KPQ3
hsMTTzwhUfK9732v/yrKWOZReIq2MJbRVy+dx7k5eJhiHQJ0/beB9cHuVDZ8
y1l7U7Hiln8gEDLMqGgcEE3lVrgteLk9UZDYE/+Vuj2X8ONNibuq5Uc2Uzyi
oCOTQHcSa3Al25Idsm9cWkraXO8VNQ9PiNgjI/3ppYWlAOn0SO0OFOA7pU5G
Q/NOIEwQQdUiMFhrPi++1/QWaMUOBXqds6aNRGbWyseqlA8V+8UAXMG7IIaY
53Rr2QysAhNMS1DVKKIQcKMXiaSRKea8+MJJWU7pRWj0S4d0zwICFpGgK1d3
yDZCqWJGjAuEq+VEVkUiXTKVniVc5GoX+pjwFzvE1tB7tBnNOGwkhTjmxpL5
tXfgFq6iX+iDeWPyW1DoYR696ExIh80gAe9sD50g+vUmgHRtszdwQPciUYgw
Bjo6+m9bavaGWCi1PeIVNlnKFSt2oD7XOd95aQcsLirEYZxFn5Zm1c6A5cBb
6dYoBFh3bx1tuqFNqnBGpclyCpPOW6Y1g6Tv6csJKbDP3RF8zocu7YPV5CpE
ldvN6uh8uLEKObvR3aYPfOAD6yCpfpZXsqAH2VIgQHMehswIufnmm8OQeTo9
H/7MqQFBZw/orLTzq7/6q90CSQpbeXu9ju0rypbzHYvg40c/8TuO1sDjk2yH
ah9svfdVYT4m2HYEnWX0i6TpxyDhajUZQgkcaQI+v/M7vxNoNLUYGwuHdpjh
q1Cw8bGC4MaXTy22l3idjyCvetYQ9gZ1T/1Llxn975i4vVMkXGhCfcqXji6i
ew6jzuYxh+WhS5sY2v62uUlqc3+mm70mKewNOTIZ1bGz5q3IrJ3baigkX9xp
NaTMAwHM0cP0t5rMkY4kjITOVgkALjoqiPsOOtzu1eSueAo6sUnglQtfF1dr
VsPTTkPQW0VSc1ipbOgxTWOdJekQNoWaw/YdqrM4DBPZE0yjvbBmteSP8EjB
xczpNVTtnq6Jku5jrWXsGnnDtS/BaugjmggwFUZgUMalWz2SZIBAweahi44c
UR3ylezbcxkUtfAefaR51Un2ke5CzlfLSqxD32rUjtY7KBAuVthF7QeMNDL/
7DjUvCidm9siRwN8Zp/42iESVRBFMcTHGmQaGpkHslqt1hZpK7f1a2vbTscy
WXe5czxf2E2Ln1Eyuon9orPqTDqrtZoV0coa6bmukcEpzlKmRaeBp8HD6l9N
sCZ50EGWx5LZxodPi6hjT/ni0YvNGufIuN0ocErVJvR0TqxIyelQI7i6JK86
aDQMcR62Oq/HHIBUJiTC6vRUWacwDQRJ8jKeJQ1n2omIYl+AjuntIHbCcBbg
6DTnVIu3nUOs0qaC0g01D6VH1CClxDYC/lHGiXC6Y/QznsuiKBONgU78LPEZ
UhiTbF0wbdZ7qNVsWTl56JFvQptUS7irrrpKxKMXm0UcFqHytj8tOZAMFWu0
VQnFN8eE4vuJzhluA65VOqiZ7X6hVY95rm2HEiQwKLEFIVenOcGNDAzkTzwo
ZVyaMuOa9kSsFQWX46Oi4WtH10VA1EGpo+9n8zTCupKxwFsvjVUXG5C2uikP
SNRaXOpW+B2s/dY7JeReJHrcI4nCaZz28TNuKB269XQwQhgAfQSMELvg2uRG
ydq0nPMRqOJYuSLwgvDoyufcDdP3BVl7zGHnIz5DLFFdcL/Y/aUShnqqPL/9
om1F5Zowrxm+xNCkWbsLcIMna4WqCpEhav0CEwVrbuW4OjNIREoFH9QvUEq0
6ru5TQPtJOTulTUxcpBy0TNGUlX6yqkR3Pjy0Wt7Zg9PyumxN/gIKLVTq8a+
OMuELtT555cWoogW46vbHAVFFy0RQdVSczuCmyhHA4H9Crxyf8cpXWvaqQAJ
sMu2WIN+fcV3VHSmWbFc3oNHz1zlBhk/guRyta9//etpiOWzIJeqbQk6mtvN
+YyNnJH2l6aKiIc8frhhdin+6vU2xOZws6uTUa86r1CluYBDNwujSepQPo6m
iqw0h2WSJqrAekP3kdXxxBNPoI4HGpK5hOBwTSVbBUuFelA7vnj0clpDE+X8
25t6W2duabSycg1UIne9er6/+XIwIVz7v7wcKJQUchR9tB57xI3pRTmLdX3i
+AANVBnfLKuLdCeJMy+GxYLoC5GAEj3DfiWIa/y7U+++HJ15q7sb/T9dDgtc
UlhCpxfDDd4rB4qrRc4I7um3S5M2UKK7kjHWVwVZKnQY0uttyo3CE5hMDdzg
QS9rzyvBJeatzJUQjBIHW4dQQqCTo1wLcs1J++beIHE2D5QleU7ZIC2Pw/MC
doc8y3ornCkczKQrF5XCzdKpJTDkWuDqziSwpp6hGpqzYMfnPK60dvlQuCGr
CxNCe03cltRuGAU9/v1x4AIxNSdB5tgrQw9+Cr/Jz03kwYnJSwKZBaiVIHUO
/XSzqyndKshnoQNG0XQt4Xrlpptuan7yuMONFcVsP9Wtoz8zPFAXmpBtap0k
34R5uWZPjVu3nv1A1Q3y2xfmkjMFBXAUBShCEaAAHSIbWKBsWrqjKB9sie64
mI/AyxcvTZGW3yFJOk5gJ0aiE7tSj/XMLU2ruSE5KThgGisIR0ydo+Ndx9Gy
Woqh9RXwNjhqyoxbjzQJV43LkmnxghRgYi3vlckNIacpluEx6ZXm6F6Mzqf6
NVjrQjrPaRQTEuSLAUOBjn9+HO5yH6fphMrIUGFsaNSIgsI9YWYs88jRRs9e
LepyFpzHVSKoxRM1/ZtLv3IWxXonKR5RXIkgtACIRd2tDDdsKMxOgVZfS/mE
tTmiC+mAoRl7A9FoPwrWxkwjmzAJzdWRrV519bArNPPiAtr8gkkuiELQRT97
MaOBQey+vxXdZG6JMTID8+4Le9IbZHPg9p8dkulsodU1+C2oBa/uOlpV8qem
OjL/bu0nOqtwrK2nydMW1h4XdFx33XUkB5ervfbaa4OOJpUCcyVLysHMfDyo
Jlhf0ivNsaZl7wmX0A/0dxNIDxM4WeunM5LSKpSnHkZwYyjdx/F8mkWY5LqK
hCF4kjxiJTDiJwhjQmcPHl3vJf3NTBODHCVjuJ/GnW4hhBtCf4jZXXKLSCZF
0+qMBwYGWgvtX2sqgCWOZ01N9KahUx6C461B8GDEOtX8Ogy55XLI42C2cyjG
GxFuXadsmfTBmiZ03Ch8Ek6Tijbkeepn8HDfM3jE+uvSGgpNEEQ27CA9Qa1v
0i7AsiT45BNFaM8pNqSIcbrGjLXLr7/JiiJtCtCDEum5ZlZ2VYHJX15ae2/X
IGY7T2ThkbVvYxKzyW1eC88iDc7emDfE5lEnO9KXYMK2dZEHKoKTLj8r07I3
fHxFLjM2Bh3aqaB7MeQ+emkZ3wQTuEYH6qZoSdM7OSxjdq3Vwlm89KOXTvF8
k9FfHdNTnbDMRHWAs4L0fqjfVVHetCSTntVBC2hKyITQm1TtWZ1qW3Dzv5mv
Ms4Es/eZnP2rtzXNdMLFozDsyxui9appgnLOfAMLfqnXjgVkL7BlKB1VlIFY
TnJTU5JlTPqvcMfM4LFKpmE4BtF6UZGSkIvselWS6mc0ogsey29ejt7AzIAM
4kLtC2qI2pq7172oiSrhC7ZHj5PQ4dRwA/stIm+BAw9CGncJGrEI/10YVuSk
g93CVpmmmTsFnWTHmDGLscxFEqdVFt2Zq1DrMeiTZ6GL3uSRRtF8bWV9cpp2
LtE2E2BiF9vEOQtfO1r42eUZgW4NbQ2Je26LlkksBBAkqeqeqoyWsDMxSPoM
qdzu4QOS6tx5dEEEM/A1cSEcodWAvCAhq4iAd7DluRiCDOlkr4YbexHGoued
O1mrd1PK1L+kCLsFzR89cdqnchwEqPWmyYVRiiJaO011UZFzg7wV361wmyQd
bOQSTsRPXQnoIGCrMWKzV4jsda97HS1BDRSWarnxxhtbL72N2GyPFK0l8szP
aXIqFLVPdaqAQqQUC0VlHM+UKNNMpruOjnt3HP3yRKRpMdmJ7FB0RFmzcnMq
2pA0VNFqCCK8hsCzIinZ/BVEXDl6uFDGa/y7ETT/WyaSkv/l5ehJfwYauoHo
8cSQoMiHO8dTgA9ijAwAfg3aNikM8n0dviT0mDUi4auAbs0aFKMZbcc0Ubk5
0ANdjbkyALntOCSXRVSo0SqLHkW2N3e2JM7ytrrM5idlksbEixIoHPCmE2EW
N3e8iDYOzC7QMcE3IcqvHZ2CF4Bat+ieu7lutIiHmMYEfJZphSSsDsUF4waL
dbjpI3VMFPHho8ubNfLg0X/2K0dfWqQvnDTG/MRR0SEIfkrFykFPHfSsQWpb
RNXgocCT1d3DDXaLtAgnSL3byhBWTtXR5FG1jTvRDZJuW24LhUyGCyJN1HTF
/vANiAF5kcllN7qJ09uRrFQrTRKqX6dj0yxS2EL5B1UsU6R/tam1B7U/Mpao
P/Ui7tO0s5ThC3d0CU2qTlJ9E2MVdM89AXoi8MZ2yvNr37yuf6xHXoauOuwN
isRr5i7TqgqMm+yDJgwz1SRZkQJY6+dIT0jIsiVgglWfUZEJIXyBe6lBKqKL
90g/Wew8Ai6AcERvGFeTydFMCIsa0n6oPyVAqQaJwf7K5ehtuhsIR0vW8HQ4
O+IwzD+J4HOZHoOExbKoLJMDdKy/ubPtPCnw5Ha1r3XhnYPL78IVbDar7WJj
F4zAY+JdOZodaOfEYiRPTWaW2TlJDbxi6OHOElpX2ygF1nJ2s3y/Ojimwtpk
sDw12fGR890fR331sMwkLtUjR2/i5WE52mtACRiprIw8o9pUKlxeQ15VSdqy
0gwVfoQOj3NSVvzO31HOLNkqytFHmnitPhXK80ZRu5FtViuUiYhxKvTkt1jy
Z3H1yY+rO8OLGzJD1E8fB9DDBQqaiCE3//Ekm1G00OkQinW8/vWvb3Y1qSgK
qm4YJQxVUvhOCxLlk30tnyWU4yuB/c4Q0k4ZSdL/E//0WOMbgZouxMTQM4U8
i1o5gQ7bk/y+6We+aZp8nqjSatMSWTWQTSSsC/EalvZWAj5uipAgCXpty1pH
rXSreMEKgQXltC1AOQs7vtTqFDAwNntiGsi5MDBgkQ7RM2B+9XKMX+Ftfdsa
OphLXuFLzrcywZBSEEuQN3JSMjxGedWUnPQZBqC4jfJGiTONIejdjWu05sLQ
mGnHIQUXIpmMCiEmPRxNiQlFEm2WcSMQ1yNNEopPvdl2z7wZS/wLR1tYhTBK
I0XONfWb2cPw8OcEqdZ9SUaYzSN0zzex2XmbjXhCHB89ejtujfMsdDycpugc
E5Byxg1JqNkqIqvrlrjSaeSi7kJ3pAUrhde9NoWk9pohZumHPvQhjiRZ43XE
Zsysn5p4iLjr8t1TyRAXHd9sLPdORo1VO0t7az/dvG3+SLUwPM6CpaFKU2ur
g4OjY5QNqz/Jd2yahXudXnd5NYndCL25VwmozcSgjzOIt8NfZvQqm9WS3ixa
oeWq7Gl08H81steVVWafY2syiMGOnMMky87pbANq0mqt1u6FvrGrwuiJ6jCt
JAWHSaALg4xezqFYaa0gg0S24wUpjL2B8eA5dR25LZEQhsp/ezmYAUFcZ9uT
5lWnKvzC/elF9ozHVTIK2jixc3RUYkUDxz6iQVgfcQL6/TVtyM8yfUnO2rJX
sQ4TFJeNgan6g6sCPfieItg9odisFoCxoaTFge4lXIYatEg78FkoA1nIPIFU
WF5MlPmtfvdcQzo5CKd3hg78DVwIiX6xAntfc9gCF1VYvJQjowJi2izrwOKY
nrk/t58CjR6lTjgp7Irur6AB/1FRQPdIfrNbn1OTfSLzpcy5s1rMVjRmrdIp
ja9OYUIZI+1/+dLRRuRK25e+MLOzydCvyJjwWagZhx70SKmV5ggHDkiSTbb2
rIGG3gqgo7Wj8iJgbJX1/Z3euZoGiQ5XFi/3BQ2t8IXmbUF7U6v5o2VbGwq4
YIQwa5skZsjkr7Hc8QHOLTNmY7iV8lNwXrkKVEeqp7kaeiuCwymdhwIuBgIC
EZBh3oTnVqXRkwDdG4QpfuFyZKJAYBaL5dxv2VYw7tbUIMvn/e9/vxwQ4ncn
6VTbEbQnyCHFuCCsQf1P6pZ9MrCSl6F7RqkDKUXlbHO1728ON/1QlFevPXjH
2eZ6EA0mbcFKnKEYkrspS5tSeu/mkhbptur0N6Ew4EOJS9Fct9KvcIUEXaXP
MITXD1RGZkUoXz16GfNWGOQ2LNrRImkYPtu/9p4pcohOjI61tvKCkwMHkQQO
y1lgEF9rioK2ztUyTw1MkT63txuBINS96D7KcwmOCcSJpwlIZqJ065VMzpOy
3MROx4q/4+h1izC5mM/0c8a51Y5Bn8quNFxq7uEt8FkCgRsvR7CQvfH6y9F8
XlH5jA22riwA4rRKfELHzds//MM/bHwa6oVcOqt+3fkLBzl5/LreCfcU2D50
6Tgf8qi419504S/lTv/3cWhEvrZxy6TIKAnGnnPoczDVKAUamo4phJdabcVR
SGjVYN4yDvFmBUVFNsamwMnvFbZBy1MXWoRMAzi21awOgYuxRpdSEQ6VaVVd
i5Ix7migofXAqimVObTjhB49N84dClWkVvtsl4PR0alig3Taiuv7fpYG3OgI
pvqVvsHd5COoLV0Kr5v75aPNot64OFfQ23P+o5zpWiad1YqQP/vX1O/Xkdx9
XDe3/pTM9Q1fubTbBh1a9vBbOaqyuvtFE4Mggz6SwnEq6RhFKBxnwRzQIVhh
/qzqZGVuayN7Lpl/QTeiLeEp/MgkTprDl/RtLfDe2Y3YxsThBQ66aiLt8H+Z
qWrYe4PeYaN8KMzvCURa+9qlge48+stPbEdiguzzpMKXDOr0mm+tmumXNnUX
eJewaxrbSVE4cCBXBNo89yLuB2zs2/rOvrlfmRdMvFGsZlWBtn64IVDTGTJl
FRaJbxMGbCvBGp1BK2T61aPZPbsCX5FXgs2OzkcPdmnujsw5kQ1LqQ2dDk9Y
IY3eDq4B69ZRT7LkM0jYjVqjhv8kN+VKEMOWMenu2+UHLAId4qgeR+cQw1zk
2fCitTdz5HfOrDO17Z0kvihkkK0jIkThoaMr/cDl6Na0baH2cU+0MyDaM/4Y
2VVKHX1W9wSZUKFmGQpV8xZdy9M9kh5VSdTBgwAOi2ZQBxWd8Gb2RrdeFIKp
MJWG1cijkTt4qZOy5KsqdDLh2TxCr+sR2ZwRsUf8JuQi0Gob6heFzdmli7xR
47HS7XrChjIgHzmOdUqVKJxs4NyZaZKfK1uHLfQ9ehI4KFEXPbPLSPPZRM4p
uf1X4LT/Un/N/l9JEfIeYTE1vLN8luXkhFIpoaPyAhOuW4MYFgope2w5dBqd
IUAgb8VmXjmGgkrOe//K3jDP+4gQn7ndmmqfajw7GV4k2w9H1LruXizBjS0/
Z3OhLZhg3+GACKFzY3vPwp5ingh+bDB+GeECFhompFY1akU1AZEebdE1CP0L
J7AnpP7tzjRtujTl5Lb7lqG2WdP01s3Tv9BCNAVG+fjXl0PKhuMjhjkFg8b2
nDmd0AeJj97mNKiGCorK6Zg8gmYO21O/hTg0/rmG0Tor9V9VjRyZnRXnSDiF
9dvEazCVD+BmY9BBD8sZRDjIG07ATbZUkZEcK7cF/q8eQR0KA6OvZXWsAs6b
Rw9TD7uS+RFBZWrQOTBUEUUsAafUdOr7cbpWHjWCMexqLnE0yBcgZlti26M/
dnRz46fsyRibjoVS7Vk8nemcnyV9RBIEouVh5eNkM1n+6kzVHbRtiUdNg8s7
W6F0MDi2fVU3sZm5+iZUHBQ+ZtKCtKpNoccKzJmL5FBakuEq26OzVZJAikEn
EZXjTpgXj20OAMMKmdxpYbmoPm59tY5CNoRSHvHZYRS1Poe8oBye59qymCFj
9KGSzsOVXhfkRFmfAiSTz24bVgS25J0bPQtHQAMLlGQo8767lskhrCEG1Qpq
/Gl59dmWXpc2zYSOvjyc6Yf+7XEImik0Q6bqO/v1toAWab+uHbPQpVwbo463
gu6FFj6OOoFQmRTS60pupVxfQNiQewU4igjkaNBcu5x+VNEcgTJGl4i9I/TQ
tqm3dcK6qATRMFytkDpWcWm6SRNdmc/S/erPxx9/XL9sBon3MAPMTGVuwqES
qTKkvRLsrEGVCOp+nU4+p4nhIcg5HXXRWj/hd2V4O2eds1ajIRJipvXENsQS
nnIgIxnpyPrSsMN824HLMTkmWvcs3qVKhUfoaYxKilpGx0BA3p0KKMTWBMF4
JbiF50Ye8hdyZyLtvSIDqAuGauvm8FpXMD84L8yhqYWoVTeqKxxm5ikqof9D
laItieHRua1LUYiBhLDWZkT2mpkiHmpIJ6CnK3pTsSWGEqbQeN1qJtqgVgXH
RnLfXeaongmB5OZwBmxw4/j1PeQcV3kkNN1CnkZfjn+IkamAu2W1GskWTiu6
N7NMenMQLfNlz+39vRKwtOqVhQYFff/knlg1531n1c0fOR1Oj6pkd61v63yI
/bJqLFvIwF9ggsITvC+bDqpGYz6/EgsUKVTsmqzQVBBhCDaa9K79KNCAhOJd
XJWxBYSt6IN1K1syTZhpeVnjzEL5rFkOjFs5rzBEQ7rWPoflP10OxoNQKh+H
ScAqhgC9guY3GTe+6vQ3VprEshXoWNXJBEt9lXPrOZYXu3fNiFm8ei6oo1Fm
K0ZHPX7tGk3p9UH4s6OVyThdzAkg89FT/xSThGgPwTRcdNYLx0ezyKZi67EZ
0vhT5+vuK4GUrWCsvqCgUnRdFQOyRM9t/b2ZMdmtb3miJ+m1ZwdkhDCZRn/V
H3ycPZGiLx3NdntDU33duIhwjgApDIihxG1HD2j26jaCqYgS0Du7TDTskE3P
UDw6vDVUWC3zxs1TSs80WqUkZW+UHmX4IhgEBHhAE1CSVlBjzsCQYsDBWCZL
slWMutcp1XSvKfS2juy8XcIEMVZ5CoV0nV7MnGdEWtxeIz4mX89ktUNNS1+A
xUmSDew8dYH/7y9HpyqXarS1hWJprOMt3MbH4NpgaACQ9ezrlf7LJlysVRvZ
LhPjV/lJFqwOKf3oFAP6dcGfvLOmR1fUXRCJUoTuyfImIpPoXuIY9Gb5KcoE
xEt5HwxIzoij263qhJNCGJ8wC/HYvm36zCawhMuVo3EkV1dYdS2WhFP8tDbo
diL5O/OQOpBrIcY+FWXytox5MYqRNGyIY5OeNwvqbSaDCIk4BqGwqXksyehP
KRstDGwxmnhOl28ZOoF0mzunAPcYbkyVjuMAbbCOTaduLifd3qHqWYMGVBDo
J9Sj9B5bbEVDNG1m3tOmaKs99+7ZfONfm8arxbYtYnT03z4raGAr9+vcPXYa
N1BFG3resiFrLDLWcTNzuDGvhw5JiISdQneCFHCHrlUWQvaDqhDBwP7sRmRm
tBDgfwtHszM8N4lIZAnxge5db2iZ95FGSYK+CSOtME7soitrArjQE4vr3CcU
fo5j3Dd38oIkJLYWIXEjEP7ltpA/zQpk0V4UbuKtKJp77WtfK0emVR8AkdlB
au1K+/6GzhZDtLYf7RZP5JB+AoKiWEdTqPkjDsklWTiUqI5aQm4mc+I/Hwd+
L1dllsn5jkMeL7JGNCCm45ThEfhwN86lJVeOdmD8XBmZLx/dz4GJIIxyJ9oO
a39gC9PAVI3/OZ/bexRsrkHbcKNjgVPBCshgkisc3vvXc3YKpWMmrDCtD/oV
ST2t9JoS3RTh60njzo2dlsuaeiAi4hKPVGx5TsJuvgyJ/vasZgLZKJL17BCO
zK5F9nNwauhMZicc5khErrptRZTrH7pMAefFe3pD7+9MlJl31Zm4H7n0SVxh
r4Wj9NgaJMEhyS4spohVdOurlwajU2FyB/F1ifH2E3pzd86s7hBDlavKkWmX
KeYNBGQYO7GuNITppiwwKKYhCiqiiBRBxK8fnezn7B/iADs95qtsncJzNokw
u2M62C4Ehui6JcHqchbMJE7eVTTIwAEx1d233ax4n72qrpbzcuNxLJPelOuG
9sHMiS5NfqGz7ZZpcte4+XIaC8Yk8Ow9XWwLiv0PDbIoMgZalWHIcIPXIP7Z
6y1/5HAOC1knyZfZAwKnc0akXFFJOSy6zKx+1ntwOaTy13V6SmJYiDrl9et9
CTIhf8Sm2Q3qojQjZgJ5w6Qp3buJxkx1iryqXC12NzHS6YLilK4VSz+EywQ6
eDdwRtqFsgQreq0bRdpb1N0ssdBuzRQsAQjbA254/i+Ow85O2kV8kgOrvJH1
Is7QGmmmdbubA7ke5Cs7WiYZFQs72O7PuuubwL2zs+1LOsl+EfXLhtUPoW0o
svBkaaOeaMAaiGW3NP9bC7hqoAMfBgmWHqMSAMIFuCjrrzF7ErLtmEijyGQI
ySUJFoI78SJJhzEucj3C7dYFeaUOCmmKf9Ezeg/jDbdKTGPieHwusTjhXMek
RRhFgsAqFIQ7mKxcG8M+cRUg89GjDYfxz3tq0BAzODKdj1SIQJmdwtU11Gon
McR6fnZ4TQ9x7DwXIakgpSehSv/qe1gdqE26VDc/tdbV0c/XNlBKgGVYWox0
6YMLDbLVL/M1GAziaWAEwsiwEHMj3qVqQNBjtQNEiYUpEMuDDpWMfQ9smVli
gWMA9inuD4NkvK/+1Ys05fg7va3/airKnSQcJyTbT+gZSstrrVrdWfbDtjzF
kquqgBusCNkT3uu5q4LJz7VZRTw/RR0EWTC9LeyGzXCSSlJgYqFL5Y+3jNUs
yz8e0YLePde4zQ7STMAPVyPJLFkuFW211dSi6NZ3Gsr5FfeNz8nz6sUmT0A3
gkff0HfedBw6zLJ2uFfTheBGEUXvR7tA+3uru3U3+qtRnUs46+6cUIYhOOFG
u9ObuhpZV5sy277dUBk7N0rtRn+SMkDm76IIrwUFEhyUNybeJcuQpdE9UtQW
2GqByrFCkllh12pstTDAhvIK9OCeAEYXQuUGXJPJGpPZrsRWaWQ6T30YQ49O
I+OH7Kcc3MSNlVqPyyGJLE7SRTUOIu3LtvBcXvWqV7361a/uebdSVazxUV/Z
wKqSENIXGBe8IlXdiujkW5iEoPXC/s53vtMjq2DcUYn1HkMGal1PPvmklri9
U0O63o+iMyUfRCykER/v9UBDI121SFKrk/tTp485PHK7SAijOkwQpw06eqS3
T2xQB4EGH6ND3Yquf2tOcVaVXwvIs4zwPJGzCHkDZVmtTeS6GwiDIJIhGjE/
/MRSvc12iTnowYHtvit+lMdff9LRfuTdFJHZX9ZqnKwlIlaWABHLebhyc1Nv
WN0ErgUWUyfADodmcjT+bFk5vTYaxDAFla+5HGilPZp7DoH99UEjvK/oo4sV
IpC11KyKQhpi23gp/al9Ffrc+DAW+/98OdAjO1sq/Xo6NIw8Jrsk7JIXbsX1
KVTeFkW3AK0LA0r9r0qi1uB6nfS2fiV0cjI6RE8Xet1kiKUzlgTn1VWhVk5y
XASeK73CwzX6Ya6Amt4GNzQZ7wS02Gj0uuSuhcx4d0c9GpRreDtb4R2D0x3s
bXycrnF96Pgv3bigo1upoTBJt3AG055KP1GjBpYxKYzf5AmU+v7WQoaWXuFc
FfrzrcrcgbG8RCnH/u09zzzzDBXZMEQD3EVN1alxdibfsUYbYVTvD50IwTE8
Fg8RS0EOHD1VkLM7hV5IF32tz3u+xm2CGAgMiIiYKghIIqj8U48jPI973+M8
6HFELXx17guEQhI7NU44nEE7XINC1St2WExvcgdqVInG8FmmbTtjgz/STWdv
4AtxDURIOCmjbEEMr3iiCGKqC54wbARXV2eHLqigG29QHKZ39s1Y6Ndff/0r
X/lKkh0UjymXdlx77bXXXXddUzFIGbuD2s/29P/xcmA28gWmiplT0Cu6g3X0
Os6bA5rtPfoYYlJ1/uTBHQ3a+KtILx++HKFNXyhhNH0DNKcxMC3AzIyWHq5d
y6c1u/ZkI8ZPEE9If1UbCP8cmfW7mXqzNzCl1JY6pg/vbfYasfc1MV8RinFY
+BQVDU104SwaxR293kWF/2RUCVYTYQ46uqFhCL4HWAhOuylKjZrtjRg5hT7I
ZRa/Cjr60eZzl6kzbGsw6BDAtKjpfFq8QhwEEPS5eOKJJ7xZ84seaTGFDL0Y
esjkrpZNNVyvf/e733322WdDjz6l+mDhkTOHBHT4Ep24ReD7k9w96GB1IIRo
XXTutAI3mIWqnMZ5Zh+SLZoGzujlq14n6iXsORHy5WSV1jKhVdP34pK8vB60
UhjSHeEIgA7sX5rAvFe5EkBB6pPhvQ6DXINzMpTvIE0jBrKkzDlh14Th2y4+
RpBnyd+FalVQEtTN0miarS3LS1/60he/+MVXX321rtZwo+fXXHNN/1WY/4pX
vCIY6VNhCNeGBcLbUnmBMyBxgwsnhql5HOqRQ+mZJ2IX+DCKxXh2rCldyVpN
WgW1TSvyYngrIQHCmhv2YqDh/dYm6FD9geRPuIa+2ZY8CakpjUCM5YuHHoMO
xybw9CuQHumWKO5b9xx7UCeg0qRTIlcu+QJDOlxp+5FTpWErbh/srBKncWt8
1j67mxLCNyvsOFIzjWHjHFxQcuh7+uZwdVGsxll/t14MXZvMXU6+QEuVzfDY
5aCOQu5Av2BtskktiW+gkvavXglJAoTQIDzh8vTi1EfxuAgs9OXfuxwTGhWO
4JtIzQiSSOgIkLIoQuwwpH9Rk2MakSpVEitBtt6C5Bfmp7Ax6GitX8laGq3L
s7TaEvRnVs8k/lbkrs20R/bGCt+W7V1gkCD/DA+sJAG91sUEXsiFqZwVuMM0
xkFVIi2s6qYDE9IKi6b2ypIy8jKUGTxiX8ydUbMmqecNZtcNN9xA5CdMuOZy
aCXZny87Dr2te+y/wUhPmCV9MCulrS0AySrmZSO2LRrMu3FuTsnliPzguocP
a9AgMizFAzoaEPnTQIAugfQKriaHC0DJJsub9HpmCT4/O/9Dl4Mgm2WowZas
2VrFrW8auCAuh0F05WiAvlaetiThU1FfKcLVafoggo2iPNQU9VMaIZEz5cr1
RDSYM7XO5rOHTUu1SORPGVrNLpExuwMRsLmZ3RfJ9CZeX9uvd8J9Ccm4BclX
S9XQNcKNT+ulyxF41BmcFfGN4+CAwA08rnCjx/5ETRckyZD4/ve/H26EHpkl
AYvsiUI20BFK9LpYCkZZ75F+xWyc5zK1MRITBrYboWvk3/7t3/KSetJ3qsBF
huRRdn9JklIQYjQuLgo9+DVuq6K5KQSqcBHgIkSsoo0hIY7Xi0J2rErb02rc
1m0B3wkisTq6182HpVp0M0Esdyih5cWPj4SD2uRnjVhfwpJ8HHUlzJVzbZ0I
gLzMCtYm8DJ7AwphCwQjTarMhtZ+6NEjKBCfF+543eVQSOudHRkbedA9av/U
p3oiNkLlY30BpAtX1QXNUOOgoueMCie2jopyOjqOqR8JNBrPuTPkaM5SfgQ/
55vgvQiBsu11f9YoxH2ciPRHj54U48OYiki564/Mah0arP/pyoTx6s89TFkg
VCA4PnhiWMrntJ1k39SwFwua2rY5aYfqG5qTzbGuVKPJaZcpheZ+LmPb7eim
N2Ea0kbSVXcC7XG6mbN7RyhV/tZPS86qKWslDh+sTakWatL/7+UIJRbk5GKE
LZkczzzzTICgA1dPwp9sA1VpK9sPGcRXlxzBJGF4eNTTHMFD5SyxQQGooKP3
IJX1qJutklih+LHQmRw47RwZkKJa865LL8V1yp5a+MrihFJlzdB+FuCaFJ7y
NxFUURHOyypfJECxyFSyyHjKC7QpaH7B/tSOUyy9I/yXZ1T52BxAalKUxIZU
ne2QfB97maT/6r4HKTb0MUaWwZkEdy8qhkU+bL0HDlJ4+PCq6X/xOBSz9BGA
swkJWGh9hB4/dTkQHR28bGaGn5ZgclbnIg62irAJxjjRfsZbo9cMDxYEMbAf
ZS2VtVo+oitCK0Z7W7abtQZ/64q1Gsaz4v24HGjwqNfEKqfyrQhdgTBkmOgu
3QP1hlyYMfDZpVOu7jTQYNaEWgJ91dlrCSrS4gv7EgpFXa9Uizo7g9M4N8Ld
1uCC+uiy7Y0bneoMm8ZBrKOPhxUCSvQS+6r2u1Cl05DH1FiNF9DyF8c4Y4hj
3TwDE25F6NHrYUU+yNNPP82i6ON9KkhB98LqUcLW64GMvIzUjMgGzwg3VUWt
lgruC8+RxktvYAj1QYwRLHS9BZdjFb5gTrjjDAzeyvgDYlOSaKgdDM6lzFa3
rkqLTwR/1lJBxvZczzIy6lSR7SM80FGjBbjEtBnJf3wcEnMqL8TVbSLdStWR
Uma7rYuTTCBiEi57M8sfg12uzTeINhAJYdVMvrIFrqOZWFn/xS0n9K1qrC9p
mQvD8iawozkpSLAMYykYxgMZf1pVFK7ohGNyEvJFd1ymRhaSjy+9AjEYGFwb
LDXVFioER89QKsgFEJty7zBMzvXRGPtIF2vLtZI91b5Ia+J4xIgw6yamrSB9
LdrxlNAVpqi5LAz7Vv7XcywXWRsaTX6IPrwNkZHDwCaq2ZljkusXo9tFQ8eC
JSHbbYLes/q6I4hAvRPBviEKOppvpgTcQNoPqMU6Ov+xNWAFfGBadLAQBEI7
tPWkr4JcERQ899xzeSsMj302eMFHFe5ouLJDtNrpv3K7RKoXUWGoyMZKyAp+
glbE8t6s4O7cIwyxvKGep0mECmKvOyEeDuOBN3puUAJbRumRhZfKP0sfS+Kv
gKvZ1RtWgL+GcXTLF0QFLKoVWBdaNQltheF3HAdEUt0gfSlK1rQPQ7p3JCCW
XoQV7I1JQCB+eA4fFO97vupsbCKVGowZC5Zr87bjQBThRJzjt97vnYojVFVQ
KJUd5gGpukL5cJ79aNfSFYFQ9gP1YHQXahjick3X9lBuXdeuoEOXASlsNglY
a7Hoa3ZOs2rDqo4Vtc+uzS2d7vpeXGeKSRZMOX/eCkUIsTgTb3K4IyRMeVvB
5iiO5GjENyb2rpTYE4zovkcBu/pQGUPiGCNg+1MbUFEO8RCDJpnLlZNq7z4K
lUP1ju5Rd7bRboRBR8OlC6SY9jrbUiPpX03pfq4r7azww0OG71wOORR0cYFT
vkyvBBHZGE9dDq7Kc5fj2Wef9a8O4Q46PyrlhTL6Bt/sa+VxUNbDonMVrebC
quEwHhWMq9SDLarFcYAbf9vBMrADCjcUBEmpL07OxyS1vWA4YDeXEHh4QN5v
hiyusujWueaFHATfmZ+SNy3EcZadnzTxqvZAFm9IcQ0/l5PbB/EZusXKpQHI
uhBaTQIdk2uQzF2ZyfI1ggZ0ZpatcMjgZCfgLXM3FtyYXJgoqOjHqy9Hb+4V
6RXksaWJNVxeS2trXKjHzrjEK5MGgY2ODWeNdcE74+ZwzZRX9B5t38llUIHG
BqEhL4ihrhmN3L22NZy5gvxWmTL7jhDHMiNrcSjCOW7YpL+ZHCM1rQ+RlKVt
Ea9eAA2bSC0PMq3Z3v64uo9Wx9TPhAdbWdyfpmVfouTZFoPYhgordEwssc2C
Wejm7h5Rg+xGNEvppCmdBh28Px3iqK8EUM1PaYsMCWYGQAg9Wv4q1CjSd7Tq
g4gf/ehHP/zhD5++HN+9HIHGDy5H/w09egWpbEKRI4Pp7sdVye+gFwQ6aOBj
iBGQXN58xbC4JfIvcANWoJQzMGRP3GvB8OkYc080IBt1Z7roYxRbv0JPNgLo
sapbZ4VmZtuaqs+iHzo/0moIKBB1KOL2J2sZG42jup+20537qqzx01iU3d9p
TRCkWjZBflNIxK7t1i/YJYYwNd0J8J6Z8ItyhAnXX3+94OcrX/nKHiVcXv7y
l0u46EUrP+tfHT0BI3NYVO3RyiNT8wKnqXnL+EF4nuL3ErILiUwZCZWr6X1m
jCOeabImfI1482dHb02r0jFSKD9UgIsBMH/W/Z3mNqOC0DerY108hOW5D8Kh
4nWiqeceAWJ0/a7I/BrNrKqI1gSJTr459sIiALoo0pqAG2FjoBFcYJxmaUg5
NSD/5nKwQxo08VIeZW6LiEcToHHus4RHer+eMqryMX/oJwgc9YZWXKfamfAm
+BFPXI6eBB08FEYC6Hj++edFNvDHet6LgYnXtQwW6wALYrB6CuOB9DrS6cZE
zR0mCQFzUevlR3pCgdDQsdP4Dpq1cRwEMJdEAx0iGLaYnrv1Ejf0dZcjc/fX
m3Wd3c4cYyXe6wIw8oYFvjXepMUGlGJDIsVqpnQqAgaUfO2aZZvAZwYsC0dm
J2hSHgWLJCLFVNGPJ33v0HVI8w5cL47GCCSSudPrXl1Mqx6AZEKEHtdeDt1Y
Ao2rr746iJCuRQ8bVazXaaezTMIQuZV1NuT7qJVT89L5rKJ8tGdCuw69BohX
tP3ZVddOnd7OWgjxHNfiCqFrcQOuxFY3Uiiu8uSGpuhi5Ne/0n60zj6cEY6D
b1sx8qpvuq3QQ5Cfr90c7l/qFJiX/RBYm3djY0VyILunxlyNhpYioh9dYyZW
xka3Hvuu+RBWKDdAXJQxUTaFHrZsV8+bAA1vRkXf0wA2gft4k0csS9QdsCMh
i5Q2aNqFf/Ob38QSHz0DMuBp8DV4KNikO77//e9nePQpfT+lZhTGrgMLFVOx
05kNamlXZjsNKBUrFCTOwrzcOvyZEXpFrnAzGJlbd+eWZ7YVsfFZHabNmDk2
ArNlewG9u3H/uFEQQ8nSdE25LaueVsgpKBr+q5+iULH+RKalGAuTYz3Opmo+
JQE21X5F99LuNeLQCmRQysfA5BTk9ook6H7ucUIQi7hOylvhA1IZmkcWCIsi
22MEsB6lZUMV2djrLkdPbrjhBn7N0rIrD0eMl2+VI4Ye46X4k/+F7mXLQ+Ii
5Tcbg94OVYFzkdG5bdzaqZNYFG0wDZgEuvOAi3PUiy/DZzEVmzBrMbkeAWuQ
yhrRGXM9OmVm1yq9jzTT9HmBcihnnJRJWygpRa62RjAk140dDb4lzEgIN3CB
urmhRHNPr58mZ+jRQLE6gg5Wh7ZNwlBa9fUNdEv4LL2fUhybEIUGJSagbsAb
sc628xzdKxAIIpgQIcNjx9G/uCfCGrwV6IEkRvtLSUtfCBCmhc7XcNfWPxqR
VWn8iuw4iZY8s4E7KZKsLkBWy3JmP5AsnuSU/65pnZU4xUsta5dhd6N9AzLY
/8fWvcbsltdlnn9lRCiVgE50jLEFUlpBlIPGcaKIGGcYjOFgoLBiGRAtDwgi
UZmYSRzFvXfVLnYVoNKdzGQ07QFHx7anW5OZZN5M5sUktsZuiGABVUUVFAUI
HhFPb+ab+5N1ZbF71osnz3M/973utf7r/7/+v8P1u37iDIT9JwtMNJVG0LmB
gjdzWJSr9zQFN/TiROxZ7a1A+r2nBrXnGB2UgBtUIKbcLjzb5eEqn8tApljr
lx79ZCuaD2MyM1GI3yLDr3mHbh0LwAopKH9o7aNnCG4EC/3ileml56TgojM2
NBGTW6EggVe/Uj4YxY3CDNfuWch3KkbrFIArTmZnvOv1leBdevrcScPI15h+
/trGTRrXYj+3c5JXZTMAjVU3KMBkcpjJtO/AwqIf64nJx2HWintoV9ql9gQx
P3UE680Um2mjscMn3cmd5+mYhGKAOn7qfI0xSLS856vkUNSd1ZFZguI1QvIc
yR5xYN7gN85E0njZJDFF0noW1Ncz9vpXZ+6mVJcoY1/EI0AQKUUyZ4pkYIiI
vvtyqEaZ2NcUP9Yakg9CLI4zotO0ZUhzGKcUGYxolaTJSgPY88ZfUHTPcYLM
Xn/n0bcIzkw4iMPSwYs0bf7nS5N31qmIhwDp6ggI0QxwtPagYnfWKR3IaG3M
0W562/dbs8J0mB6TNp1uw7nV4+Jybz8ONKQFeCc5RdZbNff0yibxPXm9hVzA
ywrQWnrSxF0n0V0Wy5Tu9FCWzkMVU7WtqTrRmFXR4oH4E7tjWCFHg71mYhPr
a/trTjYbRWbQaAmEep0eshSMhBTWluY4q2VmY4gSLERpixGVIh9ED81B/EFt
FJlTHICFL8yQLfOVnKyxi7Opr5xebufh8zKV5ywvb7uAG3qGJD6rQ80mleA1
GhAdxa9eMxE1FzaUZk6j0bNTqCKArElcQ9eT1ZnUtzR6IYzeMSE2XaAzizi4
bsybEk2trrZp1iRpMhA8JI7E8GueNJ3C6m622+/CpsIhmIkXCjT8Ajo+8IEP
vP/97++XXpGlDSt6EISFJ3QPSQSB+W7MD8LFa/h47h+nsSOXn3FoOVvXHBZG
4LmZ9aJeLMM1flqHr7VtEr9iatpQ7FP29BFKlXhLf0xNC53+nZfGJes2K5p6
U383TS744IFzf6535BjpAESd3awXjs/skAVbeDFaC+3NuEPIAGdF9+He1Jhh
2gp+V/POaAEpwIQuRGYJDVW5PDuUYm3lMLInaF3qMTcDtYycxqDMDoa8ol1d
IbJz+jmpNElkVseLLgd5MUTxQCM8lIAwgPBW6ly6hLjH2vcwKdcA3WSw2LU+
Rxtg6AIQEnlUcBVBmJBk9k2ezbr+tRgdKuNk/Jk9E8lkw7BmOZtTgDnruvRf
KtwaXDI5RAtnvc9bmZqinn05pI1kiEHjpZFkdTTxmLINXZO5/asJ2cjTeeix
qnIiQqghdf8Nljl0zZY2F9nwiXVoqdP07m2NvJ44jVWXl6OBFUYAkPMyJkZw
8cADD3zwgx/80z/9U+lXWZIeQQ9rvVSo64hmAHkGmCiHFz1ZMSUmn/pcxDwj
D1pHw5D/0pGBr+ckDAxPVt5qeqTnhonejOwHnezjshhTRxdJsJ0hoPZmCfqu
Shh2c5ijQRcIoWtqYOqS5GedcLqmymSg00oPsJJ8LxgREpErPOvwTLdw0pej
SZPQYYQovoAbxFfHWPY7jitbRUG6zgKt1izS9hdNVNdPgX0bdOShoJeLz6uG
YGmwfsVCm5zoatIi6s5kTwTfcM/wVPHN1vJDZjYTqJEM2Roc3DwbCrTnvokz
g4i1I9/e5MFNNsqmRmOKjyzadm4uptKTFb3s52aRGY5LIG650nLREvvUsnsj
Aols8C7RSxQssDaJ9VHckj5QHcbgJ2klpUvSStuLBif7UPnkRCZR7pt+ndz8
0aWrediSlzShHIiNM2ZvMN6AN214bX1E35m+QlPypgQiLleoidRi7JIIlYuU
4oahefzJn/wJJ0Vu5c8uB/ZX/83q0NyN2QbY+ZK/exyeDpdELW3jL0+huxyj
kasisTLZycmhjOi7uJa8GCjQbnIKq1OlEzbZO0f2m2+CJf4Lx8GMXIiDs6Dz
0cRAtuUxDBifWqa29Ho6wnei/XBjncXWzAUOIJ3+7NGnkqgsVRBb6jBqIdkp
0SmvAAVnE4hCoAm531n1K96x6HZaDDTUkSZ20Cen3wRTKcNhIYYZSsjYKl1R
vs2RoXvJAkFDxRJRYiObg9ra773ubGERfjuJEp1V6YJSIGe5NcKT5/qXR//Z
xc+3fbA/eR+m4lk8s8XOTlZGoaiTbgyqJ2eBGgwhZUQstgfJZZXmjGqh0YXO
hPFHGRLlGFl0JXUcYRgu89s7u+CugaevEFWqIujoSohk8rLfeumHmxMH3nHz
JrjaSg9Sepr69pobfV2PmNWhHXlPh9wxhSiFsVmbzVtk2mZaM4EKNLpvzwK7
IOjoXnpbd9qKaxy6wiVHdOXryhE2/vRyABC8r/e85z3dGq4p6hd3T+iJBQgT
hKCZAcONHroHwSzpv6BbIdsENAQogAYSzvYRLiqKL9b6BAkRb6CZt/F/+S/r
BeaBDivmMqgAku0V5Wjwbdy0B+852twTBeoMTQn5lJ6aIujVM9r3J2E6wvP6
jsnIqMAlGz4ZbeCwvgMMEuihyAKCDTpc5LltpY/s44O7mUwT10VpQ5VHQqaF
TlNIx4S1oEXwWH09AIEhzUbql0GN3KvUyUR4NMLuVCGP6m8+znRWFb7pBU9S
Q/M4hck2FDsjw1VkQ/3Iwu8kqgThbeXNUv07JhOhZa06TXkNgjP2et1s5UDt
UOwZSRD6VJu9Z93+MTokboAJRSDQPRLaiKPr0cwoak21stgbWNk6JnfLfaSH
lYOZS5IlwOND5oG0jRUXT9zY1BVUb35mTwYCDawI1bxOcrLq7psGTYx+NhPu
vPNOGv44e6RuO38A2GU32o1zV8uQwNdSSv++971PZEPhiWQKF6ZfevPKbGfd
Wc5C2atiWxpLSHP7gm4vc22g91a3+EMALtsFOvBqzr17zBZax8vU8Jhc0k2N
7ThEwhpbhhb4MheYAD2pPjhxj8lcs/xp/ghAZdphFwjoERD+H44DC72DqjA/
hfEwCTK801V5r4UK++HacSwdfOXoULlrc2EzosDIuQ/dIOXsv4Aa8EIfuOsP
AF/1qleR4KalE3SEBvCBgke48ZSnPGUiP+FJv3/xF3+xnCz/BRRgthMHCCiU
4Xsnf0fQ9UxSUs6p+2SLAvmZ+dGgYXZtN1nEkrvB2let0E9FWP2iapLmDGd8
1EQBSb+r9FTyqTKC5L5Q5wpSTNdW9IgHBDltkYvKmtjM6TXplgOSBhLE6y4Y
532d63e1XUmX1Isr1GpKNAhCoyTmgo78lB4W2nkWbzOKMWOG26qaYLpsh8bU
51YmMKrei1/8YiRze03bWUCkFbIIlUBHvm2nbREhdTTCOGDQIHDIrsg3eeCB
B/JZoLSn0KiuDs77J/QnjMPTNNr4/J6sAZwBQICUj0nJEPlcQEMlsljTCBWs
FMYnXUHntxGMGbJzap892sYScKIWdvbrRyNIuRKp8P6LASLHcc/RyZp5P52f
jjFFVUz0dPgdcgESHCIeLNXZNnNY1nlh2iDnVg4/dzoA3SyK4cbZ57py9MZd
15iVY99zOnx8ctzTI4IepDvxlomYtTFhmCvDp8WBvwFM0Dm4MLK0qlomOSgo
F6pgi/GydzafQltV7K91iPDdGAWNs94HXbBdTwdA+QitwbjbdjSFnHp/gIXJ
VZm6O8CIt3WqqXy3ik2hpe04yNo9SC50kNZUdjHOOV4005fBPEfGDF+9ldC9
hdPHeQFrZtSy6j1c42ZRfkRDkU+H+sKb0IgnzG/WkUM0McTQ2pUat6yOPogV
FpKvu5w6uE7VE2+Em4phWpOwj4QVel3pONms6CSdrRnVmkIlFQhVrtLIS8Wu
lg36Cfn2u1IXRkhvY/XJw2o9P2qudc2iW7dxL66J29Ky4+OtWlasSZ5dq2UR
V0YOA3INqX2Fwzdisyu9l6ARxcISRPeSv2DGW86go0/1BtkKda80E9aSicj5
a1/72jHMMyNXACslygeZhOn6uZz9I2uW17Ce9RiA0xleLb9ozIyl9ZGBbCOZ
LCQryrGDh+X1hV/WokV2pgvQRqG9RuFka79VnDHQkp88KavD2md7fPHlUMAS
LEwPpI8vC4NiKhcDi8ZTxTcjR9bvhE/7lDL/PHFao83eTLvG9q2XdsnNB6EJ
tRI2uJVcQYl+b87Q7eePeBuydIcc4rqgkpMCI/qJmJP7ycpdj7N1zVZzweQe
W2whFwG3cZgRP2T3MIrHTkQ9MtU7Z680S3vuiqEyLTT0FBelex90kAfsgSoP
ny3alFsVVVbHi170Iu0YgLlY0/Oe9zzigU1jLnNnaFbIy+QcNfJ9r4Z3zRC1
b1PqcIiU7in0U7MVeSLdZhtVVkoGCYdRsHSJFa7KTAv/6he5ciafEh4W3WLU
vJjpn0xFtv96UmxLUMxe5WZOe3kPTp6Xb9J5uDx4PpjkooVAwxYshaGoGWKv
JkUVm3rk0b3gRsZGr2x1W+xMDh4KOOK8jPQot+Ibl0EDU0Km5Ko4MuuzzBTZ
OVf1vzZ2a/bhT17MGpcMN8DUbJtzZJUL1k2t371qqRYyrpdYx1R91LZwQJa3
Xapl5AGJGBUTtFL706lGcQ86iI8FHZ2wV/rJedEupCXT9M7A6wpbGj1NMTri
/CattCBkUBOhP2k7FDW8dQzhuWA2+sgKRkwzHdIZ0kBjZDDs0HUXEsYEDjZN
CMOE0BRVqyBZAKUN53SALXLUEfnfPtsrva3ngj/cfJOfUoA83bPWtebaPVzs
IKGVK5fe63axfA0i8H2WyTEJ/XzJtonO05RuPqjMbZlooIlAqD9pdnUnbI30
Htko9p4Ar7Gd2g9dQd6cREm/qGVDGOvRgBdEDtQp5Ft1OnyHATLcYMsx7ZDx
5Ed8fPn0NWOS8hYhhxuzG0VHF6rih8rzSihI6bJ5RNWQ8c5BDNu3KEdLT+H8
OZKJUtXQ8VBAx/pEt5a5M1PnmODb9ndb/PQJaVItCUI4AlixOqYaBLtWmQsx
/Lng5xpRyWO6NUVV0tCLoGIXrLn22unyy/rq7qh7vPPOO/NwdZVVE4eRrqRF
sRvcyPDoRQUReALEt1FJe1EE9WyNeL2zKawTNlEgQ2FMXUw/e7GP99V9MBwL
zZrG2UVdajOkZbvlnyVM/OF973vfe9/7XpJTaqbkSpCLpFp4LiqwOmyCeooh
bEjail0s1cuolqtdURt/BDlZtNamKeKxTJ8NcfrnkzhmXauvcc7mMFO8rxbi
0M1Te5Q1ktbfXKuIoL4x6bFKWKPTayKsN5Bkbu9sAEklTL0WlTQ86Wyvec1r
ApyGohHrJE3RvlRJHW+ludHZmi1dNuIr0DBotDuEkngrHDrGgzePtc6XYVmt
WRuIWA9KUU28r3Njl8km49VAmGmniKYyDnFxPdlVG60ZnMiGr4A//bdbs/9q
wSCgCjfUqEqX8PTtwq0j5KtGW7dWtAdakZpihBhwQ2RDM6Dl2hC9aBIunomF
tUMFijBIu2eYcO4yOTH2BT3YBsvRkF53edOzEs2YZtE0AUxRlKRxX525L2J+
TK1ojZ6bhLpGtkPR+mDfTrOUyTEPZXpTAAGGKMB3iIcIn5LyACy9ssiJ9wi3
whAWSBjVi5koqi00DekRNHo9yuYhuhHG0SOPPPKXf/mXDz30UACCjyTaSagB
ixh3ug+GLfgGQU3vb6/0znUMHGcAXcRuJc4vaoct4BcFEb9yHAvsL+53lgWD
GCrjfFYBJim8ZXD6s3c2Adqzmm8tfDy9DLBwI3sjV8WibkI2FZsP5zrff3k0
VhaNz505l7FMQl91AFG1oKMraTl35c2opn1Drb2LkgoCa52wkzc40ABjbcUs
atm4MAT96BuHIUxEh7i0NvcLXAgNAc9B/cKhC20p8NF4msexoR4CuzzvWWhU
oNtGoDqGNjLCKpODAk/40BhykRbl1nZhjj9YVr2oAHa7PydFGbKqEBqAytlU
T0wIzo6/oCv739nOumGTAwIgqhjOZonA6TRRuaszReRr+ETndurMhlkgrNYV
bbGy1mIGXNyUYFJVgeDxute9rglJs/35z38+OjrFY36HtixjdNCsEyBV5/LU
4+CJMB58VhNDvk+4ofJFGGSR2D7C8BBRgU5yLjn4rZcWQmPe9GjJP/jggw8/
/PAnP/nJf/iHfwhDAhPS2cuh2HE4y83PprGuQ9RmEA+CGtCheYeGqg7EsDND
FUmAA26n24zd7J2NrVXuwhpSyWfO/GrzkUbgRifvtM2lnnXz7ZWvfOW3f/u3
I+jqZBeEanPDZW4+iB6jySmOayaIp6mubTvQk0sqnJr0+nzlsDTJ5Ra7pD4b
dHRyYrlrOdESaOJ1Lw3Cvz0OGNJQC2WoTzmnmIU1Fs0WWUKU3fodtUMUFB9s
3aX1fHROnBDGoQzLu46DiUgiaUoFcKNj1mNfgd7v4DEx85DM81lMGJuFMjem
xWjbnH2v3MTTnpMCNABIP/uXBehhrePGKuWxPrgqXB5WzVKiiGTsjfVEG7l0
pss9p76l0GM+lJTuVMgo8Y7OEXRIAk6biP/LupDQmT81kqp7x+7QiUAdN3oY
PTrhi4niOgRRJUeCi1tuueVJl6NfQoBzApfR4mC6CL2iJymNYahwWzokZTDh
m+pyAa9+9au7655p06mFn73x6KOPZkK85z3v6U99gvAHmq4TyRFpl4HtX/k4
vT/oyMEBHU1gQQnsr3N4c+sdH2CZRCixINuIRnxnuAHA/VxhPu66Ei0s97OS
WK/07JpFPQv2Bn0VTTn14WpR51dmCWS+qgGki7XKu5VqNsl7T2u/DzaA8rMe
JQpN3gr6bjOna+jb+2AfCZr00KHS1nvaOjtbE35J0oZXF3sJFLWxfpe3BRQd
8lYLcQCEqXtt3NZgBSfH0ac6FSEy4sZYwRPi2LEyJV7nOQwywYSAwvmx+wz7
EEbgerbldJyUDvFT1kxWhPC8Kn/ycmRyvP5yiI7KpLQvN29DgNXojeJof2fV
7PxW6JmDuiQLppkcsY/waBZinbeyVg5rI+VopQui9i8u0vVL3+GzRB4CEnh0
VVOKYHg4cydZQlnXdek5vTywyuls3HbbbUq2m35CoPge2QnaK3QIeMq9QozF
NEAHV4UQGV0gR6+sY5S0b28OT/pXW+S3fuu3Nv+7sMan0e7RN0v/03GEA1iL
zTExfFPUqpwEBF39EIbh0VTvnb2HY3KmK7NU+RQ8kSkH8l/mnk8b0zEpHmYA
d2aERuVXq+sch4EjzwLvUz3oXIYMDGmR1ntPIeiQWCG802PqwZlgbV7OaR42
E/i86AQhQ4aK8mQlBni8Pdw2iEyLnJHuVBPn5mozgcwp4RfCSi2Epko31Y0b
0nCgYUQ1V1avPJbql4joKutlyUEHmwGvwyGwLEos5442wxXyvHrc8ub6XJN7
5Vn8xqnNPWFG5zwnbrxzuVoTg6UHYTgmIxwufkXcWEjwnC0V1hh9yz7Oen/T
5RAgXXyjM0wtZBIxZEstWN7BnAJ50jMDfPxwaeJ5E3K7SMsupoc+DV5UDfl6
bx7TbL6Sg7NDxvncncqpzgfPiE7R3KLgpWugp9rWppy2ZUtGAzFgveda+y1w
iDFHw5KXrp3cB/QAHdq1BBRcHvSkEcNkb0cU6RUqml1A0JE/Fbg15s3zJljT
qbkKN5q9mAbNN9J8qz+1wWmyjAbJtemdSjhlVMXT4AYXY9SgKQXBDZQMudp/
dxzifk6CSvRrxyHtYjJTluBcjINtKbUPdtqmU48+UyHoRuulyUMstOXcog5Y
2jt6pj3x6fzzVpi+80mbz1Q4qBxj7HRQjXvRi17UU+7ruuUuvjM0YfJxNJvr
u2jLa1jcVOmmiGY0kg37hz/84T//8z/P8BOjntwo84/K8fQGBU7/988+luyg
pSaNTsEDr6yH1Wk7oTNg/QmVjP5xrmRcIycBJaGnxbvmpKxLHeMEM2Rhq/70
uGdyXLn02GowhRmtxO3CGFNipwwPtaVhsi2e9hSUQM9Q8DJNy4U7NABaO49V
zUOP1apIp1raBBaIE67wgZ0wesYEkLk5rnm1dWOQ7vCNAxZB3ZXa+Sxr5NyC
REw1h1fUtMlD+g/fQ08HXYHCAVI/iKb0f9gbIhgEgvwXpIQw/Sk7I3aq8HYc
aXV2o4pJ4vSe5nkLp/ncQ+kuWr/tStkY/I4HHnhAb0F7XBOPU2x/saerX2ty
qvRsKvbfc8qVdyPNh0QqfDFF4pV++4WFzCXHQxi7Sdn1FMlABIBaFwbkWOTq
LlIT9r6uidGU04VN9y4dJRT4tJxDld7QU+thiYpTlqB1M86qvbJHKe3eB3N/
pn6fMRMc9XBf85rXNNnacLvIPt6u1HPXy0k5c37TD/7gDzYtJWexSVvOeYuf
+MQnPvKRjzz88MPqVuStAnONaGXDJcpVLlM8k+NYWb0wqSgE0JBwl3PvsUqj
9y9hE/w9cZLVE3F8GBvLqgtxw23d4qTUvW1O4pgho9lMTY4goRUhxLHMSD/Z
DwJNKoBas/p+CnQoTlHhsgKBdX3CNBv/arxNgLAK1oUlzx27vAFkIayKmi7L
w67gZYCga4f08dVDmOimX1bQJ3gCppbDHY4tGbQTyjphgxAw6QLwZtvrJ1pO
TCyfhfqxWIeqFjFPtoR2Y72I7nWWMO0V1C+goZhC8B/RsX8tKsLw6L+to6Yx
Vf9urbkRRDSB2/Kaw+16ZGRkWLA12BvnmF6bju2sWd3vEnOTHT6vfUtefNXG
ZEIKVmiMjrHQipisBBLIrOjxqDt4N+rHgw72KmnBVe/23/7V3b32ta/NW5GQ
Ja4YbFrI2QAtZGE3m5eCr5Gxp6PrcfdkM5jDBz5LcJHvQ9/ekLY7tEsCnyZq
M59CaTijsC6zRCFzy6RlGAgIaIQVDz300Ic+9KEHH3zwAx/4QG7L3EYNFFQB
KwQQtRbbXC3hIqJAuxEgtI4BQnyMOGHPC7tP3JXox+hhzslu9IAWp1p5NV9m
+RQaPkuvT6Np+tVkW2hQrxR9wQcyUBPMF04MWwJY6vRhe7Yc+pY1NfXsNYcS
TLDvcyts62wDi3ElaZI4axgnRTIO+Upr1wIMkuxt8injfY3ZvjruYdeYG0MP
0CHqLu+jdmaFvRJ8KLgEkZReYpmyeAnyqMEkOSV2KgCCvME3BwLysCEA8VJp
F+mVc2fJtbTjDfVB0qZICJ1tfIbmv4YgPd9mZlvexz72MfVWak4RnpuucnP2
uJY/dSkU0HXlGHV8tAGJFb0SzDoxjRBgJdjIijYyETmE6oXxf/M4hkKKJtjY
9HWbfp0KQ8nB4Gn+tJDxP9dfuzE38r1ICkyUg5adS1q5FgzRbdlWGM40aBkP
PUHCHURipVdChqxc4mP9kqNqp9DVNOforrvuCk/GqBG3HG7ks4QbbD8mB+jQ
omXkf7qjohMMDBZgP8VYGoEwofdr7TTWurICCoSSs/I1M2DkWcbZQ8Zg1FFc
YYEYalUztoBFtBhpSKS8VIBP3sfeSubC0lt2FeDwECVPMTrIil65qGrDCoVL
UwKc+PBN5Wnb+i3bpVckbUGKyAP75BwD8R5h0mVvhXNXxSY8MgNmyVyZ2SWg
nYdr1hTSnWrEMDHYdTWiC73w77JFfLemU/vgZE7XcE1ZPXa07gw6HdBMXh9b
3LAvOg6REB3igg6SYqQyz8qlSufQliget3yE+rvyNoiMh/yUDA/EMEoRHdgF
WNArjpMQZIQI7DMPxPaX4ud9M2LHBJCKtR5J68uziJ+Q02RmsJxF/FYZyjYW
2O+7AiVRTeQlqKX8tpHvWWfrtqIzOaaGNMEuCzkroqfP3rBFMsuXJtZ0lfqN
hgvUgdiNa/vVmbNtAorXve51tkjPWqWtpnv0TgOf5kOrrzsNsRvz4OJDlyMA
CTRERydPur5O/A6tl7pZkSIlaUQUlZZ0+72BiDptMV7PWDqenTYTYq08xNXP
dm24ppC/hzW5zlFM/ZdNAjfWIQWLEnQsrdafcp0tEJJNE866emkwPbk/uQYm
Qcif7cHemDg2psSk/1A3z4ixMMJCkYwcEYZpbqBxDmT8ZFHcVCJHEqRHv/f8
wkUdXYyU8+W01y89Gtio4466R7cw3GByCAV3Zh7TPZcmehK7QAaQNqMywJo8
TTDtcfVfIwlIG7BtsTlJ6eu/uRycdJpUGisIfWRyCKiST88T6b8ipdM9VrrS
oT5U+yHdysZI78q7yGadILx8q7JNohA40v/+csjxgY41RD43O5C9HRNpDcgW
Gl1sc62a5rDwnUXp2czwZzQn4MAy70W5V66Qj6CedvRiw94i7Qbh83pvqTTJ
bAjA29HgRk9qImZ2XjA4n4u93Tl73MFRzy73RKM9HUilbHqgP/ADP2ATQXrv
nWFX/3r5y1+unL+Z0NzgrbSWsy4++MEPNuD9bMwzORgbUrR6sshznbkcnDUx
Ik4iKil6au8MKDD9OnNfIRvLwCDFw2GRYfHZ4QaNoCVW1LrqWiKmxA4co4+F
tgZM62+ygtkeE73iVhyxDvnuc7hgYIL+LT/bTwYhaoRltZZ/ShS3nO8+WsKd
w5VesdhHCRvCjL4+3te0wgRkBCtYCEpgWDLIJ5MBWZb5HIfxjYuiwEZUk26N
6PHrX/96yjAMHneKuM7Zwa1tLrXNUVnXJ7ot6ZWvfGW+sN64zedQpRd1A+nP
gIX6aAt/9VZKV55wOUCHrtaEPkKPLA3Sx+FPQKSVzLotK4gLjprPXUOX1F33
OJo5Teamk0StLmPNN23CFotT2I5ZKg1HulYgvQUuuyHkzm0Z70uI/lePVvVK
rhboY8bY7zo5jvSqPiVk54yrot3U5RNBMB5iA55vqHUj5GRrNaSNbatYhhRu
EPbkc03wCsNk8jhokIhhHJasl7X36uSNM3zIzMZa72n2WBvn0APxrDnQ/OlS
u98ch4wBKJ3hIcqRwygJwlrQzW19q0UnRJJFe6boqBRFG0rkjQyYzJjOmfUS
5sB/GMvfxGKF7aOX4+JCGGkRoct1NOB4ouVMaJovua5MMixo59wQW/nKZreu
wQXajOozB6qVsOQsjYGGVKwdXGRyWdGpncuG+N4xwOHVmOdMC6EPMQfrfbIe
y54giiO+Xr1Ii0zfEh+DTTJRoIVNRlaHBvSuM0fV/GZLLIOzqluxmmVs4Yze
c1om6bPWdELL72zNyfzodkOvt2M2yZuiGGW5MLkeCmYRNogFIX2hiuXOKHbr
nc3qcKPJ3M82x4wQn9VvqC1Y+Ubf3ny+clHnbvqFHsGFJiDrcAoEuAOicLzg
tU4IQJo/ZrJZbemd96ZfO7q5wY0FTpkWvsL6lVucMO9mNV6i3XZFslK3IwXp
RdgD/bEf+7GWbeOGdq7SLSxtFfd6A97kvPuiTIgQcm4tNxDzRauz68w9yh5N
1oX4CYNQG1CGR7CPitDjRunR6hdbrK2qPaVvbFTDBN5K9sbDDz8s1tHvUwYL
OmS90UfRSuVELHmabMtJrWETUAqFgqP3ve99PUd8dTGl8T+JbNyEG4358iYN
NUnqKUsvRStvMplBOSmLmmWyihVrvLWgJkgexOpuPUpnCIrKh0qJqjhDs4Eb
KvLYHp7yog1W6DR2ZmxADx7NJDLOWZU5GqOsn3vXsiJQuc76P1wY5JPFK0RC
Jusx9ABrPLJOizeCXR9uqNJFa19ty+KryvT0zqadjoqsZdIbL4cyYWU+RNd7
Axhpt6KHmU+d4XHrrbciiyKXrvxWJlfpSrbHbbfd1qwWDAw3nvvc52axyNo8
/elPz+poo8xVtwU3pbv3prRC2iaeRB5vZYVs6pss52aLOibR4KbKxEunNWo/
Ghlj5sSioCY/MjO6iEm7QqoJJo/u+OunRgxiobKoXQbyJ8e8BxEkCmPqAQo3
wuHv+q7vajwFedoNId45s8Bcl2o8J4n6oqZrjxKxHCDLzza8Wmj1mNoRECBZ
Hdkn+ntqoNB8axp3Iw1sRh0/JdD46Ec/+rGPfeyxxx7rzxY7ih3Vjp6FgCen
I/SgDUuISa4EmVOIqYfV24IdXeF6jvIyPE1246pdwPtN4oGrowf7Qhw2fT6m
iAqTTMRj3dOaRRh6v3I0X8DUWrXsSjyEnRnqlu3K3gnPKmxhaazOsStxwqly
TSz0vGDvPkS8V74q57JauYlm/Nyhb8w78LsQBzPAVywY4iMrjgMdqmg5SkOz
4caExAm/IJthjeKrKIoR8Vi4lXyHbpXkmjWwmyzJpAZGkkd4prLeR9of77zz
zoyHbI+5LWTVqZuu/dO5XIXQLjecRplaOfo/BMRIAJGuYnj0rJsSTUXTVdXV
GhlLyPZLq8lcIlSITc1OWDXEFiOqAGAZbWnpGK1D1vb0zAdjiotsaPfGc3E2
IUFb25pFwrQeU0MXKupkocCE2vPClT2Ono6WTxDjtw89Xpnls06IZDHo6MH1
RFgdGpRrwaDxTV+qArdHrDlp34V4pmy2jzeT+8bWcl5hhkG48eijj2ZvhB79
khHC6siL4bzgjSsKCMwzP4KCHgqlR6W1am8hfCPZ2/qUpi36UyslWPcEgzl+
1/jnU/2C3r1ix7d48XNgi3IV4CMWJGKptd+ytKBj9obUpIjrrMQzQ/um0Ohs
jH95HL2yDO+ERkfnXhBD2neNa+kkL6UrUSuUMU7Xsh4q6xkkq9lfzdryNYt2
uoybVMJGAztD5d2H3DHvDFe2lU7fDARdOaSHQBmtGNQ4DezOZDOXevUiokvR
TrCIMpVuL6HHy172sjY1NZvYpwwPhS2CpcGI2jelsmTVKUsQY58gYX9KKco1
qKroUYrPk6XiWa++EumiycYQxeFkTgxYtup/93T0Cs0utVQkB3/n6B6rtsJ3
SfWOU8qMmf6Pqf6uo9GkrU0Yf4oQ3UJPvy0+9yHYpM0YSGZ4BB3ClYLD+i/g
sI0Dv/JzwDUkgZY9+j4Y0iKKfMu3fEuggaHac8GyQ3ck7B90ZHJ853d+Z15S
hkqoEnT0vZ25Vd+6DhweeughuPGRj3wkGMnqyMvoxX6GIZKqGkoiooMLmh44
G724ZtNaZPZOBQV9dlEONAxgaCRFSxayOKt+YdfMbKBTugJDhFUPuvPw6RDq
zIrJCfL1bP0yqsriVElPgL1pb6XMVUGzmYq4g6EyxJjrcRNd07q7fvRpQsQi
LqRF3ZIXoGAULzjwc5/dZ2EkkPE8p0ssyroLYHWMiC4Vy+Mb7kmyDCrZG5yO
tZo6207n07oRY8IFExsRl0alk9lBiGV7NOuk+ZquLQRBD2yxGR6kOaRrdbsG
HdnSlP810VYHxyxpr2xBtS22RTYyPU1tVtb8CGdgEnZNGGt2EtlT82OZrAmL
9J+fqKejPXsPy1nbBYb3eE2WwFmfX+pkCUSRFjGTcylcU7GR7F5e+tKXYtxJ
M5GRz2fRYyJfpvmgjE50hZPyB8fhqhYTlrJphve4hVCyAHX3o/0YCGfhdOZw
3gaBwIN/vu72RH5aXN1+UBkshA+PP/54rkq48fjlCENCEjGK5WcnnBLGoviu
vXUAwn+RE8Ho6HUFjOh8U4gVpPr1o3+TV9hyAtHsLkbFr14aXa0BK9NOXIjp
uBP2FBBup3n7K0fvP7ixlbsmOx0iqBwQ6/1cxr6oxdihyvNXJs+bsIq92dsY
DFwS6259W85XwgIZBX0mx+ruR9iAG+ODTZpjKmfncvv1ObLG586r04QhS6Cw
EDJQGVoEVAEUQ8h51pGTnb/qYPDVv4y2niO9QWlw6NFUlNJVgNl+JyGIKiZX
q8R+BXHcFto+vbNJ3p5L5HDqHwrws+TbK/PH+4qupBvE4rZPWU1KI3/naPQ2
l2EtPKzoZQllRs4911gsmq/xazCft1opSNARZbfMDPjtQ/2Yxt2aPQngWwWT
D2roevqt2XZ5JP9gtuF6weXQwuZ7v/d7e0zdrLoYoUWUEgEExX3Wo7BAt9nT
72GR/Ao6MjnWB5zD0skzMLJnMhQ7P+XM/mxswzGVMv2rKdr86Usz6t797nc/
8sgjmHh//dd//bd/+7d/8zd/86lPfSoAyW1RSeQndgcvUhWtBtZEHaHc5Ou1
vcbP0YAG5QPeYnD9r0c3yUW/WSDQg7oCPvmmaysdGUzACvUFxddyEDBXWb+W
ketq7Q34/E7IHmAAoElMqHMRzrsP4cGFJecdnNnaa5iyRXft6Ms2AGGEcJr4
QefSlSVQOCxzGUbtuHqIMK817XpYu4utZa/4ZcIvHHze1vVDxlkBHQ1VTZ+X
pBar4elMgFc200NhO3EPLUkEbD1VO7/uDKDjrrvu4js3Faes+9Vf/dUaYYMF
DgurI9OiDVHbuOZ2MKKVQ//SnL0dub2y1dQMz17qYpo5DAPL9sw1YuKyMSx5
YQ22ByaYgAYcGHRABn9yWMYaPWuOESJb5vd3Tzr/roRlovMjUlmrYAQMMb3m
Z8PVXq9OWYC0sdK6MVOhVd9g9nS0fOJqibQoMmVvMLosSUjVM2rykPwKvTs/
8w8LvW8JoPSqDu09tQzF3EwFswEIq0PBbIsX8z8PJaz4zGc+80//9E//+I//
2C/9mc+isSynA3T8h+OYJKzfGRXwoRsJkfrXEjS9s7vgZi7CCYoNsrKCUelm
4zUT1vtArEMSTW7Fv5xwPawZ51wblD/qWOfCcwCyFQRJ1Kkhhq3VkciAxWsD
1fB00QAbPRbE5D5W4goxYMKQZGt/WZ4FVxfN8LafP5o9cV5GH737ECD11Wtj
vQ5T/uUXaeh1kVv4ZUS1nz9aQnSDKnqWVnaec2fw5SUlwZfZpKXJkrc0+m9f
x/vTTFNjSjz2bOOshZaG5lCK3aiEZXWokpOl5bBkYPQGsZF+9q/8l6Z9cz5z
uuXQ9RNIZ4XOfF3mDsfydy4dXXVHRRKYypw3szp4HFxmjswYYnMKJlrlX+sj
ySCRAmASULebyGEXYzIjt6NTdgQFPY5WqO4q3XXoinmui3dLu+UsPSpKIxHp
/JKewsJCPeLDeJuqaNv4FN3zhnTlUzyr9Zuebj976Q+VlZix0Zt7WPpF5s40
zl15d5H3kWnxyU9+8u///u/DjX/+538OOrI68lbe//73Y6FT7UAP+8M//EP1
s6TRRTyoH/cLXO2XXJU8nQcvR+iR1bFbYCeIaTM5xgde7JT1yOpQ8jxp9FG8
bHm6wa5XtVgE3Og94pB8CnFR1W0jSa48bQb/Ahp8H+say8LWjDvxs0cjyPHS
QQcoGCt1Ze8Lny7/wgJhzwxkZqV0hn2cwTOyOlNhxXT8kZXSLHIymLp+tKtb
AcuQhJm0KpjZKvwg1pTxXKBpESTBPRZIr7To5llzWgk8Tt0On58od+ihU8N6
YQti5K1M05j5IRyq7ULA0hu+/Mu/XI1M0MFbaVa3V3Z+JedTP3CRrnny1+IA
wiAcXmsfdIi6I4YJjc72EH4USvVZVIROaw6Lh4iomM97v29EYGhkeNBBa1ZH
b7bS+6Wxanza5VvXpEdf/OIXa7LZz0yFlnbw25PyWYVjzAyiN51f5kJhO06L
LRuJJYM5vyM0yOSgGoTzH0b1YsDOWSaA3Ne97HIEzrfffnv43OX17Y1qX5Qh
8dBDD/35n/95rsqnP/3pv/u7v+tnf6qcbfljgcKN2RuT9+lnVyh7IgASbuTR
9H69n/p4H+z6sXN/49KXVsMaEU7HQsRjzzIvOSyq//6n08FPFDJVViAbzq72
FXbteetnTLDEzpUg1w7Z8DXkWirTihZtmOqOmAN7fmoYKyub17ByldEkRi+/
9p8drgQWsXa2qEcXgQyTGVG0cu9xeOf58NVMCxRTzsu4bQwwx0qG141XXGhB
oenSiFT/L0cL4H4xjennEFKQjuwjCm8ZNuts2wTOs24zbflLvEIGwVJ6pIpc
eC69IY+GxDoF1Oa8xZV5317chkgg2kNH4eO0iozxGuAbC8GlCmWsdfWEqlbO
uawK24NXfmY/4oPxGqaxOUE8SxsEIZ+L2zdonUG3l/7b0u4xtTwDihe84AW5
D7knaLoqDbvTvJXgt+mhCTI1clQHF8m2aTHqTkUHnrJim3V7a+PfV3QqEmEK
DCkYhMCNITc86GhI+7pwQ2CW1dHH+/ZuoWvOnMi6+MhHPpKl8bd/+7d/8Rd/
8YlPfCL/pRfpxGoTGcKIlLqkZghXjvoxwsYU1CkTZq7oLBn0NWi/fShCrxOT
tOyY5xgdfldT/6+Pg5HMy2ZmSMT81tEREv9cFy2R6rsvnfIscPEB61FQ0ca9
MILw4/z6BTy3nM9l8sunjJ85j+C+o5P1qJhDHkhydgRGuNoyv3bR5Dm7Fdv6
7zlkTpcq5V+oVvuFk4TpoMYiYsD4xkCA4CTJIxEJEQwRIeHTsev7ds7Ighvn
XiEOzwWvsiVDN3J9zJvSTGXymNK1mQc6YrfkWxQZHuKfeGIIHmrzOzI8pqBO
21Bn9o5mvmLPNkcEaVFrXl7fiE5MFnu1aQIXOrpmPCsAn9T/ubqWGTz9jaX8
zn7Z9GS2bEUbFiE5C2/imtrmGjH19aKanapRanD0gnzhC1+I7faqV72qG2xd
ByMCEY1h21+fZc9wpgRFOQJMDqsSZaK7I1bWRAp5xlDN6lChnMnR+e+8887G
0DOSW3n5y1/+0pe+NGtH33DpFWKwGQnBQvgQdIQYuS1Bx0c/+tFMjg9cjiyH
ln8mBBxADDMllBiTldZqYU1byKTzblQQ4JPzPsbp/ddHb1+if4Kfy8wCFjE3
ZF0kUqJMYh24eZwXwTq5quGGFTSC5dVD0GYryxpcaGLSf3cfjRrvPnovjj5x
1vvyfut6vK9FIEHTlUsB+4K00pe6YwyCnHCsLXAx3JhRIeoCOuQ914xyah6y
tEBGZtZpqemquTD4ANkxcIYhGCwDFtgCQ/b72fYLQ3pksnUrfRLgklufmfeW
S6cGra+oRrS9BgJ5JRhfUwQKQMRO1c8uJMJ/6Xds0sAnlzwnqEWh9oe/NuhA
tpQ0YWzoxzG5XVY9q2DxTy7zmilI4TVuYguLYywY+weXVu+qsX7/dMzOWdrF
XskrlwKWO+hBNyzWNXZWy7kdPwuhX/oZjORQ9Iib5BLQc4VIfZL91M2qwy7f
Auw9fVdPqkfQsPcVYZEAqRhp36V0pQtoDElKqoxmcmj6FnBl1zWq3YhCoRyT
Rx555GMf+1h+ivzshz/84UcffTQAmdSPQlreyloqECQEFzovTAsIjOCud+V0
CczMaUGbh6YoQ2LVi4ZXpGsi9ot0Lb+GRyqY34prVRJinS1xZltdP/Vl9sqZ
1H3PRSpQ7HTZUpNwUjnnrMpyHDMkmBYiGKwax9Kyy4AsKiKCeu3oTH2TDSNI
e+3oBuvNLn6Sy60XHPJ+nrko146ekoKxnBRBOdTchSzWo3M6D9LfCqYAxUIc
+l5xbSbU2aNp+ayiAZMw9Gg+NJNFBcWrMWfQ4LvmLOcWfltesCBMCjr0VqBE
qo31s5/97AAkv0ZDKF2HwpOcnZZVk/yuu+7KCUJw7RnxPYmNdHkCF0IQ4g/6
QYvUaQcmQ8HjWJ8ghzo18XnFsCNLsE9Uf9vlJ6g+dhao4e+4gOUC0B2bzJ2/
h9tery/bmOdqkMONVnG32dJu/jTzzynjVrH92iZu6bVUoTeNo26nR9ncyDwL
CtTa0xwLQ0ISjNzOr9A+dzIPBROM06QYX4vqztZtqjEJOh577LHsjY9//OMZ
Hp/61Kf6M+ggSq8IUW8ssRf3fu665b+TEGSHoJ03hkIco26eORVTfbQbyrx4
KKwLeRYezcTfFDOKnHce/gie7QgSNn1L0vatkmviNkKdwguT/BWauHLUv5+z
JKtWu3IRDV5Odg6FJS/YeM/RjUU4YkGVZXv/8wr9ETOmU7pyWukVb7hy0UXE
d229qFTql557LuoUCIU1VgYoUgHADT6i/sw5j0AQY3pWikNX2skgccIpvsoR
tO6aBs2T5kzooVgStZJ4i9XXx69fVHaDjlZK0xJnks4YkTG4kcmhi1wo8dzL
QVAIkax/MTxaXy0reUONtJT8hNLbp2w6k54Tk5myLqLXSBE8izV8XHUtX/hM
HuOAKLijeNNaENYTcZ248SKxcoim9LZF8XwCpK1r0q/9/I7v+I7JFxAS7KGH
AOq/hEMFCvTHxLNq5P/oj/5IbAHfW6vrprevmMSKDEsY0vkxOsY/p2P8ksuB
R5pNIprUwHbLetn3rEOJjI0clk9/+tOf+cxn/uqv/ir/JTwRI11PPchmbJXV
d2H6ZwUvzD9UMbYHCY6GqGFvGm+R2gflTWxq0ANPTPhUpFSW1tTFH+OKTgWo
Z8q2x0T6/1X+XNRxsQJm7T1Hg8WFOK4dMjuLcljFyNU/d3RZAjgclqVX1qpg
wdX53SOT7xc19XOLRhoHI4tXDOWU/LNwrlzkl5kcoEPqU/GabzTOrscxHr5M
69rvzmGB2+Ca57j0hOIpNUSrBfiV00Fceh3PKWBr3rp2iqCeso24Rxeff83w
CAe0sV47J31eQgnJWRKaTI5wQ34WfTrDg8/y4z/+41kd3b75MEgUS2epMgb4
2sK5qi/lJlywzKxpNi8bSMrRiH4Aon6HQsI7cig3tTAb6wB/Y9RHDD0D8oY3
vCG7AsmTDBoVlLWw7wabgardu05bc9/4f1+OtWv8fy8HwVVh0t7fFzVzNKvt
nJ08k4M6U78HHVkdGYFYPSpc6B4HX7RBlFc3DxsNBYbBQvgQdGRyZG/83d/9
3aCD4aFyDQ2so9EWMhJD7s/+FcStxxa9L3SUETkQF2UiMBslTeZHMyztX79z
tAWHzL9+9KgF0St4WdH0lKxY+HMZ7j4aot196O/9/Kk9q2zIqAsLbM4qGBVK
+GJ51dkeS8pYj5ydm1Kfs3Mgj9L4Dri0dO0AZIGUK0dHWlHQJU9R5Wn+sM8J
mE+QWVwU3WL55UWJPQKWA9Dgd+gOYEpz8991NK1gisxEnHTSjt4gTtgTN3vn
d6/nmhUkPqAOuutsE2yWZjO0A2ZLaCo33Mhb6ZV8GfQGLYeIDepsm0GSrdK/
WllBRz5LWNpwwclz9o0py3fwc9ytpU5G+lo/ICjKGIY/YiaOc5rG/crMqgHn
d0/hZzVo4MhWeG4JFOZ3/XrQ00CjIqifbAs5jCXg3MehnO9dZIB683pwL3rQ
2/7NRdu8uUELPUuGELpSWdDU6/kj7UFYN4QOgpS1lgu4mmbNnwYz1G3VZ1QQ
B/vYxz4WYnz6csiz9MqI6NKy2oUL7GDv87PUp8jVuql+/v6lP3jXjERhAfbV
uBnTTpyXDRPsTUu4cFVWImSSMz6nYQI9pic8RtMsENu07q4WF7NnZsY8lFkF
yBX3XRTOVzK2UMPQQISEz3Kmaq9KbizxAddNKZXZOXBj6OQyAJ1xkz/F7p7D
RT+f7bSyPvoAWOJjvy9HwyAZFPAjbKzID6vBtF2+69T4Zu1IdEdFrxKvs5Qk
F9ZNvglG18UiNXm49t1LF9+EbGk0h/NE6P8Q/KGKfOutt2ot1AxvqmdyyOGO
GBawtEc381tcP/zDP5w93/3inzCrXPZvXBr6AA3zlpLGUqhLpMKNaXnJw67E
cjwNWyQHR4ZXwMSc5x/NxuB9j+iIq8/pM3t7IjorkRpuLSuP1YS6F1/5ylcG
LK3cnix1LHFRIY61J1ib11kdHKjuhTwyMhjRJBT0ftF9sq/ISdFJGRMs0Mje
CDf6sxczivKFu+YuoJvNnAgZxEjzVv7yL//yb/7mb8KNfhcvDVKyOpBISYSx
xwhuBBS8LfuLrJB4iCxMj+xMV7YVSuT92tFVdm0OGBj4XQt9rAuGDc4vIh5o
+bzvMSdXuzFYENJfAE0CFHVheVheDOEsbZKwAka1unbohP/8Zx+rSAURHd2p
+MAWmvDg2Q65SUjn2qnu3jWokdFQ8i2XRgyjnl499ILEWygoCh+dC3I3DlBF
1AVGgQ5Vw+PorjhOFkbekFfO9t7zgvbhBkE/AiyCA8x+IgwZqBm0bOYlKDEf
2KJ9XbfWXG3h0/HIoljvFWKD4YkZTtp0Jkd+TT85LG3QLbdmfptmWGpvUtgo
JSRGwcMVl+jykDHG3xYghRVCmmN6AJnfOZqR/Z+nQ6DS7j/0wHhfQdbsDezH
/tWFUX0xpfu9R5nv1srV5ubFL37xd33Xd/U7Ola3FqpkMDRcivuwLpeYEOho
wNE1xRa4Cb3erXUBfV2rQCyFt6KlS24gh6VvCcaF3DM8XnU5soKCjnycfJle
7zq72m6tmw0TPvjBD+aYBBp/fTn6RZ7l4x//OIflve99r1jHorWrMRHrEKhx
DDoWnDHfOCb2NQsfDe83j+ZZ803kbeE2B1nIbmJfnXB6Jn1EEYrFtdoN/gW/
Q/pVP2jBlqluTlCUm3PTRr9kxxa7/OxEMFBPVz3aG5TYuMgp8ANPcYb7j0bS
TsvqeMvR+gRbtcdHPGc20oyi+UrKVLfeVxs4MHTmGSS7wkWDGVRLl7AJO1TJ
baEZ6tnYKi+UEbUQLEOR8ClFtNyaJ81hXbq0Ylz7P9Zpc6Av6l6CjpZJ++w3
fMM3qMQPEJ7+9Kc/7WlP63ecJSKlz3zmMzk1GRvr2xLgBDt9vIUGOkRHiW5h
uEHXcS9hhfU+qUzJWcc4WvK54zmDGjij5/Lqc88M8OlW3VQyIyNj09yeiFba
w80ZaYWifqFwtMYbmX7Bxcpmxo/FPmXthwwgSymZ6OiK3DVc63paRM3w5lVe
D/J/44mOq5Zfd3ubpua2FH5yW4KOiaA2D5sArXrl9pkcn/rUp1S9IXWEGB+/
HAFIVscq7qltoAiiYzW2pMB4KP1kNfFfGmo+BeqFIkEuJ5twjQ+gBBiBHmN8
sXDWNIeuILuxn9MMZJDfFOW4fjRbmbFhfW23Ra6ezvw9R5elBRaWcBmffGGT
rUr+zhhcDFFbng3aF/mKt52OG0evN7Kf2RjUyTRWAF+jpU1vUMq1y7Y6JsnO
QHrr0cdhlTJjpo2H7z1CNJwgYAIJ7dc4Nox85rr4EmUtlolUhWwmOQjePbGF
thts5BkeUyNvCvXOrv/uSyvV22+/fSIeZEtxR0OG2267LeiQQGy29985LGFI
bwte+lSfDTraNEPgbkS6H6JKiHdTTSdzr4lK6Y5t3++WPFjD6OZ373XWCFLo
IqJ9sD9Xr+qzFoKIh92NT8RFko1V9T+7tCeoEJ6eyX97OXgrGQOhRyu3/zYf
uqluoQFUn9I5ZZy7EqVkZLU0QFlyvI80FH1F45MV0VDn/clY0VBqbPuuLA3h
sje96U3kEUgZr91b87O5JNDR1z3wwANhBXvjE5/4xKOPPvrggw8GJrTCtFRA
CVttrDQ9e5VXq+qNuAoOmPYWayJ51nSdes9ioYIe4xtQbuwrfu9oXs9T5kK+
69LgUiyLJtuom1bZiNxbRMyMRQDEVGcJSBmQQeZTjM4NE6YWuIjrOOHK3iUy
lMEiYa5MxveOY+Yjvmiwg6QhDiPtcq4+u3YppiN4jua03OiY5Oe+USt7mY8z
Dq0tWGR40Z7xz8+IinHKPtz8l4hc3156KZ6FzRrN5ncv/X+bA3pAE7JWaCbc
QX+v595dBOnttnfccUceR/hAjiNACBaCCPbG13/91wsbNslV6PNZKCFne3zV
V31Vb6BQKkzKuBJSwwdg8TbH+vYmp65ASEo87skBmXLIEmuKytVS1DkbWwzH
LF2qVDcoTtwK4ZeO6cadymDKsHR5Id5dd92Vy0DENRsgxCAk2LLNHmhn6aGo
Ejp3jWm0JYUxMBvt1u/73//+QBuLu8vrUTYaa6AgDCtjtfYrQdYb3vAG+ioh
TH5N37trCNOCjoyWztM1dHd910MPPZSlkZOS4RFivPdy9O1aKqyLU9DRaAtf
IFQ0DtzAxZnDCpz5JbzmKuok28L/7aOH7G8dzbBEsWACS8PuoCBo/VloLyAA
Q/hFL68frQ/FGKVLVve6iCUz+0x2kuVZLGLOC1fipvKW2f93Hy1clydyhvkj
qyY7F52Rv7hyKHucgeicYRlnzC1gT61/PS8e9PlJv4hJc/2QLr9yiBKPm7qA
zL2HmscK9qfPDOjwbdCk5Vy4pdSZpnLJUOwVCdmeVA+aXxkmUMLP6mgHVMLQ
xOiBytIyINttu4CWeV5GVnH7YK5HIEC7Q5RDx4Qm9gtf+MJ+5pg01XvPl3zJ
lzz5yU9+4hOf+JSnPCUYUVqbz9JsDz0yY8LhhoJNtQgwI/Z3L10OxW8FCojP
4HUMCiQ6SVfxs5bMHWXaHdnFcDhFJsn2yrbsnHCDWTKCR2Oryl4reclQAqQB
iEgpDdJrFyFBFt04Zj0UKa0uRv+1oOP9l6Nh7yK77L63KdrH6ZHyDc9ipA1s
L/btXUNva4cKYXKdeih9e1YHhyVkawYigzVcuux98pOfpM4hrIHjEW6EJAil
evDprKf01bTBzZuOytmTnaoSeoyIRz9HpVOfAjcUa7N45wfN/FtjOBDEaGRj
44cscTAn4sZJw4oU2JI48yBQFFayIfQhE7T87LWjidIZlDotMRCMCLt/ryi3
X13qvJu1TpDMXTnJ0sEL8FrIK/ycDg9gEdikJ8B+2CDM1ZLGPbNYF/+ZAXaW
AFoo4B1HFyrQKnzH6pgI8Di9C2L3yBj/rRTdURsNvTna05U+6bzT3G5xnQW6
u4tuKgetLbX5mfcdViCUPu1yqG7TPkDGQbPm/vVFX/RFn//5n/8FX/AF/ULl
GDfsBS94AcH/LBldqHo0wu+Kv5iyTa0mszSEPob2JiwvrSShCqeAxWWqU0sW
/p2W4LS+idhMgNfuOcGQMdId0pQNRY+shZnVJLcSThIE65fMj+/5nu/JHujZ
dSNsmHU9W89cAcaMqPwU+VAX39exanr6IUOn0hMnxGjA81Ma3ka1r6Zz3ts0
sw46Gkn2T9CBoN4EbnrQFeyLckwCjayOxx9/PAvkg5fjodOBEtZMaDSUsJ1Z
W8wnOirnxlWNM4Ohu8MHo2XExII/a+Ip8vzbR6uL37p0wZh2Cn6Ijc/QWVlC
fBbOefu+cihdYJCuFkOIle6H5TmtUdCBYr0w4xwWy1ARiijoKj4WahgHbFnd
c+3qTbVykyi899RFbj7UzACBi8Uzd81LozjDmYhy9ZAZHJNtdf2LlN5ziKL7
Fz+rb1wxLNwQ5h2FZlFr7SqEsnsicpSMc/57z66pItqv3x+hJ6mHX7t0Iuvr
+uqsqfbT22+/vSnaPpjlEALMW+l3XZya4S0oukDBi661T3rSkz7ncz4nAEE6
1XSSYlh7aNtroCQdAACF0WQ6mlqjOjtIe223mnpV/5poz7+5tLfWj4yst+k9
78buL3hiafPlhT7W/8XGKqvbaXusb37zm1uqBDq6fut6BSzt+K363ubKBQeW
F/bVXXCjrXooWIMbXMgmVY87hyjrLqtMCzktXfTm61t6BAIdDRcyfK6TQAcd
VOJgza6ee6ftu7IoPv7xjwcd/czGyD0BHboqaBxJHhAzcFYr1SPx534uvDmi
+KRUGvBzkxqRNNE2olKruyfN0fG/XdrInuXdRERBx+Di7BpYs42PbKZ1uhSk
dbfIgODAAqRTqhkRAnHiLLkzgT6+zxl/cK5WkHLvoRTKohir5MrRrnGBjmli
MI1YFBby208tosZ2E6bw5mkCDBDOjg9zC5RNM2Rpa97QkkdeIcYojgHSdef8
9aMXswCUhJcXF3RanwK5GDwHLXj+8HJooiSr0gf1V1XGIiOZYdxk5oxkVIQb
2R76z4YemNKavknOZmx83uW45ZZbdL5WmN+/ghrdJNs6WwvdGtarqO/kvyxt
ETluCO9YvE5nZHslWWDhYpWe8hrWJhBgdYxiIY6KoyUGu9KVafZa+y2EHlwO
wkte8hLCPnBSyzzk83b8fA3QwbAXEFi7VRaUVLihhoRU3/U6zA35oR/6ob5F
wybVK33Xejb1IK5fJCKb9gEFb0Wi54477tDRqRnYwu/bs2rQwIRDSaCTAtOz
iTIYX7XB5HqQYkPj58cJeS2Lyivhv0zSxMpdNcFIHaTjOW4Cp0LQi5AMpZ1Q
MHMZBJv71Ysct7TmYonbr5n0bz96wlqhZ7HBSTq4VHUueF9nO4GJgjK6WIST
OAARuXX2P2fqyqFevsjJgqXnY/Vxbzs6vboqGOVLnXYRlXtOcqkcn10nf2ei
YcwbFzZnx3vUiK2QbZn0xYVktTrGNYUwniNle+lIVv124XM1k3SbUKEoB+lm
vOjWiPTKV3/1Vw83pGh7kUveT9Ch3WT2xhOe8ITQY42f1pwlFKI32Gyn2tGN
vOvSm/gPDn3jUTjkYXG6xEXxJeaqTBG9G1Ryu7yAT0l2MDnwKxR5ARBaggxy
Sd6+VLvDTtLYNghdakBB2KeljdeRESLQceeddzaxG3+A49vV3bA3fK/QzRhW
5IZakk2GRqD9lKggCXRNgfuFbZOL14PAEuy7SKALtqiZzQ7BRusWMmkeeOCB
xx577JOf/OQnPvGJrA6CYMpVFLvxm3JYApNGQ2B82VUxB9wepsgkyidjjn/O
Joceoty8TiE1WiUMjH97NJyda+NUiDfz6M/lHhSGifxP9G+gsa3Z6l6acsuN
L2DtiMZb/svS9h7LbZRRm7WopgDFO4528AhgNA8FXcVvl8/1kbOsx5k0IhM0
Y+YcvTwL7wwN/Jw8KZD85aOd5fI+q8C9cUgR8s7EeaRiBxqLITN7VpnIomBY
qoObtOyZ+0SHgSG93XyUCY6tckVu9Y//+I9/3/d9XwtHeoUQh3YJxMF6McRA
Xuq/0rLZGNkbQUduCyVkuVq8dL1TX/ayl+W2SLg0etvRrH0EMO7JnBRrUN3N
uRULA3tJAWzSFikuFsChUcNNE+5YvepvHe2ExqdljfRK49CaxdGyltWSvPRy
UNfpLgLATrJ6PbgkvsHe0AB6pfeAmshS9y6mpBJWz6YwKrdFOKVvzEhroK5d
tJh+7Md+LCjL2KBn2DUELEEHFfRuQVqWjvHjjz9OnWOtEwS41nw2z44/KzPS
x4Vo5E0cy9P9/qEkHyz0XVzy5qFYJWI/l3kcAGebUjroWJcEj+zuS6/kXJKJ
b4zX3U1pJ6R8/qz4t1W2WlTQYe2PRm6NCKWemRLb6CEPKDiLBAIlOhhCpkoS
EDkoclw5dWNxHpFYtod6WEA0uGMIvfNoNTXVssU8V2Ijo+q7IKEl77Ih3i8d
7QKBns0FvHibHAQjEE9pohwgoud7biOyFgDe7FOSF9DeJD+vUNul7R4pmq3Y
RM0ezmYOOlr1eOaBRq7HV3zFVwiWwpNe78U1udasFm7o2AI6VOiHNi3G0GMc
SPHbKcycaRtIGuiXHKvu5VePw4RnnKzBSr/jairY5z4gV4xA21cssQI6zORx
RZreTVcqixIrmRldczu++hGFOT/6oz/aU9OUiic4XkruCb6ogK17YS/1pT2m
JrNJ2CBkS4QDYQXvL4DN0lNhl+HXtnv9IqmXo0fNI+joGrqezJ4eU/9qp+gr
/viP/zhYCDqyNz760Y8GFwEF6NCoWluWIKXX5eWRjQUqDeDaVWDKnSWSeiWU
QMjhnmsYQdFr9d2KiTxHkwrvTkh/8iytVn5x1oUa0tWyoW2ral/1ylS2zsFS
9s84XZPVwuZaEHJ0bu7MaupvHMJiq6PHweDOiIHMTkBUgwmQ8xzanRiIcMqI
Xla3sZq0Oz9oaZRrh37gvRfpnkVIlsyldwRSfOPMGKC6W+P7AD2Rz+kvLbjh
MQHwlXyqG2K0SMfIp++RjcKNuc3GFpbsF8o/jVvPlKo/Usdtt91G7RxZlIHx
Xx5HvwcaAcWTn/xkgY5w4ylPeUoWiMYKgqUdnaRTyeq2KttD23Mb8C6Vdzwn
RTiOY6W0k6lAkwr5cFo6a0zAHSPNYZ16kf6/MOmYk7PDESBlfjUqavTa7wK3
gEJLbtxR8UmddgOWn/mZn+nZqc8V3MA/d8HZGwQSxUBQI6gcqAxtnIWjjTNh
+Ub7G7/xG3V1oUdqtyIg5tt5TP0ZfIUnnafFS6MjZEAZpSUYkrz/OPpXL4Yb
vZgFQsFYetrBwIDGrNNV/tL26T09KQv5vouOIsKGDYttLE3TGaRfVQqMaMr2
6Dwtk3U3OO/45wI0GYQFIZdKYGAMAc4afW85tWlbnuLaIUU4E+XG0d9EGcja
zYuE8GjOBSxvOzo1sDF+6egWNz+CZ7HCGXaUL12gw2I/M76gDeNE3cqYJE4o
RINIaVGPLjveO/+O4iL7hIirKCJgPxcmCy3iUaNhezS9Z23T5amxf/dZVRt8
HMFtfgFOQu/ps11MPmZWdCtFg5XsCsUpgQO9jqdeDq2d+hedUu2ttYrrnZKz
2Ol7JymPNtaWhpkfTHXL6vXOW/8fHI3bZGPFGLtIQ0H9b2EQAMJoUSo7DqpM
04gEopQ2wfUXo33HZ0GE7qpCthBDkeykOaQ2vvu7vztgmUCHEAHCNhaHRI9r
gBtq8Fkd81Z+4id+IsshGyaHSAGySuSgtfF51atehYIbbjRWWSaugRQqIZT+
RV+IqOAjjzySq/LYY4/1C/YXAtgZNzI/MsBCtjVYWYMbHl+vT2lEayf3Erw3
aS2rcINTw75lGEvC4rSAzZm7zDz1mxaLLfLeQ2R4CnvalHAHVvu2eMhStMMT
/1IDMmrWtUOB/BwDGeyM14GYMeEdJatLgy5jMtSaNbJSU71gRvk4V+BevbRv
4Pss/DK3wsIHGue4ruOMSDAHRVY0Y0aO+hd2ztVLP7tp9bAx1oZsatLy6fbN
dRYAHRolAC5pZYHT3zy1/vyNo+e4vCcPN0jpndsKb7/99qZ0219eBnvjyZfj
C7/wC8OBjAqmBa8kfGBgkBFblKMXg4vedu4cF3R87dd+LfRodfzUT/1UI9wN
souWueuOurxWhGCF2IUYI2/a1mZiTx+DrbIu2AuALGHKhbHbjk2NRekNXUbX
06LWHVKAVPWKaln077yVZksDy/zGWXU9XBUJYi+qx0EpIXHTfEBxzyUJoIIO
Gh0YHZpQUOF4wxvekIXzile8oq8ON7QI7/esDumVJkzX3/kzLcINZfWhR55L
ABJo9HroATfIxGlwj1khHCpR5YKnNCLEJFzTmEM8OlTmD1vXrENjJvy49nYe
lgJnVofVjVE86QlrOTskQ2714+ekw7WjfRIAWTXcUqVXD9VxARBAYUV7fdWp
91wavU2kS7CFBCgvadVk9x+NDG4cLZP8eU6wCpxOo+Ncd7+AzN0nFZEbF2lN
QQ9mzJpEqBakejfoENsZT2NcNapcV48Os/RLQfrUfqaaooR5C38lnxO5mt4X
U8cV0pWVdpc+o0ZISEHMSh0BmkGjR9O4jbWttpl86623hgABAtygbMz86OCG
PO1pT1PVIqDai5Ckg5bpLbfc0mdBR4aH3G7rhdB3I8AHISZgJS4hqwbEelS5
yaieAobOZf4rpaIZE9NC2leqVD0dQjXIxV5YwxRMrWZXi1ojPM3dWsjBRatV
y6TWMsTrs4w3KQPfDiIEEBDVOhhOoKObbSY0b7WJDEIbCtKFDfg3f/M390oA
JQo6EePgIjDHP1duL9bRZbQqs80Ch6BDgZvm1Nhf73vf+x544IF+gRvvfve7
8Ui7PDiGMT5Jpf/rOGS1OnqdL6zYDaqjDJl15541fDedOg0ykm0P1+Liboxm
ed9JIfDGIVqLkrFililgjE2xuOLZwLgplHrtUPJUMWd1r1ejI9AgkbE8zhon
jYxhQY25IfIgiyHt8tajx9PslmtHR4aVn8g4Xz+6tp3levouVau0oN95aYWw
0pslcdgtIjxucJ4aI8d5lMHO9ViPG/kvkQEmN3rDSu/77Op0WB2iItPHsEFM
jIUqxVsvzfWo9CvoziT+tm/7tmc/+9noHIpTwoHhBs2f/pVZ8tznPrcNOou6
uZ3JraUCiQ+A09EvGrUENcGLRi2hU8tQAxEltOOEi1q06JSd9gtMEN+AG6gp
YpKT7xYINT6Ln3gz4Z2ldxX+2HMlWRrPBqSn3zjo3x10CCwYlqnr5NM1hbhO
Ioqr95831FejhI2r1itTz8vfEU5p6EKnMcH6JdOCmHxOkzrZvjQwUXZHzbg/
u6ouo9kbTOWDiJFyWNZYNqxARP+zy9F7tFBphJs5kqqUQpfNp8PAQhNSXt1r
7/k/jm7jQqxTOCcrzeQYB/gPjs5ZnXlECGbAWWeYbyK+N/7SivpZ0TcVoew4
l7fcd7RavnbqfrIg5GKwQIOujoYLSw1fP5qsLeQ4b2X1Iy2u6X/im8EN0RKm
0fK2k1A+myWjkIFEcU5eidSJ496LYOndh34jP2XwuNy0SC/gBS+yMGOMMJDG
1mNyrOJesWc/V/gjBi4lPbEgzQJg18BcI8KclBnGregms+pvLRLIGot5aizL
eAg32igz6bUvbLvM6sY+DSXCitCmn3krYiP90mf7V4ikn3VrIcv8zW9+c0PU
Rdqp17jwbFfABFOa6Peal3mDlkNipBO26tB+SOalswEWVSpMMm3g5CV/+dIP
Bd+7+5KThRutVssWw7PH0fuXGpalQqaaZk7Xj7gLOnpbaNMHG3ba0ZkQDXWW
hubXgbCmcr43BKNj3AXgfnBYqJPlsGTh93wXI33scsAN9kY/xUulaPszq6Oh
CE6Ju06QXF2AoZBwYZGKaQiOCQXPgvqdo724aSkAxdnBY0HJ6ye/Y0tYDBMU
2JebrgoheeXkLn/laEs9MjnvfudZPHMZ263Za0dzpTkRi8SOUzpe+mTEVqU7
yvc9Rz9Z9sbkiSb8bp2eraMdGLCTWT4zxvG+puFjuz+z0YDqcGzO3WRJoNbd
h0iyapqlkCDGsEhbMTMTk0dsiqSb6ArQYGiBDsEc/1pEWs2vxiuve93rMn2B
RjOzmfwN3/ANretnPetZGiWQ5shOCEaUsWCFYXc04bO3Q5sWWkugmT9yqdBH
iJHV8aTLgV8aBHWGztZK6VPtni0Q3eG7tWbdH18OTIxVrom8cQ0QNRkk6548
tf81bafQpYrEe+ii43NiQoqRKnlrJK9elEjb8bO7sjq4Kg1O+76mJ43VT/zE
TwjtSlRJa0pdrU1Mq4+8sJbQQVyX1BfZqnoK2XidStUbeZ8gt6Fr8HsF+yV7
rIvpl9tvv13jBnRWvVde/epX9wSbxi1SHWYDDfENzVa4Kmpm4YZy6a5EwaPq
BrJLsqutWYF07i1joztSkiOFhMG+Cjhs52BH0wqNZhBrZbu2EBax3CqzKbPG
m6hTI4QbtsWubYSKtVdb0NKKWx36jUP37+ohSz50OlfLXj0auEASDsuSHSui
3zoS4ZmQi5THqKGMonPgZRGPAZRrdrjOqXOInAxGlgYaY2TlbIg0QiVvu7Ru
PJs0M8Am0KEE2KVOmt5+QWtl+mALrXAYhyR4L528UaI9oslsoKHRm8pQC1+/
wgCB1EwvZhu0JzardVpBDCPcIWqhpbKCuD7Vx3vPkrbCpE984hOf8IQn6BzX
6yimFD9yCloIXViX2uRpWuoupFhsbY+U0su8jCqWIaGF2aj1TAsYgprV63CD
WUKby0iO9ILTTrCr3Rx/Y9DRph++BSD9Esr1pBphawrmrB+lVIVQTF+XvyDH
0e9dNpOj2yS+0RdlyRAVbMCfdTka7WwbeqfBO0lSoadleRhCP/zDP9xj7V4a
n0wLNfVww5c6Zm+osg9n8EX5qptsBLG5CTzZfv+NSxs7/iO47kaw5npSZp1+
K0wO5DepJRGPZR/OJbF3H01ViP5ZFIxALCzfbpHSsbl69Ca4djRRnU3O+J+d
cPdxbKkOMc4c7xWfisGuxu3a0f4A++KdF7VP9o8rXEsCTaa2uFYjszQxA+ae
kxTzGZqg5ZbtIGLEVG7dsGt49c6TZOu1Q6HIwfFhY7jgBSg4g4oLJgI5lTZk
kik0Gs/O3+2wMUKMJqTO1BONEaYLHDRHbi33u3qNfn7L5aBQuv5uhML8bK9s
2veTGG8mSpjwpcehVRzc6OiX1bZkexATe/7zn9/yfOMb39g4NKVbCOREWuxA
AJdbqJ/PIm0hkvCfLocGiIwQKUXByT7oXx0aFU0XHWj89nE0JXqg+RF5K1lf
3XUj0IU1SiEbPpimCT1TGh2yMwIF0CNjY2X+BEJbuV3eTA7eYs8lTMhD1GIv
k6PhDTcaw4D03GE2q0O2a1ZHv+i90qW2fLqA7rHvUuYWSnBb9Fsh1tEIrLpH
xYF9fLuhmTxxGFE7JW+TamS8NbC4eTd1dTQCq5wSJV5tqQ1UtJB+eHfXL/ce
/cvWg5iQZsdoUQtcWPgyDuBuxarDimVUz5T1RSlnDNxzNKJdscn9J0kxLhU/
YrUwgsnj53e17zgklM8lLedkEH9qoYzxV8HCak84I2eWiJv1hpXmTaVkUiT8
iPsvimpLWPcERSdmEy5GQe1nGokTKxgx9VyQe+3SkDevpImamQ00OijGNBXH
KAg3KGGS32yu6uGuohMd/bbbbiP4I0D6VV/1VU14zZuClP4lmrp2LY4nP/nJ
t9xyC4fllsvRK72tN4dFnTmLxWJpwHsurTJyfAKb5wwLbsZKRXrnuqbOx4E2
jsVRe8MoptwK8SI+vp/NkC6gy8AJ17y+ZZuxgX+eJfD617++edLjk4hU+8N0
WZJFi7cWrIXcXk9yXOkKBfu7LyJsWTINOPXXDp0pGnBipIH8D/3QDwVcmRw9
jq5HHU3eis4sQUezpa/uTkNaAY1A4/HHHw+y+jPI6q7hbV5V14mNdu/RZkjX
sxuHFD8TtxnVgAj8Ih5rBtcwqj0k42A2SgWu08dirR3//eXoKywocQagIUrJ
TxlWkLiBGLP/p1CxKOj9R6vlVYQtgjqa63jmN6l/uIZxyM/lIZaPb2SE2MSF
FyRPpz8JNgVRF10ZyWR/QuMla1wtl2ouCXLpTZ7IAr9TEUH1nH3yS0fPLDe7
VM5YN6OPKgCEjXBegJdXskT2oBXuaSbVBGsSamHffKPGz0Npuw83Qob2sqbr
a1/72kyRtrPe03RtigYjpCpCmDbEoCPcyFr4si/7Mt6Khk2BAKKpzEsHUXRN
rjE6nvrUp+atqKj1SvgTdGSldAEtTIpbIqXo3FPtkG0RwVgtbVO6F8FCP0Uj
m9tSLTCnF/kyKAqqZdsQVxlqhJX/NMLZZq3K/+441KoEazrMdoWNZ8+uNy+v
jWg32jYmFW2fvBWI1/d2U5jYPbUebisojOrMyvkb2yw3PNK+t+8igZ5zFHQ0
OJhgPYje38+wvWfUXtA06xoah/wRjknGBm+FqQM05N/5SosGyCRaQSiIohbd
TlfLQ0Fm46dA5sa/91jvdrEl/iZPFzgHGtlLucbdqc6M0hmjT5jM09aw90k6
nCMV53JUOGDViP6thG1ezP1Ho4GlU+e53H1qAmVdL9W4HKtFJPmC18oes6gt
8O37Nw5hn1HRtn7vP5QJJ8dx70lReTVuMJBhM4tihoqcozaycGO6oxsE/sUy
1NeP/mgiRVK9TJ2V/PN6+mo4eeXouss7fvOb38zM6PHdddddYUI7ZmgAClqq
zcBsjH5KjvSGNsHg5fu///t75x133NFu2+tEsTjjjGomh2KWNWfBJtWBBQlk
GNLbejMpD5xSORdWR+DD8Ogy0MMa5LbmJjysoKZLow93WtKE7RE+8ETmpIAa
WYBAQ092jCyQck5K8gTXdb2RxKFtiBocWjqgwy/ZbD139jlLY1qC2B1SP4Bu
OeWtXyQK2lOtLAmpLC45qX7+15ej0W7wexxvetObei5BBJNjOK+8JUhpuJon
v/d7v6craOaNOlmio1yz1rJd8qx4Y9ned3QpshmpmpQoIWKAG6Z9j2B1f2o5
QcqSowE9ONcMj+YhkhWvBGfD/ER7WFXXqJJcj3tO7dXWHfLM2dhu6xcLE+DM
0vbmJXGWV5135jwMCZHPFunbjz5NaBKgY6TWpURX/37fZx/Xj8PY3n+odZ1Z
aiuqXQ2OhSyewyxZORvO6irXaBa97WixN82xsVauHHrvYqRrVI0H8ktHJ6yF
XoWPyCS2IYYVTbngAg60bWVmNA/bNJtsLc9m3fqlBiOKx3tPUzQHXwpST6Jm
ptggOd+sjjwaTRPUwem3EgignSOX/hfHoVfL0572NEIfSGKzTHBQFdV2tgwP
PRe67J5Xo9S2xaL4k8vRuqBKhNNFJl0/OzncJVMkVgKQPtsi6oNtlFweaZoW
BVqjSrr1W288s82odRFOXG5FdFQ3ao4kdcdzd1rFRMICXV7f1frtGkRXcPaI
N6L6d6edlmR0mPw1X/M1agPFSDVe6aH0vT0pKo49gnDjv7ocPUqB5a6nC0A8
g6IK/CWgu84JXdo9hRRGdbbrsR/kmzC+EMM4hqsIRqVTvocNpWfTYIT+A+FN
KAEoWowqVmZLbHVvI15scJkX8cbxN1YFNgnBFXRMpmMFZTO/F4KYvKflDy0N
BV/p/qOdyk353CV0hh6zghYtmWnkLsDy9aNPysIp10/Kor3HvXB8lh6aMeaJ
CP5M3GNe20p4FoUedhmoSRred3ShunGoIELCq4ciij6VTf7Xve51TTkMjRwT
zK5mXZZwPwn9BSbBReY3fMjG8GZrpD91Tg98ek9TlMKe1InoKLdFDkXulajg
SKe9HshoY/2MZzwDdOClj+zR73yW1k6X17doTNCjpPoVaKj3BB0hAFNk0rj/
z3GwN1gjzfPg4t3vfvd73/ve0IO+TYfsrTVFwEoSUBlCs71xU8HaiIWWgaqG
BVrJB8s9I4kATsqkseS8cCwRObrgrjzoEJn0jQRVOsOVS683EuiN6rOe9axw
g2ZjD6gL6KmJsQRf3/Ed3wE6FNV29EuPo8fUeqQWsmYHaz8BN7CdbWG8qvVW
MzPBhYUvNEoRHZt3midwQ2a8QWO0i9gDwwl33LhIRa2Lazsa5Y1+DgEWJ9wu
zD5fSvT6SctXbctq4X2RC75J3Ws8hytHx7fFY99yHAK2iKwQA3tBObAIJ5tn
7LUzmCz+ee0onn370eN+5offl+6ZD/XWo7fsPUf36i3wc7imnxDynLEdGf6c
2x1M+Uaoe77NDQjEcPKhYu6JjEnLXPCzKRc4NCdxFFuSNABzPZqKP/iDPxi2
aCXzAz/wAy3VDAxpR+0dHZ0w08VpQ4/+S/NHt6ZJHLMiFL5hmX7u5egVquk2
096vh0t4MkMlEwUpXUmLqo0upp20p9m8ldl84IEHaNQQ2hLtHKd0pW2Ev0x1
pkiIEW7gNjAAII/aipY52cxmO7WuhrFxaMcnQNov69PU0cB2YfdflM2kt9au
RQ4xWGhlnRWMu2z+0fQuQg8Bh6ZlyNxpUWga1UZAjLSHpbQtYOlnlzGH8cz6
aKwCus7TlXRHMtSMnL4UWYs1tS7zksirRBCdEPdDjG8Oy6qMTL6m4etD4bS2
S7CjsKU/Sa2K9q8sa+UVdvAbhwbXvYemDQARTPhXlzadVtnVowN1top+K+Og
rkcq3Fi08G2nHiiUCVsd+qwxy+EPCwd6TM1DsmlVtPyUs1Fx5dKGvnuRfu0e
57ksy3Ne0UMPgYgFUa8dZbm/eCgzdx4jNqeDPzK+ysIpM70WSb5xlNUssOwu
7j0kBzG4wGBXToa9n1kaMiY8YgL7zTSI0XwLQJp7bZ0tyUBADOSnf/qn+yVk
aPa+9nII5udZt7F2zp86jr6i/UIDI6TH/PEmOTTgtohsoJo/6UlP+rzP+zw1
s1yVTA4AkmnxLy5H73/K5WCiaCTXf1s1XW0YNd2ttu+RqaRRIABrHN0RiUKx
Fe6oqU6nNORZwxHB0v7L6lBYwQxoHjYl8FvCWCUkwS9hHwyKxqoZ2FQRGxEq
Ybf38dYmVdVwQ2Il6PB1uzY1hlkpv3Rp0BBu9xVjdAQLz3ve8wJnvPe+UaQ6
GMk3Ud7iv/3ZM83k6EkJdHSbjz322ErphTiQ3FZFMrNHVcK4o++6dJ3ma3cv
xIfX0msKjTJTrp+dJlmp9gFtTDjF2m+B4GwoZpetOK+s1aOx55cQsY+b82te
v3jpgoRjQWyJLZdx5ein1jNtAmeQaxM/p2PuBjKJEBDAWffYa0cHhAGdPpUd
5+4Ji9zeONQ/HAPGWTLXD/UAkSX1ZQIREkALDoOsG4c44b2nrtxdCT/xxkmA
/e2HmvoCWVeOZnYr5l25X9f/kz/5k639QANFWRitzaifsKI1yO/IrtBzsE95
jjpShRKZH/0ry9mYnIn9htrDDT1od0hZhh5sCczS1n4I8NSnPpXPEm6Il2ZO
KFTJGZH5bccMJZA9whYRjwyP8CSQ6W1df5cdUjUC7W6EL2b8E7kS4adZZ3X8
++MgQj6xndAGAfvBBx/MdNE1SZpyukaaVV259HcLXTl3rU3paYGgljDV8Yai
B821t1/3u3hUV9JVkZoPOjC9dWidkhKrow/2rBv/bDwS6OLPKOiNbU+Ql6Te
TVg70PZwSZJqxKlutzuCkH/2Z3+GuKKujVgiIQKp0rN8sd4HKtdk/bBqyaHj
1RtPQSRuV7fJTiO5r2xWbhp5gEvelL5yEh6/dindeuvRlWB0I/u4DXEhCMkI
pvt0PGauLKWy0jaRgWVgrRS9GumaNnvVtV09NWWwkM+aqKwUARlR3MFR7+mz
kpUdVse0RO47RDzGAr16dJqz8N3y4GXcDB7WLx76yZI7bz0URYY8o+v3L06W
iK4QN7dRugTEwQ1pLCu6Ecj6aoFnM4hmZAlk0GIuibqjIHI3EJh/5Ed+pJ9t
T+ccmQByZ+uczWGjcebK8pImcRbgqLYQ8WDStA9mfoAO2RMyHcrcAgeKgoIY
LcZ+BiBBRK+HG73n8z//8wOZGSetnXbVl7zkJe3vGJKBQIv9PcfReqQMrKf2
NOugh42SnCCeWAvqoYceUkAadPRxauQcnE5OuKZn1FA0aGHF85///O6rGyTQ
0cWQ0+m/jV7PTmCQelI/7VkZIeup9x8vB8dBiICpb/229NqjG+Eeiqo3wedG
EudfrIPPgsKK6Pttl6Pnq2Y2r7MH19PphH0v2UAlsf0up2PJT4iAAoA0EJIn
6b91eESmnbwGDwvzXDVKwzsSC6NL7TblIvEiJsfSIub/VitPwboQiGBR3HMo
e58Nbziwoo+5GNgXY5UvkuAjrfrhRgcjQdzj6lENd7YWfGQpFS32XI80hFCn
BUiYfV1RxlCdd3AumVknWd87otrg8RwhOfNI7z90R8946Jp/+dITfIHTc3Zm
zpqr5ZK034UDSOPt/lkRMiaBRtPpmy+HRj+9x921FpglHW984xv7eK+QO3PB
np1v4Yqunc1ZcgS+ddkNafvyMrwtKxJAt956a9AhXRJ03GR1BB1to5Q2+5lN
/vSnPz2ckZ/1HnzUbJigo1XTSgk6GvAWdRDRvJVk4bm0q7YKUCkoi2IR0MpA
SpfGRf/+8Ic//PDDD2u41ouoHZjtqj77lhuXfq/6Y2LHsdwaYd2ou+WGEf8B
02bZGXY79lR7Pbq7oAoavHWnUJc6X4+7yZwZ86IXvUjDpm78ay9H4xOMNFCU
n/W1z+bBrlE+0/j0SjtCMyqPo7vAlUW+VSTrTtlsCC3oGewfyVYSqf/uOAg9
EQ5VuAeNwSzYIWa+tBQOGGKqWIE5b6Xcd+p8elatAR38bh0VBwL3Hh3NVmmy
4i8B0jEe/W71zdNZkQtQOpfSq421isHX6suAhiZuAqSrQ/mFo0k9e8PK2qkE
EGy4LhiY4KLjSAgsiA8vvzyeyVyS+04C73PEllLZe0bYG7PUYZDvO+pwXa3l
3xRC02oPajI3hZrksquO1nJ4kt8hhx48yraEOYIbkmKMJQkpFs6ZSeLuxMqU
6rvIAUgDlemSg6NiS40b4cGsiNDgSU960hOf+EQlKjgb4p9o6v0SkoiNdAQg
/d5nv/IrvzK/xjvb9PVF6uK7jCawXIn8CFakSU6ihyhxy4c2l7ionwo6uCpo
2JopkDUWurSQmwPq6+GwUtmWqpayQUrj3xg2Pj2gRk991vSXkKCQ05BM+jpm
ki/1dXTpW3SQqkfZVygO0u6tIcKqzSXpWTcCekRmW+bEUTOYgkcPtAfUlUjo
dMt/ejm62b73PxwHE0jxTohKJ1DUgkuiuJhW7XpHzqMhMDjRJNiyZitBR09B
7YNcqlWz2MUvnvqkjINtYSIrsjoWHtz6darVgDAtUKruPaTCnXDOwgpO1Vyc
hb8sCs7+tVPH6utHY0phQ4HcloDMssb0zP4z/XVBg9WqDEDYJyvk7yPMHmFe
pTr3HQ1k7z2JJYLZXzza07/91K5lgiGjjxrMtx+9NccYF1tQAh8UZCeHCc2W
9hq0cJ2DUBxbws2iJhhrpJ0o60J+NujQCVdI58alqSU2gnziSCYw5JwwmrbY
CMZi8l12p+rCWkqBVQstJ731nuUgTPqEJzzhcz/3c2+55RYag2pjhUAV4ere
3i+o7P/idGR46GCr35mqruYwnR+9ksU/SbiT3sXetMMGF/x9B2G92RsyHZ2k
U7WIWhTBTrffLTdDWqoNrFQUGVLin/kUrdwGtpHs+WIQre5JZlN/Z1fSpZLT
0VaP7cHkWBPwRjggyuoQnsrOed7loA+mw2b7RVO3CdDTv+OOOxoQQso99F7p
+ba/dA0gS2Uu3OirFQx2vxk/+iYMxFQL8qSEX9ZqU99hAoDYbtNHkljJMqHE
qDaNdjFlmFVIrS/z+GY2zfsO/iS6xRbd0i5r3srIH6qcy0BszeNTXTtkf5Y5
XX5kS3spnoXyVuO22OP6P1rswoBNCXuuZtNOdfXQ4+IOeH0hlOuHxukZrwYs
xmS6ZzeOPtfn4Zry2IRPl3d+x9Fd5W2XFk7udOkngMalylpoujZJ1Fs1h8UK
2gezn5vnIYbMabMorAAyjJMWnSYFbz061KxYeH3WRLomONDTbyQ9zbFu0OYR
n+gW9v7O1tsCKGstw0Nzli/90i8FHTo3oYfxR9ZzIdtDA3c0jywN5JD5LMFL
5rrb7HYacG0uGfw2R/smDRl0x5an3iKtGnlYEr4KRWV1mSutEenLoKNFQRWt
B9FwEX7XBJOQoKVKu1idyAgA2Np4Ecty6rXXKsbknM8yaWVRhdZ7Ixz8Zk6E
/32desNvvByNZ9+bV9i8bVIpye8aSLLLqvSUm7RNqh5ig6AX3ogrfbUi9+4U
nmjehIg70RLED3EMXpXI8znu0TWLOcM9uWzZKAonjYCZc/Wiu2XhXzu1Z12C
4MZna48vSnDPUX0/H2G5ALPxykmRg1kukGL9tqczGEY/AzugycrtF6DBK9/l
jWs6F2PQ0bC3rFqDAQg336fmCm21Xj2kgRZrXfHLOCHChi5+eRAJHahy4xAv
XexUeHZ1svBZpoYpxQTilYA4pHGg0f6C/ImS0Yxq62nmtKZaue6OjdHHm9uy
Lf2ppMg8l0Y8d1XAh5dSVCuNRMfAW8qY7dSn2n102+lQfNEtNJ5hV1tz9nYm
RD5LrgcVQcUp4hiyrg7RDB79My+HeGkH82M+ixRthhZiGJKVsB5xYCY0iTA5
FLtta+RsbIQhdn+2eqsDK7WF1u/ZLUFit9+Ntxi7l+WnlLnJzDbgGXXd74bU
iCl8mE5FpxKWsXh93YivRAtzrFpufbCZ1mPqzDksWF7rR9kF5Mj0dY18b+Ow
KDVqMijazcJsnncZWnszLdbcTdVwwxKCGRbNm7D0p/+M/bIqoa5Tm0jTg+zk
CmZ5iFO+7b/NBPHD+QX230VEzwmCaXefy76m8HPjaOi2oOiMDesURYGvjf8g
RYg8gGnQnz410LCurxyqPswGyHa+wmuHtJe2Lx2s/aUVZlTcc8hwAbTV3t57
SI9e++xjhSQTOhvxdaVqg6/7Prt9m7SOjgYkygVLRYdUFLbq5UGYDWJipGub
VPxu7CDGRqgSvChky+RoBjbN8F4aw+6rryAjphgB8QCXdbRh9gZRF/pLAO2t
l45XEkaedTdOapLAfpO/TzWSoKPrVE6rIC6syNJQTY9hLv1KlyNwCDrssLSD
1tjly77sy6imq8MNi1pNLd7GpCfS9a/PIMm7dWVqObReQERrtjUSdFDu1WWV
59KCIibWO+UuMaa6tR5lT+H2229vwHE4NY5vwLsAzd0a857XjaN0aKrUQw/i
hG3Qeq+o17MkfVHX3PXrsdXHcVan0cFbUbOcHdLDdeb2lKaEGiJigwriCKKG
V4j63fvDl4OwD6hsWMgJCiwzOSYIvy51CKgNSH9CtpHHqAf0FXp7yV4xPLrf
Fprtfk79IpBnQvj2oDNl61zjKawnGbGwxhQzJti1WnL53JABMclu20AhY0AM
QME2mBTYOTg5Z2duDvSTXCBMwZ45N1bgJkAnlzpa+z0neRA2UlMFaEwRCG6c
ZQTOgCP3ND3Dtx3Np8ZRV1bTOLvlJkmrAzFDNIOmn3bqdhkyUM20lmrOCIXb
3t+kCnB6dhteGV7SshDj3PdqumQKajiqTWb+/tbFmR+olqFZpJCczmdn6+sa
3nZqKYm2SzrGq24bU9SR89LPsCVMeM5znqO0HKksPwUv3SGf2+vZ7QHm937v
9zY9GrSuZG3IVgDO0g4x9IAecVRWRb25nomWTz9784rxWzitlO6l8W+cG/NG
vi9FH20JT2+8x9Q4G+EVBQxA9A7QN0qBmBp/wZk1bqAH3nrvKbRZZHI0dN/0
Td8ES3PiiK5nVPRAe1sTRq/bpkG4keHB5mzL6GKYHN1Cd/ShD33osccee/TR
R0HlfzwOJHwaJjLFtNHQ4doIGkMpGDqBFOd4K5SlNYQlH41/TuGkCYw62PoV
DRhZ9Jy8GAfjHSfNuqlO2WrvPcrVR+0+o4flOcsfdEjNLBS5mMaUimVmBV74
GsvDrjZtJSRvvejxim2iLvBZRmPwX7AwBUImCnbHNAlH9XzbpQvbtL/ecfRr
YzUZEEN0Tlv7ilX+jiPKDHNV+J9I421qIcaUMXLztRk1aXtPdkVvDi4CkKBD
ZUq40Um6tcVm8XnExoVAzzW8YtFMR6XidPA6mirUAOx0OIHiqJwdUXRkgFau
GrGGjm6VrTNLu/VOuVS/FYihvh55o38FL4QKcRj6nRyQYvzsE2Kn2TAiHp1c
S0SdJWljrtO61k6q7MUkA4dWkKxKoLFwJREPxfgUknWR6+E2+VuPDb4aH1ys
FmxPRLuExrw7tZ9uXfzi0YVnsSBpjj86Dk1YFPnqKUMHtefS+sqMCZ0UL2d1
iI723PvSnJFutgfX2ly1LIGOPhKWNiWapT2mHoeQrGYr7I3JoMmtTN1I2aB8
NEkiLSoksul9KRx2R0RI1hGPtwL9PHpuckcDKBRPkcPasRwYHqKjN05NEldz
sazryGNjgyyAaZ0iaLFPJix25dALsoSHJ3q4WInn8jqWg8WyRifvOHSDfXzW
C5tKtIThMRPl2qnTysiTV0/tJt9+tGFaccoZOX/5aCS3zLIw4/wpF7OoLB4X
eS6k8RCgWdqUUPPOy1aV1huC9J5OdkVzqf29FdTPTJSlTvBaxTMZz5QhW1+j
RgO3Zb275oyNaeC3+3BAZnujmpg/CJOzTzT+w2HuPN1UwN61Nb27BQpXt956
a/iAIIoYlvPSTw1ZFNc/4xnP6KcOLKBDr8l1iBP00NU6G6BRaujeeWkZTCmd
5+IWpEuwsPop0CGhgNK5dURvUGGLkGnLofncLeQF5BH0dYEVqfOeQqu4p4MJ
1koRmZdY5/RJP5HxbE0FZetpKytKxhAjC/+8d/ZE2qa7qb5IcW6GR1/dL8RS
miTNqBZjkAWWewNWvCKaaYKFn2ECJVKN7BX3ERzgLrkkMdte56N1TI+IxGgz
AafLHGB4CHfg6muk0uA3Yk1vYckxo0Qk5nQsDrlo5NIrN46+aaNQLmA4DpVV
uf39XP5mtXJJZh4AroFGv999ar20cjOxXLFubqYZjtH3tlPXtjkvvLArp+Pa
pbfaimElgwzCujWN2GAwuRtbiYt8nitfhpMDQ2Pb0Xyg9ZSjIdParGiqEM9v
eqiwljTp0LLn9cfR7xw6Z0PPYDyvWrChCDd40+oRhC/GJFGatO2m2dXc609k
HnWIa267tguTYTSX4BId9e6xNRXKtfQ0gtchThn+SOnnTvckPoQySAbRCFq7
FqW1/ZRtyQxon80e7l70oKHjh44VhiBptE5BhHAHGLHhnoXFyI4pY8kM6B57
WF1/QIEci+CNPhF0UHfPQmjkG3OVpwPYFZvPobMSgYamD5JBfa9AR0N37dLr
TR/b9gtZFa4K5XMY1a6RzRmI9Tqt10a4OdOOoy11SN5XhBiaNCldYU3RQVIS
2O+UnDloWnRRUh3tlimiF+d0flS46F9DSE07vOUFJiwsS7gqibVfXAPZQcey
qysZW4Jjony/cLR8XdzjnIhB+5z+MOuC/yITKqa6mtY5AvtJxnA2tljEWV9o
cVr+17VDAGTUhftOwqqjjb3l0nLOVi43oTSSvMZ0RSYCdmbHLeixsDDokAfJ
yOyht2U0FXmvzVXF783SJkl7n2SQGlU08l4Jc1YzeOPUNWalgtBbzaZHrGtw
T5kZdu+h+miSZ3ySl6QggaHEchMYmSLZrI6z/AtvqD+7cQipaYuSsa/7uq+T
LhH0QEfXXLI/Q4+A4pnPfCbxUkQyZfsKaRXgL+LR2cikB54NqdvkQNHAJC1o
Y1UzKzhp5fqpSg7RtLdx/Htbi70x7AHhtuHXkS/WWBZps2fRDV45evrADUKO
PERLrFGVqtCpYbJmxLX6asmprp+30pnVIGvVpEQXCw6JuqcfvOgeRdinOfOK
V7yiz3aGvrRnF1pmcuSgBSASKPwjDV4zMMIuFNyuyrMWLOpiFLW5ZjNB7hgm
s12pGPFVG0AZ/PGceSiLYY4/mRkgzMge6PUlUIYevJXts0MJJ1nE9UxQ562o
TLGolytZkHMKQvNWFoCdZhfHYY1fJ7FlFb/t6GK5HBDUuvvogXKuhL1xyKyt
Ql+5K6K4XuRsDAFS1o61Zscf42XnObO51KUS9NNUdKIZOpgrU1Uy38TozWIa
ubqgDGJgc00siIk12ieU20NvffVfrlNXhaHBLGlekaBpYhNs6c3MJxFdmw6e
JOiAG/p02PQxMCXmmiEZRUFidyRLGz5QFNTgXnPJflGoki0RJtAZIwTkPUCG
zliGR2/OqeFBNIyUb/vS6fzTsBLwFIocx4MoutAf7fT+haotd9kIsL17RnIr
YRSXIdAQI22L718heU9Tat40OLfTgrQNI14EXTJMeKaOZCjdjAa/T2VB6Wjf
N6p6U7FiB0H6bXVIrHT7uXWZJfkspErbYtDk1LsJ5qgp7hq6UyYZbUYuW/cb
hoQMBk3GZIEOzBPp2t4DK9THUTGSHjqL50zmayUhi0KI5tGmk9xseihBlSK5
cbSIXYu0uR62SAkR9v9AQBhBViVcGkosJOKrvQ5wnGHsr2snlZ7JZG0FTRn1
LBzkOpdCvf/omjRlMCi6hA5fBh8DNOFTjdk1mPKv+w61c/ZMV9u4sRwcgUMz
sL3MNOhAtL7jjjuaBtT/IEZw0YTp9+ZzQ9RwLYZvd2NOiGMMPEc/syPrSR24
LYZ836Hx0kn0yMBDttGIXQDASVJjkKqknkuIbg2akIJ6v1SLed7cVoyPIZZj
gppONEz88xnPeIY2Lv3Zv6YwpngW2nBbBEsDmcaN/HhzoBuZxEQTG8tUXQaG
mEJ7VMkWiK61bhnfsqNfuvfO0wrF57SKuY35CK1QAjuau+HILfal1EhguaFm
xeFIwGQBUqkWvA6t0ya0nrvaF/FVc1X66gy27BDldVcu+j99u9oWDSw4LF1V
G0qXQRBMVaAgMPUSuu4CL+p9yCp2kYjlalKgAYKcwhax3CVQ7BGE0Hvz/Ucr
9hHFlwq559J06f5DixuhlHq2ZT54mfvA6RhcrMbEGly1+/Kzg4VOq0jzfzwO
ztGVQwRssda1YPuFQ2SMY3WOe6zQlRVhUU/5RyRTToSH4j2TZ2STLLa5avqx
Xhf0MFvENBZ+OYd8OwMFV6LBmcGE91/84hfr6iUKF2hgNdMARCBfCFQ4TrCl
u1AjQFFBMp14+zQMd4OzKygwCP6QPGp84A9VK1UJzHikYoER4+Yk63rJo1/M
pxcF54XU+l7B0q5cO/hme8vhOc95DmdExGM6YBjpmGMdBH92TGzwzPF49rOf
nR/RWmuUmocN9f0XldeuuYk9PZ8WqfbTOyCJ1EB/KqDT0qX10o034VuGGUvC
1B5NoPE9l6NFSkuwu+tLiTpOUAuKCtjSVaZrwf5/9+XAy1K6Qhq0h9Vi6UEL
kM4TwdvpG4MOJB+qSt149gavFt+jzaU51oYVbPZ1WVYZFYj3fR0Fnq6EHGvX
oFWKTnMK5LkeLDEsNTKq8A2vQ6RrvfDAAuLBtVM7g9WjrTjr2kV1H3Uz3Gjo
ZDbxHOazoGBBAMCyhc9OWFqEveHN84BUlLRBw6g5TdePblCL1vKeRF2msDEc
W72/4jvxQAHMETg5F6yUVZFIOpxjPkvdLkWrWn8hBeBz/WiurWQGp0v+lNh4
zzeLogedGcwibTszLfuXjMn3f//3t9ZyTJqclLgCjW6t07IimBAcB6wt3pPI
MBmlFbeqQ8GIZniQXxjcSfaRimo+MFnlCtUx8YAYWm727KPJUFsvSqKIRCET
mirdgh6LpDyQS/HBFMF1LKYRaLA3RER1oiRRCFK8h1op0ZtO3qJrtJFtupcQ
jMNy1sSwCoT+WlzKxtWtiH7gPnXxTRgZUrmtHhYJQfImPZ0WcvDe9BP7Ah28
OblLGqTsDWDV7/kIDz30kAK0LIGupwsI+ftsUwudQ4RcZ2pHVsfL/z+y7j12
37yu7/wfLrqe/2iarJpsaZWBhbFQGba4niqFio1FEBAKmXBwKFhDN6vN7h9U
hjn85ncYhkFwhoOVumm33WSzad1/ll1NtpuNaWVKyEQ563C2CgoIYlvTJvvM
/cj1ysX0+uPO/b2/133d1+HzeX3eh9f79f6Jn+gXrde9CTr6kIIxT6pvCaL2
gDpgR+4nlpaVJRGnDUamhiT+ydWV1wZ08uwdRIRE4VsXxVHdg56fsizqLP8z
CcFqy1NQOGaa41S88ejONibYOcphmy6H4MaclNEtsM5WPCK3ooJ1zR+d292H
NJn9CRuiTfJxxBb2u8MT57mSPSYHVsObj7baK+IjwdHGbHAas3bcIq9XT6IB
fPxOBmI0pHvWgYZ8a4svxGjL2mxRa0D2r//+svXmpZct3CCjET5Dzs55KhA6
ZTTfV7a/ftM66I0RDVJApSAe1SY+xQQYN/czM6gxaDGsIYg0LjMGBU5DKKbL
BPadm3rVDtWeUlo9rFaBBnaA2Ux/6lOfetNNNwllTN9YksUn/9VlCzQCh4wT
KoWiqeu5EJg87nGPy2HJXG/9bSphg3v6XZHm8iR9qHFyVcKHHH+Vbk0l6YZV
ePVnM4jMjhISfSH1nsa4e+VlAx09aK6KoCit79X4I3Jz/Zp6zd8MgMwARCww
JYfVQ2wMZ5716CWCc127tAZJo6VPkN+4851GSKL/pnK8TlKup2HZg+7Xw6V+
JZj6nd/5nTCEIquOUTpHEAprTwvQufv8nDslb9aRHqvR1QWC3JnZ9x86uufY
4DRzmBxm4iyEFcEx4Ldkr9D1URnJe06dnZXDAKIVjJxrVxE+15FhJHP53E1k
UZQRRNtfOGJpF9C0fM3Swc5h+huyyePEysWcPS8nZlt53VwqlhU7qveSreFG
YyzzkrCnluhUZw2JXFrEANEM7cMoCWd7BIa7vfdf+tpjUGgaziNgWYlCTKn+
XaeNC/PApfl1j0bbHXIKHj00YK6cu5kzOdTDor2tpbUQh9wKBrt/CbQquxZR
AcKdf0tA19gEJD/4+Mc/nvgPN2RSHvIsAYVG1YEDtVIeSvt/67d+q07WYqpZ
LwRLs2e6ad3wpnNPp9vSuTXaVcbhV69zAZap0CV1Gvwx2cnmUQ+xWdxkJMAF
N3pAPc2mcI+pZxSG9JTlFruH/DUR426gtqriG+ZdKNFP6+6KT9Iv4ll1/xtm
gVXHz3joFqmvV+yWURGCZX+aBT/3cz+H4Y+i1uqj91wjJ/BsTHYmvJVpkWmo
1Mmsf0QAIhvbkxIl6yaQel7dMZ9FJJmCgQwa6pcJMmr0eogwNs7ZyWunpkgK
QEQ5TKKrh/DvWcr7TUd/sbGtztmQ6YIKray6TRn4mcjBGRl3685jGwjs65jq
9x1qgWY9U2dkdQWzFDbaeSbWyLH3H2LpC1NghoMOJ7YgreCMc15ZK8mdnqMQ
aIMh21IFk/asC3w12jVZI4/TmOyT1pRgp5+TMxK2pbCtsMh0xh4Heg3dmQ02
PHPmpY4ekrAIpZq2vOXoJzWOKIYGbZw1qwUUQGOeESEXxaHT2IdsviuiwtPp
/LuH3ZDmYBfeaP/u7/7u7/qu70IPgxVIYohhamk1tH3KU55CCbzPqSKzPZgl
9An1ZwmZm+BBbsOg+6ZudPyEdXeako8Mqezt2AvSHD3QDvX8yxbmKwxhNPZM
YXsGYSPq+tF7HaK6gaHugo1I5vTBKAsFHfK/zdDmYw+iJ9jg6f5oft0IWYl9
q0x3rIERYphfvek02k23rAyP3msd1bV3nzuBjjwinFI7gvCCLSguAsWS9QM6
Jww3lBOCjpXmWbn45vceKqAKmt50ajJyLnc9r7/895+7bNjpiySMneW7iwxc
OzUoXOXpOWNiap+LUyDGWRODaSGgsWLbK0ebOVVsV4/+7+NvXD0ERiCAcIrX
ldHdcxIkXHBj5X4Y7yvnH3+sLy7N1KZGlf2g3yLNN5KbLR+9xwUNJcKH9tS3
q0WkoTjd4H4LceWc/hgVRw5l5ZlnCocYJtzglaxBg6jvOEvrWi7Uyd5QP2vw
r/MdJFGGf8alhVs5QfaUnx3lYxU9/W63Wl940mEBwhOe8AS2BNlS0mHzUygY
/+Bl6+6FJISREck0Ysj8wA1TS5vb0j2nqseP6AS4LRrNL9aBSDkmJ15W/212
dDcaADRIOxryBu3WTl6YNPToVxr5PaA9mpUbo+OqwmveedOPNoW1hw468piY
HO3fg1PU35jJDcGdI0OaOxYydA79YgOvedqQI8nebWw4WYZwjDuxRmAPutkt
lUOyVR9M9bkMD5Gf4KUTEJZxquoOlKXQZVXXxozkirZhXZ7djVWO3HO0I1nE
T7KV/UD+Wi0nQUtDfQGNJU3uOVT+rh0NFOZHmHdzQJZGWTX9GkKtxk04lKrG
eON7XT3++GkzJ1Y24nqhnyOABb7GoG8BXkxa2zR8xnTtk0DDfcC4UEWiSE2B
dnDRkMZC1PFQ3EOftYYKr1nngixtuaq7LwJK0EA00hxfnPPsj6xyTaJnhM/h
AKarcJac8lrF4R7MWzn7OL7IASGwyTdBO4ckDF2VdP/Lsa13wLm0pxvb3esu
vfCFL8SQHMFDfYryt96opZU6adZoWCAjk4fSf+kTfsM3fMM3fdM36bOg8uVJ
T3pSh21CNeX7oe6kuBNrTfWZzJGEIxeGQS4wiPzWqS7KQTSJ2nmvP37ZeriE
dBpXc9nW40mRrG6q6k/7FbgRaHzyk5985JFHKCf3324sNYOGU6PIcvPsZz9b
3Qrlc/TyRhcLpzGZjRpKtCpJzBld7dPQQsjvQtBE+10owW9S0SOe0w4SLnyr
Nnww9bBtXUIY0it6OT3S9hHtnIbeo0rSRrY8IwCTQyGtos5WWFbHqskmXLyY
5EwXcY9zvnIAtVKRgcmdRzu2VbJwFmRbxDT8KOiDBsOfq4eOFkPiTSclYQEW
xszq2q6cyu1RL7DdmBPZV3g4To/xg9D1M5etia/7agOMkqQSS4UnLQcveclL
ZmP0JgBp7PGdkUIRyGeYqV3Fg52bIBkKFs4srHOjSTgzmsdmMd8Ei4PVgdzi
J9Sk/KNjm7Njzxk5ElJATBp3lG/bGrOyW/TduO9oMNE1dge6S81HNfU5LBq9
rZ5FTVx/fud3fifooI+R1REyPPaxjw0o2nM6Y4pfdGnJ9uiwqjyaXExQofXm
plyt7uqkg6UgmwtNDTSnTjtobYD1UJrCGnD/yGXrIea5IJGKaTd+uhuztYSP
hAI0KFnFSuv+ww8//JGPfCTc+NjHPiZASkcI166H0s1pGAQdARTuGW45i6Kb
1shBIOl3lfGqjKMFrflst7f/dqVAUuyX/gBhH9qGymNlTMjFi4dbNZgWPoQY
CtxQTDnyqyK5/WjctuTFJLmuHW2GrMVz/M27rrf7DC5mcnhvvs+nGEpcO/WB
9eebDmnxeTFzFnwd7RZeTbhjOZela816CLBMx974icVV1nZhWZsV0dhhDY96
HIEDhOSmTQqD/UC/V0OfrEfBzx5ri0IrLB9E1bxWJghdbeqRu67rF2nx+w45
9DcefWrOhe2SJlj9i4iCjgZ8+4iCzvDwxalw9N/7DolC1b5ro8lhmYVgOvg5
G8rKoGO4YYJI4Eqp8FasvCrmhGH7UeDfbex2SUm3pOaS5G6IlK6bpISs8jd6
XNkS7Rx0ZIq0J2nTXrM9qBTycYIOsurNbskpVhz272wPoZgQQ8XWCE7dru5M
JynH0WSkA6a5Ww8u/NcxoQneg2vcUlQDocQD1RpLrGTbZF1gZOWhBBof//jH
f+d3focg+Xve8552C3A6sU6v+yMqq4mbkjdhsf5sIOmJ0I82CLuHamo0pNZv
JUAjYsxd6jQ6GUEeVTPiwzKteWe8FcFwPbil57pFEzzvDQuEbba2pMtdbpov
bjDxKxNzXsZZqe8sCWjYL90gNLHUA2jaDD0HYN/41dtY5VyGczhUtMFcu/PQ
OJ1jspzyjaPtwqPYF3a7cbTtXk4ZDIqB0Cxt447hcLbNGZFg7XWF7YE/lxN1
XOFzNm1jrx1Us6KA+kqfZKqxMaSzR4+fqyjajLQ2MQ1Kj9NU53qMtvG2o9fk
iKMI8CuYZXWwAIXElWWtysZgkJkCDjyUGSTsjdWBKpGjTsOmpZZPYNBpQxvQ
4XH0+LohWQVBa2jw+Mc/Xhtr+VYSQHkuAUif56G0T2hgEs1KWcfJcCPz45u/
+ZuRTnNnbr755gyPJlTo1BxvMlKK6G4L8pzlAhgJQKN/dRM6wxamHlNTFXSg
nfc0ww1dZXtDg1SNP4MfgUTnBQHGoKN5SmKIjCGlHfIgWGdq27Wz582BDpWw
/+1lCzb7UxDDlGzZ0usTk7CL7WZmDvXdhhbdEqJtnUanxOxRVq/cb/nW9VhZ
d0t5eYUqdFrUNAVEq2NCWrh2CFOYVgsdsOeZ/ZO3mgXCNpg/Yk1fBPVRMYFH
FZjLxVw/9TDyycrWmB8rVzHFeBANgx7ZMiYrYzlHM3ZiE/tyw5k65yiKjIz2
Ij972Ygbe6+I1dznjNgkT8UxfuiykY1qrJLcEc1ojQguzplWDkvHv+MiBwoc
eAcDcwAohTrmiczFg0f/etRW5hY2GmxZL122gaC3CJ6JL/8O9qmEKfWVTvLo
RQYCDSVsDRtxP9EP763dwoAEb1u/AEgfsnvPsoTCLPSLyHeQSR90fPu3f3u4
kRWRD5I5wWHJisBIb/o0jzg4OjIENeFGe37N13zNYx7zGBqnqlqQUUmmZyFw
BqkpdoGstcGaG0uRaTycv/f3/t4rX/lKbWt6rL1inq89d4OhsdFw0hzB5OpW
rOOqXLD+jPkmAcVHP/pRZe90UPWYCzqa2ip9egSNxiBL7r5lqKuWnM1Ty/Bo
aMm4dYZZbvhgjcDujF72UvyNrp4sydBgoUczd0lzqzZ0js5T3kejtxmQGsAB
DeihhNYiAjoaV8Kk42PcdzRhFHO4dqh13Tg6n1rNl6rg0Uys5uoh37fA5kAD
IJx9kL05169tT2xVkcw3nBocKLK7+7TN97n7aINyPqwfchp3HoIbmGMcHwJc
TfM1fOdcNPeFI5r1PREa9YG8np4iny0H9HboREmqsit0jW+k5bc25BqKgQaV
v2sXFakGrTTrhKM9mnOblXNBhJnYn1cPwVKIuooSHs2qV8ax52i8/Wj2rRTR
U1s2zf1Hp8cbsShTvXZM0TNxFWeOdohMNdKyykqGxyYmVOyJBNQY1Bo9L3yB
1EHzB24ojNWfZXJh9AklYsKNr//6ryeP/F9eNraH+Gq2R3NK7lvzCERcNuoE
msRvN3SVMDcSAgfKjesH3cwlHE1Fp0NRNRETVtqPNCJ9QwqDinJWR5ZGuPHI
I4/0nhwZVny3lC8ZrjYmGyf9hMx1UCm90l0KIpQGM49b7EjN97mm9oRSG3vd
YfnonkJoppqeDliQldPkBBS7rTNs4KCQh7elD4JNQb1om5GplOmsycMCWVBC
QmRRzWtHnTg6hCm8VOYyJncfeuN3HZsJbnav1h4amNF3HWI+dx+qg6tMQQkD
ICa7P+1s8yujd3KUVu2y07jjpCpG7gwznD4wqXAuiSSpfu6qIxtFuoeHGOoT
cZKJQApfND6JbAh+hhsdof9Sl9WStevCNmTtswmFMREtxAoW0HjLsQl6WJtY
XwiTNw5BVCRS2Q08iqVEl3vl0dx3aWy3FNi2Nx1tX+CGovXVxfQqjQJGxFjY
sVxgKTy9ewQbz9R3bDTBZ5FSEcjuZNBBiENhrKrYldXDgdADqYOuadDBr8lK
CTG+9mu/VtxDtoWnw3Pp+LTBe0A93564MdAgNOwhhrHBpg3ZtqBLXvSslcfq
SdF/taLGucXP1356HdwwNqmB/fZl02wFjChiZXLovtoRuv90XPF/NHpDGsSx
b1x166zjvelPsY4GZDsIhoiRcsokTTRK6KcZP5ym3vNZ1LIJgWqCIFz8z47N
v6YdsZ7IQmrDkBFHIcaNo8MpasTKVUxhtWmrNTtzRM+zVUJEzlQW41GEDQmO
SdPcc2gPrvRDC7Y5EVLAdxz9UAZNsh5jsM9iueNonHqWIT1zMFgavJIQQ/Mj
PctoZfx3l60hZA3i+Qp3wxzFJo1PvkyjCz9ZcLWfQB3hIEyWTVSfbL5kBAdB
ldnEgiyORhflnOWG3HxMJEQsEhmLdvJWJA3H2rLAuV3AX86F67RMro3eBWND
Qa7451p6dRXIQijWYm48YqHaHXDQ0cnnQQhCojM97nGPW6T0vClUyT35zsuG
NapUnzhhZkagIVIqUbtsS/vTRl6wWjlhY+n2Q1ZOopALINrfw3rNa17TuWFp
wg2ECrWKeHpzVRhXRMl0XG0DIC33EwPBQAMj9P3UrehmIsTdTOwcWB2C7WGC
Vk363DVK/S7CCT6Y5pWyt11jJ98dvv/Spzi0V+NGVrHfDTSodnQauTBiHXxM
Toq1DAmwVxrFBtKYooblWoUyOQQtF06c9JYnPkJFM26dSlY/sgLbTWeTVxaj
id8XX/fVW8/L6u/BjRzO3YBU/dZrT1t/rsWbI8sse/pAZkfmj+ilSBpRgtUx
1ZdhbzYweqWuQ8ulJ0K1vmWrxbGxl/nRo0EEamcVrDgtSgmYsvS7JIAYSFcO
HUJsT318lg6zvo+wwb9gRe8rKxVRwM5t3BMcmwu/lLfisTpav0h+ZyZN351v
yG4MfEZfl46R/FX4qc/XaOfjnHe08Q8bZiT0XQ6QlLLEgYd7nAKuOnu7Ya9P
E/QYHV2TBZpgWRE33XTTtMLa2rndvuXYQoysjjyXXqmsA5zMFQR1JULMvw0b
dGjRLa5rj9IwkA6m5dgnXNfOuZWikdmNRWLhlHXTmnrg4twIRtdFchxq+ZHP
m8j5MpyFxoCWJU06hfb0nfSI1JO608hb0Zi74UQpeoxcRS6NWymYxn8PtBML
Cn79138da7RfDDHkhXNb3ve+9xFSnvIGY8N7MWQas+soPXEG5U54s1R9zqpZ
3F6xyhkVW82vnKrdFxHdbkJtZ+ZnM1pp7bazxIdZNk3ysxECc3QoE5Ho1RdN
W3pZDg4TsFtZAi0xaFeLY+jE2udrrdj9JxMH54UvPAtlzlmPqiMlR1gXVh8f
IipTp+zInR4gvevo5SQQtNKY5hSetofVexnVRU0Z+ev+ZmQyG6hOyZiMhiS9
0g4Saj13CCPEKh252IVSWcwxoS3xjQlpOqxyNo3ara0DpaVv3nn0IsRkFqif
3ikqCDTj4/TFa0cTwB604lAltJosNNMf+9jHkhAEIPgeq68PN5gfOSO9BzUB
RfZGbst/cdkYIUhipD+yPTp+z7cHrd8B+qJOu0ZXw4M+W0OiwdCjZ2pmFKG1
y5G1pjeYu28iVLg0jLouf4RzjpvocbjB9mjpp8Ge16BaFvtdO9cO1QDonjSK
siXoPz/5yU8WI10cwwrYqYYSYYXW1U95ylOkk6SPu7SeaQcMyTsBykXywpI7
wQj2+1rHyr3iekmTyepK55npdxw9iC1JBt46Eq6a/sYhr3f91FBggQiu8VKr
y2Is5QE3WIDapvxPp60/JTL86W5A/hG85/g4TjtQ7hWXUH6uD1EbAEG0WEl7
c1yhQa8tGU3/Fp2svtC7aS7aGTKQmhTB6EGQTOkT/UMVUsmzIIiKlUEPSZOO
r/5aweZdh6K7G7LqPzROPktTSfQ7AGEDYI0ONyYnsuSswIVRiuOBrcGRkUh9
VF088BlNlMehxupsanJdlwiGGz7hboynwewZ34wxs6VKVZT8C1bqiGqsIDUs
DRiOZM+0Z9TNbF4E1DfffLPCWIlaihxtymkDk0AguGB7tLP2CvIyf+7P/bns
ja/5mq/5uq/7usVLBT10qm1n8lkWgp6mtDsh6FUmypqFG+KTjYcGSR8Kfylq
bo5IRkBp0NEb5G23oqlH4EJzWz3UWvqzN5q5zd8mMsEuRSXt/CuX9rKdFbZG
UDCT4+lPfzrNwE4VyrVmBXGZHDwaGulBBxWgpkyDp5vf+eQ9hVohVZD18cuG
/b6wtpS6DfmcscFPEQu6cnRVE14mgyYxNxoSoGB7sGMlU+aJLOM57tbExMx0
6DTC5+QH18eZy+NVo0yzvjeBg9ZCSxYPN0Q5GBvNZQkRiz674lXHJrwJH1ov
WkG6pVLzbGMV7o3VWy6bMNRKALRACgcww3kxjTctDDqUFsDhVScwqhgePtC7
89BZZWYMMRSh0J9Rk+55aWcwgqiMKmBf/N8Ep3gplDEtUNAxaTIgI3h1rsZC
DZ1cz1lwYykYIqtshpkfPhHWYLGsbJZE2FiU8rYQZp1ZePFrVtuIGnvZ6tnD
+tEf/dFGPsIG0TC1sdMghScStVQHc3D0c2nnPtfENvR4zGMeE4D0RnmLI2R7
aM3Qs1Zv2I9KlKsCaH0REu/hNgaasNycMCRH1WCQbQ/xuiLFHT07VYFse1lO
8eTeaHvEVVHm/2/+zb8JOuhm6KB0lh/vXjWnmggNOYVvGB0NTv5yo67xJjxI
4lVzljY5PoVvTY3macOGzpt4S9ABsnrNaRLisIEOSXbEWuUqHhYQsMQAisni
ofnJtpuqQhYT2RgH48xIv3bqiLRkq/iDmMMK0hecxBhf2al4VPOuOShEKXEp
UmFbaHS+hibLNDw9dGEKJY1c1GdfNuLzgKL735jJqGvp+e7LJtoWXBNk69E0
nBo2rS8d8Fx+0ucdqkep6bN0SWfCjuJwYeDL74g6SnM/cLSZXpYEy4s4Dzo0
kD+rYQw0Hjg6TkojrrXrpNeHHqwU7smIHOfAqczI5v45qDIFPPiwsrV3He2V
2Q8rSxkUOD1ipwMQuOGTsa36sN2meXLXoavQMOj5Ngt6fGzvHlDgIIciyUKy
Q6yD6qBUi/YKf+myhQxwo+1rv/ZrMzm+6Zu+6Ru/8Ru1sm3rUI4gUxMyoIb2
NEMMrJtwQ2A816Zf6UxaVhpI9mlrmDUUu6tNNGrAiGQEtSiAUXD1ZxvWd/N0
HWwfeeQRDgvBLhJhwUtQ0y1trrX2iWA0dLtG1SsZxhDM7JA47pOF4+AhO7nB
2crVDe/0Oh/lb2GUtE7nsF5RKvJ0bVO/I2YVeuANMgNE1aZpwx6W6J+cICKl
4PPVk9DfcihjfzFFOCZipC5KsPrMBAMpuHz8F3GJlX6EGyISiNnCFzaWBsS4
7bKF/B50W7ZB96pJTbspWxSnDgn8lmMLH1qegEZvrFkcEzdcm0Wg0ThB3mjM
dOQGUqajyHzPdHaRvNLyRHefdOCnKsZTOBOiJqWFvjVShAIKshtMDtCxdLlE
2HpCqUwRrtxh/eg0RqbeL/phCnNnsEOFRyDbVEbNeuUYbBsujEJdRot1th/F
YmWf4JOsk7vgvFSLzCMMnPOLwYuv2xPvsfYoFeBnHlD10eNJm6cJ/oQeWs32
HDWi7cO8FfjQ6zdeNq2gvvWykf6wT1iEntp0o4oj9N1rDzo8afBocdtCQ9Wn
scE/bRx28t0iUskAhGGvDncyPspGpkKG4JHb0tIfaAg4ABBiHe3cAWkKdSsa
daregjgDtYFNGUxCsJmiHYyONphFjX+WSXZLM7cHh6KGlibLo3JW+TzTYuWx
roJgGqLX3Ue7EOGI8wgcTWhyXvZnbE+K845Dc1iawCKIaGqTrsUMX3MlPypj
DjEWGm1PHc24mUyIYEH08jXHpt8ZT4RIuACFGkYcXRLQ7LpuI+hYKdAzLhtF
cQlWwpJApq1nRFiyTQWiUoUMjMZS/yIG1amKyS+LdJZQ46lNzNb92Sdm+rYe
KBygc6tjBQ6wKbm2cfefttHOHXCmAtNxxFH53HZDPRVqmGjGitQkO2Y2QDNZ
1KVUmEBgQXndJE/lFLDWfXGnNK11dRyKqjoH7PfF2+88Ccn22mAImcl+9hyD
enEM2qTcFmYDyyFs6b/N7ptuukkrlnb7jsuGmq4KZr2wtaf0uYLcDJVsDxnP
nnXDYIVmKGedw4ClsUHssQHQE+9aJr6nfQnlMTrhE8nRyYX6hx1Cj1AiS0OL
29wW3Rvf9773tXN3NYs0G0yQtiFqxJIbxYFvOjQOm0pipJgDlGzbs3khRtr9
7K72fBtXWPESPYhqUj/KeHlY5Is7baiyspR7TsqiUirzoycJLvkiTHquehtP
41zcei5vWXpF4ELMc6Kg6FiCHngUgtg8DsXmuQaCjTIXPMomrGKB7o/GfOoI
pgsdXAgfgQ6FZu2gnrHHjV/R11svLCjd2IaH9hncGbxiZmquSriB3yX92pl0
qj1K6+OURv5z7UR35vrRh/r6qXMuPoYKNRqAk+ZTCTLZcGmIhuU6x7XdOBpg
TXoIgMAHEogSr6pTPUR+jYp4JQlysmucwQxYeb4hwRadvJjwJj9FTIbqb+9X
8DJFaGsQrilRceQiQWDpHhR0KX7xLqZs46dVUqEoH7MZ3YofMoCO4GKqPguW
/tfHhunxXZeNSqENWyzbQztsGyQRPMFQ7YdUx/yVy8aM6c9OowETdOjIqeCo
Ud1d0kilSWeN1qFeNIPDsvr6lboTAxHrGLniM5/5zKc+9aneZwn0re5qN6dF
Sq19vx52qW7AYg1S+q/az85HOLf/6rAg1tFI7k52PxuoHZD0n7M9Q9mA7t2n
rc/7kFM5+2FkUeQiQ3duy7nP44b95P5UhZy9lTEPV6NqACBgZE2trSRWhlio
UPYaKEt/tNac60Fa5fXpnrUgdNmd6X3oKvHBZkAM1u6zrTc9ZQ6pGGm3ugOy
NgMEFoUSSKsJe4PXw+0NxORidCiQbh7NUhjBlAG24p8DCjmp3SsgYxavtp23
4o10KsYmuoUyiqkkTd4HUk2CaYIbcjEIWjiii35PGBOAEAidsBhW6pI4jByA
NqEwX2QXKXCbKLqAzBxe+QWpSbjRJsfX73aodb5zuybGgtRnLnT/yaS3FohK
BQuCHk35KZHSS+9f5ASxKLn8gUDfUtsS1HzDN3zD133d13391389ygemurTL
Ur2khP7SsRE4NcxoMWn/bc72OPSLx2OhXzq1MQ0fl5NF58hH0FW2NzSFHnro
Ib3mFc/mwnSEblS3tCW4edHKpUuURuRCbQqjpPAanO3W7Wo9bWroFNkJq33r
hJuGSB3SQGTeO1W1b51Mp9HZgjgKz7Q70LrO9aRqo+Y7nxfNBT/PBSM4FXcf
Dc6uH/pg44RMAWPs0zsu7Q4lSoQN6XgQy5IwnaIve0McspnbcpMB0P1RFRL4
5/CyKGxsNloE7axOJHSVeG2DEuJdvQkZ5EGUG8ilEpaEEgLmQAZwdVayNp0w
Epe6Ztkoi77lXmB5KQ/LKGtkaaYZIX0orMErXDb8l49N4oM3sfK3s6DrAF84
YmjvaGPmcIUsGXorSMRIxb7r6Aa7ChSM9LedOtG4FnDXfzGC2BuSBU2W1q9p
FM/N6cjYzopn1UwteaRuTuiVGTP60MiEDI+WlZ4FkYrclmVP6BtzVZrpMq26
rrTgil1bGgKQMIcQUPZJJgfoCC4Cjcc85jGDDsW5zI81ZZD2DY6CoIacadjY
0JXAZFTux7ZnbEAPgoQqd3Qy0l1O52udVjQxIRMq4tFrE7mjddieoyY1HBbh
O0xmPV+ClEaplIFWkhgF/CxwR91IBzrLR+OqRyNC+/DDD2tRHY5xqTgy9BVX
+oe1ZdhbK0f+sWYJVnA6JoWBqNPrlaNZs+1RZadez6X3aN60d6YbBi5uOzae
iNQ52SUiDGIRcJ5pAUhJEHTTmvu065kot1623mBWKIKm/9b4Ade9aiXM9eAW
kYYLtSRwHaf/dqoIadQRlcCvfNXMFRIcaCxnffUixLpwBCAdbsunjJp11spe
hZp8h82UXDuG6cTO1Nk5LDsmM0L+S90iO9NvrZBWquVcHSMIw/UQJ/fd1aTP
zUFOEHgX9iQo9I5Tf0l1K7/6q78abvCScGXRm5GLtBvryP2icBCztjcNuXzD
llS9TrI2W0GayJpFCpkKaxBF719hS56F7FiDJMzpcTcAVMScNcdkXoh7fPNl
670IquCqplFBkxJdsYVGjlU+ZOv+YOV1sV3FQhw8EUGDLnOVYt0NadmQQStb
0GHpf//736+HY9ChoW3f6icmZdzCpxwbB57wV0M3u/01r3lNb+hVNoNUr+B1
tH+LYwviWmeGdd1/ydnOJOggT9pp0GYHZQGLEJxAxJWjMyMAmTDXLEbZkHVT
WplJbxbfEMQ4k0JZmObX4h4SDSija2uIP9Nlou82wSmzdVvEdsQoQARBxbZg
U1Ci29XN6StTgGx74WUjCylJCkDUtPZJnxtCQuKEgsdgZ1cocHNunWRGUact
Arxo8PwyRtqm/8p8rh16qoS8eH8m4DkJtYMAHBYC2a6pQwh6LGMyXgfgmhDH
YpjeT/0Pw7P3q4CeGUmuR5aEecD+mfQHmtaDR0fLkd5ZHdwoDcusmA3yFVzI
DvfTPBrlD80atecTlWr95fiTsGifTlhSb3JtPOWGHy3fnruGRCFD9mcooeV9
iCH0wTxY/rTxowcrl6c1mtHSt7DFlOLiiQEQGBJu8IO0Y+iAWTIdTZlzY0N5
e6fnhmA+yIgJdOjz2J+qkPBL1Z+qn21iMjywwhBKQwzULIGOjtB3m7kNRTaz
Kkvrae8VTDWkkRvlAd0l8yi0pHZLIkysowfdo+me603Z765lJElSuqz9i73K
1z4bDIIYTG5qDJSvRCRs0/mUV534J+qC/IhiEBo4dx5N1vC1+DiMDTTOJiYb
o4vtkhlgYheMK5scBxBAyCTd9qOXrW+JeXaEPu89WBj1Qplq9oy+q36XQxRi
ZEsIvEgHS+sQ9ZK7WQk25+Kei/KP6v67DoXSc1+JQYSogv/OBwQsk30e72X1
g3ZWjTIKBAQYV1NSQ6ZVooRRMbFQ9fj+RA1lwCgPWfnzwjIjYq3ZkyDGbJ5V
8cMN+8vGagSAEini13RoXmhvLVazZiv/4rKJxMoFW3w51LqtyUEL6cBGXmG/
23BCV+hRhv8CgI2Q0EPKA+d8VkebcEeTPf9CXEKLit5La0ryhgmgY1X5cEPQ
dU2jOlSusfwm5cCGVmOmc+t50UNG1cCb+rXLxkPpabqTmhnx70hytdYvwgBG
1L797mX7rd/6rfbpmN2TbkVGBW65LOE2Yb1G/hhHvacGgLYkJOjk26EB32AL
jjoTLPRQizKYyAxpwc6nfz14aNUKWYwCTeF83dVZCFhbszSkRUQnVJGgckmk
YviLV4gDQBgHkSoaaEAAejg9RDYV47PVAWgsGxIOBCxiDi+7bD2vJTuyOjAr
ehUF5YB0Z0iF//3LhvVB9882Agla2nQ5FLYgZkyB+Z6jv204sHrbUTVEMMx6
q/+EHVaNwqc4WyNsPHb43Af4I2qqbBabaB2UJtPBDJhtIBA6fog3sqViER1q
yl3yrZwRnogwpk8m7bU+cWBEyJRlNcAZi0Oj50ZgCND0YTOwTMRSyElhOKh9
ozG1Zsf0H6zXRDw6E306rh+tu6xHGl1lE2KINWue8pSnPP7xj4cVoGOdInNk
WCNZJsT3jJbWYhm0Rh0xMa3iUDvaUExpJhMy7Vdauwn0CUs2CNWfdiuCQQkm
WZXsKA4aIh+0h8zdHDFJBDAtTkBHry36Qg05LAIdvQ+Q+0pH6A7w11x4V0Ss
wwrbMmqy6LIBWsnFNJtoxcsmN/u6jT0j2a61eqT63vl0VuyQ/hQhP5eqCU0Q
n9xSuHqTVbWjcmF7rrSEz2ICtuGHI3P2nu437awW9y7WzCVoY+J3/nT2BL1v
vvnmlgDc7+5Jj4YwbEBBNgcySKCrEFnSBBdL9jZzohPAWFurBabRyqXHUVyn
FdeiclbxrEsjfQZmrx8Sx2I1MsvSJW7aGPvu87ItpttmweI/S8pIkYwhpj4F
zRLLYmKYIhK8EtYI88OvLNYh/imyirCBqCktsv6PTNCFWB8lBLT+CEgaayc9
wqoQa7vpJSpjoj4FQ4P74zQ4JshFUjD8/TYdjbGnJo3b9YKOKc1quzyZl54R
qmRDqJGTPRAChBsmO/KG6EQfBiwZHgaYfISRo5AfwSxD5XGXLaAQbpWj6YuE
FHyRNEdztuW7odiYl+JE0u7qtG9rMipw01SaCEmPphsylbDxOiz34hsEOhDC
1bw3iwOi7li3tBHbbGoSIZnAjQlJNTto20rBKOmVgmF7YIB009qtAdwD1ZeN
w9iZjNfKeexCVmJp4ZNbMfhF+IcVi2pOjAt6CI3ia3mDtUXwRP2pKAGUkCXR
mR0PvDViHcBZUGhavDA8tyCCx4H/mVExogX+VRsJPlJao5WqXpf0uXH0vZ2E
IAthxTIAxHu+GFcr6OBwMUjuvrRDWt4ZgECkaTifYdb7RRKUz5/r1CjnLDqt
eoWb88Cxyatibgu4rdRapgOkmMvLgIyOPtwYxxvRi0S5WhL0CYvINBM0XcUO
RQrl6Uz4SzUuI+rBQ8J0Nsk/O22oI8ySVdsR5OxaOCydFXFjjdTHXccPQUbt
60jO037p+XJeeu2TV7/61QpbGkWqBpTKYojZAoGlaJm1ErWC7WYTf8f7ljD0
jyc84QntLIbQUGxMyr5Z7NpzeQrFp7ARNcLUazKGJOy91QN2k7vwTA4xkNb0
PALBSbTzoIOyXw5Lr/233Zrd3f8elu6xradNB428Jal7kxHVFMvelkwMOhBf
FWRNe5AmSbeuQdij/MeXltOoazKwQE+Ad4VOWL5idGyMMS5E+xeM2gpr4Z49
v5gG24Mv0MwdfWsaOAI1HC4J6J5U1kWPOBjvYjFjlaszHVsFsiVwrnouK0YT
GMfHoOA0SRwRS56RbAXfgUs+F0BnRpILGRXQb23jBoO4oLbxxrcun+lwJp0I
nlxJJ8AUoUvWyZDEMX2ENNfIRh7qxtGz+MFjE7uQ/Wzq0ZulQS3oMZG6c9eD
5UA5Mu88GjKKjUh3jovObAYdRkKn2o8KcQiVzOAhI8YIAR1nyqsgqtRPfyKI
MjnGpX/H0abBhfBKcMBYU2CQIcSaWnOovtt9sMYxd4kgaSvZmOxRNk0aHno2
NetJedDoYDlIu5DjUEi7PP6kYsm4EcNh9PqkI7e+c5Mbz9SVIUzfalT3eUMR
d7SrkG/VgFXP9x4c9RKoq2BkveAnzUFUEOGcRkdb9kbmhwBpuNQReljNuOYX
XlMnH2ZioeNFm0QBC0aBGr3gIgxs6jXdhDuClOZRw/X+S88ItJxOHvG1kych
MlqXIMYYnqtQsyKL+C1qtz4mA4pFCVaaaq2f7L/MpqQGF0NtDsFVWZIVKSsQ
pu7L8eSBBpI9EekSKRIxn2yMLJm1nhxHYgbSmCdXj1ZxprYpj8kwnWRvhHFo
f3FSIIkLV5Jz49ID/eyGcC4gksj/6nRWpNNxrhzNtZG1VgwLrpkoU7xkM6wD
+Nwf6lLCAutWsI6NbH4RDJmdcTzAyJIya8mkPf20TMeEd41sEtN2yZ2lg3/p
aLiA68VFmpNlBC4YuPpcZysLI1/JPdEeTiRnFXYizLwwtDf3ljYv0UXPVKZY
c6KmycRLMzxkVVBJgw5CHEGHktg21NCGJetdYqJRBz3EyjjUOjERa2pUN0rR
kn2xsRqw3HbbbT30+y8SghrGmX3qxWbviSkpbEH5UK4yXR1s8w996EPBBb0d
7Vfap1kc6nZPuvzuQ3OhM+zX2UtmEx1L2UZcdK1h2k1DK7uBzdblQK+72g1f
QKyTR/3CQl9pQ49gkwItQVniWjIZ+RPkZLFTwqGcQ62xKaZ8ta035PLM8e55
56khuxKDQD4b4wwRQhbeKApo+5uXDTEjqOyAOzjfh+QXCtYilsBhqYqRrESA
RRKsUNvM9z5nIXSNGHdUvLo61su6OXBYFrIYz22m/rnhAvRYRzm4tGpiFWdL
bUz1YuJ+bKT5WaYzCrrMCHjR9MQkleIku3Eu2L//UJEdDcy45RbNWgA4zqc9
G9UqWNftUboW94wKkKhpn0g2LeTL2TmjzS8fvWAw1Z2z0pjRzv2QM2GVATcI
6YRRwsgbWhogKhHCG5d2LVm8MnTNnaZS4BBKqJNVt0K+w4dZIL1/4hOfaLFu
9uEQ8kpazZeYwKTCBtE3ra8ImACf1sH+1bqGlhlEdF1ixTS1umQqNzpEdIHd
fFp8TVJqfmFFoPF7l+2RRx7BqaBN2pv3ve99+TLt3JF7Ft2BDOOgjDRZM4uo
IBdMxT3CRqfUbQkfFiklH9FX0FHo/HTD5cjGM1FHYzm2suC0yz8SzGFLTAuU
DpLwoCCnFMPEsqbJGcwSLpAf6e4ximTJg4uei7LTzhOkhwm4FkhZSk6oZIzG
2TH7lWBKOnj6P+u2JubAmWJRLM4ww8l4PusiLko5z6UJ7qqDQU7W1AgneYpx
IQhgmstZwwoMunPGZLkqXh5PClYzkIY/KwuymZgMGA9ruo7nro7jZKKVrhpO
lEDKdbixeoEpiY3cBXnO7Rqn/tFheRBAY/o/i3YKa5jUfDcWLJSTgVWaNwYs
fPDJzI91oFuYV2DWLGMjOWGrwLWj+Q7yPIKZwEi79Xko3bARFbQQt2DlngQU
PBdKHQIg+t3331kgPJQZEs0+VFWhUc5Lr1yDCYDo/RTC9LtNjR56J0x0dL1Z
2YpwQ8J92VsmB0muT3ziE5/5zGfCDcX1oUeuigYopMhzcLqZHaS73azMYQnc
8q06B/2pFXU211p5OxkKeA1v/cIQShFgeu3SAkl6Hd06XUFpAnRiQYdFcNoa
DAmtG9EYePeLWvhcqHCdAmjjhBV0tNBpmukI4Z1Pt10JUk8h0AjYp24hfawA
RCZd5rSv+9DREDU1HFmreiFEa5D1FCtefOz60UVlhLS1vBcjlSc1rx81xxf1
BctSPyInBAdWFL+sx84BWPlEgMK/2l84SFIbbjgfjo9Y9P2HQOhcyKlzYHf3
07KZ41/ZDYyY+MKkIYZmZL32fuOTQ6QY+d5Lk3qOxiIP4q5SGJZ+Vo1JrS2s
BX3kWNYLT2f9DtgDXSn3oRNT+bKo6T8+msxO/0es1Q+tV8vCMmhj/qvYf1KK
S0XJfaNPoIV0LX2xfRAs6VfI8uN4MDnCjTwXtfZKa9khUir5OI1hUcRGLMlZ
9dS9Klfvv7jrHCJfIQRKbkuis4V7HDC5FUFpuXLBkFBFVTtvhfC4ntQf/OAH
33fZHnroof77r/7Vvwo3ms4ZKh2Ex9006UrPaKBlVecZjqmVaDxj70tCZVNh
sEAYChIhXqfd4OQhqi3K1WrQTpF1wQpyrMuZav9KcK9XQQz6vR1z2jgqzcHF
0lKEs8Sl25zVtNyR5BkY4tJinrhbnbMyQ54C7oQgg/k7C39zhyNP+0WAccqE
iKziFRqXjAav8H90RMs6NVRylxQIe9Ofdx/NK0fxskzonzieLQRjAPDNmRxA
TPHsnUf3WyFc4dB9fXDxKE8KPxMlY4kS4QjGg1vBbGjKnMWmjM9lcFwCgrE+
sFIz6lsbvUgUU71bEsRk5xxxcmd9oZ2P34402OeEONanXoXv/3bZVnrPHh47
hb2x/i8uWYxlXgxNj5XMTHQO09tVdAn9Cr56U6BxuzBmo7Fh2RyHD4RJJ8dB
Gmicjf6bERI4iH8KnDa5KJJ1qFAiY2OFt2hmhIDClqCm6dni2z3p5HsoalUU
8jDtwKP2K2jn733ve5d+VVw/GdLgoqXfQSgCdY0GQDdBY5oW4pBtOUoRGP12
m7atjPdf+mg0vLNDMqX6V/to1BLONBk7wmte85ruG1+1O9lv6U02Cda94X1I
ntqoXhDPsdHcEyaSOMbt7HfhGwNJOrXPkVKIWqxRb+4VUZTnXzYZE5Qt4o2m
ObYVWgVi1b1Hr/k2obCRusVqppwzdis/C8ULAgg73HX0p4MhI7Eo/8eS7Yud
gDV66srts5IQ9SmDjpUEshO4P0yRvoWrvy5Uy3SPLTaHRdTCUv72Y/ulo/3Z
fBO/bt3no63iTO8tCtUK4pThu4H3X5QJJ0nqsOa1KqeG9yJ4o2zJdKiU72zV
EcBSp7HAETayMC8Xgz9i8ZJyRfqaAIhNf5bV6fN9mFJTMyMjxkThiKkWdDKd
g6iLbtcuofNpMGRAClNIuOg5e+aX6tWC69X2Ld/yLcpSsD7CGc5IQKGIsvGc
UQGFpH0Xdw2O2h/aqGFvkW00djLI5/SHz2rGnXN3oztP/3NMUVJ+0it5KEra
Nbp697vfrTuepaEB0x1o4rSsi3VIE4MOXMquvSmsF0mDnEwBRaB2sMo3Ybu6
+Vnysw0ndE3bq4+NQg7qNQdkVWZagUjlaIfqlDqf7uTNx0ZvGVOLhE5GHXqM
RGreUxDhVaE6/V5FJUrUpUhYQYt5Uqtgl5qeU4ew5sqh6Mo042Ry6NM5XHrF
mLcbSZC1P5PGJWzYq0kxdhyT5tqpF9XCgBMQYI288Wj2em4GMfrZQiVvPvrX
iFTPx5Gp4ba/69Qvfg1QZFuGYCuvW4heKo0ort7B5IVprSAPjHT6tqPFCUqn
KSzBsTJVvR01dnnrpQXDuuONbDzpJ9agT1yCn0N/xew6i34ImfoXmwSkwBwJ
X0Q1zgjxUvZPw4BWA2UDlqTwCzeHWdhtb5o0wlEoRSqU5OsdKdyhIcujFDlI
A/XfzAlNJBv8itObCHiqYQUJMjwxdfeaVAZT/VyDvHPohCkPaKrYTRD8kZ7u
X1kU+SNKYvVW+8AHPvDBy/bwww+jcCBXIKP2le6YBaWrbpS27DazmmXCL0+9
bJPl1w6yldSy1SxovjcfeV7tAzdEEjIenHPnGUqYrXQtXnxsqxnvzYsum4aY
UqgYFxk/TkABO+/Pb4W9PQ7yenR1FJ92njImapm5JB15ZSOZMcweVCsTeRRu
dvUq+iVV7z96r2NGEasxeJaZ5YhNrG/iNqO6USsVzJmCOgoKS6Nb2lMATecC
vYmWnEW3BGNXLMaGUQaOSSJ4Mo0jCGONZrrgR23SAQTrtTSoRRZraCaNqcpK
8cXVjOBT/fPLxt+fOvGDhyrpMhdTQSclCqDYCWafOSvOMElAz8UIlILBPsVH
3XzvyJ6U3K4ohAJ8npRIS9+SZWYsqZwVj3WGTlJ5jgts/47fTVjZ9bp8TqNg
MgU99J6sctHRpQTibrpsmi8EEbRMCYIBjQBBNf1f+At/QbUL6FDkkh0SUOj5
wsFR1M/wCGf0jGtxb1wpJevaCQtwCUWHKHjkhgQdH/rQhzSv3yvoeOihh7I6
1Lz8H8fGstKMoJkedGho5QLFDcQ/zVNWh9HSjcrjaNraX20+Jm0TuUN1zM6Q
zcASwMBkcXHc1PX3L9o49DaxcFkX3aLpsQNSlhiKhagmXKKXJccKLsg2KkEN
LsL/EatYCLhSk6cYaEz0ZmW89106faASPXhIfKvhXXJ5OYvFGM335fKU9uuz
gyEvwxuIUea5dmnkKk2wxM1IlXMZFH0DDTbG1mLGzLIq9x3NdkEZ8GEDLNjo
vTl4rjFZVmJZ1FEm3Ap/mrYrgpPoxOsQLpAE/OVT1ySekZs50vjG4QpmhVLX
sg07y10FoVMXnProJEkFZpXuvuPSXkFxvaJ7PLRfuPTMVYf+f142xvx02kGc
g2OTtq2NtXipR3Dv0f5V7NGVdudbWWhR6t5L0KORLy3SBNdPgdsCKPRt0cOF
KAclsebCQnbNx76Yy6O8hXgy86PX9s/wkLNo8GcVKwlZ6QoohszdsS7/X//r
fx1EaCIvA/uhy6bHq2ZJ3EnrQiDcQQSF+GWN5Oagyt8sK9ARQmqjgIgu+NnJ
ND7pidFFFA/pi329gzQXejTBAlOhjZQ35Ubpp79ybOhYMKqNnC+GJ/YFRMqK
CBCQWnUkobJFFUecE9OVLCe1+VyklnXF+OfWkOc3DGAuwFnrA1dtHv3GvIHX
/sgnnBFWqwCIr4ygZaavICWsQFfTm0nLpGlNrIR8DVDuP0l6+ukxuMRYzqyP
5Ys5OIszLBG8ckIgeRZT4kTM2Fhdm7kALpaF2at+B6wFDs5aq6zKnuXPGHB1
m9ScI/SwwaPsrToUgYh3Hc0oz/IjDxy94VhKzIlfvPRoEw+BDzTHUDjOTaip
7WkZiYhOC8gOrlepL94pNY8pfkytCPByxKCHpJvWwK0UyqLbQg9ykWwPxXG4
YTIv7I3QgBzHHJZWUvowNC6aQVowrOg+q0NFf8cMOtarMbOn0+v8Aw29dNc2
Qp1IpkhGhQJVEoK4o5kcmq38xm/8hqYn65E0MmpX2kBqweoym3FBBEoYDm3G
knRPM/TWW2/VdQ6VTqxDj0LVH0Fid6YJ25xSOajBdweh0qzZt5iqrk/0vUdG
5c2xRnI3tDaTQtVJRGmqjdoedb7OHMEDk0plOnnh5iae6jlcQPpjLeEWrOj9
uQc9c/QsjjpW9oBoAX91DZhC5rWDTCuAViHBDd3kdR++eun2PvI2j2CT1Gw6
By3xJZz/OsgsJHKmRflk+ReMJv8dgcrIn+ae+Tua99S6zrYHr2esDMX1099w
FZCBYWwFR4roTs6EWzXcWFhn7JKL4TqNzCm4Oo/Dr5gLEw9EJlkiDEWkmaK5
mwOu0z1zwrxQGrPjr+a3m6Dapf1lKMiVzIF966HlPt6+UFhPvCmjLdf05Zoj
WKbIGG1PeMIT1jlu4sZrVssHUdrWHAkWtLhFCwE4qu/7XFPsXptKQgeNE/0x
BTrEcjV/DzODDiKlv/mbv4n3lZmhThaRY/0Z+7ruriqIgbk1tNW5CZiLoei+
S8NSU/7WdG6GLqjYDdHdsukciirS79L6endJKz2aq8pbiIlJeXBbMOVkSCEA
sT6aA1IhKx5Z0dnqStgYPYgeB9aWynoeAXcAjHS24oRnsUHBgfUHF69YS/pF
P6ZCNhbQ9aOTy5le3ibsud5PaFem87VLRydl/iprKKgHI30o52vWWHBNil88
ujSy4S3Qa346d3tWDbNnPteNo/GuEKV5J0pzz6Ewz8MSsljcABrwQcYtl1lQ
JPL2oz/jPI6VsTA5NsHVswwJ33y0aeMALjM7VWSWhmvczPUT8onoGUt2+Mo5
qDthEImSB47eDXiJpMBEV1DZfQX9A7dk+qVyxxSPFcrhynYEekES1oBiRhRU
Z+BJkfeIWyDGY+zRrz8ahrPQR7ZHlgMJU0wPzZtChgCheaSmTBAycMi6UE4r
HoKYao1WEdMS3DRp9WyQUwmmH7gei11R1/Jrv/ZrquxZHWEF5yWr4yMf+ch7
3/teGmuyM33Ra3eAT9pVN/Ya1Rn5ujKtfA+ntDd9eBZmb450KxD1GR7CFwFd
wIhNgZq+ClNxS9RusU2VaGTDEbqUlRHd8iE+jKpVcdGsPjW8whfCj9tQI/7+
sfUJQtcMCRP5TMkmDYTXek52+K8g2GyMG4dO8ppRzupgBpwDDoukoXlwVQh8
AWGeDpdkahUzy0eehCHQAwiwlk3G2VFsqp0nkJyk8Fn6bwEQR+ZucOEto+t8
pAJdJyP+yKja//DoAumURu80lyfpCU8mLSi1zUsaLEy1g7PjVO87+lTOMUfJ
sAlrsGeWBFn2ROZo9FFlbhojQkL30J1hZa1RC5tkyCmAA3mI5HScfmvm3/2H
OtmjRI0evAjfNU6sJuIejdtmmQJSa26woG1c9kagsXSt2IWes6OHISSw5NXF
wBCgYbGWeaRQmmvQSO5UXQKPg9PRK1HWjIpe5VmyNx566CGd5dt6Q/RYgkaO
huDzWKmtQf1E1yUUzDRynqsIbgp31c1Wbj5JsXV/a38xZALpOLS0RzIt+BeU
tdTykAWmSLZqQdDB8AguSHoGUAtcyI80DXsWZu6UwbSHHoas2yNAsM9aF2Fa
Tn5Q+HQEeH7HSmnWTvFc0ssJ4rbzi1d6tqq30Uq1mMSW1zu4uzfKh5qUc3xj
+nWMmatHawN2/uo43nJ0kxfEWHx1eh38rGUwxzUdJXX5xJnojBAGgIVYZuHM
nhK4gDYjd0E2uCHpKVFrjC0AciaQLBDqUMvdSARb0H/h0kxqtsFOYy7DVEYx
vnji2GgPHhoj0GMtY0RK4djiPNx/0RWGDVNksuqqSnGi2g3SAmfdprgAAiYi
RS5EVQsadkuGOm5xD22dm/LasiBprOMkdke4oVmP9KI20BTGpHoxwXT+6vMw
RMFFc01qo7uNX0e+Q9xDvTBHJvSAGLktGSGulK6gS171HMuNtgnDo1HXEA0V
+SBNZGaD7m9EFDMVunxF2U2o7kCfBAiUcKQ2BHMwPNsELgiGq2QnvkfuQwgU
w9af2pGwSXQgWl9vBgbKhADCCJPXDlF0ZAZFMZioFH7WCPLM/FxTyFHfsVbO
TeolcFkg574w08N589EsQCQEI0sMk7Hh+CRPQYeL6sT0hsZTxe10KIaumm6k
VsHYPhxSCVy85ehQMIbDLxwdePkvsidzRsaTPKtvvePUzkYKRuAFrULGRHjQ
dPBbE/GAM3NegMY/P7bpXo6GNBdsWd15EIIk45mDQVST9WYCAhM2hxtgQZXl
u9/97n5uUVwCI4SO8bXOjSCnm72SGeW0o5qgyAoIUKlqWjXXOo2lngkRTPds
uZ5ZUDI+PUHESHGPTO4W0AY8ipf+C0TUscIyOTJFVKbIyGBY6UXePPq+7/u+
Pm8HQuiyoiovOloI09zsVxpFnSRypuYmIsPUz3RPWOuEgCL3hEqY/iznBk99
sZ1HGO4aewTdxsZ5jkCXQ/cmQCCTJcnShw374MUj7s2rX/3qzIbmfv/tlVRp
Z6viLxjpk/VGxEflcQh4ktvSSsBGU+uVr3wlnljWhRISE2e867EasLiNLiu+
an2RbVUwTb2Vqy/siWoFIta/ifoWd6P3AibiJ/1XcHg+yOT7Jv3Ndl3dGeI3
3MCx13BW33nXBaaERLoiS6QUJGLGxIvUBo52MlfF0jzuhGinWTNJ0kUMphQ6
NvWSyEM8DHM+wjowWkM5CHORQBOTAHpY3McNk8UTWmR4mOyQh8Ej7ynW0Q6Y
VMuPWxEYJ6wOVpAMKcRT/Yq2YRao8CJXyKYa62yuFnfPhT94KIrwejDHWFko
smR+NftofjWzOo13XjRRhzyYmQQH1ntuVe0snK5I244GdoOh2aQJWouyKR9Q
hBvnPrNYXm2kCNut2aTphhoQaVCQ0iqvdZSwan82DVt/G0JdbHe4J0JpkHAH
KFjvSJ1W1mGhy+yqOWg8mu4t76Y3a3U96NBttl9ctQ7QC9Ca6f23Ic0tbbT3
JzG09u9yFJEpONWHSBMitahBBBnPMcFCCSEL4pyrpm+jiMV9aGahM63oA4as
rnO2/TKqK9Wf2vk8mrUrGskTXKzLm0AHJCEHSlka5lw9miKhaY22bSa+6dSW
dE3l6KO6QJTy5URWItc50ABfqSYAuffSyoroJfOJnB1XaAENpsgDp/4CC4+c
M54cihEkVHycNVJWFSK2MELm8rMCg9wigDkS+wQG2SqNUp4194FRIfcxwO88
GQzNuHaQVL1+dNcCkl2ILIw1XYkcYUNgAg0Chz4HHS2IUE64hoNz5rRzqbpR
8NZl2lPeAa2Ut9Jca1pp9Y6PHTR1mYNrcVQXIl8jSEKjjK01qgllp56juu+m
Q9OqGdRcy+nQf1bHhLVqIkuoJL/1N8QQ7uuLyFSBBiYDsof8rP5QLejNO7I/
qu/pbk3zR8yTJGlwob1ab3Qr6H6em7oyOXDDulFixbTdSJSgaihqQ8lAYwsB
mkSdA6u10Z4bxa4IRbVNXNXJOq7inPeJe0UAHGLMqDCpkTnP8QflWmdKJ4iQ
4JP/AiPTApomBvN+opELWYhqcm1smFpnnmdTdcLIzf3OZBmWaXBZ8UfzEOuY
vbFUi5oUnaHQzxYDcckCaBOpOzOdmATtqbgYA5YKGfRwJsz7kamWCX3HqV/b
g0eTRMDy5qNl3qrkhoQELqzpS9TK+Dx4qGRYr5fWuf9oM/32o/MaK0LS05xd
f7ez7I+EqelMtQ9DRhxJeKdJZynvVU9znM9J/02nFFmU5rkcEAAUhlWowija
L3JSFkWZkCnmmBAxkRwV66KjCljuv4iNr2afYePCAZqALZsNXLNSuuF0I9fn
OkAIOprvYQUuui7Vq4zLFAkQnvzkJ7egZ9VrvZH5oXwslMgswQyRaslW0UGy
HVq7W7Z6vp0t3iyARWXRklt16lpUhxur0OcGduG647WbRo3yvF1g97kH12RZ
j/vMDCGOtk6AWHHX29Ns525Cc0GyQL1no1oNLNN6CQ4F9YrdgougIzwZ9dos
MN8hwGTxhCWHG5IF9x49rEdguH50Td2sHCPLyrg5wlqYiTIdLXilef06Fwhg
rrOJg4/euerXcRtWSolfyt4gG9iFr4+DvMYSNOt4C6yUz+Bo/eLREnGVMiqI
OyCcOcuQiroIby5Wae6AiwVGfuFoSD1Lg6m2Ai7jH3QsJyL7s7gKDOfujfy2
Yha5lcn0LUb64CEI9rZDu3gFMittUwNIb03I5ZeP5rN6Kv3qZZMgGHMVsEx4
cMjJh+JqLfkCQJzSxH/0ERA8xJsS8TBfNGPtF1HQPX23l3cGG8+b3LE3Y/Xz
lboJDbkeYq6r2hYyX2ilSB1Bh56zvQ83+lwZS7OynRWM4z/kFCCVKZ7FLsth
kZTJLAk6dDZxtq6I68F4kGchXqqj67/8l/8SekAYcKqTNW9FhETxfk+TwxIa
ZA6NHaqMPaMIdDgHma+GblODdIxkhIeOWMUOn5p3Zj/bQztUfsG0uwcLlptx
O6cItEXfjHsUI3QlZmNl781AaQVf4xhM7BS7QzZ2alrnc1vi9Z6jM9r1o7mz
aOQZgtbbGpxyviCDld20XbBl0CHfLaSDiWHy9hX1L7wnptqgxo9OdVCJypId
3O23HR3kZ57t7tnEE5akwLcUwXjr0aZtWkASNJ3/4kLsH/7Ruy6ypWY0hoYQ
5ZR2sD3RtEY16QRm+wkdo+9OfAwRS3qUdLnOKeNozRMRmRwsQKeJfkAhlva4
8QrP6W+bEbCIgEBTTFC0w77l6NbNO2OoCIzY/tdj24XzeuR9gExPtrvX8MhK
z3lvuuXvZ+QHAjpW//k//+cV0upRq7otQLj55ptlK0hM8HEU75P+4KqwQBTs
t6curo2NbubUFFcD2/1E88Ap1eJE0GON4YCGb7XheEgkyXH3sHpwWVD5UETO
kVVEYJ7xjGe86EUvahZ032C7KXDOdWJHgAWk64l6MTbghn14AStmVy3iONMx
tpTP75hkzZlGbvW85+gOufZMfkVKhZdx79F9Fc/B+itr5nzWeJFrM74lMROT
3fH9OVUfTspUQBEI6QlMgXCxTYF9t25Qs4ZTfvfMoRouyTGxdedY+UVpZUFU
en0MaY72KNP3Hk0TVncPTqfUNz1zzs7EfxgJeJXdunsurRJluyZjAjfM0yl8
iq9O9JjXz6+RPGUCTZz2ytGQjp3zD49+kbYJbgikrMJd3MMqP2Y7YwMXBYDM
ryFVOvK8lBBfvv+K8WqCJiAgfOHgK80jNq77MzfKZjK6k90ExhKUEx/ownsK
PevMUeTSTAhlKVkOQUEgkO3BYVlfSD3jghdMCfmLgGLCQZpDCagqlwteWvFD
p36oZ9TJdxqhgd7TIUMIQOWgS+jPPteIVu+V/tT3ioj6xDr6Ez2Mt9Jj6uAt
Z13Lj//4j4t1dHq4JZ3Dc5/73P7Vw+UJNtjGiRpoGNIWboNchBCxs/M3wtef
6MymsHpurTfLpjux+ADcuHG0PmSljNzFXFHbvuYmlDdW3MGYWQwfHLVpKzn7
n2dhrvmhK1+9LbRy9ZBt52fNjdXUG1/0XEAnJLI4KtfDe1cxiFsGBMV91XPT
UmMgCQoBVXbacoUrNHjLIWbo2lcGMoUfnhfEWHB1zGr2BoJrJzNlEs+rIzMq
TEOk7pW3TzPQLAYdO77T4GKIpYz7vcoUNgPQsLk08VVdnP7h0USbuyTuejZ1
kGM1euOkA5khm6YDvHs2PBXx0ENwAE19ORRkD4ADMXRV609QI+nzvx+bPkq8
HlYWqg/tdDVxoQF2x6ADbgwWVIOiTGiMzszQhlJkEvdDU6RnP/vZL3vZyxoq
jSh9GLHNdVILAWgTaXwvCRuqnKEDYjBIek/rjyrpVqXmSMM+fEBE12LgLMGR
a3bfpX9lw6z5IpIJOqZBYb1e0lP3EFao6cy6Vs1xXpqxtuQo5whsplsimRaD
EYnLkbgY7YMyHQoWwdipOm25Wv7C1PYEVaTb3noR0GOTTAR4cHFW3FokFoj1
W5q/iANrwnLv0UEVV4GpxmVbSsj5CP7IdCyp17WDGrg0r9B9Xu8GJ2PVtrLD
jdkbg+XZXZMoHGkTerz9aBS7QtcxUVeqI2BLV0cWZqx19rk8hSkMOlZxv0zQ
O4+eUP/kaD05hEEzM7sdFi2ByMzq9OehLCKqat75iGzIRzM5RFmhGWtk5S1M
CJuWH71qShIsUD5cBDgcwHAALGKMQqnsFjKtQpGaKDVJzbhuI9JOc6oZp1Vr
tsQ0xAgBya3Q4jjXtY1yyWfRZUwBqU5wqzF/wQte8PKXv7wR3j3pJOGGijah
DA3ul3JtCyioj7azLO26WvNZgo6+8o8vfcOBf/Oxa8Hr6Ec1nFWSpl41X6Zz
wDia3IpJNL7l2X8ROjD15mjIPpjasrHmgjKTM+sbBI06fo4POAhkMIbPfavX
DsnSzA1hkywysEoTa72cqR9SCirIMGL50GPhzV2daXvPRTcYjYTo2cS+BDAt
5db9mU8jpzmlEePFHxgeUqjus3CrX9+iz9pxk4EDu0Jgc4QNmWgXOFUcEG36
c3D4OOOXTiIMkMo+TwwcJK4qdvIaExd1nJWxT75P5HaUMBFO2ZZ/cjTCHqkV
JpitTUOaye86tpXnL4/Mw3JkrpOUh6WfswNP1jiGlrssJEYozkNzqinWfBHu
4MgIjEAMCGMf8wsLjhEiMsOFcfD+9a6LbCnosMpkGGQeNNfU0ur4Ji0riCFM
GkpIuZILo3w1RR1Nn3/g2LRrbMXP2u/ZdckhwEMPPUTM/D3veY+iNgFnl4y+
ktVBu7h9FjL9fy4bddMuua9YCPjUDa2G/a233vq3/tbfetaznkXBj1hf55nD
0hpKOGJKvONjWxMt3+vFJsMijECMgvchrbk0h/m45OxYUhPUGnt8CICVBzrW
m3WKoCZ1Py0TMUt+/HDTcFAzC0SJ3CT7CGGNAfIoq2N4Yq3vCJK5inZ/9md/
lkqh+OE7jrbLRPB8fY7StMXO4Ol3z7ST2Ru75AGXezI4Gv/8/qNJPbtiAU/5
1tWMT/4XeZJHsOKUQcebj44tkk10BX/ltMEZXoPZOuL6CvfOEmEwYZQw8QQe
jTj2tHpUr8gkjtklS+Ln3n70qHWBrmhM+EVLTGExB+QQ6Q/XzliSx5FE0HTM
lGeBkMoJEGRe5G3lNJt3mrlgep+3vmVN7wS6QEUfFMJJ8y1Fm12RgUGyQ3NJ
DWq5JO0QRKBkk7/D1m62sjTUdOBvP+c5z2k6N026mZ1DJxloEPDJGeGL6asL
/dq6ihADvIQhCKV9EStsTa7dOijdMGjI6VrVLzqZ9aHOCOnqCAbedzSH3Zya
aoQpKU6+DtF0jCdwN170ZKamYs19MB1uP7YVoG1VZS2jiAsVznL4+WMT5Viu
xGyyxI8UMS/jLJUDuEZ1OLtO148OzktP7Ahyu50Strmr7tf7iolpnr7lortL
TvDMXQGSyK5njDqT2SSw4LAj9B6oOpPZe6uIYXis/Ha8DvPLFHN6pm3jQdrC
sg4NuAajbq4ub4zTkcOlXwlPcVXOaVNLP3oD6jh5n+Vf/OssKoLVpiYufJja
xrQHV9LCvpo+mBp5U1g3N+ixGb3sjCTsyCGsFOUqzSaV5gwVPUoCB6UfcIOd
Dz1akdvB3Rt6CJ+ia7Znh+1MOr17L2L164n8qle96id+4ieyE2655RYNIrWK
W78nKVeCP81HXgB5K3Xrk+F91rER2Gyfhk13L/QLBH7rt37rwx/+8Hvf+15A
5zLVzA4oSHaEHu3W+2wVropgaW9EbOSjFencc5E1Xqxjveo6jVyY5sIoPYsx
Krswzq3pky3FfiTqO2VdS/+bj4Y4Dx7a2uKE5s4SoOaOnKMJfs+huvm6o9fn
647erLyP5Xxff9qGQpMpZldwBLYBqP30kMF/LbVDGIERMQpIFW4oiuyqqRn3
LybHgo1ymq8/WlEv8IKqKtKytNEZP+ePsEwgFXepc/YgnLazdYF4oUuUjBUm
fSMuumJPcULGPD7GmBIQACdhaoTSH3hQC1dKgvgTfWsOgmzLZr0Ju5zFtNdG
wpEnEnWZH0QrDOysfvadR+tDxol9XM4qXpc0QfESxMDfWKGKEE0zvTnefMlK
R3xiyUtQ9i2REK4Ky8RibX9ZY9aRQAeowYiQrPmVS7cpBaQqIPJZhDtar1G8
ZF3DDdpfvdFlsv+GFe38yle+stUcwUOPV0lb0VHdkfqX1Ea3Ra+Ehx9++AMf
+ECwoKItnyUbQ2QDUGgy+9u//du9hjO6vKHRtkmvsLuoHv3KRW66a2n8dz5a
SjmNNvzzXzwagc1V8YhHsIQbikdMahGAew5tLvEKRgv7eWQJbshIHTKzDj4t
yquXtq3myCKTJiDeOEIa72OxiCWC7zwaql47dd5xGn5ieKL0Y5UUVw9tYXOW
GcBBGJcsyNXr4dWvfvVySX3Lui/K8ZZD6n856HO8wnbmtg0HBstcJFnvcUVE
RRZM9krnfNGVNx7tbtl7lvXpS6yIXnJEwMGG+71Bsho3pssqSlZRtYbyzZ3m
kVkmJWfmOhT7QQT1f740PFpF7UpLfuFoeitOsqzu2N1nc8UOXBKIxIiS41BK
IwSh7p4Z0LmNic0C6Y3KL0vtUifCiV5Rsl0dU5+30hfxM92EBUN8UYqzT/qh
Tl7s2tLTEG2dbY7rE8dnuemmm0DHlHza+lxL2Ze85CUvf/nLcUJyEAQ6NAgQ
PhUPySZpQDbme46dQ0YF0dGlTrrSoCPQ0NCt9/o3BS8f/ehHs0+0l80gkbTt
W+5Jl+lRdi09psbhT//0T//tv/23z90KetMn4y1vFgt4svx7vwm7mP85MgAx
Fs+3pqyAwlq/YrRlTleqds8hGXrv0ePsUZQq1jsK6MS4uDMT3zhHRdSfvvm0
TUfiXA52/9EugRdjsoOOzX2dVjSAQLnvfT/dr1g3p5IhYim9YrmBsR1kNpXt
xqnTgajLgNQvrhXd7B+hzmVSIIMs8B6E7PASK6hN7zpaGyzsIDQxAieb4Z8e
beWtMuQpUDSt1HMEhCUnFIyICEDMqeHSRL3A0TuPltPAbdW+KxNmI01zjMKP
5ItflBHG9XL+8q0K7Z052QqgseJxkpvsDS4/m2QVprKu50QtopRujKZVANK/
wKOKuXVNWqBAv1eZGoWEomShx2233Ua2NBD4nu/5nic+8YmPe9zjEMuFO/Ji
dHbTRzLDI1+gqapzAd1OLWsJ+eaw3HrrrQ3FBkOX38ksRupsu8zQg7bPey9b
OwiGfPTYQo+gpg+V3kvOsrW4ct3tHlYzKysItw1dra3TE9m7cqj6b2Wcju6m
pLkMN7ZiXju6E459ZE2HACbL7I1FDxxW6uQsm3PO2C4Awsf3xVWuiR5I4igc
my3E3jjLYoxHrT7rvqNN6huPJl+qlvhELJz/4bJ18JwUdb7hRssHH+3q0c5V
PNCSev/RBI2DIwrE4Tqz42RXYY7EqIAtTumaPoxNuifCDkQLWQ3vG492jUrk
tqxPB/UtRyemOS+jdUn6twkaNODhxhq4vPPSt+jczcRcbvooVJ+RT9mvSS3y
s6ubqqfPGR5vOTpJgTiXP/qu/JGiM47J5GsIcawSDW2MdkdHC3aaRGNZDDEY
ISCCXTGvRHwjBFhkQ+fW9l/Rx29cNlaK0rkOqxC1ySg9oROBr3ecdujMUbgb
WhouaOKs/zufBWGjrTfZIbpJPuMZz9CuWjPlLI1w5r+5bNq10OrMOGk6N1S6
mUwOzWQZVIwl7d6ICvYveh1Bx0c+8pFPfvKTn/jEJxgeRDzYKl2IQ3Ut3cNG
SwOPw5V7Qn8j+Arf8DnP5rRlbrzrsdDnEZyLUkdUuOdoXjYpm6niDEBYIJIO
m6TT6LhyUEyXbZzxP/kORogYwpjws0BedzRMHIML5ly5yOArl5BTEOFfdbk8
miI1oEHMEO8rU1O/+9XGCqo4JsEcAhEMjyEAyO18zhS1UbZWlj5BUZYYI2rZ
5yWwZp6x0JZeWeBxVXsA0w73HY0sEb9HHP2lSy974XdECAvl6oyA0qSxVh+6
rgp9V/ywycge+CdH7/hzfm16BQ8cus2cF7drdLXdn3sP7XGWUlghjpGRoIPD
OcnLZ5loqk+4TgMNUQt2OOtIaMJMZ2YIcsIKfsdysv/fZVuRKcpZ32qGto6/
57IJLACZkESSQrz0+qVHeSMnqyM0yFSYsCfZjcdetnyWxz/+8SFDs7LpSWRP
rVlTtZ2fcGxqZvNZVI40PLpLmsn26yulZyxxT95/2XDAes1b+d3f/d2Pf/zj
Gtw/fNmWc2mHrqvvdkO6mT2m2y/iGzojMJkyPJSmDjTGvVyJq9SABMqCpRxz
K/5yHMtNLAy4HJ+FEnogbLBnln3A1wIdrAU+BbtFZudMi5r7A4JwL9XlZe2j
hcvhLqFDK+OXju2Bo69o5+ZClOdgZGVa6AlLuqf1QlYFCIxE0RmKJb7r1P/o
6tEhnbvBj7CSYlmMEWdCTdxYh0p+k8wLYSK4t7jQXK0hD32M0cDm+/D+Fvbx
9e2JJWXqEYMS2ZMsXtHiSmbM9zVwwesWjbSgt9Ar0FY+ds5BM0qh0LuO9klz
VdhdWCiMsSGqcKhcKo7oUjm4o3yHs+s0Te8lJdvgBtCYpaEsnSky9hSnQy1Y
uzUTBQ2s42Id7dCfIUZzrXUcebtpS3K8V41fRysFHa0+LdxhwjOf+UyyP6rh
1p7pO7/zO8MEJCuVs81WxbPCI6wUndTUuWcJN7a7D508Rww3o3NG9Or09FvB
4ggTQgmSpFq/BR1ZHdkk4Umv7QlMwpyut+HR028owj0tI8MN1rWVXfzfkodX
MNoGtuQsbSCwHIf455kBAnlW4MaWNnduHF2b5SjHdBr97Lwo8+s5O9bca0fD
6BuHxJZMsZwp0OC/oHxYvlGbUAjeemrutrpaGef/8diUr7b99E//9HpChbq6
yg7cTMwbh5LGGB0rt1+F3RLWpu3iOarzTKtZaNdP2oZuCPfk3qN18puOFku8
AJxM+UqBbsehmDHKvRA0VEHY4A5gUPSmoyngHVvegvLGS6OTFZvIgwhFmnEy
gE1M4jx8kImrOAdBGDQPVt8UC1Fwpz66zg7Sc++4dLEPppgceO9Og9uCIyo/
oq4NZRRNi9HOLvIv1oUpJiPJMeGt0Nbz9d5T8CD+0xvpFUeQ4swRaD6KRrZq
N/Wahk3P/mwfxfvihM2mhpA+JoFDVsSKWWx/8S/+xZChz7NJ2uelL30pgdOg
Q1OGOSzt9tSnPjX8Qf/uDvdEQGIXghn7G8fmJIkYd2ITQg8fQo8wxJuPfvSj
ve/1Yx/7mPft391reDRUmlAveclLOpNMndkbI3pZIwhsCh0ose+SLbUG7eT9
531sZF756m2pz7tPTV2XIPDTbAmGxKgLdx1afCNkMni2mJ7LW2AdXwMvXdAD
+tEEM/6taJuhO8OrR7cFkVhoqa0GQeaXvexlPcGQRE39CBUq68eM/c9LYHYf
FgxEToAY7oAwESviPxcEBkeM+UG3X5f7ZkHN5jFt56cM3+DPjZNkosrQdVQx
wq0FC4OzdqYuqMSs6SAdaVFmbEx4/ywbIvZ79ehKz+uBDDMzHBlVQ7H8mOcy
3e2WgcFamJLhyvdWEovfxSTQ4g1utPJmA7QK+7qIx/912WRP2uRHJk+BEdqH
fSvQYFr0plnpwtHGWpTXOq35aGW3lLd8BzXt2Zl3CfCzcdjIbDiJFayujbei
iF4U9Pu+7/syNl772te+5jWvaaEnL6bDUYZH3wpe/upf/at/42/8jWyY4KXj
00JnTQmNcrI6DXFR4VON7NtCD8nZTvhTl+0Tn/hE/ssnji0AaYeO073t2eWq
v+AFL8jkyGHhU5+p0UIKgg8WX1EIodFrh57/6Jp3HYXzVw9NrS0xV4/S9Q3C
M/9qdWEjgzk4iHAaS6yMRXnlqGm966vr8V3CPzi2OSnniptzOdg5cnuO7bAT
6PYg8LT17H7msrFn5jdtTV/2dtUuM5yW0VZczytBiDLBzybBtDvG3z7b8HZz
2tADq3xrNMNjgj+CrkIW1059J1dZDA2m7aPkH2gsccyShD+4WCKTHAFF8ate
gQaUiFAvJqPtttAX4qec6YKYYAIailwmvS4RRjxQ5BPTAEapySVTPJY1dpbk
6TIpk9z03wwPhC5xD6EPJg0DhtsSPrRkiytiO8i/mJtNSYZ9r8KPvZqGzbsm
XdO2E+5aFslpgAUdYYJMaziwnpKqYlXcK6LXb6iVy0JPI+gvXbYplAYdTees
jm5yTwGs4dXznlTWo3MIk8qweN9JhnKf/vSnP/vZz37uc5/7/d///T/4gz/o
/b/9t/+2970+8sgjGV09kSYUKuzznvc8BK07DoG+pt5qRsjXqHXdTJzYi9F4
97HxiA3smQpLkWw3o/3aIcThh8ZIv+fU+nB8s7U8wKmQN9maOINHpHRa6Lyn
nz/1aVrpGXyTgeVBOO1pceBxwQ1toXqz6psRM+48dZN3B8YXHaP16knuTKAA
ao05Nqfp+qH4xwxAfljUFHSIf3LcrhylbchRww3zCC0Tj/T+S8vLkWcWbThn
lGYpuQq2AavSjRX8aZ8+bOJraSrdj2f4S0ejN4FZxhVyl7zk9UOkUR5qVS3e
TOQQSWO08zM1l9WxWjOapY4PzdTbrk0qspbMLPekmc4NYXhIKjFjzDW5IVHf
AIc1wgcx13pP+FdMuMmobxp7gxdgJoYbWft9IsCoMhH+NzxCg+c+97k/9EM/
9D3f8z1ESlkdtDjobzztaU979rOfHcLkI/eq7CWckX954mXru/kvz3rWswhz
df+7RV1aiNeporz2RliDgdHZahbZe8ZSQJeZ8YUvfOGLX/xir1/60pd680d/
9Ed//Md//Gd/9mdf/vKX27Nb0bPL3tb2fTbkaEtvOPqkU5ZYd5Lbv1rnc+bu
o+hMm5hjd6x+fNEJr0vZ4EuY1/cezdo2f2EFuHiUstDCno4gQOqEQRzyGOdl
jIi7jlo2/Iq5PHx/pgvSVxiesdGNevnLXx56IFcMOcVqtj+rzO/O8BDpXdOE
cUtGfzrjxs6k01CWvp4j56IS+7ux23Ptln750mXJ+PzFo6M9p2YpmEmXuN7V
ECHKLgM1iou7wfVrnz4HHVZtpFO/ssgPx4oTgbyx+C0m/Grc+Fb8lBFHEcUn
x8ERg5AtfArkJWdRYXFLSAPJsS6NMn1CQqbLHUMP/FJZkkHHCupNOsrhuSTY
DoKfJD3zX5qMIoo5KWIIpmcfNiv7SkfQ9XWc+Z5F97nZRxAYqUOsY/3dsij0
VdGB+qd+6qde+MIXPvOZzyRlLNbBUOm7fZgZcNtttzX8ehCutNMjxyFL8uEP
fzgcyzTyps1pC4qGHr/3e7/3+c9//guXrTeBRgDyla98pTfBYFfRc2nOkv4T
v1pBx8jPZCIkAW8/1CFWDDuLl4l+du3PpG7m8fWjftMqfOOrdX4cWYaF+b2S
kwU6phSxeIXUyVjo/sWrWv+FgYmrmHbHlaOfoxLXqycqONfpHxw9QwVFSTG/
4hWvkIrtu9Zu9rMcvXsVdFis3TFrN5wZ21Ot+iQyJvs518/dUw4//93Ky/Dg
y/jWQhlCi9bxR0kcb73+ha/eZKx4hcON2Y33HV0mxfTOaiH0BBSM0M+hFewS
xoefeKmoBWKqaMaUAFeuO40+uKGGbjX7K47j0fzTS9dU0UuE80kAMTDEK6h5
jx8ODRbKkHW1gwvhefmzr4QqWRS4DW3sjd7Ivfb5Q8eGxW0OZm+0z/972fgI
vVFJJxOkwLD732jB4g46xEjDihAj3Pi2b/u23gh+/vAP//Dzn/98DZf1iA8l
NGfJVRHx6M+8HumVHmK3rgvJ2HCqqCaB2O9eNrGLDIzMDLTzXmFd3kqIkbER
YjA/sjpyVQKZDtI96f739FtBRnRcJGGFpagRttWMTJZnPM+BxibmaseuHtqA
Y39dObT7xjhdVeyKQM9RAkcwpF936vWGkAkiZrFMoJhOCHCQyjR/z3FaVsrM
p6UwgGfHUZmiu3Sg0WufaBQrucnOn9qVkpbRa21u1+j02JiK0LGk4AATa6Bx
ruQ1y0DHuJfjWJqMQqaL+g4W5C/GxVq4dRwPG3weUFsabhxiYr3efgiHzmlt
h35oPRpA05JBN44Gc2rlnKfa2BXwAoHsCgpgEjqrcyH/tZp9Fy4+3IaQNp6q
chVWh6gpIvoYX+wi3s0qUzC+JIO4J7ItJjhXpd3moWRO9Ca4ILTV5xQw+kTH
NBMw3Mg+oe2JWapcfYJ+bYK6XU7Do5nefP/+7/9+JA0qozM5kDqe/vSnZ05k
b+Ta6IZGZlD75ic96UlUuege51N327sKNHiagcFXl9D0Dy6yKz772c/+wR/8
QeiRybGgR1cRkvz+7//+H/7hH/7Jn/xJZkag8alPfUq6tqvraJ18DxR5ycRc
NdbI2wj2TZb1Z5xIBYt6AcarR/sky/c4AzcO6c4lSq4cOsasWVHQM091ZvOy
kMuTQoZzqHbD2L+QN+gLsSWgDb9mtSd3HO3pRUrHwDT9zfd+gvIGYdUsQFEO
lTJXj1YskzKbz7XE9LnmxVXPgF9EYhkHc9mV3nPUAC6aatWe4aHOlG/CmBd7
XKJ2zJn+lAEZRtnn6iHoupSx5LLnBcm5S8gVuDojAaLHLBcMBFg+k02GkNNU
n6jg2F9MDnkQImCrgl+HBZsLHA1+IsyioAMKfDB80X9xbFyPXu0ptcqFQfIc
yXwx3uEGMUMFcVKZmFEEtYIOGQqrueSmffqvdG1nSEtn/QucAOeoK+1udKsz
a5/3vOdNqTisyPYQI9VXpe2WW2559rOfrYdR3oq+1YTCBENydp7xjGc85znP
Ie/TvUVi6QJBR1ZQTkpYEWJkVAQOYUKfIHVAxXDjM5/5TFZH/w00QphwJr8m
eMkaac9uWsfs/l8/WhOaXxBDKFIqVnBgjA72v1E9QoKU4jkLucj/OeixGKYx
OaHdSWrMeYEbfKXJcYjTjmi6bSRPPBM7vO7oE3fHsfGJVnOKWMVvWkRl+WgK
5HTMQoygY6X0LJkR4AdBY7Su8u588ow0GLXGBzO/Hzj1mb3/aC20MIjMizm4
2nnBgWlvYk1cO7XTdUsRL1cp9sCl0eGSXIwuaL9wzTlizCeS9LlyiDHamGpj
qD4qj7xULNQCGut25JO3He0mgwvlqyuWoaExOWLb1M5/5Wj3JkAxgXQQtGAF
M0OIg6Uh/bqEyP99bGtmtHArASLs0/YXJWjiBBGK0/uT7eG99ARgyYyh3ikv
3PFDEqW1OGbYp8TKQIdkaxN/Iuffcdke+9jH4qIHESSCQw+4kW9iz7Z1iszk
+Mmf/MmAqIeo8Urn0E+LzwQOLApBjByQMOE3LxtRweyKcCO4CFskU8KQXJsP
XDYlt923zvzeiwj5nYeuDsYUAlUbf3aSEeec6fVDQp+vbTQuzTra8Bjmi13c
fVIpZwavzG0COOOS3XlSGdXdidkzWtpwYzKGk+8w+GcLAYT+i5Su2Fk8dhod
fAQTf/1TJoFIc9i13HWSHhJgGZKcS+m5LfO5lsg4V9RObc+baY9vsR7IoGpM
Tw9iiBL88qWDqh4fixf12k020dCw17dofM7xQpcE94yg/bWTQMGMmSWvx+Bd
vmaiiGtxMhkugc3p8AiWLmmrJQEaucvRs4kXM46o8C89Ye6GzAhbYo6GKhLc
0bkzvTZhl5OlWoP3NWzh8tABUzLsi0GBVKbyUtFRvG6kst6wN3DAnFhAgXwu
zqA9ASLZuOv9UJffOMkRpvYTAgh0IJHikSpOedrTnqYlK3tDYX6o8qTLdvPN
N2sye+uttzZ5e2TdqC4nEBvKdf6ZENkSX/nKV7785S9ncnC1ZILago7Pfe5z
8rBMjo997GOZJWIg7dZBurplLgz4rd16LTVPJTKYBFaZVcvOqFgR64gQK1Na
3GADkvM7L/j6qQ7lrpPkjlk5pxulRDIUD+31h6AQemevQwbnLJk4BDOPVNSO
nWJnIVbTZy6bOtyfu2zhhu5vc7JWbHLH0bV2ZvztJ73TFbNsAkpnMOlNNEEJ
paOmksk1bWHrMsSY2rD4wOS2TMDzxF9AqV9BflBZj1UlIgFnBJ2sAiCCx3Tl
VH2wPNdsoZFRDYCV14GFdYtTlT+dDSkkwChWg0OCS8ZmgDMoqatT48hMP7Ad
zAguBlsCbvBZJpm+prdCo81lKRJFHEgdfBnIozMaqrnv0tzD/rIuszqwqpgr
gpBmVm/WQC2IGFOi5V4CdAdpB71xuwkNNhJb3/u93/vEJz4Rj/Tbv/3bifzQ
FSRWrKs7AeRAQ2ktCfQ+6es/9mM/lrfSAO7GBrldC76rDEv2w5e+9KX/+B//
47//9/8+q6M/hXlBRxDxyU9+Eouj195/9KMf1fheRkmGaKSFreyWWpNFn6Cf
P1Q9LZoLhC4csTDgkrlMhUeBgDk155oncsdJRVAyYlb0bJvFXTc39YfidGC3
IoX+g1O3xzsvmkJm+rnmlCGxUAl/pD+hltzNUjYiPIpT+DUOuCk2IgpDZeXD
54z2AjjjTiwuBH9GeBhZ68apmdqoX2IIbz11kp2iBRkQMaLrp8197o04KrW9
RQ80+xOPWqeVSZXec2x3HfrzSwyd08G81KtHReQbD10jPsg/uvRhhAasI6Bn
Y5awphTAWug5KcwGYiBqUSmMQU4JHRRx1ayLPSKGsR/YDD7B7lBvwk5Ycb1q
2Sl9sQ0ctvckbuRQEKjQwJTnSNDQ6xCBRDjH7g4u2PlNydbuT3ziE0pCJkje
KXVd3cxGXaZC5sQtt9yS/ZCZEWiIkQ4ZFLX94A/+oARuoAFb1pS2L/av5z3v
eS39PbUegSiNcwvH3v/+93/xi1/8D//hP4QbmRxZFGQ6nFX/DSs+e9nEN8IN
0Y9BR68LFZrFizFaZ9EVVniy/Om1k0TnMqfzZRYPGQVr8/1sAwsmjGVhyT5H
UIdI42cuzGj6S6a87mhcwk8BJiNsXD9KLFWcdYTQgAhPwKhhtMDFzpm/pkSl
HTSc0le6w54NqhHYdhVL8bzh2G4/5M2XHoIeqyh0PwEFSwNuuMlvPBpTypKc
qRcrojcHxUa8n/mxRPm9hzo6A4Dxz+wXY1m/1HeeGrKPgDdPcwwNQVGByjP1
t8uEq8K/Arlkh8dPU2K/ev/xvlbmL6DBzFbALrCpGx0ry7VodKhOjQj5iuAE
KyRYgQkJIBaF4i+tiLgt66Pqv7KobVKxi29QtJhFAVKkdKkDtc8HP/jBZlwT
MKCQ/XzkkUc+dtn6vD+VhDRP27lf71TD1W5s4+35z3/+X/trfy1MUC0bYgQL
3/Zt37bmTeuP0D7BBWChHtbON910UzvkrbzsZS9rYPeYetzrktAJd/Kf/vSn
Mzn+9E//NNzIqOhsg4vO7ZHLlqXxh3/4h30umRLihX7T8eDXIHcxKm4/lMmb
IK997WutwufatNW3ztW1AJ0thNnnsxaMt5W0M1E2p/gFptsbjjasVw8xrhkk
EADm3HX0WLSNpGGbvrGGg0uXCPU3Vjs9XV975eDwa+bviP2+7tL9QUv6th6o
Hq9XDpnxGfMzwF5/anBwx6G/ulTLlANvHO3tzryXEUJmSFw/+iycw0HQ4PpR
nz5HzGVKNCj4Ah0MmxHbkFHbAb9aHHI9UyQyxED8kNqWKycVJvRX1tHbjsap
KKx3HQJNd13U0TlfWK+jsUGPKRXLyomHTOML6UtGwzRfMkJlCnr5g5fW0qTR
ZTy1AAAaIhvIG3CjN12jOj51KzABLKgcX4WsWSYswK0Q2WDwq3g1B/kgvWrr
TB7Hkm32feYzn2kyNgdbvkMM1Su9aZ6224c//OEOHoL1u8Fgt07LxR/4gR94
ylOeQh+Mw/Id3/EdoYS6thyWpz/96U972tOCEUWylEvbua+EJxktL3rRizpU
I7m7Ki3L5FBKH3T80R/90ec//3lMcgTXzrAT/vxl602fdLbqWVToZHgEMt2T
ew6x3C21ulD93b/7d5sm5rKhuzjGQhljTC2eOcm7ZRzYt6NzwBDz60wI8dPs
DRbCZpz1WonEPt/yfdchsWWDBnRQe88tWk2KhfvOiwyyYI7QJY4KatPsFjM9
k+NVr3pVJock7OsvkmLnkI7YxfVDWEC4VXb47lPTB9goF3P3qXzP0ZaVXp0s
p8NM5CycvQ8Wy9lbcdOay/wCWhlb1s8uxv1HczeVIFPmWW9HjoA0me/ec9I2
nN0CEODG2HSvO5r9iZwPYeAGWBgf44Gjay08OeuZr7+SrChuKuVh+qjo5YQR
kM/VgbI6lM2u3uTcag2JPTjCbTAdUMRV1svRwA0owfFvulHTUqJOKjzEyHJo
0uFQIV4q9/jc5z6XO/DHf/zHoUfzUZ6izz952XrTJ1AlDOmLTcbMlU6vOykz
m9Xx5Cc/OSjI2NAvUoYllFhdW1vwQjW9/7I31LZ0hFe84hWN256aqkA0NvFP
RTSdBj78cCMwcdpBR3/2L2Q2Mh1BYnuGdUqZxlBanFDzaEvkGFN3X5rJmuPL
x7HPl3O889QtEYCYJst1CjKsqQGbxP4o4hblc0xja661b57CJtf8ICFKIQv+
gq/zAkQk7jz6JuCE+9OF83cEQNgt2OaMDYbE0gcrZrlyqKkPHM6ZGvTarmWp
HGEcuMeocH9muT0qYTEDbCwXCDAhjrFG6QgpJiVrPxsGIkFOX6Ql2EAVP0SE
FqvUvQsNY5HzPUdJEzYDv2m6Cu7huQpymaMz53yMa298uFJ6aSP5FNwMm9YG
fA0xEOLbfaX3at6JVolqYl5xcFBEeCtSwyHD4hUKzHVyV87GnBDYnMlBogfx
I9OiP1t/m0RNfNDR+2Ck5bv5aOFuApqGqFbNSiHHUEXhmGqy9s8GyGgJ/YLE
7lvz/QUveMH3f//3/+W//JcFP4OFAEThW1ZH4JC9EW7o5ZopwiZp5yDle7/3
e3NVXvziF//UT/1Uj6Nb1B3o0ihyKKvpPDtzql+9dg48lC984QuKU3rfh10X
Nmmg0WvfCmEaGJ64SMJwQ+bC4H/DqZHB9MbVhpzlPUeTuPPonsBxmNKmdXmO
MErzeUVeBcrCGqMKjOrJYLbwTS7vTPxYMvSOo9McEQAkN3b7FsfFaWfbgBo3
oSmwuKj4BjNpfE5QdjbUZzs5gXPiiSMz+secuBtHO2lR1jsPzZ+ld8+pjfmG
sOjeS0fpldKby2shveTLdFDXp2mtTBqlJmPzVBZYymNOxFkEdcGZHXAmh5O/
/ZBlXnHcW4921YIbbIwVpEgQS7U4efI+VNTkYcfhxD8nfAoNREpdRZ8rysAC
FaZYXTybim6YNGufY2WgjgcOxLK4KtMl1lNgJIf2XwJFWrOp1KJsDrZ5v5RE
mNDsaw4Cil5xJ5qYWRpb4ttyW1gdXcWsjuc85zkcFtUresiyN9TMKokNQBTH
iXVAlUyO5z73uS972cuyvXsW3Wp8Eoy1fgvcKaIJGToBvhU/RZVKl9DlfOiy
sTQUwT1w6WW2ZMryC2aKJAXcmJM+kLn91IbAiDJyzJqVpLHbbz91BhkCjCEg
sDYRHnD0KNLIHUfHN58sPTGZmtkACyq+4dK+c7J7/G7BzCtH7zaRk0V333D0
u5SrJfylqE0f+TccPXCvHfJZkybeQfgXV06k+mvHJjQBZNhj/ddB7r80gLv7
1FN7Yd43HAqrd5zknZFdTTQFX1Iky4xI0Vrr1whp5faypQs7iEaubt0RRjIR
rWXkrJ7X8ReqXRTLg7v7UjyrcH7t3uAY0KBWus6zy0ELDuvbQoI4cwiy+cqq
+MUx1j4+kKEnTNs/6KBPThikL3JeGCF9MQRoEsky6JJA9UtRm8SK4jVVHjgb
QQotdB0H2Py8jyYU0ZveNOPmnqhM55gMN3ovsNCaLnOhUrVjZil1fxpmzfof
+ZEfyaJ4whOegEQaMkidPPGJTxToyOQg+9mf7UPEg25YJsdP/uRPZnIolZXa
7rZQ5BCZ6fyh4nhfmBtqYzvzTk+8NL+GumAXiLt75dBeVpeRO08lLwzBs5qg
nxVwBafm/orQbxxdnpeaHPFpMZAbR4vY1UQst7s44RKaq4U/u0J+3YxrWPJz
33S0gFkNuIQF5BnLy/mM57mI6/VDQseY9xPzU/7O3/k7uksjmc9RevPRgdGE
GqVhcd3zzRnrQybivqNJDU6Lc4CBd10a2Am5rLx3lN0ux0HWu83cxH+AHlu+
ze63H63qTVLSXjNLeBCAZY1lCYGO1SmFsaPNjDlnb12R4QHYZYjan7rgehyg
dgiwUBsTsVTw0iss6qfxyRHFEUpt+KJK1WhxaNt01kxeU4OmIUEPsV+UDJQP
lC2gITbCRMEsxUhXkC6sIYGL4NG/qIxKRnz6sjW5ZE+CgibgYhr+G1awLqBK
u0nRhjyzWEKPAKoLaXQ15J73vOflrSi3RwZjcmCkhw86qWF09CFNsFtuuaVv
/fAP/3CwI9DR4OlJdQe6P6vzVboyTbMMDziWpfHlL3/5T//0T//kT/6Et9Il
BCkEjTthYe0rR2lq7gnZ/5/5mZ8ZSXKUafPu5w/p79uPhiP3HEI9Z872ytlm
YN84usNvhysHdXmkStAx50jQdQbANut+BxG0f/ul0bOE4DkYwgS646iJ+/vH
NmPmHOA9s6zHLO0mdCvYG01kP3rjJCH+4NEwmvHzKL9JmHc07FGy33JqBs1+
WNaV7IAkkYDtan5BB+wyrXRc4giIBsg2qlGVut3UZmCYuWODoGtOyGusdWGH
KRCuzeuYJA8cm5sAQ9iuwA1mEtWRryEKusjGMsJDj4lv/NKl6Xlb+7eDaT53
g33i6zRA8EOEVfscvVyUg4JNn6CNteEzEBXkj/z6sbVnXxEJWfJ3moEMmKAm
uEACmfZvZvzHL1szK+iwOqNOIWzjbDM/+oT/0psAh24wtGnTf60f6m50G2+9
9VZC6Dkm2RJYXppTZ3KEJ+HGX//rf12DJzHSNqGP/hV6ZHW86EUvuu222xrY
SgK7LoyOsV7R2LoV2SEZIYFD0PGVr3zlS1/6UufZhfCqwGNnOBNdBMPkwuju
zRTCX39ocSxRcp7mi+MxOa6dOifuPft8OURvlothA/iVnz+6KY0Wdc+hADYq
uAjD+FdImCuTOQdOreN9wpoCBfCwaXiOG4zGNmZpaL8kbO8J14xOLyiB723+
LrNw5dRx8hyU2CzGfRKxVHXu5G8cMkdvODoxCdUuYYSz+saj2bQJOC0LfVdl
HGgvI2cOptaYYE0eMTHGLmNdTH1LxNKvvO1orPCmQ2R4qsir4keSGUOvO6mp
wco99DJYS5fM5pXDr1GskIWczoS8RtxSsUIkULPIoeVUwpr42jhyPXrDikA8
02aFYrnmBTIpejapnyVirKJE3Hht7mUlUEMnpSVBKbgxkyOsaPZ96bJl8zf1
yPH1JrelfzE8mozEc/o6UgdSerO7m9Cq8dKXvvSZz3ymrGueiObURIyfctkC
h7DlWc96ln0CE81WevPUpz6ViMeLX/zixnCjqwfaverCGRvgQhCYm9bWv1BQ
OFmdaifcn0I3neSSfeKERulEWkRBYcVioSvouPPYFq9Y5H8MjcX0NjG3uEOY
TdURNf3i6q32rS3o10+iQEtfTjJ0s2/0A4YEUBo1JehAxhgjBZpdPdTIe17t
lvVFHhCzfUnYG0cHJQaPKSNAOtLpiuDmrdx/9H1WYrZK2Ambs/ZZXGwe9h7o
dsDrR49aE2fKNtAAjslpTnxj0PTGoyG1c+7nhuq7ovHAVxTz4LHBOiGOBU9W
SuPkZzJJuvW+fSjviUhoxcItojbc0t/nHBD2BndpYiPqXDAxxEK5M+2mN70u
S7Q4ZJbVo5HOyCqAHqyOsdABhXrz9WPCGsXmkj0BHSuuz2dpUTbN9R/Bvu5N
f/b5oqPhQ4jx7/7dv2Pwr9wjX6DZp+b0i1/8YlOyP1kadDwyYJrRKsh6dq10
JEaDiOBCm0gNm3DLJVDCjQCkfcIKYqRaJ/TnM57xjOc///mZHI3kxmE3oYui
EKJ3A2ctC6SbIBDUZT788MOdakCXXeTM2/qzq1Nh8fpDh5MDsrZBI1BxE6bV
uSAA1scbjg7Ro2rb5+cPwdLVT53J53eeBLgGSqIKkiA78iKo83RGSNhqvtr8
KUsMMUAiI4qqRq89C1CwuMrK/wVU8TqENZwMVYr7jw0omfWjYPGVrlzkODga
fVFCc2col7GQ4wrBzJSFZbB2BWPdNA6dqI4+Jiz28bdBB6vg7Uczd/4Ih2jF
yFgc9x996ziMno6LktU9ByrPYuwCLAMTeRAxZ8/oyiE+2S92tMwDcUhiFKGE
cIcuTlgWDAaQwplyCdJAPCmhG4GXGS0cGeyvccPU1Iteyps0KQIK5oo0jYp7
DohAh3kkbKjSpDmljSPee7/CmMdkaAY1uTRMZHsoqP/ABz7QFGu6qQT5T//p
P/3Zn/1Z77NAMDD7YqgSdHzxsvVeufq5lQnBn66xe/iKV7zix37sx4KFfJDH
PvaxuOVK3oKOPgwu8mXCFu0gM0VyZG666aZehTuCjhe84AWtgw2hbuD/39W9
rEh1RlEAfgkdKDjxDRQEBw6EBhEHCgo98TpQIYFAxtHu6osa2xhMCJnmUXyO
5BG8zByJkyzqYy9+/AdF9alT1eecqr3Ovqy9dk683Da1Zty2nHsuWl4NauV5
QAw/TRSG5ppHbn8Z5sChGlnNTDa9qaix+gbPZ8b0wQyaXwuyTYeyfYDTO2l5
UGuNxmFUs6uU0aPRJW5wVHLp65Hb7eLtHy4DVjpH6YftynOJjhfLODm0THf8
zVa9h7KofMirrQxX7ahqn83eNKo6WibquueuzPCV/Fn0EA4QA5QabYfy/nYC
BUBTvaJdk19U7guxMkxLBiXRLXGxBnFiqBZl4HxzwjVzTT1vlyF3az0FdDjT
Ns4DpUoPrX0Ebge5IDmqwEJFLwMd6qp6T9RE1FxAh0ik1LVWcNaUrHSrXnuq
OxwGbSn8lrxaSfPghsEEmnRKPo+vEtzA46LyV7k/s8xyzHkj6mlWYCSnEJuq
Hjh4wTbPOeZ/JWyJ1wEZvn79Gtz49u3bly9fePtk+vIkO3z69ClRQG7iiQuC
G2YvtmkuB5YjzLnHT7h3716gQ21FlqM6xsGH+hU7OzuBjuBG4IIAqUzI5cuX
b9y4kQ/J3TPfWi54pVNz5DmXAFogIvDF2wGDAc8cGM6GeCqgkceXM+ajMp4I
k/U0NiN1Xo8CFMCNZvsBy/EMf3+5aGptltmynjwfndu9mUxUolcLkXySgxny
fjBKpIeji360qF6UQ6UsUh8G7dzpdCpToEC/SZ6LViyfz/HIh+ddwRYp4rxx
sx0DATfcZKsLWsqo+KIdOsUNd2cZht7iJY3FBbrABDvcmHazvpiR2aVgteNG
7M/faC+teGGNvEoPezODJ9qDUzG0vWUVIcv2VGaFQggwJb/Ve+FjtA+3DpJf
Tl7NgaFYoFfBCg3yUp3UAuEGDFEVWus43eL6UyCUEK7zoDFWqiSPeYmyt4qJ
vlrOg/JulibZcrD/nYUqqXHeKCVj4CRUsz/FGwMWFWVMhKedFTRA3sgKaMhy
xAkhhhM7LdMD4dw/xeLgwATNcvA5wVznOMm7u7tXr169cOECtgbcyCMeqdpr
ohUSQFQEE8XQEowTYojkkydP8vXFW8vlkuPVUBNkUPcx/qBTZfM8W9SU9bDk
EvE36lQzLqnRDkcWVjPYJkiRPRrLtI+sBRQBwt4IpCMesxe3tiJA06qso+a/
Bj6lijUI4hdVG+R4RiQ0ywo3mlp0tN9lb9Q66fMYCAsMeRpEAp8+fRqQyb/j
w8ttriBQCn1jtAZcz7YjawFO9XkIjB8ufTdqqc69/DGIWpJn3QaoyP+nLFri
ZeOFMknEd29nXpvszbMZRFte/aq72GMWlImb5JlbKvJFAJmTUYz8dVRk1w4C
2V1pmRwnCSyJx5ptllALTbT+Rj0olSPFnQohctLQw+Qt0bqMeK6STzbG3pv/
JMphGautXSX2HmuN8xDLLY8r1iT/GfPRnNIWWrONBCagwyBF45myM3P78OFD
YhPMDWXZPCq4GO6MRpUtSpxEcvLv1GtMgsvh0eiIyd+8eTPBSKAjPsa5c+eM
ezt16lSea6IPOAQ3ghKJTWiC4X4EaqrOke89X2tOPHFQTiQnqB7kOHMwOTDN
brjlGLBKKnCDv9F2Nk2gigg/b5dEh8oaKldRBZi8mLUyMY5HrRTNm4GspZa1
MbbZ1LV77uVQQ+2zmbZ0eJUD4C0YTF8OJyZ8eafor+2QLZt0tW689B+3K67F
T7NMon/8+HG2ZwcYdTQT5YRC5aw2eQsV95d1OA1uULGdMq1Er6u4VxxGgSg/
0/9ij7BUOlraxH2/oL3ycns9W9eWJe50LQzhzsppE82r0Ya19mcup7yxJqBy
X5vOrfuaz6w6Sq6YTjTSnaibSOCEi+kElmfyzywlGErgTXCBDqVbzkM+pzPo
CXGYkJItMRAqPWT6CHy1eTYvxULlNAIC+s5MbNcHaiKz8F8OhAwOTx7UZP+A
TNXA3Klt1/0hUeCJlth8PvJVjFHFFm0shtmh1Vk51ODbnzM07dq1a8Q3NMye
OXPm9OnT/I1Lly5duXKFAGkwJLuZYX3+/HmBTCAlLke86Pwsc0lz7vn8HKpg
BLJVGzDrv+1S6FEkcuTHM3mEJ+9bjvkgfbkvC0Zqj+7a+fP1jE9qW70bLidh
7SJfY17Pj0bgy5b2tthYovWqx9WiDzRQnYRpciyH02wip9HRCU2/vJzm04bh
DWfwu0iJPplFkTgbK0XSchLcgyFr2uH3rUL4dymg+hV/zBJKFDZfTY9wPau9
mSWNSc5XDzK0sZ3lls/fjoAibYPBCjUrcPQSZeWsO0E7j5oB0ellUHtUCDC+
eq5a+xHaHlhWHqD+ZRm2C3jzOTK6Bs03kwk9GH5rtbKmAhlEr7yx+WcJn3Ls
MUtJEilGa5/XDUe3R/s8/nnH2qJ5BE+QP5VFyGkiUjZnWO0aGhTcDKhCWIO5
rUKC2KSQAbmrnfXAgdBx3kJLXI8bOnfeJRFEmCiXKAiZryPe7507d1qWDRok
VAl0xN/Q7AYc4ldQMO7QBBLHBNIDPvni8lvN1c7VyDHkP3Iq+ELmyRojZVwC
NTPZ4GxZb7s8/4pcSRu2X6yeZ7NnliwfN1hwwdkuUBQNmovrXawG2AyDnzqH
GTLsL8PaPDbjYTWfsD+Cot15zanWsWmKQLWle0KPYGYQI3Dx6NEjk+iDJDEr
rlf9lvJYDkfVsG2tVTnbzLhqzoMmr3fL9Oc1miibZTM9hnik2GV/zzzEvPG3
GZgrvitJTMSxN8M65WpKgnWFi8MuiG9W7IZIj8Cz2coOy/q64ApSlUqz57OZ
PeHDZbkbJ9Y/rM48xlougvgCt1MJtTQttdr8nmP7Uhbr7CRMVznePOq+53JI
aKwiHigcaqzESAMa+kpkOykGZyMFTrLketx0rGjcqMeu45756IS1v6awz58/
f/z4MbAAcLTYG5Hgxh3Q0NqmQ1YbLBmcfEheze1elTYr/zSfIDVq4EugL6eW
ryNu8N27d+N1XLx4kbzP2bNnE60EOvDP42zcunVrd3c3Qc3Ozo7ibCfa513X
r1/PDztfRy5UPpmYT52iPFFfRkrJojJkeJNj+3M7PbDW1M4sZlg6aI2dy10N
wEbBb7dy+q2HNinXhq8Xo5VX3ldbpZokZDV7M0qgdRmu+MkiSVfIWkmeJXuo
qHb/+kLtLT1ZVArfLsqZJ9tx8DGN3HkTqiCL0ktEFWu3SE2jwdTrkUZvZaGU
tvavtS6AWnkyU6vW6ykoy3tLJv9rlq5z99zu75RVf3TwHc1kxnV+Sq9Aa09y
nnnpzXbWJyTEppNxNen13Yz2PlgE23l3fi0Qo9zy8uLqf5Z/C+GzUVpGKZmk
J69AlKHtnaYulU68brZDy3dt/kXYAB2iG0VbZVNEJoEJ8S4WHa/AiHnYotuL
KA1XwW76QGMveRW1kluiaYU7Eecht2mk0JhedtYrRxlMGz5GqMRjQEOiIDYY
29SkH2zhaTDVJkjR2rFbA6rxrHJh82u8f/9+nAr0csLmHZoQb+T27dsPHz4M
vMQ5CYYosmieNRrywYMHudfkSgZR379/bwqMnLByMH+j2oake3JSOZGc7//u
i8YX
    "], {{0, 340}, {360, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  DefaultBaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{360, 340},
  PlotRange->{{0, 360}, {0, 340}}]], "Output",
 CellChangeTimes->{3.706948235996274*^9},
 ImageSize->{364, 340},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Load the stored seed points", "Subsection",
 CellChangeTimes->{{3.6364522235786133`*^9, 3.636452224730692*^9}, {
  3.706931624676347*^9, 3.706931667123242*^9}}],

Cell[TextData[{
 "The format of the seed point data is \n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["seed", "1"], ",", 
       SubscriptBox["tip", 
        RowBox[{"1", ",", "1"}]], ",", 
       SubscriptBox["tip", 
        RowBox[{"1", ",", "2"}]], ",", 
       SubscriptBox["tip", 
        RowBox[{"1", ",", "..."}]]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["seed", "2"], ",", 
       SubscriptBox["tip", 
        RowBox[{"2", ",", "1"}]], ",", 
       SubscriptBox["tip", 
        RowBox[{"2", ",", "2"}]], ",", 
       SubscriptBox["tip", 
        RowBox[{"2", ",", "..."}]]}], "}"}]}], "}"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "\n\nwith ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["tip", 
    RowBox[{"i", ",", "j"}]], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " is the ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["j", "th"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " tip belonging to the ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["i", "th"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " seed.\n\nIn the stored format the coordinates are specified as follows: \
seed = ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"k", ",", "i", ",", "j"}]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "), with ",
 StyleBox["i",
  FontSlant->"Italic"],
 " and ",
 StyleBox["j",
  FontSlant->"Italic"],
 " respectively the row and column index of the image ( (1,1) is the upper \
left pixel in the image ), and ",
 Cell[BoxData[
  FormBox["k", TraditionalForm]],
  FormatType->"TraditionalForm"],
 " is the discrete index for orientation. The seed points were saved at an \
angular resolution of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"s\[Theta]", "=", 
    RowBox[{"2", 
     RowBox[{"\[Pi]", "/", "64"}]}]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ", and index ",
 Cell[BoxData[
  FormBox[
   RowBox[{"k", "=", "1"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " corresponds to ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Theta]", "=", "0"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ". The corresponding angles for each ",
 Cell[BoxData[
  FormBox[
   RowBox[{"k", " "}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "are given by ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Theta]", "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"k", "-", "1"}], ")"}], "*", "s\[Theta]"}]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "."
}], "Text",
 CellChangeTimes->{{3.7069316683093987`*^9, 3.706932005862444*^9}, {
  3.7069320716684794`*^9, 3.706932135124298*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"gListRAWIn", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Import", "[", 
        RowBox[{"#", ",", "\"\<Data\>\""}], "]"}], "&"}], "/@", 
      RowBox[{"FileNames", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"StringTake", "[", 
          RowBox[{"imfilename", ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", 
             RowBox[{"-", "5"}]}], "}"}]}], "]"}], "<>", "\"\<*.txt\>\""}], 
        "}"}], "]"}]}], "+", "1"}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"{", 
    RowBox[{"thetai", ",", "xi", ",", "yi"}], "}"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"Number", " ", "of", " ", 
    RowBox[{"seeds", ":"}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{"Length", "[", "gList", "]"}]}], "Input",
 CellChangeTimes->{{3.636452234727378*^9, 3.636452275771961*^9}, {
  3.636453325144884*^9, 3.6364533252168903`*^9}, {3.6380725303207273`*^9, 
  3.6380725306171317`*^9}, {3.698658347496126*^9, 3.6986583484180784`*^9}, {
  3.6986583921883206`*^9, 3.6986583925322533`*^9}, {3.698658422801132*^9, 
  3.6986584234887285`*^9}, {3.698658467009062*^9, 3.69865847788509*^9}, {
  3.706932016532798*^9, 3.7069320298281674`*^9}, {3.706933452293441*^9, 
  3.706933458789732*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.7069482362439375`*^9},
 ImageSize->{11, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Downsample data", "Subsection",
 CellChangeTimes->{{3.6364523496270266`*^9, 3.636452351403164*^9}}],

Cell[TextData[{
 "We down sample the data by a factor sx for faster computations.\nThen the \
discrete angle-indices are converted to continuous angles.\n\n",
 StyleBox["Note:",
  FontWeight->"Bold"],
 " usually we use the ordering (x,y,\[Theta]), so we would like to have \
(i,j,k) ordering when working with the discrete data, so we re order the \
coordinates as well."
}], "Text",
 CellChangeTimes->{
  3.706932187739271*^9, {3.7069322705646424`*^9, 3.706932290595905*^9}, {
   3.7069324041169324`*^9, 3.706932410485859*^9}, {3.706933290949207*^9, 
   3.7069333118618765`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"sx", "=", "2"}], ";", 
   RowBox[{"(*", 
    StyleBox["Parameter",
     FontColor->RGBColor[1, 0, 0]], "*)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Downsample", " ", "image", " ", "data"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"im", "=", 
    RowBox[{"ImageData", "[", 
     RowBox[{"ImageResize", "[", 
      RowBox[{
       RowBox[{"Image", "[", "imIn", "]"}], ",", 
       RowBox[{
        RowBox[{"Reverse", "[", 
         RowBox[{"Dimensions", "[", "imIn", "]"}], "]"}], "/", "sx"}]}], 
      "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"Downsample", " ", "seeds", " ", "and", " ", "tips"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gListRAW", "=", "gListRAWIn"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"gListRAW", "\[LeftDoubleBracket]", 
    RowBox[{"All", ",", "All", ",", 
     RowBox[{"2", ";;", "3"}]}], "\[RightDoubleBracket]"}], "=", 
   RowBox[{"Round", "[", 
    RowBox[{
     RowBox[{"gListRAW", "\[LeftDoubleBracket]", 
      RowBox[{"All", ",", "All", ",", 
       RowBox[{"2", ";;", "3"}]}], "\[RightDoubleBracket]"}], "/", "sx"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gListRAW", "=", 
   RowBox[{"gListRAW", "\[LeftDoubleBracket]", 
    RowBox[{"All", ",", "All", ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "3", ",", "1"}], "}"}]}], "\[RightDoubleBracket]"}]}],
   ";", 
  RowBox[{"(*", 
   RowBox[{"{", 
    RowBox[{"xi", ",", "yi", ",", "thetai"}], "}"}], "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "Discrete", " ", "angles", " ", "to", " ", "continous", " ", "angles"}], 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{"gList", "=", "gListRAW"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"gList", "\[LeftDoubleBracket]", 
    RowBox[{"All", ",", "All", ",", "3"}], "\[RightDoubleBracket]"}], "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"gListRAW", "\[LeftDoubleBracket]", 
       RowBox[{"All", ",", "All", ",", "3"}], "\[RightDoubleBracket]"}], "-", 
      "1"}], ")"}], "*", 
    FractionBox[
     RowBox[{"2", "\[Pi]"}], "64"]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.636452358458639*^9, 3.6364523772939234`*^9}, {
   3.636453315817244*^9, 3.636453318680439*^9}, 3.6367784264508963`*^9, {
   3.6380720952922916`*^9, 3.6380720956672916`*^9}, {3.6380722423262916`*^9, 
   3.6380722545172915`*^9}, {3.63807253365917*^9, 3.638072533939974*^9}, {
   3.63807342048458*^9, 3.6380734236108923`*^9}, {3.63807435034861*^9, 
   3.6380743541861606`*^9}, 3.687783479750167*^9, {3.6986583534655275`*^9, 
   3.6986584327866106`*^9}, {3.6986585348912277`*^9, 3.6986585528621044`*^9}, 
   3.6987507948635063`*^9, 3.698751583345185*^9, 3.6987517020329337`*^9, 
   3.699677484647979*^9, 3.6996775198957925`*^9, 3.699677714231489*^9, 
   3.7005403252935357`*^9, 3.700882945231818*^9, 3.7008833894399166`*^9, 
   3.7010655228703394`*^9, 3.701065637350809*^9, 3.7014950765835576`*^9, 
   3.7014967278953447`*^9, 3.701502675271824*^9, 3.7016784488389063`*^9, 
   3.7016785365190897`*^9, {3.706932312932331*^9, 3.7069323221017427`*^9}, {
   3.7069332730937347`*^9, 3.7069332746619053`*^9}, {3.706933327350047*^9, 
   3.7069333893179274`*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2. Compute Orientation Score", "Section",
 CellChangeTimes->{{3.685072668240795*^9, 3.68507267428891*^9}, {
  3.6850750299643908`*^9, 3.685075049932601*^9}, {3.6850750943489633`*^9, 
  3.685075095021793*^9}, {3.685075125293414*^9, 3.6850751254699163`*^9}, {
  3.7069323285799575`*^9, 3.706932329156496*^9}}],

Cell[TextData[{
 "Here we compute the orientation score transform of input image ",
 Cell[BoxData[
  FormBox["im", TraditionalForm]],
  FormatType->"TraditionalForm"],
 ". The angular resolution is specified by s\[Theta]=2\[Pi]/N\[Theta]:\n\n",
 StyleBox["Note: ",
  FontWeight->"Bold"],
 "In the orientation scores objects (ObjPositionOrientationData), the data \
array is stored as a 2D multichannel image (hence the Image[ data ] in the \
Affix statement. The data of the orientation score can be accessed via os[\
\[OpenCurlyDoubleQuote]Data\[CloseCurlyDoubleQuote]], this returns a 3D array \
(not an image object..)."
}], "Text",
 CellChangeTimes->{{3.706932336851987*^9, 3.706932514614917*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"N\[Theta]", "=", "32"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"os", "=", 
   RowBox[{"OrientationScoreTransform", "[", 
    RowBox[{"im", ",", 
     RowBox[{"\"\<Orientations\>\"", "\[Rule]", "N\[Theta]"}], ",", 
     RowBox[{"\"\<WaveletSize\>\"", "\[Rule]", "151"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"os", "=", 
    RowBox[{"Affix", "[", 
     RowBox[{"os", ",", 
      RowBox[{"\"\<Data\>\"", "\[Rule]", 
       RowBox[{"Image", "[", 
        RowBox[{"Re", "[", 
         RowBox[{"os", "[", "\"\<Data\>\"", "]"}], "]"}], "]"}]}]}], "]"}]}], 
   ";"}], 
  RowBox[{"(*", 
   RowBox[{"Only", " ", "take", " ", "real", " ", "part"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"s\[Theta]", "=", 
   RowBox[{"os", "[", "\"\<AngularResolution\>\"", "]"}]}], 
  ";"}], "\[IndentingNewLine]", "os"}], "Input",
 CellChangeTimes->{{3.6850726842243853`*^9, 3.6850727105284786`*^9}, {
   3.6850732828034153`*^9, 3.685073307844141*^9}, {3.68507387297015*^9, 
   3.6850738730964856`*^9}, {3.6850739143293586`*^9, 
   3.6850739765050707`*^9}, {3.695979186280089*^9, 3.6959791957562714`*^9}, {
   3.695979609561066*^9, 3.695979609624235*^9}, {3.695980048616548*^9, 
   3.6959800487629375`*^9}, {3.6959801196244535`*^9, 3.695980119687622*^9}, {
   3.6959816767293005`*^9, 3.695981676969941*^9}, {3.6959818292424507`*^9, 
   3.695981833643154*^9}, {3.6959875097289906`*^9, 3.6959875098242483`*^9}, {
   3.6959876286418858`*^9, 3.6959876287020226`*^9}, {3.695988744481688*^9, 
   3.6959887446892457`*^9}, {3.695988863618758*^9, 3.6959888636969657`*^9}, {
   3.696065286607078*^9, 3.696065294159153*^9}, {3.6986577560283623`*^9, 
   3.6986577820780373`*^9}, 3.6987311717930393`*^9, {3.698746220732786*^9, 
   3.6987462207969627`*^9}, {3.698748541006583*^9, 3.6987485410878067`*^9}, {
   3.706932381429555*^9, 3.7069323941032724`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["3. Vessel enhancement via multi-scale LIDOS", "Section",
 CellChangeTimes->{{3.6960660576760993`*^9, 3.6960660616757293`*^9}, {
  3.6960663348446937`*^9, 3.696066336940278*^9}, {3.706932526548623*^9, 
  3.706932531797592*^9}}],

Cell[TextData[{
 "Here we apply vessel enhancement by taking the second order derivatives in \
the perpendicular vessel direction ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["A", "2"], "-", "direction"}], ")"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ". We do this at multiple Gaussian scales, and sum the responses.\n\n",
 StyleBox["Note",
  FontWeight->"Bold"],
 ": the factor ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    SuperscriptBox["\[Sigma]s", "2"], 
    SuperscriptBox["\[Sigma]o", "2"]], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " is a scale normalization factor, which ensures equal responses for \
blobs/lines at different scales. Here we included an additional parameter \
\[Gamma] which for \[Gamma]=1 does not give any bias, but for \[Gamma]=2 \
gives a slight bias for larger scales in the reconstruction (summation).\n",
 StyleBox["Note",
  FontWeight->"Bold"],
 ": second order derivative ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{
     SubsuperscriptBox["A", "2", "2"], "U"}], ")"}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " of orientation score ",
 Cell[BoxData[
  FormBox["U", TraditionalForm]],
  FormatType->"TraditionalForm"],
 " is computed with the function LeftInvariantDerivative and derivative \
specification 22."
}], "Text",
 CellChangeTimes->{{3.706932533701657*^9, 3.7069326852398047`*^9}, {
  3.7069327278130655`*^9, 3.706932790552972*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"\[Sigma]sList", "=", 
    RowBox[{
     RowBox[{"Range", "[", 
      RowBox[{"2", ",", "20", ",", "2"}], "]"}], "/", "sx"}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"List", " ", "of", " ", "spatial", " ", "scales"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Gamma]", "=", "2"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"Bias", " ", "for", " ", "coarser", " ", "scales"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Sigma]o", " ", "=", " ", "0.4"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Angular", " ", "scale"}], ",", " ", 
    RowBox[{"specified", " ", "in", " ", "radians"}]}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PrintTemporary", "[", 
   RowBox[{"Dynamic", "[", 
    RowBox[{"Row", "[", 
     RowBox[{"{", 
      RowBox[{"\"\<Processing scale: \>\"", ",", "\[Sigma]s"}], "}"}], "]"}], 
    "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"vesselnessSE2", "=", 
    RowBox[{"Rescale", "@", 
     RowBox[{"Clip", "[", 
      RowBox[{
       RowBox[{"Sum", "[", 
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            FractionBox[
             SuperscriptBox["\[Sigma]s", "2"], 
             SuperscriptBox["\[Sigma]o", "2"]], ")"}], "\[Gamma]"], 
          RowBox[{
           RowBox[{"LeftInvariantDerivatives", "[", 
            RowBox[{"os", ",", 
             RowBox[{"{", 
              RowBox[{"\[Sigma]s", ",", "\[Sigma]o"}], "}"}], ",", "22"}], 
            "]"}], "[", "\"\<Data\>\"", "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"\[Sigma]s", ",", "\[Sigma]sList"}], "}"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "\[Infinity]"}], "}"}]}], "]"}]}]}], ";"}], "//", 
  "AbsoluteTiming"}], "\n", 
 RowBox[{
  RowBox[{"vesselnessR2", "=", 
   RowBox[{"Map", "[", 
    RowBox[{"Max", ",", "vesselnessSE2", ",", 
     RowBox[{"{", "2", "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"GraphicsRow", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ImageAdjust", "[", 
      RowBox[{"Image", "[", "vesselnessR2", "]"}], "]"}], ",", 
     RowBox[{"Image", "[", "im", "]"}]}], "}"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "800"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.6960658447494173`*^9, 3.6960659703658113`*^9}, {
   3.6960660472603793`*^9, 3.6960660554210978`*^9}, {3.6960663563816195`*^9, 
   3.6960663647007513`*^9}, {3.6960667308970165`*^9, 
   3.6960667585285664`*^9}, {3.696066843997924*^9, 3.696066880255363*^9}, {
   3.696067044160444*^9, 3.6960670486874533`*^9}, {3.6960696268644133`*^9, 
   3.696069627155199*^9}, {3.6986578483663344`*^9, 3.6986578996064043`*^9}, {
   3.6987260446533413`*^9, 3.6987260597755423`*^9}, {3.698750546080681*^9, 
   3.698750663229312*^9}, 3.698751696129228*^9, {3.6987518394916*^9, 
   3.698751840866288*^9}, {3.7069326916398587`*^9, 3.7069327170393972`*^9}, {
   3.7069328104278502`*^9, 3.7069328202299213`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"16.803252387754974`", ",", "Null"}], "}"}]], "Output",
 CellChangeTimes->{3.7069482578136234`*^9},
 ImageSize->{108, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzsvfu3LVV17yvuDWwexuSgIgQDSHgj8gyPg6iI8pANuoFANgTFA4IgPjGo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    "], {{0, 418}, {800, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  DefaultBaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{800, 418},
  PlotRange->{{0, 800}, {0, 418}}]], "Output",
 CellChangeTimes->{3.7069482578196297`*^9},
 ImageSize->{804, 418},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
4. From vesselness not cost/speed function (to be used in the metric/dual \
metric)\
\>", "Section",
 CellChangeTimes->{{3.6986578250981593`*^9, 3.698657828083022*^9}, {
  3.7069328239558344`*^9, 3.7069328508052683`*^9}}],

Cell[TextData[{
 "The vesselness function above was only computed from 0 to \[Pi], here we \
construct the full vesselness function V(x,y,\[Theta]) stored from 0 to \
2\[Pi].\n\nThe cost function  is then defined as \n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"C", "=", 
     FractionBox["1", 
      RowBox[{"1", " ", "+", " ", 
       RowBox[{"\[Lambda]", " ", 
        SuperscriptBox["V", "p"]}]}]]}], ","}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "\n\nwith \[Lambda] a parameter that balances the influence of the cost \
relative to no data-adaptivity, p is a contrast parameter.\n\nIn the end, in \
the code we only need to specify a \[OpenCurlyDoubleQuote]speed function\
\[CloseCurlyDoubleQuote] (dual cost), which is given by speed = ",
 Cell[BoxData[
  FormBox[
   RowBox[{"1", "/", 
    RowBox[{"cost", "."}]}], TraditionalForm]],
  FormatType->"TraditionalForm"]
}], "Text",
 CellChangeTimes->{{3.7069328785330353`*^9, 3.706933063047941*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"The", " ", "parameters"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Lambda]", "=", "200"}], ";"}], 
   RowBox[{"(*", 
    StyleBox["Parameter",
     FontColor->RGBColor[0, 0, 1]], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"p", "=", "2"}], ";"}], 
   RowBox[{"(*", 
    StyleBox["Parameter",
     FontColor->RGBColor[0, 0, 1]], "*)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "vesselness", " ", "function", " ", "from", " ", "0", " ", "to", " ", "2",
      "\[Pi]"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"vesselnessSE2Full", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"#", ",", "#"}], "}"}], ",", "1"}], "]"}], "&"}], "@", 
        RowBox[{"Transpose", "[", 
         RowBox[{"vesselnessSE2", ",", 
          RowBox[{"{", 
           RowBox[{"2", ",", "3", ",", "1"}], "}"}]}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "1", ",", "2"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Speed", " ", "and", " ", "cost", " ", 
     RowBox[{"function", ":"}]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"speedSE2Full", "=", 
     RowBox[{"1", "+", 
      RowBox[{"\[Lambda]", " ", 
       SuperscriptBox["vesselnessSE2Full", "p"]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"costSE2Full", "=", 
     FractionBox["1", "speedSE2Full"]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Dimensions", " ", "of", " ", "the", " ", "data"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"Nx", ",", "Ny", ",", "N\[Theta]"}], "}"}], "=", 
     RowBox[{"Dimensions", "[", "vesselnessSE2Full", "]"}]}], ";"}], "\n", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "Show", " ", "minimum", " ", "intensity", " ", "projection", " ", "of", 
     " ", "the", " ", "cost", " ", 
     RowBox[{"function", ":"}]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{"ImageAdjust", "[", 
    RowBox[{"Image", "[", 
     RowBox[{"Map", "[", 
      RowBox[{"Min", ",", "costSE2Full", ",", 
       RowBox[{"{", "2", "}"}]}], "]"}], "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.698657907982162*^9, 3.698658001570568*^9}, {
   3.698658091752173*^9, 3.6986581064569054`*^9}, {3.698658189213372*^9, 
   3.6986582234356437`*^9}, {3.698659145083352*^9, 3.698659189150502*^9}, 
   3.698726252942436*^9, {3.698748401119438*^9, 3.698748418557796*^9}, {
   3.69874845099011*^9, 3.698748467453889*^9}, 3.698748513166518*^9, 
   3.698748600782609*^9, {3.698748723006771*^9, 3.698748770606406*^9}, {
   3.698748832062873*^9, 3.698748858558358*^9}, 3.698750345840066*^9, {
   3.6987506777008114`*^9, 3.698750685472518*^9}, {3.6987510240010967`*^9, 
   3.698751024512457*^9}, 3.6987510639684515`*^9, {3.6987511021760693`*^9, 
   3.698751122944352*^9}, {3.698751781809171*^9, 3.6987518858088446`*^9}, {
   3.7021828228323183`*^9, 3.702182826529147*^9}, {3.7069328585538774`*^9, 
   3.706932902132814*^9}, {3.706933067541889*^9, 
   3.706933204042045*^9}},ExpressionUUID->"6a90b452-52c6-4cd3-bc13-\
ae8672677bfc"],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJyk/Qm8/VdV3/+XoqBYq7VOCAYChARDyDwQkkAgIUwhZIKEDEAShoQpQAgE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    "], {{0, 229}, {242, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  DefaultBaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{242, 229},
  PlotRange->{{0, 242}, {0, 229}}]], "Output",
 CellChangeTimes->{3.7069482580382137`*^9},
 ImageSize->{246, 229},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["5. Vessel tracking (the experimental set up)", "Section",
 CellChangeTimes->{{3.6364531779107847`*^9, 3.6364531796549044`*^9}, {
   3.6367801929570837`*^9, 3.6367801978394146`*^9}, 3.6368935386338425`*^9, {
   3.687605747781656*^9, 3.687605758195363*^9}, {3.706933236340931*^9, 
   3.706933245813158*^9}}],

Cell[CellGroupData[{

Cell["\<\
Select a seed point out of the Length[gList] number of seeds.\
\>", "Subsection",
 CellChangeTimes->{{3.706933418293996*^9, 3.70693343413413*^9}}],

Cell["\<\
Here we specify tips normal arrival directions (g1dListForward), and tips \
with reversed arrival directions (g1dListBackward)).\
\>", "Text",
 CellChangeTimes->{{3.7069335176543264`*^9, 3.706933575832144*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"seedPointNr", "=", "1"}], ";"}], 
  RowBox[{"(*", "\"\<\!\(\*
StyleBox[\"Parameter\",
FontColor->RGBColor[0, 0, 1]]\)\>\"", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"g0d", "=", 
    RowBox[{"gList", "\[LeftDoubleBracket]", 
     RowBox[{"seedPointNr", ",", "1"}], "\[RightDoubleBracket]"}]}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"The", " ", "tips"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"g1dListForward", "=", 
    RowBox[{"gList", "\[LeftDoubleBracket]", 
     RowBox[{"seedPointNr", ",", 
      RowBox[{"2", ";;", 
       RowBox[{"-", "1"}]}]}], "\[RightDoubleBracket]"}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"Select", " ", "all", " ", "end", " ", "points"}], "*)"}]}], "\n", 
 RowBox[{
  RowBox[{"g1dListBackward", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
       ",", 
       RowBox[{"#", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
       ",", 
       RowBox[{"Mod", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"#", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}],
           "+", "\[Pi]"}], ",", 
         RowBox[{"2", "\[Pi]"}]}], "]"}]}], "}"}], "&"}], "/@", 
    "g1dListForward"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.706933471509592*^9, 3.7069335158164344`*^9}, {
  3.706933588310297*^9, 3.7069335945198493`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Show setup", "Subsection",
 CellChangeTimes->{{3.6352447857058425`*^9, 3.6352447906756015`*^9}, {
  3.7069336900219135`*^9, 3.706933692118497*^9}}],

Cell[TextData[{
 StyleBox["Note",
  FontWeight->"Bold"],
 ": in order to plot Graphics as an overlay on an image in Mathematica you \
have to take the Graphics coordinate system into account. Mathematica uses \
the convention:\n(x,y), with x the horizontal axis, running from left to \
right, and y along the vertical axis, running from top to bottom.\nSee the \
mapping {#\[LeftDoubleBracket]2\[RightDoubleBracket]-0.5,Nx-#\
\[LeftDoubleBracket]1\[RightDoubleBracket]+0.5}&/@ in the code below to go \
from array coordinates (i,j) to graphics coordinates."
}], "Text",
 CellChangeTimes->{{3.7069336937187233`*^9, 3.7069337385650263`*^9}, {
  3.706933844469774*^9, 3.70693389827993*^9}, {3.706934093830197*^9, 
  3.7069341224413033`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"colorForward", "=", 
    RowBox[{"RGBColor", "[", 
     RowBox[{"Sequence", "@@", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"126", ",", "239", ",", "88"}], "}"}], "/", "255."}], 
       ")"}]}], "]"}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"colorForward", "=", "Green"}], ";"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"colorBackward", "=", 
    RowBox[{"RGBColor", "[", 
     RowBox[{"Sequence", "@@", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"253", ",", "87", ",", "87"}], "}"}], "/", "255."}], ")"}]}],
      "]"}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"colorBackward", "=", "Red"}], ";"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"colorPTR2", "=", 
   RowBox[{"RGBColor", "[", 
    RowBox[{"Sequence", "@@", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"83", ",", "177", ",", "234"}], "}"}], "/", "255."}], ")"}]}],
     "]"}]}], ";"}], "\n", 
 RowBox[{"Show", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Image", "@", "im"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{"White", ",", "Thick", ",", 
      RowBox[{"Arrow", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{
            "#", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], "-", 
            "0.5"}], ",", 
           RowBox[{"Nx", "-", 
            RowBox[{
            "#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], "+", 
            "0.5"}]}], "}"}], "&"}], "/@", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"g0d", "\[LeftDoubleBracket]", 
           RowBox[{"1", ";;", "2"}], "\[RightDoubleBracket]"}], ",", 
          RowBox[{
           RowBox[{"g0d", "\[LeftDoubleBracket]", 
            RowBox[{"1", ";;", "2"}], "\[RightDoubleBracket]"}], "+", 
           RowBox[{
            FractionBox[
             RowBox[{"Length", "[", "im", "]"}], "10"], 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Cos", "[", 
               RowBox[{
               "g0d", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
               "]"}], ",", 
              RowBox[{"Sin", "[", 
               RowBox[{
               "g0d", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
               "]"}]}], "}"}]}]}]}], "}"}]}], "]"}]}], "}"}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Graphics", "[", 
    RowBox[{"Flatten", "@", 
     RowBox[{"{", 
      RowBox[{"colorForward", ",", "Thick", ",", 
       RowBox[{"Table", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Arrow", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{
               "#", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
               "-", "0.5"}], ",", 
              RowBox[{"Nx", "-", 
               RowBox[{
               "#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
               "+", "0.5"}]}], "}"}], "&"}], "/@", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"g1dListForward", "\[LeftDoubleBracket]", 
              RowBox[{"i", ",", 
               RowBox[{"1", ";;", "2"}]}], "\[RightDoubleBracket]"}], ",", 
             RowBox[{
              RowBox[{"g1dListForward", "\[LeftDoubleBracket]", 
               RowBox[{"i", ",", 
                RowBox[{"1", ";;", "2"}]}], "\[RightDoubleBracket]"}], "+", 
              RowBox[{
               FractionBox[
                RowBox[{"Length", "[", "im", "]"}], "10"], 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{"g1dListForward", "\[LeftDoubleBracket]", 
                   RowBox[{"i", ",", "3"}], "\[RightDoubleBracket]"}], "]"}], 
                 ",", 
                 RowBox[{"Sin", "[", 
                  RowBox[{"g1dListForward", "\[LeftDoubleBracket]", 
                   RowBox[{"i", ",", "3"}], "\[RightDoubleBracket]"}], 
                  "]"}]}], "}"}]}]}]}], "}"}]}], "]"}], "\[IndentingNewLine]",
          ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", 
           RowBox[{"Length", "[", "g1dListForward", "]"}], ",", "1"}], 
          "}"}]}], "]"}]}], "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Graphics", "[", 
    RowBox[{"Flatten", "@", 
     RowBox[{"{", 
      RowBox[{"colorBackward", ",", "Dashed", ",", "Thick", ",", 
       RowBox[{"Table", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Arrow", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{
               "#", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
               "-", "0.5"}], ",", 
              RowBox[{"Nx", "-", 
               RowBox[{
               "#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
               "+", "0.5"}]}], "}"}], "&"}], "/@", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"g1dListBackward", "\[LeftDoubleBracket]", 
              RowBox[{"i", ",", 
               RowBox[{"1", ";;", "2"}]}], "\[RightDoubleBracket]"}], ",", 
             RowBox[{
              RowBox[{"g1dListBackward", "\[LeftDoubleBracket]", 
               RowBox[{"i", ",", 
                RowBox[{"1", ";;", "2"}]}], "\[RightDoubleBracket]"}], "+", 
              RowBox[{
               FractionBox[
                RowBox[{"Length", "[", "im", "]"}], "10"], 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{"g1dListBackward", "\[LeftDoubleBracket]", 
                   RowBox[{"i", ",", "3"}], "\[RightDoubleBracket]"}], "]"}], 
                 ",", 
                 RowBox[{"Sin", "[", 
                  RowBox[{"g1dListBackward", "\[LeftDoubleBracket]", 
                   RowBox[{"i", ",", "3"}], "\[RightDoubleBracket]"}], 
                  "]"}]}], "}"}]}]}]}], "}"}]}], "]"}], "\[IndentingNewLine]",
          ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", 
           RowBox[{"Length", "[", "g1dListBackward", "]"}], ",", "1"}], 
          "}"}]}], "]"}]}], "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"ImageSize", "\[Rule]", "400"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.6876049881477532`*^9, 3.6876049986316442`*^9}, {
   3.687605369189462*^9, 3.687605411842936*^9}, {3.6876059042649584`*^9, 
   3.687605922419286*^9}, 3.6876063110641904`*^9, {3.706933612965887*^9, 
   3.706933679159012*^9}, {3.706934075895477*^9, 3.706934076695606*^9}}],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzsvXnwXtWZ59dJqtLpTnrJJJme7rjtpg0CZBZZgABZLBI7wqAFSWhBMhJi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    "], {{0, 379}, {400, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  DefaultBaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{400, 379},
  PlotRange->{{0, 400}, {0, 379}}]], "Output",
 CellChangeTimes->{3.706948258095396*^9},
 ImageSize->{404, 379},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["6. Vessel tracking", "Section",
 CellChangeTimes->{{3.7069342621970844`*^9, 3.7069342723280487`*^9}}],

Cell[CellGroupData[{

Cell["Set-up the parameters", "Subsection",
 CellChangeTimes->{{3.7009988502613487`*^9, 3.70099885553938*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"prms", "=", 
    RowBox[{"Association", "[", 
     RowBox[{"{", "}"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"Model", " ", "parameters"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"prms", "[", "\"\<model\>\"", "]"}], "=", 
    RowBox[{"model", "=", "\"\<ReedsShepp2\>\""}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{
    StyleBox["parameter",
     FontColor->RGBColor[1, 0, 0]], ":", " ", 
    RowBox[{"try", " ", "different", " ", "models", " ", 
     RowBox[{"(", 
      RowBox[{"\"\<ReedsSheppForward2\>\"", ",", "\"\<ReedsShepp2\>\""}], 
      ")"}]}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"prms", "[", "\"\<projective\>\"", "]"}], "=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"prms", "[", "\"\<xi\>\"", "]"}], "=", 
    RowBox[{"xi", "=", 
     RowBox[{"\[Xi]", "=", 
      RowBox[{"0.05", "*", "sx"}]}]}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"balancing", " ", 
    StyleBox["parameter",
     FontColor->RGBColor[1, 0, 0]], " ", "\[Xi]"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"prms", "[", "\"\<eps\>\"", "]"}], "=", 
    RowBox[{"eps", "=", "0.1"}]}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"Speed", " ", "parameters"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"prms", "[", "\"\<speed\>\"", "]"}], "=", 
    RowBox[{"speed", "=", 
     RowBox[{"1", "/", 
      RowBox[{"costSE2Full", "\[LeftDoubleBracket]", 
       RowBox[{"All", ",", "All", ",", 
        RowBox[{"1", ";;", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"prms", "[", "\"\<projective\>\"", "]"}], "\[Equal]", 
            "1"}], ",", 
           RowBox[{"N\[Theta]", "/", "2"}], ",", "N\[Theta]"}], "]"}]}]}], 
       "\[RightDoubleBracket]"}]}]}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{
   "If", " ", "projective", " ", "then", " ", "only", " ", "the", " ", 
    "domain", " ", "from", " ", "0", " ", "to", " ", "\[Pi]", " ", "is", " ", 
    "considered"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"prms", "[", "\"\<dims\>\"", "]"}], "=", 
   RowBox[{"dims", "=", 
    RowBox[{"{", 
     RowBox[{"Nx", ",", "Ny", ",", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"prms", "[", "\"\<projective\>\"", "]"}], "\[Equal]", "1"}], 
        ",", 
        RowBox[{"N\[Theta]", "/", "2"}], ",", "N\[Theta]"}], "]"}]}], 
     "}"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"prms", "[", "\"\<arrayOrdering\>\"", "]"}], "=", 
    RowBox[{"arrayOrdering", "=", "\"\<Reversed\>\""}]}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"Domain", " ", "parameters"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"prms", "[", "\"\<gridScale\>\"", "]"}], "=", 
   RowBox[{"gridScale", "=", "1."}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"prms", "[", "\"\<origin\>\"", "]"}], "=", 
    RowBox[{"origin", "=", 
     RowBox[{"{", 
      RowBox[{"0.5", ",", "0.5"}], "}"}]}]}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"Seeds", " ", "and", " ", "tips"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"prms", "[", "\"\<seeds\>\"", "]"}], "=", 
   RowBox[{"seeds", "=", 
    RowBox[{"{", "g0d", "}"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"prms", "[", "\"\<tips\>\"", "]"}], "=", 
    RowBox[{"tips", "=", "g1dListForward"}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{
   "only", " ", "take", " ", "the", " ", "normal", " ", "\"\<forward\>\"", 
    " ", "tips", " ", 
    RowBox[{"(", 
     RowBox[{
      StyleBox["parameter",
       FontColor->RGBColor[1, 0, 0]], ":", " ", 
      RowBox[{"test", " ", "change", " ", "to", " ", "backward"}]}], ")"}]}], 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"Solver", " ", "parameters"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"prms", "[", "\"\<sndOrder\>\"", "]"}], "=", 
    RowBox[{"sndOrder", "=", "1"}]}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"Export", " ", "parameters"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"prms", "[", "\"\<exportValues\>\"", "]"}], "=", 
    RowBox[{"exportValues", "=", "1."}]}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", "Options", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"opts", "=", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"\"\<inputPrefix\>\"", "\[Rule]", "\"\<input\>\""}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"\"\<outputPrefix\>\"", "\[Rule]", "\"\<output\>\""}]}], 
    "\[IndentingNewLine]", "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.697215605706993*^9, 3.6972156693051414`*^9}, {
   3.697216020230321*^9, 3.697216100700306*^9}, {3.6972162548121157`*^9, 
   3.697216287372102*^9}, {3.697216546821309*^9, 3.6972165709332085`*^9}, {
   3.697216616594465*^9, 3.6972166214231234`*^9}, {3.697216741429738*^9, 
   3.6972167415547504`*^9}, {3.6972167868233647`*^9, 3.697216806372264*^9}, {
   3.697217034732287*^9, 3.6972170448113656`*^9}, {3.697217107309045*^9, 
   3.6972171127938614`*^9}, {3.697217175644431*^9, 3.6972171781133823`*^9}, {
   3.697217262653626*^9, 3.697217268247966*^9}, {3.6972173560899115`*^9, 
   3.697217375873415*^9}, {3.6972174269412994`*^9, 3.6972174286914763`*^9}, {
   3.6972174630232954`*^9, 3.697217468305105*^9}, {3.6972175248734713`*^9, 
   3.697217526498744*^9}, {3.6972177308643646`*^9, 3.6972177360836687`*^9}, {
   3.6972177720093856`*^9, 3.697217773712569*^9}, {3.6972178084819803`*^9, 
   3.6972178221841407`*^9}, {3.697218024395872*^9, 3.697218060189486*^9}, 
   3.697218161962892*^9, {3.6972183616643224`*^9, 3.697218363635556*^9}, {
   3.6972187659663754`*^9, 3.6972187894317894`*^9}, {3.6972188194909625`*^9, 
   3.697218823696308*^9}, {3.6972188760986495`*^9, 3.697218898584714*^9}, {
   3.697218931351689*^9, 3.697219003368492*^9}, {3.697219122913432*^9, 
   3.6972191248045797`*^9}, {3.6972196501885667`*^9, 3.6972196614715977`*^9}, 
   3.697219762968602*^9, {3.697219812255763*^9, 3.697219814068431*^9}, {
   3.697219868243829*^9, 3.6972198754634314`*^9}, {3.6972199343454795`*^9, 
   3.697219934439099*^9}, {3.697219986742331*^9, 3.697220011276314*^9}, {
   3.6972201856756816`*^9, 3.697220205137453*^9}, {3.6972203194316206`*^9, 
   3.6972203581623025`*^9}, {3.697220394228874*^9, 3.6972203946976805`*^9}, {
   3.6972204260135803`*^9, 3.6972204606339307`*^9}, {3.697220493887476*^9, 
   3.697220494168762*^9}, {3.69722052800037*^9, 3.697220542352211*^9}, {
   3.6972206707281885`*^9, 3.697220746664567*^9}, 3.6972208680820312`*^9, 
   3.6972209112115684`*^9, 3.6972843229490347`*^9, {3.697284540932329*^9, 
   3.6972845410416937`*^9}, {3.6972846489287343`*^9, 3.697284650944565*^9}, {
   3.6972847513773923`*^9, 3.6972847815054026`*^9}, {3.697284848927646*^9, 
   3.6972848633979073`*^9}, {3.6972849059648705`*^9, 
   3.6972849071837454`*^9}, {3.6972849677526474`*^9, 
   3.6972850083192472`*^9}, {3.6972850595122557`*^9, 3.697285109189214*^9}, {
   3.6972851682922487`*^9, 3.6972853723918133`*^9}, {3.697285410489418*^9, 
   3.6972854192717695`*^9}, {3.6972854964871473`*^9, 
   3.6972855136452265`*^9}, {3.697285645151368*^9, 3.6972856462141047`*^9}, {
   3.697285682921138*^9, 3.697285684780564*^9}, {3.697285731347955*^9, 
   3.6972857361922116`*^9}, 3.6972858211228776`*^9, {3.6972860131931877`*^9, 
   3.69728601602159*^9}, {3.6972860555257163`*^9, 3.6972860576353054`*^9}, {
   3.6972860965759783`*^9, 3.697286096919764*^9}, {3.6972861296129365`*^9, 
   3.697286130066251*^9}, {3.6972862206224995`*^9, 3.69728625168838*^9}, {
   3.697286740957475*^9, 3.6972867443172026`*^9}, {3.697286805839175*^9, 
   3.6972868093553114`*^9}, {3.6972868576415834`*^9, 
   3.6972868838786254`*^9}, {3.697286922414051*^9, 3.697286965356078*^9}, {
   3.6972870166175227`*^9, 3.6972870466361804`*^9}, {3.697287085749672*^9, 
   3.6972870946882024`*^9}, {3.697287127207119*^9, 3.6972871816972413`*^9}, {
   3.697287267346876*^9, 3.6972872785980587`*^9}, {3.697287319649206*^9, 
   3.6972873206471777`*^9}, {3.6972875151633964`*^9, 3.697287515632172*^9}, {
   3.700368049200569*^9, 3.700368052687879*^9}, {3.7003682423702064`*^9, 
   3.700368242687043*^9}, {3.700368301260742*^9, 3.700368307711898*^9}, {
   3.700368350412425*^9, 3.7003683802387285`*^9}, {3.7003687485561495`*^9, 
   3.700368754316466*^9}, {3.7003696724947057`*^9, 3.700369725803441*^9}, {
   3.700369776477172*^9, 3.7003697928276443`*^9}, {3.700369919723199*^9, 
   3.70036993025019*^9}, {3.7003700438662786`*^9, 3.7003702908887644`*^9}, {
   3.700370362283574*^9, 3.700370507232789*^9}, {3.7003705591197166`*^9, 
   3.7003706637699904`*^9}, {3.7003883249637175`*^9, 
   3.7003883261257715`*^9}, {3.7003884235809245`*^9, 
   3.7003884260184097`*^9}, {3.700389108254994*^9, 3.7003891090791917`*^9}, {
   3.700389155286043*^9, 3.700389156179413*^9}, {3.700389221821948*^9, 
   3.7003892221638603`*^9}, {3.7003892691588097`*^9, 
   3.7003892711160135`*^9}, {3.700389352383233*^9, 3.700389354578096*^9}, {
   3.7003894144632907`*^9, 3.7003894150809736`*^9}, {3.70045146635285*^9, 
   3.7004514959084306`*^9}, {3.700456276174454*^9, 3.700456371089845*^9}, {
   3.700466907914756*^9, 3.7004669110713463`*^9}, {3.7004670733853245`*^9, 
   3.700467073572936*^9}, 3.700477094686808*^9, {3.700538603842599*^9, 
   3.700538619491206*^9}, {3.7005405882065916`*^9, 3.700540588814209*^9}, {
   3.700540640846551*^9, 3.7005406410099583`*^9}, {3.7005593571724606`*^9, 
   3.7005593574391656`*^9}, 3.7005593971066313`*^9, 3.700560081589526*^9, {
   3.70056076352966*^9, 3.700560781345055*^9}, 3.7005615642125216`*^9, {
   3.7008102918413124`*^9, 3.7008103347223234`*^9}, {3.700811305171568*^9, 
   3.700811306131092*^9}, 3.7008116605975437`*^9, 3.700811707585473*^9, 
   3.7008136702975826`*^9, 3.7008141182415686`*^9, {3.700814341864132*^9, 
   3.700814362715602*^9}, 3.7008144272742195`*^9, {3.70081464769828*^9, 
   3.7008146704056554`*^9}, {3.700814771097372*^9, 3.700814773418569*^9}, 
   3.7008148857151427`*^9, 3.700814953240651*^9, {3.7008150103675394`*^9, 
   3.7008150131930523`*^9}, 3.7008151007478776`*^9, 3.700815471612893*^9, {
   3.700815569252496*^9, 3.7008155715074916`*^9}, 3.700815607393905*^9, 
   3.7008158669510126`*^9, {3.7008163455715623`*^9, 3.700816368217809*^9}, {
   3.700816418422257*^9, 3.7008164196284647`*^9}, {3.7008165211644306`*^9, 
   3.7008165702790775`*^9}, {3.7008171844409423`*^9, 
   3.7008171847317452`*^9}, {3.7008243617037888`*^9, 3.700824388776779*^9}, 
   3.700912982874543*^9, {3.7009130223194003`*^9, 3.700913027072036*^9}, {
   3.7010607289508715`*^9, 3.7010608712212124`*^9}, {3.701061600407365*^9, 
   3.7010616010168147`*^9}, {3.70106456224684*^9, 3.7010645703122745`*^9}, {
   3.701064626941938*^9, 3.7010646309355035`*^9}, {3.7010646887944183`*^9, 
   3.7010646902171974`*^9}, {3.701065130728764*^9, 3.7010651308270407`*^9}, {
   3.701065164685091*^9, 3.7010651916237226`*^9}, {3.7010654883294764`*^9, 
   3.701065497896923*^9}, {3.70218257806404*^9, 3.702182596079976*^9}, {
   3.702182806032609*^9, 3.7021828082555237`*^9}, {3.7069341399619236`*^9, 
   3.706934155927391*^9}, {3.7069341924706078`*^9, 3.7069342284092317`*^9}, {
   3.7069342781525517`*^9, 3.7069343161085434`*^9}, 3.7069387724750795`*^9, {
   3.7069389271315236`*^9, 3.7069390212178335`*^9}, 3.706939998540436*^9, 
   3.7069402514683156`*^9, {3.7069416416165867`*^9, 3.706941651918024*^9}, {
   3.7069417046683617`*^9, 3.706941705996889*^9}, {3.706941739116974*^9, 
   3.706941739996312*^9}, {3.706941779469352*^9, 3.7069417958850236`*^9}, {
   3.706947017185916*^9, 3.7069470178577037`*^9}, {3.706947779362582*^9, 
   3.706947780728221*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Run the experiment", "Subsection",
 CellChangeTimes->{{3.7069343989027653`*^9, 3.7069344009031057`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"**", "**", "**", "**"}], "*", "Load", " ", "hfm", " ", "library",
     " ", "link", " ", "functions"}], "*)"}], "\n", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"LoadHFMWLL", "[", "libraryPath", "]"}], ";"}], "//", 
    "AbsoluteTiming"}], "\n", "\n", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"**", "**", "**", "**"}], "*", "Set", " ", "parameters"}], 
    "*)"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"hfmSetVariable", "[", 
        RowBox[{
         RowBox[{"#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
         ",", 
         RowBox[{
         "#", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], "]"}],
        "&"}], "/@", 
      RowBox[{"Normal", "[", "prms", "]"}]}], ";"}], "//", "AbsoluteTiming"}],
    "\n", "\n", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"**", "**", "**", "**"}], "*", "Run", " ", "the", " ", "code"}], 
    "*)"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"output", "=", 
      RowBox[{"hfmRunModel", "[", "]"}]}], ";"}], "//", "AbsoluteTiming"}], 
   "\n", "\n", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"**", "**", "**", "**"}], "*", "Get", " ", "the", " ", "data", 
     " ", "to", " ", "Mathematica"}], "*)"}], "\n", 
   RowBox[{
    RowBox[{"values", "=", 
     RowBox[{
      RowBox[{"hfmGetArray", "[", "3", "]"}], "[", "\"\<values\>\"", "]"}]}], 
    ";"}], "\n", 
   RowBox[{
    RowBox[{"geodesicsAll", "=", 
     RowBox[{
      RowBox[{"hfmGetArray", "[", "2", "]"}], "[", "\"\<geodesicPoints\>\"", 
      "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"endIndices", "=", 
     RowBox[{"Round", "@", 
      RowBox[{"Accumulate", "[", 
       RowBox[{
        RowBox[{"hfmGetArray", "[", "1", "]"}], "[", 
        "\"\<geodesicLengths\>\"", "]"}], "]"}]}]}], ";"}], "\n", "\n", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"**", "**", "**", "**"}], "*", "Close", " ", "the", " ", 
     "library", " ", "link"}], "*)"}], "\n", 
   RowBox[{
    RowBox[{"UnloadHFMWLL", "[", "]"}], ";"}], "\n", "\n", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"**", "**", "**", "**"}], "*", "Reformat", " ", "the", " ", 
     "data"}], "*)"}], "\n", 
   RowBox[{
    RowBox[{"startIndices", "=", 
     RowBox[{
      RowBox[{"Prepend", "[", 
       RowBox[{
        RowBox[{"endIndices", "+", "1"}], ",", "1"}], "]"}], 
      "\[LeftDoubleBracket]", 
      RowBox[{"1", ";;", 
       RowBox[{"-", "2"}]}], "\[RightDoubleBracket]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"geodesics", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"geodesicsAll", "\[LeftDoubleBracket]", 
        RowBox[{
         RowBox[{
         "startIndices", "\[LeftDoubleBracket]", "i", 
          "\[RightDoubleBracket]"}], ";;", 
         RowBox[{
         "endIndices", "\[LeftDoubleBracket]", "i", 
          "\[RightDoubleBracket]"}]}], "\[RightDoubleBracket]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", 
         RowBox[{"Length", "[", "startIndices", "]"}], ",", "1"}], "}"}]}], 
      "]"}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.7069344015839014`*^9, 3.706934416474513*^9}, 
   3.706938692250655*^9, {3.706938789663783*^9, 3.706938790682518*^9}, 
   3.706940397563957*^9, 3.7069404921235476`*^9, 3.7069407150426016`*^9, {
   3.7069415985670958`*^9, 3.706941600844117*^9}, 3.7069416365160184`*^9, {
   3.7069487689080596`*^9, 3.7069487694284415`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.021528510837341894`", ",", "Null"}], "}"}]], "Output",
 CellChangeTimes->{3.706948258186607*^9},
 ImageSize->{122, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.047528728911588276`", ",", "Null"}], "}"}]], "Output",
 CellChangeTimes->{3.706948258234733*^9},
 ImageSize->{122, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"8.98112946657143`", ",", "Null"}], "}"}]], "Output",
 CellChangeTimes->{3.7069482672176647`*^9},
 ImageSize->{108, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Show results", "Subsection",
 CellChangeTimes->{{3.6876721199444666`*^9, 3.6876721221202545`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"results", "=", 
  RowBox[{"Show", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ImageAdjust", "@", 
     RowBox[{"Image", "[", "im", "]"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"Graphics", "[", 
       RowBox[{"{", 
        RowBox[{"Orange", ",", "Thick", ",", 
         RowBox[{"Line", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{
               "#", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
               "-", "0.5"}], ",", 
              RowBox[{"Nx", "-", 
               RowBox[{
               "#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
               "+", "0.5"}]}], "}"}], "&"}], "/@", 
           RowBox[{
           "geodesics", "\[LeftDoubleBracket]", "i", 
            "\[RightDoubleBracket]"}]}], "]"}]}], "}"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", 
        RowBox[{"Length", "[", "geodesics", "]"}], ",", "1"}], "}"}]}], "]"}],
     ",", "\[IndentingNewLine]", 
    RowBox[{"ImageSize", "\[Rule]", "400"}], ",", 
    RowBox[{"Frame", "\[Rule]", "False"}], ",", 
    RowBox[{"Framed", "\[Rule]", "True"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6875203241788177`*^9, 3.6875203428013625`*^9}, {
   3.687520450286275*^9, 3.6875204521622863`*^9}, {3.687520934191323*^9, 
   3.6875209457771463`*^9}, {3.6875863642813416`*^9, 3.687586365879634*^9}, {
   3.68761063944882*^9, 3.687610641004958*^9}, {3.687610868104125*^9, 
   3.687610869639209*^9}, {3.6876721125528*^9, 3.687672114200205*^9}, {
   3.6969116649284143`*^9, 3.696911696718953*^9}, 3.69691208673678*^9, {
   3.696914413438072*^9, 3.6969144231980195`*^9}, {3.6969146591990757`*^9, 
   3.696914659794628*^9}, 3.6969177789690733`*^9, 3.6969178211762753`*^9, 
   3.6972169892432055`*^9, {3.6972873646519346`*^9, 3.697287365761428*^9}, {
   3.7003895065110254`*^9, 3.7003895087881227`*^9}, {3.702182619310788*^9, 
   3.702182622244594*^9}, {3.702183245984214*^9, 3.702183246542699*^9}, {
   3.7069343642144823`*^9, 3.706934370710792*^9}}],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzsvXn432V55+tYR9uqta0LboCsIsEEIoYISMIqEEBIMGFPQgwBDCH7TsIm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    "], {{0, 379}, {400, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  DefaultBaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{400, 379},
  PlotRange->{{0, 400}, {0, 379}}]], "Output",
 CellChangeTimes->{3.7069482673299537`*^9},
 ImageSize->{404, 379},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["---Exercises", "Title",
 CellChangeTimes->{{3.7069388079614596`*^9, 3.7069388096269245`*^9}, 
   3.706938888697248*^9, {3.7069537126927176`*^9, 3.706953713012577*^9}}],

Cell["\<\
1. Experiment with parameters (\[Xi]: flexibility of the curve, \[Lambda]: \
influence of the cost, p: contrast of the cost)\
\>", "Section",
 CellChangeTimes->{{3.70693882701816*^9, 3.706938886059251*^9}}],

Cell["\<\
2. Experiment with different geodesic models \
(\[OpenCurlyDoubleQuote]ReedsSheppForward2\[CloseCurlyDoubleQuote], \
\[OpenCurlyDoubleQuote]ReedsShepp2\[CloseCurlyDoubleQuote], \
\[OpenCurlyDoubleQuote]ReedsShepp2\[CloseCurlyDoubleQuote]-projective)\
\>", "Section",
 CellChangeTimes->{{3.706939027257867*^9, 3.7069390985856247`*^9}}],

Cell[CellGroupData[{

Cell["\<\
3. Run the experiment with different end conditions (try to find curves with \
cusps)\
\>", "Section",
 CellChangeTimes->{{3.706939027257867*^9, 3.7069391169063635`*^9}, {
  3.706954910374647*^9, 3.706954914981906*^9}}],

Cell[CellGroupData[{

Cell["\<\
Prepare the data for back tracking via the LieAnalysis` package\
\>", "Subsection",
 CellChangeTimes->{{3.706940069739865*^9, 3.706940081883135*^9}}],

Cell[CellGroupData[{

Cell["Put the data in LieAnalysis` data-objects:", "Subsubsection",
 CellChangeTimes->{{3.706940149228308*^9, 3.7069401640758*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "Place", " ", "the", " ", "data", " ", "in", " ", "orientation", " ", 
    "score", " ", 
    RowBox[{"objects", ":"}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"W", "=", 
    RowBox[{"ObjPositionOrientationData", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\"\<Data\>\"", "->", 
        RowBox[{"Image", "[", "values", "]"}]}], ",", 
       RowBox[{"\"\<Symmetry\>\"", "->", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"prms", "[", "\"\<projective\>\"", "]"}], "\[Equal]", 
           "1."}], ",", "\[Pi]", ",", 
          RowBox[{"2", "\[Pi]"}]}], "]"}]}]}], "}"}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"cost", "=", 
    RowBox[{"ObjPositionOrientationData", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\"\<Data\>\"", "->", 
        RowBox[{"Image", "[", 
         RowBox[{"costSE2Full", "\[LeftDoubleBracket]", 
          RowBox[{"All", ",", "All", ",", 
           RowBox[{"1", ";;", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"prms", "[", "\"\<projective\>\"", "]"}], "\[Equal]", 
               "1."}], ",", 
              RowBox[{"N\[Theta]", "/", "2"}], ",", "N\[Theta]"}], "]"}]}]}], 
          "\[RightDoubleBracket]"}], "]"}]}], ",", 
       RowBox[{"\"\<Symmetry\>\"", "->", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"prms", "[", "\"\<projective\>\"", "]"}], "\[Equal]", 
           "1."}], ",", "\[Pi]", ",", 
          RowBox[{"2", "\[Pi]"}]}], "]"}]}]}], "}"}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Periodicity", " ", "and", " ", 
     RowBox[{"AngularResolution", ":"}]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{"periodicity", "=", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"prms", "[", "\"\<projective\>\"", "]"}], "\[Equal]", "1."}], 
      ",", "\[Pi]", ",", 
      RowBox[{"2", "\[Pi]"}]}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{"s\[Theta]", "=", 
    RowBox[{"W", "[", "\"\<AngularResolution\>\"", "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", "ReedsSheppForward", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"onlyForwardGearQ", "=", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"prms", "[", "\"\<model\>\"", "]"}], "\[Equal]", 
       "\"\<ReedsSheppForward2\>\""}], ",", "True", ",", "False"}], 
     "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.7069397521870556`*^9, 3.7069397976279097`*^9}, {
  3.706940084075991*^9, 3.706940111933076*^9}, {3.7069408310040913`*^9, 
  3.706940866395218*^9}, {3.7069464797972746`*^9, 3.7069464923195815`*^9}}],

Cell[BoxData[
 RowBox[{"2", " ", "\[Pi]"}]], "Output",
 CellChangeTimes->{3.706948267753055*^9},
 ImageSize->{22, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[
 FractionBox["\[Pi]", "16"]], "Output",
 CellChangeTimes->{3.706948267754058*^9},
 ImageSize->{23, 26},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData["False"], "Output",
 CellChangeTimes->{3.7069482677650895`*^9},
 ImageSize->{39, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Pre compute the derivatives which are used in the gradient desent\
\>", "Subsubsection",
 CellChangeTimes->{{3.7069401337230453`*^9, 3.7069401431160355`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"Calculate", " ", "finit", " ", "difference", " ", "derivatives"}],
    "*)"}], "\n", 
  RowBox[{
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{"onlyForwardGearQ", ",", " ", 
      RowBox[{"A1W", "=", 
       RowBox[{
        RowBox[{"Clip", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"LeftInvariantDerivatives", "[", 
            RowBox[{"W", ",", "1", ",", 
             RowBox[{"\"\<Method\>\"", "->", "\"\<Central\>\""}]}], "]"}], 
           "[", "\"\<Data\>\"", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "\[Infinity]"}], "}"}]}], "]"}], "/", 
        RowBox[{
         RowBox[{"cost", "[", "\"\<Data\>\"", "]"}], "^", "2"}]}]}], ",", " ", 
      RowBox[{"A1W", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"LeftInvariantDerivatives", "[", 
          RowBox[{"W", ",", "1", ",", 
           RowBox[{"\"\<Method\>\"", "->", "\"\<Central\>\""}]}], "]"}], "[", 
         "\"\<Data\>\"", "]"}], "/", 
        RowBox[{
         RowBox[{"cost", "[", "\"\<Data\>\"", "]"}], "^", "2"}]}]}]}], "]"}], 
    ";"}], "\n", 
   RowBox[{
    RowBox[{"A2W", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"LeftInvariantDerivatives", "[", 
        RowBox[{"W", ",", "2", ",", 
         RowBox[{"\"\<Method\>\"", "->", "\"\<Central\>\""}]}], "]"}], "[", 
       "\"\<Data\>\"", "]"}], "/", 
      RowBox[{
       RowBox[{"cost", "[", "\"\<Data\>\"", "]"}], "^", "2"}]}]}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"A3W", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"LeftInvariantDerivatives", "[", 
        RowBox[{"W", ",", "3", ",", 
         RowBox[{"\"\<Method\>\"", "->", "\"\<Central\>\""}]}], "]"}], "[", 
       "\"\<Data\>\"", "]"}], "/", 
      RowBox[{
       RowBox[{"cost", "[", "\"\<Data\>\"", "]"}], "^", "2"}]}]}], ";"}], 
   "\n", "\n", 
   RowBox[{"(*", 
    RowBox[{"--", "--"}], "*)"}], "\n", 
   RowBox[{"(*", 
    RowBox[{"Interpolated", " ", "functions"}], "*)"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"periodicity", "==", 
       RowBox[{"2", "\[Pi]"}]}], ",", "\n", "\t", 
      RowBox[{
       RowBox[{"A1WInt", "=", 
        RowBox[{"ListInterpolation", "[", 
         RowBox[{
          RowBox[{"Transpose", "[", 
           RowBox[{
            RowBox[{"Flatten", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"Transpose", "[", 
                 RowBox[{"A1W", ",", 
                  RowBox[{"{", 
                   RowBox[{"2", ",", "3", ",", "1"}], "}"}]}], "]"}], ",", 
                RowBox[{"{", 
                 RowBox[{"A1W", "[", 
                  RowBox[{"[", 
                   RowBox[{"All", ",", "All", ",", "1"}], "]"}], "]"}], 
                 "}"}]}], "}"}], ",", "1"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3", ",", "1", ",", "2"}], "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1", ",", "Nx"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"1", ",", "Ny"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"1", ",", 
              RowBox[{"1", "+", 
               RowBox[{"periodicity", "/", "s\[Theta]"}]}]}], "}"}]}], "}"}], 
          ",", 
          RowBox[{"PeriodicInterpolation", "->", 
           RowBox[{"{", 
            RowBox[{"False", ",", "False", ",", "True"}], "}"}]}]}], "]"}]}], 
       ";", "\n", "\t", 
       RowBox[{"A2WInt", "=", 
        RowBox[{"ListInterpolation", "[", 
         RowBox[{
          RowBox[{"Transpose", "[", 
           RowBox[{
            RowBox[{"Flatten", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"Transpose", "[", 
                 RowBox[{"A2W", ",", 
                  RowBox[{"{", 
                   RowBox[{"2", ",", "3", ",", "1"}], "}"}]}], "]"}], ",", 
                RowBox[{"{", 
                 RowBox[{"A2W", "[", 
                  RowBox[{"[", 
                   RowBox[{"All", ",", "All", ",", "1"}], "]"}], "]"}], 
                 "}"}]}], "}"}], ",", "1"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3", ",", "1", ",", "2"}], "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1", ",", "Nx"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"1", ",", "Ny"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"1", ",", 
              RowBox[{"1", "+", 
               RowBox[{"periodicity", "/", "s\[Theta]"}]}]}], "}"}]}], "}"}], 
          ",", 
          RowBox[{"PeriodicInterpolation", "->", 
           RowBox[{"{", 
            RowBox[{"False", ",", "False", ",", "True"}], "}"}]}]}], "]"}]}], 
       ";", "\n", "\t", 
       RowBox[{"A3WInt", "=", 
        RowBox[{"ListInterpolation", "[", 
         RowBox[{
          RowBox[{"Transpose", "[", 
           RowBox[{
            RowBox[{"Flatten", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"Transpose", "[", 
                 RowBox[{"A3W", ",", 
                  RowBox[{"{", 
                   RowBox[{"2", ",", "3", ",", "1"}], "}"}]}], "]"}], ",", 
                RowBox[{"{", 
                 RowBox[{"A3W", "[", 
                  RowBox[{"[", 
                   RowBox[{"All", ",", "All", ",", "1"}], "]"}], "]"}], 
                 "}"}]}], "}"}], ",", "1"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3", ",", "1", ",", "2"}], "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1", ",", "Nx"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"1", ",", "Ny"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"1", ",", 
              RowBox[{"1", "+", 
               RowBox[{"periodicity", "/", "s\[Theta]"}]}]}], "}"}]}], "}"}], 
          ",", 
          RowBox[{"PeriodicInterpolation", "->", 
           RowBox[{"{", 
            RowBox[{"False", ",", "False", ",", "True"}], "}"}]}]}], "]"}]}], 
       ";"}], "\n", ",", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"if", " ", "periodicity"}], "\[Equal]", "\[Pi]"}], "*)"}], 
      "\n", "\t", 
      RowBox[{"(*", 
       RowBox[{
       "Here", " ", "minus", " ", "the", " ", "copy", " ", "of", " ", "0", 
        " ", "to", " ", "pi", " ", "because", " ", "A1", " ", "and", " ", 
        "A2", " ", "are", " ", "in", " ", "opposite", " ", 
        RowBox[{"directions", ":"}]}], "*)"}], "\n", "\t", 
      RowBox[{
       RowBox[{"A1WInt", "=", 
        RowBox[{"ListInterpolation", "[", 
         RowBox[{
          RowBox[{"Transpose", "[", 
           RowBox[{
            RowBox[{"Flatten", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"Transpose", "[", 
                 RowBox[{"A1W", ",", 
                  RowBox[{"{", 
                   RowBox[{"2", ",", "3", ",", "1"}], "}"}]}], "]"}], ",", 
                RowBox[{"-", 
                 RowBox[{"Transpose", "[", 
                  RowBox[{"A1W", ",", 
                   RowBox[{"{", 
                    RowBox[{"2", ",", "3", ",", "1"}], "}"}]}], "]"}]}], ",", 
                RowBox[{"{", 
                 RowBox[{"A1W", "[", 
                  RowBox[{"[", 
                   RowBox[{"All", ",", "All", ",", "1"}], "]"}], "]"}], 
                 "}"}]}], "}"}], ",", "1"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3", ",", "1", ",", "2"}], "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1", ",", "Nx"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"1", ",", "Ny"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"1", ",", 
              RowBox[{"1", "+", 
               RowBox[{"2", 
                RowBox[{"periodicity", "/", "s\[Theta]"}]}]}]}], "}"}]}], 
           "}"}], ",", 
          RowBox[{"PeriodicInterpolation", "->", 
           RowBox[{"{", 
            RowBox[{"False", ",", "False", ",", "True"}], "}"}]}]}], "]"}]}], 
       ";", "\n", "\t", 
       RowBox[{"A2WInt", "=", 
        RowBox[{"ListInterpolation", "[", 
         RowBox[{
          RowBox[{"Transpose", "[", 
           RowBox[{
            RowBox[{"Flatten", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"Transpose", "[", 
                 RowBox[{"A2W", ",", 
                  RowBox[{"{", 
                   RowBox[{"2", ",", "3", ",", "1"}], "}"}]}], "]"}], ",", 
                RowBox[{"-", 
                 RowBox[{"Transpose", "[", 
                  RowBox[{"A2W", ",", 
                   RowBox[{"{", 
                    RowBox[{"2", ",", "3", ",", "1"}], "}"}]}], "]"}]}], ",", 
                RowBox[{"{", 
                 RowBox[{"A2W", "[", 
                  RowBox[{"[", 
                   RowBox[{"All", ",", "All", ",", "1"}], "]"}], "]"}], 
                 "}"}]}], "}"}], ",", "1"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3", ",", "1", ",", "2"}], "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1", ",", "Nx"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"1", ",", "Ny"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"1", ",", 
              RowBox[{"1", "+", 
               RowBox[{"2", 
                RowBox[{"periodicity", "/", "s\[Theta]"}]}]}]}], "}"}]}], 
           "}"}], ",", 
          RowBox[{"PeriodicInterpolation", "->", 
           RowBox[{"{", 
            RowBox[{"False", ",", "False", ",", "True"}], "}"}]}]}], "]"}]}], 
       ";", "\n", "\t", 
       RowBox[{"A3WInt", "=", 
        RowBox[{"ListInterpolation", "[", 
         RowBox[{
          RowBox[{"Transpose", "[", 
           RowBox[{
            RowBox[{"Flatten", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"Transpose", "[", 
                 RowBox[{"A3W", ",", 
                  RowBox[{"{", 
                   RowBox[{"2", ",", "3", ",", "1"}], "}"}]}], "]"}], ",", 
                RowBox[{"{", 
                 RowBox[{"A3W", "[", 
                  RowBox[{"[", 
                   RowBox[{"All", ",", "All", ",", "1"}], "]"}], "]"}], 
                 "}"}]}], "}"}], ",", "1"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"3", ",", "1", ",", "2"}], "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1", ",", "Nx"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"1", ",", "Ny"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"1", ",", 
              RowBox[{"1", "+", 
               RowBox[{"periodicity", "/", "s\[Theta]"}]}]}], "}"}]}], "}"}], 
          ",", 
          RowBox[{"PeriodicInterpolation", "->", 
           RowBox[{"{", 
            RowBox[{"False", ",", "False", ",", "True"}], "}"}]}]}], "]"}]}], 
       ";"}]}], "\n", "]"}], ";"}]}]}]], "Code",
 InitializationCell->False,
 CellChangeTimes->{{3.706941294989453*^9, 3.706941313133729*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
The actual backtracking (reproducing results of the fast marching algorithm)\
\>", "Subsection",
 CellChangeTimes->{{3.706940177962757*^9, 3.7069401888426905`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"curvesd", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"BackTracking", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"#", ",", "g0d"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"A1WInt", ",", "A2WInt", ",", "A3WInt"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"prms", "[", "\"\<xi\>\"", "]"}], ",", 
          RowBox[{"prms", "[", "\"\<eps\>\"", "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"W", "[", "\"\<AngularResolution\>\"", "]"}], ",", 
          RowBox[{"prms", "[", "\"\<gridScale\>\"", "]"}]}], "}"}], ",", 
        "periodicity"}], "]"}], "&"}], "/@", "g1dListForward"}]}], ";"}], 
  "\n", 
  RowBox[{"(*", 
   RowBox[{"Show", " ", "results"}], "*)"}]}], "\n", 
 RowBox[{"resultsUpwind", "=", 
  RowBox[{"Show", "[", "\n", "\t", 
   RowBox[{
    RowBox[{"Image", "[", "im", "]"}], ",", "\n", "\t", 
    RowBox[{"Table", "[", " ", 
     RowBox[{
      RowBox[{"Graphics", "[", " ", 
       RowBox[{"{", 
        RowBox[{"Orange", ",", " ", "Thick", ",", " ", 
         RowBox[{"Line", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{"#", "[", 
                RowBox[{"[", "2", "]"}], "]"}], "-", "0.5"}], ",", 
              RowBox[{"Nx", "-", 
               RowBox[{"#", "[", 
                RowBox[{"[", "1", "]"}], "]"}], "+", "0.5"}]}], "}"}], "&"}], 
           "/@", 
           RowBox[{"curvesd", "[", 
            RowBox[{"[", "i", "]"}], "]"}]}], "]"}]}], "}"}], " ", "]"}], ",",
       " ", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", 
        RowBox[{"Length", "[", "curvesd", "]"}], ",", "1"}], "}"}]}], " ", 
     "]"}], ",", "\n", "\t", 
    RowBox[{"ImageSize", "->", "Medium"}], ",", 
    RowBox[{"Frame", "->", "False"}], ",", 
    RowBox[{"Framed", "->", "True"}]}], "]"}]}]}], "Code",
 InitializationCell->False,
 CellChangeTimes->{{3.7069398382520123`*^9, 3.706939881179186*^9}, 
   3.7069399843757257`*^9, {3.7069405777283*^9, 3.706940585233225*^9}, {
   3.70694074563098*^9, 3.706940797180107*^9}, {3.7069410197882977`*^9, 
   3.706941049708922*^9}, {3.7069412388531027`*^9, 3.706941250207341*^9}, {
   3.7069415260611944`*^9, 3.70694153486158*^9}, 3.7069416229850245`*^9, {
   3.7069467072483892`*^9, 
   3.7069467171206355`*^9}},ExpressionUUID->"5afd1a33-2e67-4d5f-ac32-\
a4d2f7a53c46"],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzsvQn0l9V575vbnjTNZIY2UxuNGhFUwAFUMKiAgCioICoqIMogiBPzPDnj
jANgUBEHHGOSajQmapSIIlGjSWPSnJ723J5zV3rO6e2693Y4Z/Wcs9a93//+
ZH/W9kdPb23TNqm/ZyWul/f//t53v/t9nu9+5r3PtEtPPf/X3ve+9y34zfzn
1POWDJs//7xlEz6ef5x+yYILZl0yc8YJlyycOWvm/EHTfr3n5P/2vvfNzv97
jp9++ukvF1q+fPmZhQYOHLhfoX322YeDAw444NhCF1544axCw4cP71+oX79+
AwuNHTv24kJXXHHFLYW2bdv2zUIvv/zyzkKvv/76m4V+/OMf/6jQrl27XiyU
y36v0OOPP/7VQk899dR3Cm3fvv27lZ4t9Mwzzzz55JNc9sQTT7xQiTs8+uij
Xyn0jW9844lCjz322MOFHnrooYcrPVjo3nvvvbPQxo0bbyt0xx13bCl0zz33
bC7kn9avX391oSuvvPL6QvkT1+R6b7u+0OrVq5cUmjt37rRp08YV+tKXvnRA
oUzd6EKnnnrqGYXOP//8ywrlW/Bqzz333FOFcs+7C2WcdxS6+eabGckVDXHm
qt1o3bp1txbatGmTL8IBIw/l+KZC1157LcMIP6xYsWJZoQULFvBxwwAXFMrB
/EK5ZlWlywtlchgPjw7lmAsyJ/xpzZo1iwstXLhwUaEcLCiU6eJPee7yQgsq
5ZqlhRZV8k+LK2XC898VhVZXykmuz8HCQhxD3qRjJAsr5YnMQ261stC8efOm
FwrbH16ob9++gwvlg44tdMQRRwwpNH78+EsK5a2ZotzBR+e8T+HmeWUnhx9m
TriGF+R1OJNPMK8QUxeaVymfaU4hD/JXXu3SSy+9qFD+dH6hmTNnzi40Y8aM
mYVmV8pfpxU655xzzi00ZcqUMCdcGm7k406cOPGIQn369AE39txzTw5GjhzJ
PXPNsEIDBgw4rFCuP6VQhsTkbNiwYVuhSC7g8MYbb3y/0E9+8pM/LPQHf/AH
Pyz0yiuvPFcogPBooQzp6UIBCkBjx44d3Of5558XZ3LwfKVvFwpccIdAx9cL
BTfuKZQhbSoUSXmgUERya6E7K+Wvtxe67777+FMu5lc33HCDuIFIRn6R6NyH
8eRlQaSI/42FcnG+Mmw2ZsyYQwsddNBBQHHA5NRC+SjwbYQXCMq7MCePPPII
6JQxgAC5LSKZMVxbyTMM8pprrgHccjG/2lgpuAFK5Ji3zs25JievKbSmEHIH
dITCexcWyleGS8PDsA0MH1q7di3IkwNulVExwnDFZZUQ7dxZaZVApPyJaxTw
XAZuZEgcCDt5LkKXPwl3IfGKW0XueJGIFc/KT/jT0oZEkksL5f7cJ8MG9/yg
QX74P8ICbuSDnlgoYHJModNOOw0hzc8RjdyKucpLZSS8bwbDa+avLaqEMgZG
206FxJj9RiJJMGFWJdA+f/LOLAQ5OaNQYIE3Ou+886YWEiWiS4wvJK9GzLu4
0cWNLm50cePd4kbEEHPga1/7GkyVAZxeKCpWr0Kf/exnP11o3333RbuOooJR
E+joVyiyAJLkJMMOw8DtEVskOlYJuPHWW2/9tNAf//EfAyCxWb5XKEChRHMQ
AOHnGSoAEpMk0oQRFFFFmc8POQhugIS5w+OFcs1jhQIdGGV3VLrrrrsAhxyg
seekUvbld1KMLwQhULCuEpASePxaoQzjyUKxie4vFFSJMMIn+RbwUuwUwHnU
qFFjCuVb8JnC5DyOu4WCgaBT0OzmQoECJDGDEQEwDwUQBDaUiwGQ4N5NlUQb
DRYeGki5oVDwJwJyZaFwspozHzcHvFG4RRUaigyKOWsLZSQMO48DiHJD/iTa
AAKhyAj8nztzn1yMaOdiZESUyLFGjeLjcX4CRuVdENiIDFCA0h7KYEQ5RpJf
IY8RWK0zhpRrGH9mAOEaMWIEhufee++N5R7pOL7QIYccgp0SIxQzIU/njTJy
x5nBAw4tDmigOQBG6zWZKK0STTY+TU5iXwQuGGSYCkzIGLhhHqcJM7PSeYVy
MQdBEg4mTZp0dqG8yIRCOdi5c+euQoEOxC2LMiMJTuK7CFx8vlAAZECh6BsM
MoMZWQiVIxToOKtQZgkODMOzFkfwedabb775+4WiePxxIXSP0Ouvvw4gZMG9
t1BEj/X3W9/6FnpFNJAcc1nWd4YduEBgcwY1IydxdDxWKcfIclBiQ6FIYsdB
CPyMNKF4RJREEqQsMnhdIQQ2FOWER+S5vGyOwb08LnCEtGZWmZxM1IGFgI5Q
OA0wzxdH3jPIhwpl2OgwGRvOE0AgFGEELjI8fRc3VAIuIrZoIBEcDlBLQgJg
fg40BVp5I/CHyyIv8HnGrzLAEhwpg8nVFvLdXev5U/DH8SC/Cv6KhrghDgoM
ecQfhQG0UbT5eZ7CAgqmoX7oBMiV/DDjR0/IHTq8KEEMsFEnjO6FyBfClQNu
7nNbfePgQvvssw+KxwknnDCiUFZSNBD1jdyBRwQ6eGUAEyjLBQAIiIeixWwH
NxhJ/sqtABMUP2YJ1SWUa1QhoEABAJKTqB/5OdiSV5hcKOAwuRK/ymW4PlBC
0EP4U+7TxY0ubnRxo4sb7xY3IsWI8A9+8IPthcLwcGAm5+RCgY4+hfarNGjQ
IBSeiBUfIgbdUYWing0qFOng9SMvSFBEm0cYWMkB/o0f//jH4Mbbb7/9WqEY
Jkh95A7vRGRT10d0+G8U0i4gthLCyRDKSWM0CHXAR9zAvlASMe1DkUQPEEl1
+6jxQFlGgnDl54wN6UbAEfY85b5COZPnYhaFh+G34cOH4+jo27cveDt06FBs
wNgysH0k965CuRWeIqyeUJ6L80SIMETCS4UyYKWVAzwMocgRB8EELK/8lQmJ
ycYjMiG5HnHL9foHNAcYJN6GUEQAJkdysR0EB2wBbSgdFAZN2mgCsKPt430y
DEWba7T09Uig/Itg/DW/Nbq0stKaSsxAxgaAaOa0LhdNMF4290SUwvbARXAD
ABk7diz+jSAGghDFHqnPfRi28ZRMV26LxREQQKZynhEa6wkUXFipAzdyzM9b
uMObEemG2XJwTqGIPFCQX2Gb5CRYEWmdVChnuObiShk5Z/Jz4StqBnIa3Hi9
UBZ0pCyMxw/HjRvH5AQx9irUq1cvQDU88EihzAB2erQRDL2jjz4alMunYb02
Mvvd73735UKvvPLKS4Vyhqf/uNKrr776TKGMBGnVFxFhxAESyqOVU9SSrPjf
KhTkeboS2BIA4Rq8naFAAVIWkQEK8tYs0zmJya87MY9gZoJR4I+ujwwJ/0b+
yp/yCIadt84gOZmbI1yxEI8sdNBBBwEgYbChhQLUfO7wAFqNoWEBJMd4DDJO
vaA6OkCANrQKBRz0SepFBEByHx0dDDsHwUwGkJt3/JBFHw8kspwD1k2Dfagl
hC/5uQqPflfxB/Wg1SX0iEaE+XkQjNHqxmxDlm1cmL/mPLiRk7hTdHSInAEK
3jHzA7AYbM3YuPn8SgZns6yDG8F5/Htf/OIX+Y75fAhC+P9LhcaPH48g68PE
Iwos5FZqNXMrqUSpHUEXVVIXijijQhCuBX/AhClTpuAx01ORk6BNHsoBEVic
G2gpOcNoDf5mAFwc/YSDPL2LG13c6OJGFzfeLW6E1XEaRGbfKvS9732P8F+4
lK+cy1C9Yo+LG2hlsd2Q5bAcysxxxx3Hn3IxEZYMBnU3ujQ8GfuCII4AEujY
USgDeLtQrJhXCgVnCIsgL4Q8Iqoc526maXHzgAkmzLPPPgtoxFRBqMkBA4gY
tuZ8bkhEMjfnTEQPjT2ghH0UwDHZjBvmWdgpuSHXGLsJsukxyIOw1CKMTEUm
CuANy/UtFFgGN3ISR0euQe5IMAsFOR+oZGQZzR8rIBTjBbcM6WGhwIURFuMj
ehUQqPyQi3NDI7OZAYy4iBVSpkyZ69V6KrQvMLQjaIiJ4UsTsYIYxlNkTg40
E1Y2xMVEwEMtXLR+FVwrgmF+aJSHseWHIhjA5dgwVTDNhMTd4YIzEVKkNUsq
q2SEgrU1SHJcodie4EauwZlgNMR4ypKShyYacPNLK+lNIgJCfKdNx8J2ABMy
GC0XEADEIMDKNfhYmCsOtIACQd4Z3MjLCukgksPIsVK2fft25DS6B97LrNeI
ZOaWG4oJffr0gdtjxOHo43uFgnI4OiIRWO4BHMaWjwUfZnVGAKNOABcBK3JK
c/CDQj/60Y/wgQRSQLaIJCITiQhX31UJ14FIopCav5Ef4nyIXCt0CHWuN19U
xYPwsULqfUgFCeldCYBw54cq5VnoNjlphDd3M+ETV0NYEXAYOHAgC1Ym6uhC
gQ4Cecbvwt7MW8amx4PHZXighPY70AF6oOapb5jRERwwy1Trnl9Fx0DxyFRk
VlFdgic6D41aqmaIIUh3u9wbtDWQ2uGgMLTaIoDhSMFNaFIT2D34yNIMdHh9
x80BAfJLzTaBwpyga6t46HIEfAjOIr+I7UknnaS+QeJozpxQKB8UlTK6B4K8
qElSdYrMEomAcHNDqwJj/oosRzHgYE4lAcQkDZO69Yu2KaA8Ig/11XhWHqE3
A2FXXTTYDYKFcnEXN7q40cWNLm68W9yI8m8AEedDAOTVQhFYAhPhHD5EMIG0
pUzUvoX222+/QwrFiOND5P5IxJAhQ0wlJd8so+WLRASQqQgyj3jhhRd2VcLf
8sMf/hC7KSMh3StjY6iRmkiiYo50REy4J6HPkD6Q2BcYEfkt/gFkmdoTcMNq
lBwjm4EUAiIRT0tm8JwIRJk0xp8DjKlACulnQgowJYYw7AggqunIkSNhvKAx
jDdo0CAAJHiLGzzzhsFI4DWUcfJqeSkGmXuak8lB5oSL8SeEAhcGXzDqTS6N
vBjYBaMo1WHYwWSuFy40NIyNmuUlgpn3uLDWlRi0NbXJM6aMKsvkoIISxiWh
NluyI0lySUOaPAqgFkebpQZl/AKvpp8GS4cXJVI5pVCMShbQ3r17k+U1YcIE
YD9sTxpDviOC7PAMOpPVxpAijxosHSUnmie5iYjhxUKZMRceN70S0BHKrzSC
+K3xLGcVK6yFr+WVdPVkYIYLMeRDWUZZ3yPLiElOwoH5CWmisdpIP9hnn30A
kAEDBpxUKK/JzU8//XT4P5BLjsfZZ5/NSMKBiE8eirjp8Qhi6DJFA8kxuBH9
h7hqhDQiw7KYJZKx5RgEyBvhqn2wUoACd+hXKxGKDQU3WK/JwYDuqaTiARDl
h+a0G/NFu8iQVGn4E36VUEaSe/K4DA/FI6OFc6KqsSplMsk8DIAQv4vOBgeG
P/lwmTdYOgKOlpVR8Y65J1FjQ6vRKwwoG65FqchJK86g1j0I4eswCZ9JJuUS
zm+dFRByJzoBHaBHBwdKJoS7pkfM1QFMcvAytQX+lHtynvhjaFHNCTe9hMuE
F9MshSmuwdcRyrQwFTk2a0VBRtzyRcicjAbOupmvBpNPnjyZ7IV8Pr7s6NGj
8U9yB9Z6hme8FR8CN1eCcHJSS8jb6SCN4HON99SthPZF1qhJ5h1hXPNAcgcB
nK+ZsfHzxU15IDODesmEdHGjixtd3OjixrvFDcKaofAGTBI+RxaeeeYZLJfI
C6GKMAP3jOmNE6NPnz6kku655544lgMXPC6vhnmSqSNxLpOMdhcuhYGjDyNH
EW0cCBFJcsNyAJK8+OKLlMkDZVDQDJsl1gSxhogMWBR5ByUCR0q3cRCMiBxj
sOStwZ9o9Yh2BJ+R5IAJaavhsHesOBMcxI3MHtfYEAAE41Z3N4Qk5otTYn/o
oYfuXygaL06kQDEOoijD5OQsKclg+CLAhAwbcDOynHdBbDU9bq9koUpQxXxR
Qg+BDpDEJLEITobHD616C/Po80fu9EJEzPGB5Camp3aUxRESRUvvSL5a1iSS
6S3h59oyOeDpmjmYPKEIC5KF7u1tVcK9TCXfyAKyoPNERweBG34uyCCY0fmp
4dJOCecTRomFTvAxyE/p4imnnIKZoOuGkArhbEAYcEO4WqcNdEmlnNThI94a
xTZ6yyMok8cZYvRWowYSP50HvVIhc/P4ImT3LS+5wSZFbKkUfDC9mWhjmJ8z
4R9YIveE28PVrJJROb5YKNNF0CffnbEFbwGZQMfwQsFeEIzVkKWNNT0CSJON
gAPVr5awRVpZ63fs2IH6Ecrw8F6aiaE/M8LL+MHAUG7FzYGOUF5c1x8AoqM4
0MTPc42xWjCW5h74RYGvxyvloSgAOFhC+fn9lQz7WlgX/mSWiMmGevXqRVJu
cAPFI9odQdvMKmwjJpDrTtrG1kqklETMTYYHW/I446q6NdrsDm7omRyjw4ic
mSX0E6OHJAPAz3xTe4CwQrULqxngJn7re8lxB5IIRAKIcVVNbyFlSc2yZjyq
ENxzYVNJaozY0GqHx2NlTS7N6zMAPauuxeJGmJmvZoFzFkoAJMslB1lkmaul
lXiKpK/YrFfdKbojxA2ke1XNvRdAVtRywhBPEW1aT4jqVoeWosfYZJW5tYxO
H0irIHVxo4sbXdzo4sa7xY2wBDZIYEEDH/bDXU8jCyQo18A/YQlTScGEqGqo
2VHYiEPlxdGKM8l0QAr/k9qUv6Iu5tOoRVsfgSTaWCPQAUREkLEOgBT+GkxA
hPMTAdDxAw6xI0wcfbYSv8qr4cqIRKCK51fYMpbR5TKmKMaFIRtcKJkQQzaW
zkG0FwuRrmYOGK9pGV2eCwNYYn/ggQfiMorlgp3Sarz41fPhEFJDq5TPhNrY
jRiFCZZXAKwsurEqx6L7aypFXtqbAzgZMOiqwRI12DJw2FVHR67pQABDtDnQ
4LKliQ4T/RvGfLmPIZX5pQqmI1arARW25FjfRUeEtyVtAc35yAWYpv/HbLfl
tXwvnwDcCDNrp8D2Z511FoWKBtZb3NC4MJ9NY0prbm6tuVvY9EDryMXVdjCQ
3ea2aU0YWu3ADSekDTA5RdopmjB8l3wLDc9wkdqFUU4TpPmTJn9kECTJ4gVv
AB2hoKvLJeHXmHg8PZND+DjQAW4EpXErZZA4OmTIcD5LszkSqhm6PtBDcHRE
iwAH0D1CGTkSpD+TTO+QhbFttJR3NJ4b6TYwjZYSBLNmDdcrjXrwuKJUmICK
noN/QyTJlehyQEfIrNQACDKVr3laocDFPoX23ntvmwoS0Qvw0hzp/PPPh+0V
wIg2M2kroa21GRFpKqTUQkKKnQNt6NF6J3SxkvtB+Rsgn8chU8uaxjsul3o8
Lq/U4erMsA16cp/WYOeGWty7h1+NFdLThppQ1QlLvVRv/KuRREOiOeAOpiuI
eyp1ZpAqXNOnT4eBw8y49Q455BDcoXRnCuVjgfaTJk1iPOKGWGcODPJuloiv
qXqgx4M/tShhsFvB58yC2vbHlAwjvD7Fr7akJoWaRiLILC5VwxQO6zXq4kYX
N7q40cWNd4sbkRR0VzvrRhbU85EphCgUKUbcovlzTW6FxZE5xBjv06cPXcLC
/zD5wpouGOjA1YzKHZo6dSqvH26HyXGwhAzrfLMSDorQjh073njjDfqD2aw4
BJ7kMr0xmOekdUEMm2wuErrABItfcjF/+lqlpyoRHAmZWmahWU4ye55vw77i
LUUuXMbjMkgkN4wKA0fXpWuBMe5YLijDAwYMwNExceJENE+szpBMHtLPY6WJ
B7qwrMfXbgJ2zJYkJQlMsxxMY9x6llgxAILqsdlK6re5A1hkozxDLVfUdsqX
lU7Iyo4x2aWla59Mbs6SBVbiBgMjNYsBWPEhgCyplenGgzQBTKEUN7Td6Oy3
qjY9C0UG6SYdu5JV8uCDDwZJghsweVZSDJbJkyczjLbthp4fU+lW1OzWRU1b
AMQ8wxM6NK+457Kap7285M5hu+m64ZrMg+Xz2juCDNcsqXHwSxoyesUIKQMM
hQ1itNr4hTUo3GWtFhKUpVPcQJZj+xPiDOAAQbFzgdnMIQ7S/fffHySJNsIk
5NHEYUeOHInLKLOKEzWfCZa2uV9kjYdGYMUN8kkyjEAHWei7du1SCaG0dufO
nZzJbzvaippDrg8kIq96wMsGUkw35Uzug28kAwBA2oshm6gHEzjjI4BiZxKy
FQ81uSEVj4AwaRvRNKgipL1P6KijjsJkhhthSFjRetgbajNAklJQKkxEYUj6
bPP5DEODG5a+YiAjyytL5SzBffitdVAAVvmJS6Fp3vyckjR0GPPVBRDPuArr
6oRv2yikwq4cmTjd5pYrXA5JHUYNxMW9w9KPJKIC4aJpHSzCWrgd5XDw4MFA
erRBUpsCKayJpt9E30Ba9fqqJOSMTgMzYdqMjo6A7MLawWNJ05idM6trD9W8
mlmdvLVpJyaXtqVzhl/1iHbMtt4Y+0ZmQrq40cWNLm50cePd4oYBQfOFqJ+i
hArusnSFrr/EH5Egm4PltiBA0ADNrXfv3gBIJtB0LwaZ6UXfHjJkCE2upk2b
BmuFq7EO8hRxw9ZemgwvvPACZSyvv/465XhGWGK5UOfy8ssvY79EctXGcWIE
SRCl6OqYHhosFItRBU8YwriSjYItcLu/9iILMgAIOQkggFd0IAwsE4+wY5iW
Dm0BQrEjuD6cw0xmcjRYDioU++74SriVchmcbLaS3cvzOEwJASQHYBSFOZTy
WemGB0MLAs40v9GAggQLBaBgAPwAIWXTMKi6NDKI30MJ0vWh4MvJsP28mtNl
gNK8L50eC5vmYGrsC5otRcQNbQ21+g5J1P+wunQmxJQAQHINI4l9bREW+aJh
crrNRDb5NPlYGCz5Roi/oSIDNMSDfIrGoAaaQVIONKYWN43ZecdFNZ7lVOjx
8K3n1pRU7buFNULdmnJOqTFf48WWDm1sCMXDLEFW/5DyQuYD/g2kO4KGIJDU
ETKVNKskeQj9+vUjBTfj1JsKJg+u5A4L4WHENloND83jbBxqG41oHWgXAQeq
8ESJ/ASXqU2Bontwh6gBCA7mP8BorJabB2QYgMnhtAHEdcx9TEC1iahJGuaL
5ldgBTFNUimALDoCba6kCEP5CUIBdISieDCTQWNm0iaW+Ejp1KHr8tZKqBAU
/dEo1V6C9kUHN4QLF/1lpfuEngpjhbIQTE4JLVW0HAgdK2vfDNJBkUewRW/G
0qbPhk7CjuxE7f1Wu9CvqE/AeKKruSddSZVEfY+Lm86HSpnBYmhNsx8EcpeF
j6hrvgiQHn2DnN58C/0bZCudc845TKP38c7OKpMDFLudVk6qbzD+9o38k6qX
7yjaCwVMlz+3K+ny2j6l1YWWVeK3bWxXuOviRhc3urjRxY13ixvyEkYuiUD8
M5ozwQL9G22hh+mRBAhIBiMfDNMvZjhTGoOFFmpheBtKMJPR9IhVxbpx2yaG
EQHEOApEACDtvo0hTsYwoQ5ux44d4IYIEMAh/kKUNpRXwPmAXRAyxNzuugIC
6OjAR0Exvn0C+RXISTjGzhhu+Mg0Etm0WIyT5rltrDtF0gMEAAFk8n1JLiJK
BYEkYUvsu1GjRhH+i1mNkFrOdn2lPBeJNuqap/OncClfTVe//JOTGtptmI9/
al9Q3U98Fpy8tjb4vay2Cl9b26Evq5UjRihW1dKzZU2/QTOa5F7TRC2sQOqX
79agGCbvcEdosGC2Y7mbMNlhwnjP1pbROgClzzrrLHEDSA9KEGGZOHEikE5B
Vkjc0CIjVrXqnXX0IYZtG3n/ZNBHL4QBkRYuREJebVGtglnakH9yujRG5ARh
fPk7qTUGMcDbXQDCYJwxfOminKUWfSPyQj1Xu80QbJ8n2kKNesB+lYLJcHs+
H/MWbieVlH41ocw8r5YBIKS6Q0kZxS8qelh/mpOkW2RISjcA4t4EOYN6QNJ1
iLY8IT02AUNzM1AzjFpurR2B9IKCnIAnIBPo4GJ1GxwLOi0RYeHavnymzWRs
zH8YjLB75seaWazpsCXzFtYl2BfIpYgpImnOJ2B1Vd2n1dphm/kY+3PZXVP7
e1NFa56nQcw2Qoq2wDUBOtQbd6TCEUo7UFcrRaMjFVOXhT5Y/9SmMpoU2sH5
ei3ADX5oD8CVTYI6IkxwtnUCXFr3e1rRNC3XT8iv8le0YjJFQ1kWybEJSgDg
+SgshUcccQTYMnXqVKReJa11hK5qupSAaXkF4UVtypCoSNKR2qFQ+2mW13TZ
3dG19YrozNFTjWy6WLQeD6Gpixtd3OjiRhc33i1utElB4IbmsK16Tby0UMU+
V5FinAnuz0ibjtD06dNh6QEDBmCw7L///gStYrCQt5PhofhlepntYcOGTSyU
4QFENNrC6CBikoeCVERC3Z7JHlzaUB01I4/VZuN5I6s5bM1h566OwrQtW7YI
quakmXpKOCYgw6+CLdgdJKyGMEk4zkkk1whLjkUw3iiYw4tHbOGoGTNmwIGx
9eDSww8/nLkdM2YMWvExxxzDNZlMBLA1BLSgCVphvFxbtp7nTzJbrm9TQ3XR
aOBrzshvJhPaVcxq/Y5uxmKCkU25tB2D5jaP6LBBdIwgRMZVW4Od55rvis3V
AUHGEZAgu1uIRWr1SnSuoYOWvWXyLSjLyjFdI1gEaWYOtsdOwS2zpjZJM7BC
EFYLAsHJkLRioDZICs1rWnl0WC6ZMcVf+OVl9YoQUqGQB7RZUcviLi+7YuFW
0qkiaRNpxZtIAHSQzqHpbfKDBaHIZuTX6KdNfjB4Mzxajw4fPtw9rUiA7N27
N8keRoTD7Uz78EqTJk3iW+e5SGj0DTSKqBb0w6G1xb2VGFtO2g5UKOjIM3+g
9gOn/zmZsVxDugVJs2oOtjYSN1DA9G/g0Hiw7GnLNZlPsIJ4ruDGJLu7U6SS
SRZ58kNwmyY8oXwmsjUCFLiRA8JsnJclj6bZQ4YMwZqeMGECmKxrYlnTZw92
VTdwlwRqY7GsbaNhSk8OOlrxrK5d9SyFs12Pm9nlr3IgohGWUKlgbPL2ilqz
5qLmsHVTtLa2Fyv+muqqLg4yb6cfEuFqFaeOFdxbLa05HgJXZJ8OPCeddBIZ
NfkQbrdE/gadRUNBcjfg4xH0Obmi7GNlW3Wh+9K6VXcEE85XAVhWk/kX1a5E
LRT7cRmtWs3ypiMHIKOj2+1xhYIlde9avSsZmNoORBNUKo67uNHFjS5udHHj
3eJG+BwxwbLG8IdvCdiFghuckZHC25auYOBHljFYIt2o9xkAQwrDWyFOJpi1
b/kTfJt5oCdSLES78nImk8ww8iy3T9L6aEtFDJsCDiaaxoay9ZbJqFyDH4NG
gho+nBEu2iniDIlbD5S+x5a9tNe3YVwMPbJhvbllKW1EWHTCctlYt6O9ofQ/
D02bNs2dN7H4+vXrx9weVyl/JcvOcvJ8ZRjsytrdKwfIuE3SjKblDJBC4y+s
KjelCsp1VJpQUheyWYe1+bkMmNKHgP8EZRhh0Z4yOrm8Zm0tbgrbzYT0T0jE
ohqiXdgkUir4auzmm+kxmF/7b4g8C2u41jzJFbUD2JJa1RJxI9g6evRowMFU
3nHjxpH3xc4poax9rJv5EDzUxgLGuzG4uDm2Eultxp6cE9+XPxnjXlubkyyt
Udc1teHh8tqdTJB0KVlYdk4JLW7K6HhWvpqZw7y+MxPrxi2iWARVOUKmZBOw
C+nr21B3UxVSrBSLLCDUdgHNncEE4q0h8DnkPrNZJQFwzbQzzjgD/o8s4EQN
dDDbESXEn24bqAcO+56GbHiIYyQqCkOyuExvBp39UFGsONtW6eFKnmGi7i2b
x7EFg9kvCHtOejGDiXaheOaYmcwBE2gOvIW0wS63lzKjAx0gX5npiqpGhSzV
siE9pSNHjqTR63nnnWf2hc06WO/aZoB2gwej3AchcKGnIhfIFVyf3+pFUd/Q
6Sry2KgTDrymbvzUuuCQIDudtsLSEUbUz6B3YllTjeva2uowOnnMU9Xn4xIs
FsGBdM+bV5r/KJLMJBFYVGgWvsy8/nzq2qL7kb8UxYO83/xQX5CZ5PonSUch
Nor7tO0fwgyoJumgQENYUioHTYY3ospT1ja7+qplmfVhFbBOFT4oOcC0ZNE/
zAhzPW7hAEgXN7q40cWNLm68W9yww7bNrDaXDf5QTeFbTBUSk+AN9zoPm2Gw
t+31oMgmt42tRIgw0KHBghc6mjbhgFmzZvGyucy2rhgskQV+TvVKiB5fVogo
ywIIzxUBKFujGM1rtLN2zxflVzb1eqy2ATQuYw2L4GDaZyQOVwYbU2KSWDxo
jDtTajkbk7y17CZDWJlX21p2z0SWkcSIFV85qjKJo7GsexfKdBFPGTVqFHgb
9ia5Mbwkbmjv26zDA5ufWw0nArTpar6mMVa4C+iwbyH9QDjIxUZY7JnsSGwY
iIPFMIpavQlIqvTzmy2BWncHDhMrxVbVwgoHic3CBR3ulIU1E2x+szcT1yyo
WyPZdmPYsGEExLMU3jz14L9a9f7HLh1A4mI4lty8WC4kJCyu/SsMTLcv4nMX
N7vB2hzA0SL4bWEawzb8dHltctJGRsQ9o+0A4IUXXmhHAgGEabcIMZ9SM42n
t1Hs8KR8Yi+7OytZmWVCKcxvF0oWo1CYXAFkKWf71FCkhvnPHDLtmVu2Udh3
333ZbChWOW8dNsOtcfzxx4PbuZgE1EwpbHzffffl/qg39sSwbcg9zUaxHeWf
Kic0+ghZj2bQVo+NjkpxQ5CxrNWYb24utOImMh+DaTRtwxi3KziKCj+5v2xd
bRkd2o61b2Rxh7IkkUqa1Q19g73zQpk3ACTQcXahXMzcCg6mWCjjLYAYdFaV
MruVffFwnnM90AGvIhTEeds81bCHqbOyDVoKHdTRTKyZRSVoC0XFDYRlbi10
Xd4kabv+avILQTpPDIAS3ESO2iTt+c3uA0Y2I6ck0kR5ABwy7e6y99y8Xv/v
2vd9feGgjmaYZ555prhtaBuJVl8i6aJVqJTQec0+dxkwF5jvqpqE+xcPMN9U
rcaXNWyt72j3jqMhwZbvCIYzWsAqa/eCSl3c6OJGFzf+MbjxX1Z8OLhx1cWn
v6dwIxdYcgVvmB5JNyr2zsCtQdVba6eocGZa4G2b8rEJUSgmP/OWAbBhZVga
uOjVqxdqdmYby50XD+UYgyV/wmCJ4g3/5LnEgk3aRKiRO22QR2tr8RxbaWK/
L4Tai70m4xccRKSObZvsAShI6h4xnA0UkABGWh0xFGbSXsFmoNmMK2PjVnT8
wDmjUYZER3vE0ozpB1xkDilgifFCzCWTDIDgPgrlqyn+mhKGdZDx1sqQJUSS
vAhfOX9C3u0raJKSsfW2BZnNOqydac+DJDCSwUqzPenOQYMOjXF1eyOzKyqt
rCVy4oa0tPYxXr1b0Zz2gnGNuXXjkmAI2YmZSbIFYoaAG2OOHRDQ+OvVv7Fw
7kXMdriaRIIpU6ZgAiwvG2ax1PJ0FX7GrxsHKDPAsaR2StTiWNzUnvBNdeDY
nWxt7b1mmtzK2gBBaDL8aoDGYegLyrfgYEFt3xHcYNiZE/aXIU9YV2ebeEAv
SnGjLdsMEW7DSmVysjZh8rdeBdbiPAuYnTp1Kub5wIED4fboHrhD83WYoowT
NeOYY44BZI499lgijHnHsBlPEZ30P5iSoWLwUGkqjkKC/BpI1YcpepjmITh4
hkI20mU9oGIu0g2kkF8K5Oo7VZcTJXQ14+IIWWpnw5/AhTtPUbKX+xOrzfzD
gXalO+yww1DhcnBCJXJKM4ewfeQIlNhSCVgD5ayqA0AodFUXsgbBv+pZtXGH
OZAACB6VkFW35o0Y4bX4Lme4WAcp3Uevrbu1wqgdAVl9EctrLRuA4NIpkpjd
wRldH55fUPv2XFp3WLZfkH32Jk6cyMQOGjSIxN0rT9svuPH6oj2zGsLSOprE
DYKbEE9fWDuNL6ydkVrcU94X1n1119TWhTpILykN5AmeKuaXVRIKvLMR247U
lN2D3a1f2pi15YTOSRc3urjRxY1/MG48O/u3gxtb5hzxXsONcCzynq+pYW6a
k8o8kAJ708QYsb27bHUKiS1ck/sgtjo6NtdtmzISdlqnMojILA7qQAe2TCYH
VTwqNw5q95kN7AR84EBCwKRpmbGJcLmniUli2BEIJtc8Vlsu2ytAw6d11NhG
gDNPPfXUtythSrSl+lo9ZoJZRmd7sTyXYWsMtu04gJSgBKl0O3fuZIfcPAi8
og4oFM4BS4MPNCvo27evcUCbMeJWip4JX+U7GnLqKNjRp4EHw45h2BdWfPgn
tj6hOMWdUKwm01Oh64P7aPDalMyCOG/os0xJvbL205bbW58AWMELmkuJ4LSR
hQ7VXVGySH/OnDnE7y4pncD5J2UpQWA4MKvYwQcffMRh/f9m9a8FN1ZcOCnM
DEpnmcMHEh7GFuDF2WHKTCodBWagLfnb+reLcvp5dIBocRgQ73gj40Erazmh
4LCiaapmqEVfCs8yAr6wtoPW4ZN77u6gQ1UgycH23YZoXa87sjTNMsUPFsrS
iZ3OtssIFAiT4eF6inlOHHz//fdH8YjNSBgx44RbMhUEzfNRsBxPOumk2bNn
w115rihhrgUDs1IMb23Ifuxt8dpj76TgBpoDTTkosyWyzL4JoZxBkCPRiHZU
gh2Fnn/+eWCHXZkgfbY5FmfoH/LVulPt1rplHrWx95et69A3XnnlFTqm2tY1
XwflJDwJt59xxhmga/gZAMlE4Rc64ogjqBnMcolXLYs4KKHDxyRVE0fJSFG3
FCXgQNtuoHKgdYAJ5oteUbdgW1HzNnNZh6PMxokZAM+9ue6Cva7Z9lr9AU5W
SVhUG9HMq6148BCCV0vrFtVtoqa30nfKxctKn6L5pdgWL+gFlfCIhoIbQDFM
e9HoHiPlT1b/Th4U/gRSMu34QIIzeAMury0cnRA9k+RecplNy03vXFb7K66o
BcWr6qYJS2ornhXVIWxAViewytXqpvWoShfXkLjSZpO2wWt/ZSYtB7nDLzlu
bLx6cRc3urjxy4kbT0z/reDGcyuHvAdxAzOEtEZxw/aAEDEF5BE204eAEo79
2xFq3FTbaOdXABGmSih8CwPEZgQlNM+BjlDU7O9dd+L/vOz9L9z586oiP83x
xx9/+umnozuFzQAuNqA32wrLBQEMFIAb7iMfAhMsixMGjZ5gYYVEiYCDnccQ
5Ndee+0HhXbt2uX2T/YuNv/TseU8T3/ppZcAHNqJhDLJNkLH98KeU6EXK+Vi
XoTcs4fKdlGIRnhbdxBcHehwe1ko84a+HUYy7xeyPbViC/4bZMELYclJxA3n
Q9tRBLjYWDbSDeWMHn5APtcDDhvqNlsho2CwzY3NDlBmkHZo11pA4sb82oWb
Ag2LaPyhdWSMZE3tatWGaLkyt5pTCenO3BLsGzduHDMZRh04cOD/uez9wY2r
558TPgxz2rnOjVQMWZola+hEz4mh1QW1KZlJoVhY1PIg1CuaZu9MxaqmU2Jr
qVk0d1nZpdfn6vHgzJrawtFHGFgRUQ2+mF+aoSoyZBq0FAkyn6FjKX+w7Ija
5mBbxUlQj+g/Z2zxkTWFg3A7M5lJwzwfMWIEdYW9K4Xzv3bpwfku/2Ptv3lg
7eS1ZdM3MqhPPPHE2I+UH7ZJHXbzs98Oo7VC1kq3SC4iGRnkV6aO50V8R7sV
IeMBBxqWuhtU9I0fF3rzzTfBDdqfhpBu3La5CX+N5kAb9pdffhkAodFQKD9R
BQLKqBYEPWy1ypk8RZcv0pfPzeI4duxYcKNv3764jMLnpOkOGzaMhH9tQDI3
cC+AJDlAfwD/zTkHTEwUb+tngQsvNrsYhxgOND0V3FylVDe7+qoO0strz3Od
FUZ4VRtcCqW8WpgfwMlN9EOypK6se7/qRVQ6jCOb7x19GMUjjIfGGy7FRR9G
nT26T5jzPy79COVsJ598MpAyZswY0mbIFA3pMWjrYRF2gMLkeeOwnM8F4Iah
1SVNCx01EHUYnaimp+JNdQCGcZc0W77y1kuaHiYdjg7BuYW4X2bcOOecc56Z
d4DQ0cWNLm788uDG49M+Hc78ygW93pu4cXvdU8OSK0q/qf4239JqDqSMY/In
YeCcxN6x+ntTQ1oupqTCLZkTvlHMc7eJZHfUL3zhC5RuPX/JXvlA/33Nr29a
cArfKEpg0AO1PNogmvOddX9GI7P3NLs6IpL5E/6NSCKCbMlbsAX3gulYGSf2
gvX7Bk2AhVDOsN1kTJU3CgVMbM3R+kmwdN56660fFnr11Vftk+buMIDbtrrj
pAGpduMYd71060mmNMIIRwVLcWv079+fWCG7e4TcrSamOixh73qq2CAAIfJr
FZsBU5oMh9rMT3D7lrKfJqTV482Nw3Jzy1huachCfp+ldm0Vm94JAyWw/bLa
LgxHAX+9su4vmWMk0bALFtYNZc8X68KgPNHiL6yVWCjmOWNEB5P/fPlv9ERS
ph4HpGRWhxXKioZRwwb0rSBfWclQ6YKmJ8bcug39gtr4y3jKmtoorE3l0mMD
7q2svRCX15bRxKTADSMj4gY/v7I2pjbAtLYhrllRKuMojjNHzqJXfV8b6p5E
IaN1ekq/shshHQYWbXNnpaeuNgK42O+s6bkY9stnInE6CyXby+633354SsP2
z128J9Cxbm5P7u7EiRPdeCifDOTJTWBa48h6Gu+uGyurQkTwO1ZwEz7tmyGQ
tq4Pe/sARBFq5HfHjh3fLxSNwv5FZobk5mgX0TSAl0ANqoueFhuc5gC8spXQ
1+sO109XMgqcH/Jp8rLISOYHJqdaNkRn19CAAQMAEPrGhyKeNl1B/C00i0je
UDbhsks57X3MzUDu2vg7n3tz7Y8qIOSvHcnkqit2+2lL5+CWDAbudZGVIgIu
lwo7IobcIZX5q4kfCEVb9SlI+r4crKr7wEaQyQSYPHkyrs7gBjx57tC9w5D/
adkHo1SgXdBbPhR1jl9lGMzVNXULvDaRVSXBjAhTx9WddPauaErVILWjtc1u
Tfo8zejQv2SwVcEXeK04sDeLXhE9J5DjyVN+JXAj2gXQ8V/XfCDQ0cWNLm78
y+LG1879eLjx0VlffM/iRrvjj0k+MIA5jeFhbPbo6gZZ2tou0qVs3NeWXVAD
BZJYTabn4eG6yVH4hLkKdNAuKQxvczB64j170eeBjusX9PRcogoj0EEKWX6L
Vrahdghvg4w2CmCQj9c+5OR3haxQ0xYz+ry16eUl3IlRNkNG/GNBcIChZDd4
jIsXX3yRXaJerxScIdjq5rPaIO3mVsCdNxdkzFzNsEGAMAl68nHHHYdSnQnE
d3RopcGDB2PlhccQ0nwvPvo1tZnw2lKRDVOZlNV6GxB/OwNYIHln7SrZdg8w
LmP5vFmg4Ia1b+YD5BiwQp9vaVnt+G2k5qpKuAIY4drSEZHCEGRhea2Di1CA
ElbY6ehYXUvsI8uUWAY3SOUizH3EYf3/YsWvhxVXndezlRi4ceyxxxLsi52I
o4msZuw4hiom6EPoyOCy2M0yELdN0efA+65tilB4WU0Y3RRtXEn3CBM4r7Y1
zn2Yf7o0EPJ2rryhUW/DMaYykg5N2w1rNpEaY7JZ6dySAEGgIjX0cO2zZ+c9
YrvkUVs8Zdqk26rawY9rMkgUj/A2y2WgA5DPmRfm7g10XDf/bByqYX6+6dSp
U8lkyHQBgJtrN1SCm6SJdiSWqzlY9BpSA3EvNnNUkM0cc5B7dtSu2icQCIWM
w0bSOxyk0T3YN4r8EOAC0osiJuc+HT3bdeao3uQLsihkDlEzvvCFL9DWtX//
/nhKjzzySBbH4C0Ld96FYecbmWywpu6JcGPdlC0HXK99TbUaRXB+ZatobQok
J3CxoGEeSEDGjkA8S03G7qALdqNltbWIOe2RU9MkxI0bSmfUkIuyIU4L6y5r
WrszgeEl/KLBDdrhDho0KLM3Z9S+YcI/XfnxKBsZAwicP+E7kg9X1a23Lf1z
BTecqt+AlHJeM9JtRge3stvGytoeEH1gVdmYyRBth1KxrO5ype9CzW1+bfuz
qla/XtZ0OzH7pVXwGLZ6zq8WbpxxxhlCx9Xnj+riRhc3/vlx45mZnwgHPrlg
wHsZNyzx1hm+qdkN0OxQ+JYNU0LhfLdQRMrCwMiIeVM5tnTLtEOzjGAtCtO+
UrZl4RG5mGHHEiGwRdVbKGyPeb59fg/g/8/L3v/ETXPc/vuEE04AcKZPn86r
WYVhj/H7ayOOrXUHJa0S+2+YJGZyaf7KPNxWt0BtTSGG7Q6YwQ1eLc+tXQl7
rCEMPTNXM287CwU6sFyef/55k8qMyGgDMsi25k4kgUzJy5QiieE3dq7ff//9
v1Bov/32o5txjD57UpHaFNWXbxQk5B1hJ4XRzl0IvgFZW3gZmnHdoakLZfic
wfoIXdWQtRto9bfUnWXs1UC+GXKn5oxkmVqpJo9Rz51zvTWblsxY/QGb5aQg
ps/BplikycX0YCYPO+ywIwccTE3KZRefRekKuQF00g7FQkRsMwBQ6+ra5uuy
hkxjW1B79xnjWNp0A2Mk+UA2ENBDYiTaxiNaFqZyIe8ra6XJ4t22iRT/l9Sm
XotqY4HFtb2zlumquhdknhU55VN+ue6yJG7oqjLEqTeDPaZD7Srpwmevb/ct
6qiZ+nLdVdn2F2y4huXOr/K56R0d9sYqP+igg2D7oUOH7lzaB+jYdhn2ypSY
lm61TFZwXhARuL/u2WoBLOkZuEn1IZiOwkFe0+3hEFL752yoTcgNlUYBYx7y
LrzsbU3DQKOobXCW/SNefPFF9I3t27dzTdu3x3YfQjEH7CEF6FmECEhubrZ7
Yx6OOeYYNLcACFWEQWBcRrHKSYMJIyFrhs7xkV5TiaUz4gy8tP03zEs32t7R
c5VQLK1HuUaHg44+GtPRpFR9A7Ay/cNq2Tbd2owCJBHtyA6Zl7+T1pRNY13o
yegQuJCgnMSrMGPGDFxngQWWsH79+l13Rs+a9aNFn8KZSYOpUHgSd3SUEMZm
Ur2opevV7JFVpWIXoTZ1XHDTD+nB0mZTqo4g9dImh7zDHdES9zHUay76opr6
Hv2KA2A5tKqpHdb5/CuKG1kLfrJuEClh62cP7eJGFzf+eXBj50U9kZTbZwx8
j+PGttI4Fy+HCZNyPl8QJ3nInEwCB3j+yYnCpQ/PW88lt6NCmxGkBXR33dVI
r4K7z+fnfGsTmQId9MSLzR5ZmDZt2lPz++cj5n8PLu6Jf9GfLd8Xz3bMUpS6
jB8R1gmjo8BytkcqZbQaF4IkxkVgx9Q4A8rAzvOVcjEva5lGrslvzdfiVno8
gr2khO3YsQOYeqzs6gJEMCRtKMdJ7ivxFIfdASD5cPDP2WefDdsHMcjFtQt6
FG/mKtegpkaiQQYCIkirAc0ABQjQlrxxQNWS3aG3lMb4oIT5Xdak5A7a6TzC
rDMqXJg9PR6GU5Fx80UNv2p6Y3eAG/aBN29K3DCisbT2/jVaGgkiIBLIZYv5
LEbA7IlHHRhmi51y8cwpFGbGLqbWMteQAJaTTDtBolvLVry2MjMGDQ7jRFIq
dXQgsFoTotzy2lpkdd3OlVcmB5VX06wge5YEWgTBFFAdHVpteRxIaG2O3b0o
WsH8MTPtkbr1mB5Cizetkby9knpC2MMMUqRMkdSoN8HDNVF7PEzlkmQKOiFO
AeSZZ55B8ciEE1gMJqB4HHLIIWF4fB1fveTn0PHYpQMwMI888kjCjoMHD2YJ
yIuD/FSkMkjFkLHlQfoQOKPrwDR7RbIN7KoA2JqDO2+pO0pQ2cdfn61EqieK
B5kYL1Wy6NXCurZE96uVQFfTU8muITWFg4wWaQ17YINn6siN+eIXv4jmljPs
WJ0V094++jlvr203WCLxRaBmbCh7OrTF1GwdRWYOTu98VgPxwIWRWZSBa0p/
dfUZcCOXyRgsZLm5hbc8XV+BwiIO4HJElPSQXFF6DK5odiLQ+6ckeqsIGh1g
gqW0DI1WRjLz3VN6kohemvt5XR+BXNIGjjvuOPbUy88Zm7ihV1ad6rranpde
JQxgWS3InVdJtySBY5QTU+5t4uqt1GEgb4gfY2XZaNtMEhBJB9HC2td9fu3S
E5VDXU6/qOrKrzpuxEJ5aMnxQMe2mb26uNHFjX863PjZkg/0eESnDO7iRj4r
omRB1ldLszuCDqigZoKZyuUxSVy03TOVSyY3jKjrgGflMnN77ngnhU8Qluee
e87ES6Zo5syZ2JKHH354eB5TPTbL+PHjb5s+AOh4+tLeuYBPmT+5Aws6WL6X
+VoGSS3rsxhHcldHDtyZRfy0fQTIA/hggJj/RtxWNw5xqO985zsACIEbHDtU
rMRmsXbGvsSm2z1RCTslt7KPB+ctvQmkgGCRVpTq6NJM2l577YXBkpnEhAkm
kxIZPkHobi7bOyLv15XNXuF8w6YsJVYzWf4fBGP2tOZMAjSJFKufdE3ubAJY
hJ25NeaVCedZN1ZaV5tbXlZ7nnd00EL3dgshgrNKqOhh/ILaDdTyGPiUQWU2
qAekTnDmyJ79Dn624mOxX6LDk3aYtYlgd+YW3Mg8i1odgSFzZR1POwzfxQhL
yCw1HRQAoPmu9j8RN6xQ03NihGVNrZShxg240FQxS9amXl7DwbK6y1Ww0b79
ZE2z3OOyCANYhtbBAIbYJD0V+gdIMyCMiNTYwc924qgu7hfACsUF5mZHBOD/
cDKGJ41T2PHNbNLrzjnsv6/pyeLbPn/fk0/s2Xsoy8TQStSBBkWBIEervLcp
oGoa4me7owGdRkxuNBcdLcXX189D9giPI5aN4kGaaERepYLp+kYlVYvghrms
hmgttQNdneT81a4dHOShsFYYHiBF5QhFK2MlHTJkCHZ6FlmYJAypnmnVmwuc
Tj9dVVYl0JWFxixMqRdkuswDcbnETr+ibL1EI0GrEvQm8XNLIfAMoAXp8UBG
FpSiLdg7gqMOo+KkvqF/A7QJb8BdJAWF7LrPLt4vzO7xiP7eoh5lI7NEIDt8
yCKVi/Ewz5o1i8VdZ7I9VK+opD8H9YAZ0Flq91F3jmsr+/SCciv7r7bdivST
8LJmwOrnIXkVzUFMMMdDtPEaDnSzBFseqDuzm5gdnmThC0/C5OHJjvxqk8Ta
XrXIFO5Hll3sFDqGtaBxX7N3s4Ue1tWai87Ts/4iYvkr8x/N4ZRTTkHB7l8p
x6vOOpzY+luLPjf5zNNOOOEEShSzFuD6oMdmKPOsY5PxaJTlwMQwXkTtqO1N
xMKnvkQOG7ghfmqmUdRPsyNe88mGgIJgAoKvh7atAOLg8doqWatEPSSP9tOA
WoFcvmMOuHPYDN9dZAF9I8DLYhoRYG3NpKGBZ/0ytGEDHwvqr68bGViAr+pl
71nlvc2Xg23aRkAGVlAhMJHabLG2zoifY3rgDDQxQ7XBlAPW5VCbDA/OLK0d
bHKAbIYrMIczP2R5RQ3D4A13nX7C0WGtLExzZ5wZ+M0sMW8xmZm3MCQJ59GK
uWHGZstldYOO7Pq2YEeFYXndD9pd1fRMKsvRqbhYvG1jNPo8BUkzz503k1VQ
RVY3+3qj9qyoW2GqeLh9w7yyH/2/GtwIMsw/46i/Xt1T4Pxvl/zWaWNHdHGj
ixu/ENy4c+oXw1RvLN6L0HYXN6zw0umXA3iSNpgY2ohwpAyb/c6yMRmk8wf+
uaM2/Myduc9DdUujnFSBt2QMlgjba7Cjrj9Qu4Pm6XbJA3+im0UbxGcVHdts
UizNs04Y/J+Xf4heTFNOOnrUqFEjR44krTrQQXJpvgifzxJd+yXqzWNUGDLM
jBnUbU6+rUs0uAxEWkNnkPrh2mJdUDJjHBTFgrMZqXDBnFhXuK12mxdJ7B9i
lWKusX6WX+WvMEmEwpQYVPHgBiZMYHZiobDZ1bX9eCSOe2qq04oc/NQvAYSa
lq8xu7luCWFk1u5A5lKuLn1B2fsATDbCa4aAOwm6+0bbI4JXo9gTMVlWdiwK
XV93FcwAsB3M9F5aO/8EN+zuQhPR8BJp+YEFNmVbf9FovECBFP6UGYOjYqHg
TTX/IcIFj5kmbR6L3eBppajFYWkeQm3HUVPQV5bGhm0HkpW1E5EeUeV92bJl
uyOA0WqeRaYoqSOGg/nV8iYNnmG4O21uJU8+Wnc3s+ozrOgW8xjRgQ4jCy4l
JgIZnUeU7iu7DLRJ0SHXRzCBpA5MYCDl+eefp8FvFkrcqmZHbN++HcM/QpoX
xA117LHHIgJto7BJY770H5b0fOgAyCVn9+wCgEM1FwMgkQs+bmabMYtj1KGQ
CW+koKMF65a6xYk5TohJ6/ZBgkKZAcuH0V6IOCDmql5OaXsHLs4d9IWa1Q+U
5Q5qd3w+02+sPtYJnKcg7PhIQ3379kVbO6ohVtsZM2aEhZAy/TkyvNXT6+pG
jXbC2VT7fdnOy5RCBYeaeh16oVXN9oK6ULh4Y90YQmS2V4MAsrp2BwU94HMB
JJIIFm2o+/5cWbdiWVA3I2M7NnZko1NomApQvWJSj9f9T5Z/ctKkSXiBooTw
p0wUKlx+iCpL/AIfBaJ9XelvRh6UgQaIaewoosloDYigbxgQMe/Lah1QBQeI
uej8iXoW9C49HswPVfaoKJxZ3Gw3CVyY/kEOmF2MQjn+V4kbkYhxo4f+aNGn
8rn/atX7l00Z1sWNLm78g3HjlUs/05NbeMkRXdwQN1pt3Pg71EZY1Hhh4AgC
17SucqcCtg+fcMPHa4+LkEa9cmRgBQqYEAXYtWvXK4Uovw0FSQCQPD0P4h3P
OOMMDMwojWRTR/fGLB01/JjXFn6eRmFrJh150kknRVJsroI2HsWSuWULJwpm
GdKmkjBJnSZjM54CmBBd4mWt+V1f23pTI0bBLCYG+0EAj/fXHa63NO1MsVM2
Nd35gKlttdGr4dd8ESbQ6OdX6nZRmUBQbkvd0Uk0E1KinfL6gwcPpkdHZIQA
AR25QzHYwVVSEXipiLP7F/C5LTqTsGtubzpyGMc3nmJk5Ja6IYKBFSOMRl1v
qtva3lt32TN6ni/CDY0m0MeG40W130WkADExgSSPQ2OPfCHvsXwpdCIFiCyg
TMik4wfAQtPOObsN8ROnC/vRo4O8ShR+MzAhHR231C3J2jqLu+sGEG1arHVw
eiGMp5hnDigtrCQAmh9u40ET1w215IdMUZ7CfeijTu8ggybEdGbOnEluT6aI
R+QaOJwCTxMYEBxdc3oqBBB7T1k/briNEglMWhhYvSUMb8lnR/OfXHZzJVSR
5557Dtx46aWXwA33Wc59Mki+hY3C8hEJyOLuC0UcYq1/ZeaepHbcfcHhBNdC
I0eO5CCWKXpLJorPZ0Q1IsxXvqUhllSM1pBv7ZIa6OjIQ8hMZg7RE56qO7AE
OhABWxhZ4K8TyYdSCEOPIGO1ZK1bR+wjhBQjs5Fcvbh868wbLBFBQN848MAD
gd+cGV7p7LPPxsNmVyjzN6w00VMht7clLXoqoNtqc7lbK+mNsSdYfmXmudDB
nwId4gZcd1/dhgPNJ0QuNzqMIryoNuq0BVau0YcAbmQFwXeRSYCRok4EQ75+
wT5hnqcu2T8QcfTRR+MOpf9waOrUqZj8i8qWi6uaPp/KHZkkobyCKfQWE4XB
7KjG2Mx4d9rVjkhdW93sqGJOheqBZSltQWsHkOoONXU8r0DTALZ0Ie8L7SJw
gecn6hZu4dzhXz1uhB678CCg49E5B3Zxo4sbf3/cmHTKcUT25005oYsbLW5Y
PLih6eYHA5umaNJ4u0GqSYkYIIQgIWBHs9qaLCOzsn3AxHbiMIBKaS4GJb7z
ne/gXbFrUEyVjIGnRKwwWM455xygIOrlAZVwegcltsw5Auhg4chl6Jn5k7sA
w2PhbewFO6ZuKDul3lj2A0LdtcAq3xTRvr929jCn2gATU2q4WacNc2Kwps28
hdyW19AkWVWU8fIhgq7MJDnnbPFAoVzmzYRzZVNzA26ZMGGC++WhnGcq8AUF
NwKqcE4YVZbmxU2ijsB6Tzty4KAgjbzNr7Ys7pbavdzEuYiSDhPuc3nZ341K
txsq6V/iG1kpKaRfV4pnGS1Fam3mkvGIiBXKfORlVqEwAJGR4AbGSOxZqp++
v+QLlj4xXZkcSt7OPfdcu0XpMOFZWdGAlAAIYntd2XWd+LKdoGhm0hb3GVF1
BgTVq2v3VwNJBkQspzVoa3KswZc2E1W6qBLfemYlt50iFy4UESNmlD+ZimCe
ntWj5IrTwdLcRXHD1rjCgj7PjgrN3Qs9ck+Y3G0IkKDQ5tIeJ5RZ1ZXqYm0H
ThsH5QK+RSYQv1Y+NyLQt29f0CNIEq1jyYSDSSgNG0w+8zSW1KwgHIQrKJoO
BMHACmmmgkcYbTfvzq418r/p0BZTkFQJn2Q2mFIR+NHSUnhr2UOTa9qUWhwg
t9StAfJ1TGlgcoKioMT27dvdkIUzu3btwh0UsGJs+bKgXMYGR1144YWEs2Ow
4+jIRHEmiMp6Goq48ZoqA2YgrK8ti625EFJ0WprVqc9Tl5G56EAHbhPwdl3d
TtpuYyZCkE2KT56ZAcxFLaO0CFQk10IP1IycJPfexTQqK46dIAa592ecevL/
s7onoL9i+hj/RLQ68EKWSxZo7pzH8WoCiM6ErM6Iba5Ry9LRYfczphf4FRN4
KaPeJqvb9WhN3XBN7cKUe3Ni9XlmJPpA3F/ePaNVMyCzR3KAmhHhUid57+BG
aNV5I8kK+/dLP37a6CFd3Ojixt+BG3fP7BdW+Q8rfitLbRc3OnBDBU8DIbof
fgnDf9RmQoh5hFfbAaEWW1rrBpTIrazO0GHCNW1XCgThgdrTzwhLfu6jGUwO
sF+o7wCdMn6+zowZMzA9KH8DPcgNi2ESQ5Ucnv+8/EOzz+xxdAAp4QosVgs0
wo0dRXAZDN/96rodALUGoIdFTPC22vINpWEmQmGfn+AeyWyZOnwXba1xB0W4
rC/TvYC45Rt1lNOK5/T0oK0H4zfEnFvBfmF43DtDhgyh5C1mHTISUy5YSl1P
OMfuOlpqvJ3gYI8OXR/2byFcgv1uzMWcLr8yL3tPpfzVREodHUC6Ef88qyNx
1HAMLhcDmmZJ2ZuCOEgwAf+YYZSAJ0vJz1Z8LHyy6dLjTzvtNIJN+avtSoxI
2m2Dl11X9h0grGNOGsPIu/gWXIyrB84xIGtsaE3t7+rNuT+Iqg+Hi4FHupK6
Va7hGBBAlGg3ewLc7P5xaSWzQ62QjcFiZNZJpv4xZA7nvXXzaKvjTXcUT1oH
hYZ5q2BAevy8oXa6jg6ceOonWK9KLmkMQBNuMcvtGUBGy0fJTMISUTywRvv0
6bN/oWDIoEGDRgwZ+NPFnwxLRAtdPu1ExGRIpcgLEfnMGNwerjaHnBdU7qiD
hlxSOdBoRU/Ad5RBom+4IULk2mROtAKL/syYzTHyjhsBf6OuQuYkegW4Ebhg
Zqh6C+VP+KUfrPt6u0yHqQixRWrItg10DC40fvz4k046Cd0jYgILrax9cW2e
Sb4BKY5Y5WR34OcxSG2oEW4nJ4SArL5fmy3o+UGg8ghG652NemdCOhwvQIfJ
8C7K4jxSFqHAis+HBhsDFLhD+/fvP2LEiDUTe/Ym/rOVH4kK6vaOUUIog41+
Am6YI3FN7Y8qA6gvrazNkNUfWt3MkLTuIL2g5tA6A+okV9Rt5lbV1me2KYs+
wDclmQS6sJKpHWggRngtZ8MzA2hwflWzLbUbNLwHcSN01unj317+8+0jV5/R
v4sbXdzowI1/t+ijPR1dLj68ixt/K25cX0lNu03Ms67krkoY49aDm8Gll+Oh
2pDfkjEdHeSghuhlgf3SEal5rHQUp5hLMweBamFHeMkPie1GGJGyMBXGe6aO
CEuAAiW8d+/eWPHHHntslPPn5+9PkOWW8w6NCQOkhDfIDYvuijWXW6F4O9qH
ahPRMIBKqX0k1MlbpwTzGQjlNV944QXaikbMsfjypzYNDOOIecP7ETJLSusA
WAvl9ali27lzJ24NDcZA6/ZC+Vh8PrM9w6KY57FeCaMEOpARNu/G4oukYM6H
c3jNlslFEmVBoQYujFbf3uyDwIHqt31gwgBAaxgAJrm5bi9LcAoCQAhy4dAw
JKGDRbxaV3aMgtDGaaQZmjRpEmEUS05ysO7cnta1//eqD54+/qT86eijj8bj
EQvFnvlEbyOwLhMmd+neMf/TcDCyeUXdIPuqsiu3qWhcb7G/fULclA3IBTcs
e/fmWBOU5oUySDwVbgk3t+xVTU0f0KR7ZGltfLSsdkEXUvSctEFbfVbG2XXa
3Fva0ZDJYDmbhCC0Db7c9UOyhycXm0G6rbYUyz35kxmVJqV72/vq7id2xqAf
BX/1h0/U3UYyJD5cZpuPS3CtzSkNdIAS22b2AjoenrkPLq8stRwEOtiZJfPP
lFK1FzKrFl8HVr8lYB0ZHSAAshARRr8KUBBlts1ONAQTxSFz+G+rO4ncUOpP
ETdDk2Bafgh+RuUAkWyL+o2yoz0JMCgnmdKObM+sL2SQ2ttq2LBh0Tfw+QQ6
CDuGLS3CUl46EODa2rnL0WYq9FroYNGrxq/ymlxAmhCRejjh1rLnI/wpaJiK
z8+vrzs1cCveziTVPA5UCedrqqNvWLsUwOTFwy3/ceVvo2zg+zriiCPIPLfo
ddasWSzKWYVdJnT5tjHWUFvoikiqm60pG9AwcnXI6+sWcjp79bWqfgRDOGPR
WV6KgHIUJMKmQUV3i7CujV/ZaPTysjEfe/OBDIsasq4N0ncaveU9jhsRCtzm
Pb3CZn2mixtd3Lhm6pH4vmacO7mLG/8r3NCPmpvo67Z2ydorDRYOHii7G2CS
8yktlMiHhoHZ85TMUhTmh2sLU6rLsW46+m4ZT2nNJeOSqLLUuRji+XolS2CA
lHw43igzhnoZriDC4lZEwZDon0vH9SEtcOfcz44eMdSKclymMX5Jd8lMwhvG
VTfXTQeECyOkxqwzA0EJoic7KsWgcGNoa3ZARR0dhl8jX7pKEDez9W4v2xtR
WMfs5T46OkAkts+mqoUhZQ6RX+8ctgFjI0cYd8GKvDiNSYmthCJoMJ5usfyW
kdxctjm4tXTqAOW04teX7hyEk2CA4AOTZkZT3ogh3V97sWZyYBsMNEg7hYvv
LJ1p6cthgMYqGD8NoWeiz0hZbFi+aaCAz33YYYdhn6JsPLG8J10W3AikwAlh
ISKSUdSZB7JAIV/WUk2GcXXNX11TW5dbHkJBDVBsaFu77Jq6j8OqZqM3fkV4
l7gqHy6fhjyELHP493LSBqGQWaZtuzNtEB4BBLFJHL8SmgIX/GnOnDnrKl1b
s4LNALRBIl9cxMBfJwPAEmoj5l0gMjbxkIcJ3fLPYAviY44BpbUQd0Y/2VY2
jrRZR/DBJoSgx9fq7mameeRPaDXhHL7X1KlTiaNF32DvSJyloQWnHPRXq94f
hvnp4k+eOW50hCVrENZ9Dlh2YwuDw/mgjHBzbYV3X93eERWIBBW8Cq+++mpE
GFl+sSHSLWypkeli3sxkYO2+tnavpWeCyTZiu0FPcwOYpSeaNsgMSTcUXqNQ
HgFumFoZ9iPdeuzYscEQY5QIThQSljD74uqQzBisKWZOzG9XGchL6aFikLfV
DeCsfvU+NjIy/L2xbtGin9niiC210/X62uzitrLbApJ4dU2zjHRg8ke40KDy
cVEz2Gv7umlHhQf+cu1Hrly7Mks2bo2gCvh51lln4XLMKsy8+SEUdl03GadJ
L+oJtvcUQEwgv7xuOqkSqO/I8LHS7RaQtje0WDVqBi5QCvqoa1OX0AXaahSL
yw4LPEL/Kv6QNrCbe1oD2MUNcGPIkCFzTj3qPy37YNjmjxbvcc6po7q48R7E
jX+/tKeJ6DNrR0dau7jxd+CGrukcdFSCm8KkEX1H7Y5FPcWW0qkYE9JvuqHu
ZRbpRuGMlo6rP8JCslbkBZ+/2Up220DMby+NGrhz2z7C1KBwPuL29brxkJ4W
8co2ZfkrnBxFkeTAESNGEHYMbrA1QO/evXtSno48CM7589V7rJ09Dv9GNFXM
2/CY+ZOKLXAXjLLpn8U4gCTdSxjPtxpqmwR+tdnj4OHaKfH22q1C21lvgMlC
KvD5cPCtqWiZOuYtMwBuWH6uVZg54RHIVCh8gjc+Lxu4oENvAISgQwQNzllZ
tzkzkJExWGijEdeR+Wmtn3V8uQz2MxNSh4ltNwhA31RaC3JDwha3lLJ0kxWd
NKGDR4d4r3bL19ggQMFRRx1FsD4sseHikSgbl8zpCWLSOT/U086lUBYOZJNi
kzZz9c6y0WHo+tpaRMm6oXY1vKpu+qAB0loKpmld3RDxFGOjtsjwTJvwieUS
JOHAYhzjIFo3tiPOfdwWtiOem2sM2fgsI7x3Nnuo3fZOIgIeEveuromyHQ1q
8ODxK92q4Q3Y1Xq04AZwYSOgHLDs5k9gS1QRWJosXPr1bd2N3CDy67UB+EMN
oYHk5sBUDhDJcCzfK4CJLjFgwABSO/bZZx8Oxhz3pT9c2dO147+t/c2b5oyK
CRz+wa2adYdfhfGY0rA3kxBh99V4ug158MAwAL0xu3cONEv/idLeJPRAaaUe
0q1k5rkZ423ypPVlLG1WgTGG0P11Z5O2eg5BzjfFBg+TEKCMymG7kuAGYIJL
MITSRU6sKSUMo20PqPfV6C0clZN6SvnK+aHKFSKTy+QowC0rNX/Sl9IWiLls
tZPD9RktS3A+HJuHommwVTRVbIGF/2NVT6On31s2jPXiyCOPJJUlM4Bygo+L
rHLAgcwT8hPwwpncq5/n2lroaoWvaSe0v7CBhl4Ie7yDGxFnVny3LaDb57xm
j5W267hdegAiVZplTTt0i+BMHOXn9v8BecjJ51nknKN1dHGjAzeiVyyad/H3
VhxEVtgdFw3t4sZ7ATcIq/3Fmg8vXTi3ixv/v7ixuW57YTMrXfS31tZ/N5Yt
hok2Ml0GbTfW7Vc2NG2+YFc9/LE+bNgFSthJgx2IQt/85jctXiN6a76oPbU2
1ibAFENhs5DXRNaoHXpBj9yNx8UO4ikRWF42DIy+ffLJJ1OVEDtl30I9jcIK
mRV21+yBRBOGDBmCLezmXFECmbTwP4CQd8Q4irTyLGLNZpyaFKeniGHbrMDw
kF1KvlG2zaUaiDNac+rk2oka2jeWtngbys6tbVbeQ7W5+r2lxYrBXyQxYguT
xBzLJNisG9yI7FD9Fx6Gqa5sNgDSJ6anBfm9sfYuXl9JkMEhRuc0jRq0eqsz
9CGE/Xwod95Su9VtLRvyYhpsrL2yiROtKLXtwF0+GZZXLBTSg2OcDh06dNTw
Yyh9fWTV+Ly42y25b5fhV26o5UVJ46bSS02Qh/8NORmPJlZyc+lLbBTGDC7y
MLE7MBl23+QFewQZNw5iaNWG5DYA4VduJru8bsDkr5bVnoo6TEAnKlbsoK5/
AzMtB7fVTv55cR2b1pTxLW5piJcljTbkzy3IuqchWKKNrCG/WZeR6O3bt+Pf
yMmO/YbCDKyt9DZRKWJNuaN279TR8XjdtN013czDPO57hV5++WX8hLb7yPTC
SMOGDSO1I9BhTqmpHd+Y1+/cc88dM2aMuWH4CSNBaGJ31F6gD9f92nDokchB
fFYPHh4Ae2Yy7DZRFtcHuIovCNywXVIuY4Y31faMrrybmjaDCHK+IMKlN9sE
VPNn2AkiFMnljcJIEydOpMIr6zLO0sAslv6UKT/fWDl8BSfofLi9bsrWho/5
062l4cam0oDRdAt47O66x4HeYDdz1AcbcQNSIghIIp4lcoSYEJCTv+YypGzm
zJmkNAT6iDJ/6Utfoplq3i5f/55ZPdUosVPy1m6xkQUC9TLzgFckMohWdmPt
VnRd7R0KdJC0wIvo3ndJVScUSCEm3EZ/IYvLWPdxTra+0AV170UbcThdthCM
pHO3IICB4DalHLIbKh8016v2QO7LoOs113Rx4+/AjUjKunMH0bXjpYX7dXHj
XyVuzDhzLCH4OxaO6+LG3xM31Gbp6rC19AlEhbZ37j113wpFeEPtC60OaeJT
LjYpVCLSEYZ/rhKWi+XwgQ7Pk1H59bKFygPNPsVYwViOea7GryE5RMDHPd5s
UU0K5WuvvfZmoVdeeYXH5Xpm8vTTT4eRDjzwQPqi9+3blzDc2nOH/tc1PRsK
/3DJ744/YdjIkSNzEtYKdJA+lI+C3Nk0ACcMU7exbp9tJfvuDQZJmcPIwqYw
zzOIQbDJ1gS2GVTebT2nnShuWA4mtgjpjITsKb61k5ylIexhRIn+50FOCrui
5yOJYSfdKSIAUHZDbbR7Y7NdiLaMxVxgwm21h6Hr1E11byZFw0zUQAcHeQVQ
mmrHUO6wru45q1sg42QTxiwQ9HkbOHAgvosJEyZ8d0VP5+EfrerFG+X7YsLk
fUHLWDfILy2aqWq3UEhjRDsda9pYj566duHTXvM1cS6FDIDmwMQtXoRQCJmf
JnwCF/oQDNZYsZLrL6vU0c3YwvmgAdli559/Pk/PZW7bxENj14MtuacJALfW
ViqtMa4Z7tJvnrkOug7bzfg7hWyhrXUXePpmsIwaJ0W0bVrugTHKrCawhB4Y
5YKVxRRK/mr5apQQEjmiYKDVROV4q9IPCgVAAJlMKTHWLEDoG3369HEnuCVT
j/+/Vv5muOuPl3zsrPEnROWgdjLcRWpHVjTWVveW0odJhE7vpSgHLxmtUyex
b8+DdavZgAlw8WDteW7Q2YR8PRVtk42OwLq53G02jiuCfioov1q5ciXeDJuO
nnjiiazXOYPHI1zEqnR9bVeyte67pHTcVvPkb6v9RXV0iC2mW99Wu3boaTef
QQcjMIWo2tqFVSO/uq7suxqKMumWrzg2x44dCyYEN3BirL7knP+x9t/ky159
yRlEZu3oHni06T0S7bBNIAkZKzft3xXNxUJVRN8pkAID+6UAEEtcl9a95NzQ
YUHZNZuNs3lHiuOuarb8Nk19Rd1uCa8pKoRJGpDOWGOs4WQekWGowHCGzhuh
XNPFjb8PbvTstzJ57J+t/AgNf04feXgXN/514MYPlu+bb/r6ZYdnwe3ixt8f
N1q1ShsEu+yOumMjCX4Pla3VYbwwGFNxb91HHsUSFZT51PCRch9QQv9GLBds
+XYvVMnQJLqoPnODvyh+HSUbGYB+FRR+to9kv1R66O3cuRP0ePvtt98olMeh
5mXqsGrDWng8AiCE6s454+Q/Wf5J9nKaeUK/GDUxgd1WlTqp3EG0vKshQ1Qd
Nu+mukuR/b6cLg3G1vLiQEgx/mLeKZ/pvtLoG260TOOOZlNLA9bm1NnnUGMw
3IheeuqppyJKkSlTKIljRvmHl8LAxuh5ES0mTCRA0i9oqAVvxlW107jhS4pu
Wqvq5tq0XCHNfb5ciXfMDXMrDXybemFx5BX0XQQWFp11dL5m9I2rl18SY4R3
jBUDgMR0xQi1GiWj6kgz0wdoGOv6psKOi416P1Q3/3Uhvq3W97HsMoFt1T8A
knex24ZxEA5iqrjPo50EmKLYdwZETArFl9J27cBayTval9gWAXY25uf28YiM
yLeuOC4H19fu07w77TgsI+IzEWckyZxZur3uJXp7Lf4SbUKAg33tXnzxRfPM
O5pOZHrNjoZyBoG6o24YijwqjAz75mY3ZDhKDYrgbAiPSmjXrl0oHlFFQLD8
CquQToMh9lENBR/OnXzmDxb/Tpjtb1b/2uqzj4jhz/qVP+EwzJTig2oRQM5X
doxxqz5taTpvyJOqB9bKMYEqHrqF23x7m5zw0C11o+e76xYVJMbfV3q28ysd
Jlvqbk24ZbCUp0+fTiQ6iEGebeYEAcwKTjlVVkD4FtcoX5/Xv7vu2b2pqT4z
amxKgxIkyjFsl61NdXdXEy/Nn9Fjn5Phc2TB4rWoTGaHoiiOGDEiL/VHyz+d
T/nkggGzZs3K27EERHtEOQkkIkFZ8RGfDBJhkZ+3lLJl4XFD2UK3I1fhrtqS
6KG6KbB5/mSTijZOBXcw+kDyOfLIDARS0EAscQ0UMEgaoUOgRKYCwV9T95U2
kcPs0DA8bg3r4Gg0FCIxHvRA/5k9e3YXN94VbkyaNCnQ8d0FXwQ6rph4UBc3
fkVxY8slx5DoddHsGV3ceLe4YcmDETFVr1aJ0gZn3gwzba5pY/fUvrKba/mw
BsuWZjdVZphksNCzzz5LmugzzzwD/0c07EmokaIVY2YXwUTCmkjH3ZV0g5gT
pUP7rlpzZ5ewQBb9+n7yk5/8sFBO8o3onke6FyUMthmMzfvk3L6kdlx39oFh
wijwOOqjuiNH+V4IICGhjtFuLBVY60uBCZzftj5DhG+v7arsX2FCrPFuoCOk
o8NZMpilvfNA2ZOFyJSIZBzW+/AIqoH4XuEZvBkkSoUyFWymOXjwYHsXw11y
y521waMh9TvKrrvYsLy17jXJ4AstE1l0xDRY6+raHtliFgOjJGGihEf3Jn4a
GwSrKsYmcDd10sQgRj7fPUtOASWGDx9O1bxJbjFwWEFs6iVM6YYyfGyIGa/F
zaXJMAetw822mUz7prI5jn3SYDzzxKiSM9eUmK9xKN7R4jXyxOjpBziIG5gq
dBtzSyazQztKV2x+znaQIe+TR+gMMaSFJwpT1Klg/Jb43Vz7sfunnEEQsMcR
EIS09R1BqiIba8lSuNQmLe4fRLKH/g2AgraT+gC19NFMWIvRT1w676kNBu8t
LcGRVs7YnpQ+IaE333zzDwt9//vf57n5NFjHgQ5CtP369UPxyLJ73nnnPXjJ
z/dyeuzCg4COECkBoaxWfNm8730NGZx1oVRzQ96DGwCIOZy31NZzX679Bk1i
l4G1ncVYEeCh2rkxb82BsKOeaeJl61Zyc4o8l0UtChX6Rhutxi3g5m70oEDr
AHbyavDGPXUnKb0udzS9idRAOkrGXBHUhXRqXVk3iTNbMoujx4Ey9I18C1A9
uIHz6plFh+bD/WzNZ6JpEFkOJFIrffrpp+Mhz8KK4JA6ggeelUhMU4WTt9Wy
MnK+2p111y0zgR+te7jjGAQKTHexldbVzS5L+DdurP2RMr38ScHX42HxrN0F
dXTksiXvJJM0TCZH5bCZOQFZs0zBli5u/GNwI7R17lCg48nZn+/ixq8Kbpw7
bii5fLcun9bFjX8Ybiyq+1pmwHoznAr9BhYymybXNla9qXSg5eMSf8GOgDmx
6yGZRAsCzqT8jc5USHSggzNurRJZ0JYRN9zp3kYfdjiPmKifgxt+3IzKNoPA
1Pbt23F0/PSnPyW5NFKDAhlFl0UqcIHBEugAHGI4b7h4JEy44+JPjR4xNDow
XpFgCApw5vn6ujHo7nGo22t2ZWaDP22rO2ZG0IQ7Y+Wc0UUvbthCzSYbhtFF
j1yj8QL+bKlErQoWHAAe45HEVCAIeQ/DULxz6KGHUgaYqQBJ3Ioo3IVqvb4W
qmCr8hTjcR05UbkMvjIqIadpAmypRUn31RqQa+u28gYI6F+H2z+IQSrX6NGj
bUh+2mmn7Zrf49l+eXn/CAWdzENBFQAkNiYRooieAwA3rq1t2F2AsItZBThw
Ibu32QMI2PxK3cOXFL5QTm6u3QbIZwsp+LYFW1nbyN9Qi4AsGfPF/ZVNBe0k
BvJgaAAgpolqldBtmKgKrz+vbgFp2qqNv3KmbX3GANgfiiTDDoVBT0hmEpmy
bYuW5u211FE9QV+EqQXe6qa6/445HpjYj5Rt2txF2posZhs3oEqIZaT2AuKH
rYfQZEi+o64qxeS5557D0fHWW2/9fqGXX34ZMcxUMIGUiIaiVGDdZ5GKvFw2
ZTDbwL258LMnjhp+dCUuzq9mz57NeqGrVnIqDOSRGU6Oh84302bU7jpwA+gA
PYhit/P/SCURyYaNwgjT+O1vf5t2Q3n9559/ngQYQDgU9ibcHCljK6tevXox
FexiFvJldZCaEsniy1uoeYIJ62uvjGvq9rLX1TaD+FpxMJoSDOWHrNF0mSCw
mC+Fi2ny5MkTCgUWiKSPGTPmzgVjiL0uuXDqBRdcEGUSRTEHuDUuvvhihCsD
4BsZBVjflOzJSFyjE9uxPVA7XuLaRd9wd0Jpay1RvLFu3JapQ/DbylYAxEbo
Vg3T9hxyrwe7A9lsnwO8pqRkdNS++SyTNKyhM+ld3WZe2cy9ixv/SNwIrZg+
hhqHf7fooycMG9zFjV9O3Bh/0gl/vnqPfKZnrxhDrKSLG/8w3DjggAOY0nA4
jvFod7iRV5bdZLBfNLSNsWJoGD67tja4zgHX7M7JEXwARIPl1qZVNTdUWB4o
PfcwJWBp2xrn4CsN/a39tag6333zWfg26iUjyZDMKUVeXnvtNQIrARB6COfO
jC2qGqxl2mFUX2YvXDfvvPEklP7R4j3OHDc6yjwpUgGZzC119/n0iICOhZYn
NQAxSzOTPFd5MUR7d927ltkI6cTA1WNXZLrKc42cnAMgkUaLIY2jJ598EocP
CXI0Fcn8cKt8Dpg22j6BCbbfJbCCNZfXhLtuLJ3MycgyWcsqMMVNTmC1sn+I
NoubhpgP4OKSLwhnUiROBVaAizTXMDNhlHwCvhf7y//ZlZ/PkMCWmDDYKYF3
3Fl0KQ+5AmqMtPnS2iAmG4gYroB6dTjw07SsqzW9ubZDzES5PaXNuHi7NXVj
Ym0QC090WQgOmRMhxdYEhlZNHLVrB8BrJzH3iiUmCxm9/dSnPvU7hfbdd19W
kEGDBjHbEydOpGuBSa1tDzdmT9NbtDS2Hh7gmnAjgh/2I0diW2kQx6JjQ0KY
ZH3ZiIF0Sn7u4qhTcVtpRAMnq1SYxB4+t6cHj7PG9sGySTR2vbkNoJMbNO/a
tev1Sjg6Yulzn2hKzNukSZNgNjKW2asoQDHlpKP/92WfCGf+lxUfnjXhWPIB
wrSRKXxuU6dOhQEIz20udW0QyZOha+rWn2YA4jUF68QKmBMvMWROL9yryygj
54IHaiMg003dLy+fBiSxvI7t3izIpSdqZomRRDvFHWpyy4ABA8DJQCjeyLAr
uGfWyvra2FCfuTOg12t93ajalnrWqQV2uLh1C4PDxl6zLIZjaZcRqwSHdvCt
dYc+sO6ifALqoAPpZM7bAzCrA/Nvas1ddbNvgTekCu2n0YkkbphVbiaPS6Fo
//W6kcfWWqR8Y1P2u/ydtKLslERnkmsrsV67tYFkn0ChBqcxux54RteoLUyt
kHUTaubWHuyZoi5u/AJxIzTt7FPfWvQ5ctGnnXhYFzd+eXDj9Xk9bQB//8qB
YbMubvwjcWOPPfb4WKFPfOITnym011577VOoX79+THvmnO5q0QBRQTVGVNu+
XPs1Xd/sGoMgWOcSLtVe5rtvrM2QzZGzra7V33c1/UD0TrfRRm6VzwFuRPax
OMLk5lJa8GK+JQq/JgBbrIbc4mTnzp2vFAqA4PqIBPGrzACNviM42CmHHHII
ABLoOHfyma8v2hPoWHXW4QRnkalADTOZO2DftdFq3jcnEROaKoSuL431CAYx
A2JF68SAjJKELWHIdv8a54pf+UXs4UxhC+o36BGitCcUJAFe8oGYAcLTof79
+xNs0mCZOXMm/G9+r9iIH6x9IxX+TbUGEMfITWW3RM1zZub2WjuZXzGNKurh
9kCWmGB/tlsuGEbP2JVzZwT0MnK8T/kihL2sH8+DsJisr/ly7eev+IvAJi3c
URvCPFibP99T2+9r5ny5NL0kZIZEbCm7DhlbgQ0MrNjHXu+NwVbXFLNMg66G
OFnl7bCh60Mzx+ALNw+tqFuriBttKBapJ1hDn+QAxacKBTd+q9BvV8qfUEX2
3ntv1hQ2OAtNmTIFd0oGCVzocrQS06j3bbW3j9FPy6lMsdhci7B862tKEzYk
Cx67rbZoINorqnOrSBDL6wuVvv3tbyMUZpy6BOeMET1jtWCLzYVC3CfQQdeO
1157jfMZAHPLBmehLLuIT5Zdela8vHh/OpSuOr1fgOXQQln4YNeY3oS9DH9v
rHsJhRNA9XwpmOSqZmNlEzn0hapmQKagG6tlwmkl5GWqK8yMKTRC+qbSmNG6
ABsu4TuKFDD+6KU4OvJ2R1XCQJswYQKWcuDC8KtJGnxKc4kjNQzJ8ev6MOao
D7Dd7QhOxsVHi558FLbDjjbI15k0ccJfru1xPX1j7VhyMzJsNMDx48fj6AAx
Qjpvt9YmS/nceo+FDv50e+05L/6b3ap6bEJCrueN7iibId5bNhe7u2x8TFIx
EpTpUuFk4Vhd901YVvdBCHvoBGMAt9QtLa6u2zypS6ys28PhEWUabbFu8BdH
hy1MCc5SM2v9rIpHFzf+iXAjDPzs3P3IClt32t5d3PgXxI2nLtmf7NDAQhc3
fiG40bt3770Lffazn/1koVguHy0kknz605/GhPnc5z63V6EopSTgRd8j+JIB
aAzy+m0JhkG3u95J1lxgWYco3+Z1eH2Lem6snQqoAlNMiKd8pe5gYjwliEF6
XuvBJsISpd18P76pUpaRtHuv0N5wZyHbhUV8YK3MIVrusGHD0NIPOOAAKjhi
sIwbN+7h2X2Ajk0TP0M3DzTnTB28fcEFF8CulvPcVnptkdJjDqQb99g0gKkw
8Bf8BPfcNZIANMow0KqZJtvfV0rbaKjoDi+ALR5+LssFGHFuTxnA4aPEKIAT
+vbtS25VcMN2vjg6wt6whKq7bo1Muw272uIjYvdm6yERbcEFvB0+N4MRX1xW
tJNPPpkB4NY4/9RjcIfef82F+Qmonr9SfHTWWWcRkM2tcNDdWfeOlDfMndO+
kHDx6eW7vXS9M90OcIDP+VJgzp11uyiitMzJ1ppofVtt7W6pmg4Ke3BFLrRT
zM6FN7zY6bKl+fK6uZIAYuVL/oog29jcrh0aLOwGi9VD3VYoC6V7p/5uoSAG
SBIA+XChD33oQ0BKtJE9C1ElGoo5yeKye96pTGJdmzZswIS5tZwzcwvI0BKf
+XG15Rsh43CXcEGOeshNB9xvyEhuLnZR42PpfTURYlttdkFWaig3B4heeuml
1wrt2rWLxL+8C/jPRkVs/oXHI0yLT+OWKQcAHU+d/+ngCZpbEAYACbzQLyWf
Q5jVQepyY2RNVyFkAkzeRd2APBY3nDX8Z+PB4IMlxsbKmSL6mgKbmSi1QWZb
xSMXMJNhIZwJ2mLRpig+DW4Q2Y9Q82omTFr+nJtzH7KvQw/VJqg6CvJ1cHTk
9ZltgCIUecd3F8TAcYTTCRUokx8Ywdf0xuVHBHVzARoI2/6GomkgL5Epo73y
rZlIzK3xX/3SIQfp4ghriduba+3nttrHvl1bW8zxn8hyvjsLh54uY/SWh5if
77B1MNrmyH1MTC7lnigeuj7cv8lmPh1bO9l0NE/v4sY/NW4EGZZMOJh9q1+e
s8dh/Q/s4sY/G25cP+s43KHrr1zaxY1fIG6gM/dsITFqFG7w6Jlo2n369Nmv
UAwTYi4f+MAHfqNQDvYoFBOG4EtbssFDM2BczZklA6mWNYEt65udyg15gCQ3
l80HSa1HRTd2qZ8/ZBjLXRRJT6J0xT1ZjEjCAJqW+sNVSu+pDQF0C6j8B5qQ
mtgsuD7yV7glzEza7ZgxY5jPaOx4PBClWacc+Zcre/pY/sG8Dw4Z2DfThZSF
t4kDTp48GYe2wW7LqLXrNXiNOtmqN2gjAps3q1HGQWYGGyR/Iq4a0wO3Rt6O
a4itEM7OTbDUTJzLzb0DIdpMF0wF54QCntgCbGpPP3DMiggOkalXXnnFviuG
0UH4e2sR4tbSanJb6QOAQOWt4WQ3YQ/eskvUjBkziL0GrzLzrGWxE3+25jOZ
8+3Xjgec7Tmc5ZJMvJy05zC4kZm3rAZ+eKRpxsgB7gv8S5hXGSScrO9C6/ie
ureUJkn+amDagIg+H8rkQ3b3cr2w0q2Nw7rcCDs2HIPInYNciTjQYFled13R
vyG17cKsZfvUpz6F5tC7d29QOooHIUUBJEoIbo3PfOYzH6u0R6WPF8qf8JMc
eOCBQHpPT85C4Wom+dHSdTMkbujou7P2ari/7hwaWeZNKfAJZdKY2G2lbJOP
4vLkrgfk4GHvw/bhSRM5bEsoT+q80sw0Ri/+ACC2BIlA0SA9GgjDyCswt7aI
iQWNvd+/f38isGefeNSfLu1pbvyzJR84Y3h/5jbQgX6SFZCk6MwYvKE/cGXd
F9ggez60HSGsKwQAdT6zfze5K/YStL8roervfve7JmbYTx74zbER7bwvJ20b
TvdF8khRHadPn46nMS8LA1inkyWJRp3BQO7z/UoWBVgQnTuzOhCjNJcyFBmx
scbMSrhQghhkuRP1xnfx4OJRme2/vnyP666+nH7m+Qr4paMg4Q6lfi0kAtst
h7TeO0uf/DZ7/IFSag2vmkeUAxhJ90g406RQPTb8nPTy0IbSJeamSh1lpFkr
9QMztqsaEgfM08a/YTK8ef7WDLLi6BGl8Jb7GJx172mTRuxuKtoEiLq48c+G
G6GJxx/5bxf0tIv5ixW/PmPEfl3c+KfDjXFjR9OZ5+mbzs9EdXHjF4sbH/nI
R7Q4PlcoGAICxPrATgmkYIx8/vOf/0ylTxfaHUBMQM2v2KIidi6qYGbJ8CuO
DrLx15Vde2D7jbVCOdfw+lGKTJbjYpwnfNP7atl+Wx0AbnytNjS20TFeCw5Q
jwWrB2qr2Ltr50NNb3VRLRe3faFTGcY+MBiuppw8PIzUHHbYYYJDT63K0CHf
vfC3aDN49al78ddQgBp/SKYLiXDTc/lHB3u+O9xibyiqh0Kba9W2o328bkSl
nRJCfgmtEigh2y1IiAnGFpycDEJyYN5Xpt3acGQhGi9F68OGDWPdyfvCAJkE
kktjx/FNg1R/UOitt94iTZcGCBCPuLP2/r2zNKm4pezHhJ4cTtatwWwHEzD3
2NQ1/7z3gkMtRZkzZw4WE+28QhkJd4iAIEfX1c1bgY6ryy60cKl9Gh+pXdN1
UFjpk3lgQvRayD94lgBw5kof2r2lAbti7gAgm72vq9tKmglmfYrp2V5pY2SB
yJJJ4QLvGTfUhQJFygimhJPb1FPI5mOf/OQnkfcPf/jDn6z0uUrmcnA+lwEX
e1YyeqvvNECEQpJfcZMgD1KTxZSn48dDSJmrgJiOPlscGIZjisIt/Bx56aj5
aoNlfEEB396DD9YqMJeAR5oNUnmc3123mKD0UN2xGl+HngGcA7BEXo1BxuLG
8xZDO1oHohSUoL/lfVN/lyDLQ+d+9ujBh4fbDz74YBO2YfIso3o89IvuXqDE
mXWlE3g7b1tqw9KMv0UPMYQQMxRB/l4lsmRxkgAXr7766q5C7leVKUWH1J+c
FyenJYAJXJA7GnJngfHjxyOtYWb6u7799ts/KvTGG2/wLLP6cTaGjEuGge1T
R9Q14o+bImBLl78hQ4ZkztesWPLf1vaYhA+vPTMiFu0Cr7U7vQZJ0A8zdbbB
t6+4HVFYy+6vjfEfrS2hyH2lQI8zukzN1zWRw9nWU7qt9uh4oOxDASebrqBj
/KaySziFfh0OijAY8s7qjyvM8Ksp+ta+mXCrBHG3/NVdZT3TkfVhQw+vyXi6
uPEvghtRPFafuj9Blt+f+5ERQwZ2ceMXiBvPr+rZ4OBPr9wbeenixi8cN3r1
6oVZYaZoDj5RKGhg6QoHH/3oRzFSvlAp0MHPgw/86oMf/OAHCn3oQx/6SCFd
KH369CHW4LaqG+sW8/lemmkqaeYWcrFtmfP6KmNCUFutDDholqquP1r7sz1S
u2O1WUYdlXoGtoyzbC3b0YYM4lBrExKajCNnkPA2aUjAxSGHHEL2Vw4GDRo0
Y3RfPKX577kjfr7Nk+I2ZswYlHCggwRaGamjx4LVQBYGWntoNdzjdePLp59+
2qZeOGp27twJaLz22mvU9NFqHnNse6XItfX1WDpux5mJAvkvuOACTIa8ArHm
4cOHcyZgSNA2Yos1Guj4USU8HhmJoRZWhIAMvJGXJZ5y/vnnk/Y5adIkvEkB
Z6zCHF+xYsHfXN6zufyj183hegvqgxhMabALmz2cZtTVAiv+aW8NWUhrBdcE
9Vl4Kuzt0EZY9JJ1MMkDtUE0aaJ8JvlNIygvbp89wQHKVDD+CHWHeWWbwQh4
R+0JxxS1dRSzWOmmA+TKsp/smrqlLE0FjeYQMQz17dvXqCvgEAzBcSFuhEhK
D0qQ48Ex/wRA8isAJLqHP0elyZ8+X+jAAw+kejRfELgzTTczAOyLmfYktJ/A
ZaXRIv4Eyi3Nct9cdh8w7MuHM4HBhEkT/0xT1796d23aT3uWDaXhqmkMfG68
jmx3i3/AXh9fqQ2F8vWZ5CgekRegICoH3Sr69etHfukpxx359vw9sFnWn7l3
ronNwp8icYhbVlU+t2as5cMaqu5bpIF8fd3GwoyCMDNwZ/FvEAPtIojB/lNv
vvkm8hsA2dkQ8JI3RaiJ84ZyDBZlTsDbfE0aWWRxP64S5QluSx15///YexP4
rcoy//9XZm4opKCCAoaiIeKGouC+ACIhsggqIAgii6wiKIuAihu4YC6Z5JKY
lZRLaWNW5lKWZZpL7jU2li1WM9bktMzM///5njf328PDNL9mfq32XK/vi9fh
POc5zzn3fd2f+9ovTF4ZW/Anz4BIk3tyxvqQeX4WQpYJsRZhGwytQQl2Iqsk
TZw48alLjmypgnLB7qeddhrSxeDBg7E5Z8PCIZufNkzXhc+8X1X6d1hmyipP
bEYfqcq887I3lLqsnyiVXQ37sf5GwAFzujEq2nsRfbmDxd7Nsc0ZJZ+G9E/S
HnHQI4HYH5bKP8gJRpmevS7lZMNOpClDE4q0tCowSI1Bfitz0cSNvyxutLgb
Dj/4rlM7AB0PTt0yOksTN/7XuLF0ytC1hqPLz2zixp8ONzKqtMDL2DLy2e9Q
tLt06aIRg0SVNr+fAg6oObkecAiSbFtRPmpVCPMIRo9QVgccFcGVcSCRLWSw
igCiW6HuPwI6iJqzOIPdbZidm0vPVv2wmVYjcMyrMuEFcIjcqFH62kJCE0yS
5QO3Z00ZdcZP5AC2yUPatyjiNN6Tbt26GXCOG2XB0F0JDHtl7ibHHdQ1wBJd
hkiqvn374qogPClEoBfWDKTruu3dyo0a2LnYx844YL6I6gFu5BVofPnUU09R
JpEqzZQ+C4agxeQ1sW/k7fB9RNMBQNBZQmF7HjLQweSGqWyhSO3fLHmL8rFY
stwsC6n3nFnLsOMFiMahWQO/au6pCQVkeHlpS0usXy7dPOwddCIJKOyNehI2
w0KypOpuTzkIVQYwwVxLdRCLRRiKRhZJyEhatFcUWN2vfF1DR75ogpsRhoae
frg0A72+FKO7pjSfvbI02LW83vLSA7du4HKZ+JHRYjpNRAOYxBsSZkZAqSkw
GtNMsQc3cn1YkdA72lqFRowYweRmUtBPw8N4ZhFCkEPAgUggHGy66abYRQMv
Df7cCCHABTaTUO4ApBDvEcJdG5o8eTLggKQBtDogVtLL1sPIWFD9qlJ1X79/
PcyPyaVkCpPLQeaLi82iuqGQ7j9ThyRjAsPe2PeyTWMWyDr63LqUHw1/sgVn
VAmS2X333Wk+G+ggSKZXr14jj9gjoIGL9pLh2wdS+CjSIJCeqaFSd7YACygB
s+5EGogYMUZP/7WhBQhggQ7iNwIIiBlBCRAj0JFjE4HBDWsZaegIYgBBenJz
BtAOXhHMGQHDmuEgSRY4domhQ4dSLSfPr9eSrysuZpHCAKS7hgIISGIZNOI/
s/21MMM5Z//6nJYBvGHeMQGZcePGYZoOQIEbQQw4Pz9nkwWDNMD5m0ufu3q9
HaFDUzNsY86gWZAW2A9uAA7eTee10MRJ7mCYyqrSNyEH8JvB5FeULsxuplpK
M7+W8REc3Dj4r0KFmZI2VrM8o5m2dSDiW1ZNJ4KdewZPCBiOFMcgjx07FmM1
JVBCEbPfVxFCSIjgc2jDijbeeGP0lKgwXBPFZ8eKcgCARD5BhQkQIZzsvPPO
COf5FeCL6kCkCXsA1W1EOW9UMAQPwAZYqIiUxoeC6CuAGEGt4OHXby3FwWQt
S4DmGZjH/ATSRZbSixVlxWFCtARQFld+CAaYMWMGhsHsj3hYAiAIHgHnlkL9
+/W8bcJaF+1Dp23V7+BedK9G8DjssMOA9Cw0doewEDb/q0p3Tlnr4tIjwF3G
MTTGI3IXBlJaXiJ1AIDRTXSj4EkJRZEBVZ599lnEkpy0HinX5IuMQMYWxgtg
Ypa0q10UNxTVHBBQkTcCCd2LTUqNSMDmGChA7goQsaPZLS4LIa/zjStHZdxe
WNDhhHUpAALezp07F+Zxvat6CFOmvXugGbOeIWteD0TnDjjNlCgkWJWaVaV2
rprI9VVTGNEJgdnAj7wRX7Qua91S2pB7Ui//ZUTHBYXAhKx9c+QR13FAIG8Y
9sbFy0td6HCOQekYY3PQxI2/KtwIRVU/+7ge6Cw/nb/h6cfs2sSNPwQ3br35
hjfPa51Bu3bWUU3c+FPjxtWlrmO+C4/Zk8W8+xww7EES5Mzo4yRtBUDQXAIF
mxQiZzZnsIpEZ8Fp26VLF+LVt9tuO0yv7QpFlwFbovvjiI/2ihNNcSuDpinD
4Do9udpFry/dwQy3oFx5KJOLhSq40eCR/0hpCUSkZSjXsxCyBLhP7sw84i8O
5RjeiGKOnP/cc8+x7iL5uxKDKijvYRgGOcDIawYq0dSiszCkJMmOGXTQc2e0
MQG/70H74moxixZ0DdpbyQeiHh1lG+GN9YM9whKYfMOrDEj0KRa75VXz4saZ
P1woMEhG8LOFcozJNMoOw5VrsBVH4+BXwkvYJ/v27UvGWQCE18+LoHEMGTIE
m2eezeRQpjtn8L9PmjSJaif5On7t3AE7Z5Dz/stOojhPFBmsr8ETcCa6EryU
haOpxx2ERer6VVG9sfQv+GgpUa56srq03A0LaXK3zyD2DbOwSZqwnCBWsoYS
Hzeu26sXBsbEcU1VOdCO26qleuQl4MKN9cJaoVoucOGbvGb4h+b0fAtuObvq
90SWh2VAdOxeVToaYIpEFTJKBDO+lX8oMh86+eSTMUdkE0QCiVyxeSFkiVY1
AlsCDjb5wi4aMMELE+hA8KiXRwajslnwsqrnuLYtk9KQYJK16WYKacTT/RFM
YJ/NtNY1zZur5s7YJcL/uBjoVh/K9XALgWoE2GhXh23yLdadRX6eeeaZ7Muc
vO+++/i5TAp539QKC+1WSHNo1tSNE3YBOhA8vCxoY90kVkRwlXn8UK3lPRMq
X4VtkFJMzM+ncHK2XTxEdkAIgBDOEcogaP7lTBASO2qu4XpNrAEQbpWFBm5k
oPCe5H3JYcl6B0DyCiSzkDMSCkubZwEnh3WBlGxbmjXAz4hesGiggNTXVTOP
yK9gIw1SkYQSJCF2OsvN1FRlUcwpwoWRbKaTYNL8aNUqArS5teT4uzdZiEB/
iulRGkiF9BtLYiz2NK33t6xLeSq+qDBpVGTWAvum5iwDwy4uda7MoycBf1nV
csUkFO3Dyu0wSRY+yy2fMmu5mG+ZdB8kaeLGXzNuUK7KAI97J76n917dmrix
Pm586tLplRul1bTJpzRx48+AG7qGV65HykIGo+a73FOP2OjRo9G4I0V3qWjr
Qu95z3s2rmijjTYCT7bcckur/VhvE7MG1o867bLLLlgAwlE46/O7CGkUAjJr
UulOhZFhN8ENL/maqmUzCguprKEsZGRRvKvI7bgaia+mWAQHuZ6ksNyZtWmc
SQ6wmefr5IXl66w1wIc1lfMov/k5nZVGV4IbGRxiPKIMYlbK4rrmxE4Epf9i
4QYXHLM19pBQvoWHN2uKpZF5N5DDcGX5BznT/sKZUADQHC41F/rtggkGkWrx
oGoifhbNOAxpho47ZC4wp4R/2HemTp2K/zTbgY0kbFXAmSxzHunS0g4grMtu
FSggKJT04VAAgfF/dkmLYPbJWftg7qDWuslrwSIWTlYunEA0BaoEmHBDrdIp
/FOPEzaXoaHQqGGin6o1OueAxtyEZ+h8ATf01OCKFabMNTYmhDtYuMb8cRJp
WaRGk5onKwPotMXKcVHpKLGgahEbWr8hQrgCuAhQY/DMYufieuBoPaTEch8s
ig+VrmqXlt4omE9JrbUCIZWXMoPqnggMkSXwuuKlJewcUcTIc0ObsjTgn6wX
DB2BIIQTmguEsn3ABnlx0IPFzrATjVOvWn9boVIM8mYBJGsf/2OWAIIHgHND
VTXLRodcQ+0sktCBlBxYZAb8t+Bnnsf6xl8slOWGxJK78XNhCZ4280UmuF3v
d999d148QwG6ZplkEPofsMdXpq4VPJ6dudGYgzrSEd6ypSj1ARB2Z2J42GXU
c3WoKUlCeu2zTWAEDt9q4jNOLMPCmHiA0YO8El42gwPbY5pYXlX153fDNiBA
+AS4CyoCBUpZQ4YMgbWMOgh34cWm81ooPEaVpHOrEpqXLD3jt0s2yN+EkQMj
sVCNJ1TPkUcszKpk/DOnvNrNpQdo3azRkHqjwYHkaFNLEAms58CV5tHXg4i8
oWlZQpOuf8uQfqpkcMuu+TnuqX3j8qp/PdnQ+t/NRmEqLyy1fTR0ZEhBGDkB
q1doWa0mmMqFFcAweNq4LUPaxI2/FdwIZXHN6Nfp+3M3BD0enbrpsfvv0MSN
e5ce1TIap3eIQNLEjT8Pbij5WC3Euh8m2lj5kBoIIZwyPKEqM5CSn0MWjZgN
/5vyRoXSUDQXVJgACGwfRR4JM5ovpnKSv6hsgy4feMGdF8bI7xqwpzyJpuDE
KTFaBNKJoOw5SxvTx62l4mi+BTiIG0AHRfO42Dp74UAs7cZtqkHfWgqt4+vU
JWFcOvyWp0V0zGrCIxmt39LouGijvNjbqCVCbO/dLx7S/o0F7wQ97puw2fv3
2T6CB9+K5E86bQYTL8aYMWOAptNOOw0HmQUkrQeeWeOMAXXhSXMG84Iq71ZN
58BkTyt7mCpL7ZQLa1Ujwif8ip4R81jDLRxkBEAJq+5Hu7GPEsaQfAu4Cyvm
db5/dksjtuXj+0Q3CeMFT4glQ2sjmJxHwrkWytQTneW8687Q0/HhWlveBvuG
XpjVpX2D1+i9vbWQ7pgc6EPh4rpvV9xwtKlzcnOt82w2GrbyjC24UVdSzFBj
3M4v7TN0rS4r/SNYwqCu4aOcMZFNkSB7kL2nLc3BTXD76rfl5leV9oI+LeUT
Q5kIwc0CMiIhD5CJYyFku0SEaNu2LWZSfbVkr4SyRg4odGih/Qqh+WJPC2Hx
sP9IQ7cLXf+4ydaUjmafqHrcm6Bhx2SuCXugQl5XuqEFOljp5mjYIyC7LRaP
iCtsxFapCv5bGsVS/7eVXnLZlzUegkVhXZ4/c0rgbjZctuCgBJpI165dCS6N
FIcEEnzYb49drj6u3a/Pfgfo8ZlxrQbutyOX7VkIO0lEEW5oXmrEElZiEJjE
0qAKqzWzxsCGPSyURMI4zaB1dmujBq6Nt9ToB5/gMec+4UmsuHlN/MgROZhr
64Nllgm6wCIXykMaps7mEkECRGpxDk4+Nq//z4s2HjtqZEAy7xJQAjcsNWyG
Th7SMsgYbzVari7tRPNSFlLw1Qzt4MANyAxrg4XITDHvyfzrT1SNBU1vcWsj
IJaVBW4IFLk5tyI1JnRd1Z+I9QhumFyQFacREmGSWHEyNTR+srRXlmaay0pf
e42oObZVPfJGcIPNJWe0lDZx428UN1AG++ze5YaRrYGO/H1h4uZjD+n8d4Ub
d81uqet138wdEa6auPHnwQ2jy5ZW3WZpPYl0t6I0XAvboB6KG1eXftBEIYZy
Dfxv3ZuVVbffUDRN/AIRufGVmCLXunVrsloCIGS17LDDDsjbAwcORAUOw8BR
4X9WDUGVJDhMmDDBUh76U3iSG0tlcrkluEHyZhQHnK05QF/IFxuyUcIJXByU
ADeMgIoKY/YoB9HuYRvLUDgyxIbhmwt0YDwBOqhxgTKV5wdwFMvz4haWByWC
IWgugRQwISfz3369dr5u5FZqLl+bssmsI7cNUOMizzV4avxWCGXQ/A5CsELB
eTSIaDcTJ07EVBI+QR0+t2oQdnFV9NvysFeuS2q+LD2Isb2oKhwRCjcSk5wZ
ZLPI5PJIduiOxoEX1aRX2lTRqYrHiMD8w0Ut0XHnnHwYIV4BDeJCQ+Fkfte0
xOtL6O/NVbdimj2xSF2txgnrPflorV8SH9l9gxSnj1UtllB87EpskFgdQ/Td
wKsoR+7OLJwbSyUZjScCDkBNHILqiQ4Rw7RYyLaUDStyse7a9U0f+UhHKvoO
qkqI1tJYObghqp9lPA3bAIKMZVWNumw9woMMIyGTUCOUeG82qXwRmAo3ggBh
ZpPurTbGQSCFbLiIGcRv5FvskmEtjCH4H1F1s4fq9+dpMXqQH8SBcJe50NCH
ESMrFxEiU8mgKW6JhOEuL36k0NcKESaaA4AofAgbZPmAAxdV/SBgGAIGQvff
fz/3yW3hDR8g44/5d9iwYbwjto5QoICDDAKrbO9CLX7bnt1XDt/29bPeBXr8
5MwNrhre9qC9ugZY3lfIFjkKMJwPImFCadGAKgqSZGwR8LJg8WxGQsCwqW9O
gdP4AXK6EVyVN4xgtAQTGWoRrojEMN4+T8WrmX1/8MEHI3BmQIhbDusCIPPG
H4OSEpkES2lQN0DHjmkwpKnoxNOyp2g8txQPE6d5gUo72CdNeWMeM18IkJFY
kARyQ+bRTn85xjohWLmR3Vp6Wd5YawZ3Q9XNh8rSPBL+YsKbG3Aj78KejhSH
mVEA0cJpCDoTIU+eV/pomAHnNVnUzGMGGfjFxBGi5Sgs3cSNtw1uMDg99+i+
cOB2+lx+ffY7Pjuh9cTDOr4tceP2Gbu3FC05vUsTN/7MuLG8kHFiBhPW/XfW
EAMlLqvVbFfPaiisHQxBPcw4MGu5j4nVcAvellAQA4vHxhtvrK+WhRCmRXKm
uUAocjWSbSgczuIaMGAAWXhhGEYA3wrwxdPmGdBzI2HqJNUxysUyOWAYIn8N
zEG5iGKC5kIaF22YLMdtywBuSB4cv1uPQMOhE9xAvg0XMUrnle5CLKuQMaVd
u3YlzjbrHRUm42BFINZ7r0LTB3T93Klbavr4wbx3RxoZeEBLxF1ABtzYqVAQ
iYOuhdBuLHnKaNv7NauYgOEgNoGv48ePJxRQsTY7RUPjHpKeaAHGxYECHhsz
jj8daskOLioMPzpy5Eg2oNwHG8jTZ7TNq33g1D6YNfj1XAAnh2MtRYJWFdxg
IjIvMKcokfnlTGDB4qvwhjXbb6r11RUlUFhws4aoSRLSdGb9H4NULRhIQQ/L
WnJzVBtYxfqEJtbp4oTJw6WsVurzhMxCsshGlrA5j4YCmh8HFFjAh1y5ZVX/
EYaRiQtp78q3MokWJrUrk006dLbq7VUUgcnzJKbRcc96tQorY6jnct6SUFns
bHPbbLMNSXCBDny1OSDlLSxEcPLQoUMJUchxGNgFsn8h9OIgDDhJ3ha2LCYO
W80VVWszvYfsKbeUPggBmYZQ3rwU5p0wAOJKuMIAbOwV+vXuvvtusCXXYB7J
A1xZ9cImGlPOsVADDxAGxj4WJmcisgRQ8AcPHowVwvVOGVJkA+3JjNKAQpTh
HT/08NtP2+XHCzYVQB6dseWy4Tsdtm9LGl2QQdMrgofQQf8LpRQNLID5XjVS
PsF6efTRR2N6CuIR6JsDgoqN5AyxF+QjbF+BJn6CSHuqjhC1ko+QNwKkLA1M
QGNHDs7r/HbJBrOnnGwvQopXY1gL85vwBeNpBNPCSVUW/fWhfMSB7WZoTBlC
KiDsE9a6szQVvblU7cixHSV09TbY2ahMGwI6GhIltOdT/AfDPjuXhhEq4126
bjNQjA8uUvMLjDNnebrp1/f9C0s31eW1OqUgg+5XQIlqe03ceHvjRih7egbt
nDG97zttO4LV+fvylM2j0Rywx45/o7ixfHwfqm1EzGjixp8ZNzJxKoZGd9Tr
EC6tSh9bLwhTbd0GwpMQBk/CL3NERXc8FJg+DMtHeg8FtUhBCm+Q19a2bVsK
mZoTFzAhfiwQwYoIzwQfAA0rduIdCIXBEO/zLkinGWdmLdNtHQPOrCn1N/J4
gMPKqrxSyCptF1WVspByUW/DLVg8vv71r2Pl+PznP2/gkwX0gBSCylTZTD2A
38KNevR4kjwbKB1R32ZkrMRAB3AhbkRDYbVmQKyJh7PSmTXQK0B90ohjrjpl
n2/Mait6tPRqn7HFhcM6jzh8d8aTOyOK4EB/X42Yi6AK6Ui5hvVOJ9xQJkI8
Ae4C6ZQWscJ5lA7y2nIMONQz+5hQQv64D0ySF8HyE7UoWPoP03bIw3/69L2D
J+pE1MBUGmctmH1zQynuYe6Y2Si2qcrUqCagwljLK/OOemKU6U2lcqB6Ch78
EKpKKNfjTDHuVHUVTw36rBHLHyl1+NfU+llz/U2lKt2q0j1hRekibZJ73eJk
uJd2CT2k4IY5LNow9bAQm0HULmNrJ6as3GwTuDuzGHGpT5gwAQ9+AATB45zS
znhx6b+A+YUnNMqUxWW5j5VVPb16WU7aN7OKNR6iOoUr4LHwIRWPgxi4aCle
Gtp2223hq6ygPC0Ykn0WM1o4jU9VxrN22IOCeFqc2NMz4EAZOB+ymuiKUs6X
d8FMqlUNtLmt9H0zXj3yBvEA9g4w8INmZFi6VhcKFxlDaMYlH2FjCUW1xHgY
3GDh0I8spO4foGDWbHSYwcGM3NLrsKIxY8awxUcCQSZp6cI58JBLRu/25ent
6gDy6lmt1kzeacGIvbmGoHdKGpq/z5kcdysEbuAd5iMkloCMtRDFFh3ByJm5
xrQCegJ26tQJS4t3zvsinAQxQMKAxsCBA/O0LR7YKUOChziLQ9ltreBhokQW
iJX6jAq2hmRDbY01paQGQmAoMgOGjkwum4LdH8yZrWez8q1IKSZfYwMxOl2H
LFGmBp8LIPCkD2li7E2lIodNLvJ2OmRdmxYIbajbo7yBrQNlQYslXLesdE/Q
PGJdYhrZU0iwiRt/n7iBThfZ7OjD+5xzXLd7p7T/17M3FECizjw8re3yEV0G
H7DLXydujDimH8YNFN4mbvyZccOAvRC8FGUTbfSEE06AbzMpmMEj6yKxkAhD
uDu/i2ZEvSAoT2KlX1AirwmMZA3y1jnm2SKC4g0JJ8NRnTt3piaYXeSivBA2
Fua00WfWAkspX8HEJ5NH6mYFjR07lrfOI+kRs9C96gnPb1S/I2mMU8aZKbbi
sTwWAIG1SD+nVDh6bg4isvJprjR0sMFE74EiaOYL/5eYEJzEsxAJH10smEAO
Vw5s68yAUFYrlDNocK76QCuwk2HkhlTAmH/cXrdN2pF93L+fLXj37RO2mTuo
6xEH9Mz9MUcYjEcjcnqRo4yQW4RfVdVj10L8N9OkvgNuqPhkfgEQC6DlOcGN
wCMAmDldOnr/PNtzZ23L1kDpKiqiZJosuGdQK4su88Wivq30QqIldIi5IJkd
K1YWPtd8tlDO2AUbxSHzxZ7oBqQqmoutoAhLROVpwKiPVWWx+aJ+WLfXeoKV
Cr7F0GDg/HSDXcJ40XMLLStNYKm4ws4IblxYWgEaCaZRwiphOQaRTKWPMphN
GXlDFooSClOFl/ho5MiRRPcZiZebGGbmzSHd99GYDLQWk1kaFic03jVrhNjg
QAc/Gj5n2yLMg0gPLKUdO3YMy8GlWR1WCIcVw3s6K1kvVtWzgkeehBnMHPEA
55eGFBlezuT5AecMMtvWVYWos0FjeoyfRqLmDDwW1rJTOcCC6YOtx/DmD5em
YGTycsBD5hkQxoIJ2DeyWgGHrB1MH9l8XUrkimrnMYsWW0Eoa7Dvvl3HHtJ5
4cDtPnRC+/xdP6Yjfx8evT1/pw3sPmVAt0XH7nTOkPd+7tQtKXPq30tntLph
/M4zh7WE1pjIjKCYA4I9qFsesvl7jnEWh6n0pCMTIijS45JZI5gkFHjh+fN1
Xj/IaQjxzafu2hJXP7cHltJMH7MWhnQvvqHW6VJZwuYmFtsxcBRI13pJ+huS
5GcKcSaTy9c19dt1Rakj6x3rRC4GQPyW8sPNVTFzbZ4GY4NFGkhvLw2prfwj
KxI7iqWCEbBtgfV2rLtirXLNkiw9HNZGdFywLmVs2XbnFYrg18SNtzduDDqo
x5kDO68Z1/apmZvVEeAP+fvFwg0en9n6a9PbfHP65i/N2bT+UZSaB6a3v3RM
j6H9+vxFcOOhmS1V32+adWgTN/4iuJEZRD0ZPnw4dviozBZzk1AKrGwQnUWn
j1GChptyQCI2EaTmB5kXzFg57NG8EK4ic6Kxhk8ABMqnh7YptPXWWwdMEGsj
e9vJiEDTCLp8FMyBJ8Nm+BpyW0YykKUEa00qHkAv0vmlM0smRcXTWeP5w1E4
TcIVDXFf+QgmwYqOwBnpFwBBML6lVgPKCECQitA+cEMsDTiAEsZWBVLY91EZ
1BpOOKzbrWO3eeH0TdeHgsembx5BAnnjuhM7cPDBkdtce/y2N4zaJp/mb/0v
+veTszb85aIN6meePH3LK8d2P/GYtW6saIWkisgtUbVQeMeNG8dHmQjOBMzB
hDw/u1XgxV66UM7AkCjRANFzVdHm5VOPZtasMA+8W0BG/4XeqzsKcUZ3SfQR
5ksVMihBBNcXv/hFNoVcY1duLtbFHyaHt3NDk9Gs2uGuwX0MJWX/MgWGZULB
CiInuSbXwz/Xl2aCxn2ZHxTOYZlbDZIOa4RVyNI6plFY7Mu8rPRhWR83MHEQ
F2ppjuA8ewGe99CwQtGm8ZsbIBEJBADJdCMe6LRdWMi0GuuV6f3JOPDWbvdi
crRCFmmenK9naRATGD4BGaIF28x6++23RxrRDxt4AS5yGRuWYdUUvg4FFWHX
gJs99aAwngVMDIrDP5UZBP9XV02rQ8pLmW5Y4oEHHmBPsR4+LduINzYxSk9c
ftGaSAo8DQg8Z84czICaOvP8BNxmfBj/Y445Bodm1l1Lw+6je90+qfOP5m9S
t3B+ZcbWq8buePrQvY86cq0JyzZnfQqRYxuqyyoH7r/PhCN2XD60w82jtnp0
6qbBnAYM+Y8l6/z3u2e2Xj2p+7TRa3u+Bxx42kwlYeERWUESGiKHwj+EjmPa
xZIDShib2r9/f4v8uJHRj3vm2MFwcobRlFVSDMgyYN2FzZgLTBOhTBlLWHtU
Tpqqxi6f6z9fiI+M97bJ2kdLCzZ9/Z8sZPUMA0LcNYz6qEOQthfTAMN7rJfI
JFha8gCwYtjVKClxwzZJkNXL3QrFBI14K0pXRJtC5hqxxdw3VIlco6GjiRtv
A9w49sj9Lzl+p+/Ne0tICHR8etJ2Zx/Xg/oDxHjk+H+EG/mXsc0YEryxb4+u
4w/vcs2IrR+e3Oqn8zf8fTLJawu2+Pi0PRdNHv6nww1+aOyokU3c+IvgRuYF
Q0F4BnUy+ABcEHMYyjEyJJ8St8NUjho1ipVo3YbIMEjXZ555ptIRTxvdUzcQ
MxtpkEFjMEOZCD7KNTxk+I0CYuEW0iVQgcUEzfha77Hn77zzzmrK1vFAFwvr
Ag4mOtkw0by8ejA/Vu6sd4vCmWqNUJpXwKyhfWNNrc2fJR2MsaF2BConOGkW
AOUpQsFM1KvgBiOQk0ie0VAIxTxt2AH3TmlvFOjPF2704Oldzpk4ILrAuEJR
HDgIBOG0yqcs0gwFakLmGmjCSxvCBAG8GMxpggwRX4fv3WVm///OePLKvM2u
OWnnUQMPOGxdCnbxu3kFCoDk8bDY5PHYm3INXqRcA9xFoEK4EjdyB6A1Iwn+
Zy70d5u89qnSXiqzgxZ53333iSRomg899BC2C5sIA/4h/SmfKm2Fqcr1saor
pSFhkLpM+ERHCQd5EgPJrIIOelAPhFsFJdhTVpTGvuE0cIY8plBWB6v+yqoT
AWn1Jpg0pLxRihxm44DFaBVHPCb6WO2ypG+U9ZuTlgnNyKMzBgpMrgRA7PGd
a0AJSknj0dO3zu6A2SpE7ZSQzW7IlaN6g1mTJiqa8KXPi7HN7LNa8/rYUuiv
yg5rxDX6L4GIAEieHP8dtg66xXEmWxg7b9Rw0qAyOII2VoWgBACen7amBNjy
kaq1fb3+T3iMSaeQNYGgPj+4Qdyp5l871+BAzF4M3uZhMN4ed9xxwAUxGNil
iZPMtCJmRBq84MTdnyuNmfL3xBnbXjnpgOy/VsnL5LIXUwYwZD1qNd8c89H0
6dP5Vr6OmBdI0Wni5pLRBrpzAKsYm7Ffzz1mDtzlpjHtn5ndan0AeXbmRucP
atdnd0TCllANjNiBd42fgEPm96hCdnc1fMWgem5rzmwAh43gpqoeOwvQEFz7
t2qDysSx9ediInBsFxXoAFushUhVDaq1MLmIyiEDeAI7lo5UNoABqHdESp1Z
jRbWCJ/AQspCARMwUIniutJfzwrnua0OWS0ewAUmfcK2OaD6Xz1nVqHCnHfr
mYstlpw1Q1wDabatJm78beHGWdPG3XnG/v+8aGMWzi8XvevOKe89dejBw4cP
R4T4S+EG9ZNDLXJdr13PHtTxrnGt31z0zvUBZG7fdu/baYc/Cm4M6HtYEzf+
IrgRFQPZVb2SBvSUYoATMk1oLtSPDYWFbPZhSA9WCNqYhqLggCS5OYs0Pwcn
G+hu/SgzCDR9rKnauZLZgbSmr3bEiBFBM6sI2jrQ0lUoUxSaQFuxBysfkSUX
ylPxJMbn61POsb0qGgoPmoRiI6fwEnNt0A7VFZjf4CQvTjcKKkUzJgFDlAgK
BYT6FiLUM0QK87WLxn1tfrffLllrnHx57ubLT9x1xDH9rIyBnB9dhsklxQD9
VM1XG45nOFBqNZuJHlvcM7sAkVcBMdYpzh3iN8DtfQvhVA1FqQlin3xQ+0+M
3sJaZPz9+5L/8+VJm+SjCB7GfdkRxtg2YHPChAlocFRgCGX2Xztzo9xnxOG7
gzZMZSjidMbcgM81hQzlQuPAjmExFtpcGt6pYmLuob51KN9CyzAoNLBjeDAX
6zzVCUKSPoknFkXX1+az5ecavnh1IRWWPICGMsuFmWEKJtSL5LBZZ1pt+qn7
Ve2mod6gNigy46xjHKLDLEGJxDOH2F9C2QUa4v2yy5iiiI9s/RqYmXqLW+JQ
y9JmlwdDQvktLWYsKIv258VZrdZ1vLk0VAp+8thz587N6kDBF8rsnWqQQDiw
IQIKMAyFJ8GNbK/kfBFwguVB/U5MA9vxtlMu0uxXKFMJbhDVTKYh+B/8IUkt
FNDjxYnwDJGjV1fegxg4NPOOWHg+vujY5+e3d9F9cerWpw3uaXZAva5mKNIF
bHNpac2Q3QquUymWTzTGmrtnfiKmWoYCLgoF7nj+sYWQTEJZyybtGkijUBEa
fMAut45u8/P56zhlfrXoHatP2PyA7tt17twZN7oN+3IfgGjAgAGMXqYGlg5I
PjqjpbTImYN3YfbDtMgkQeCwOvs7i5GykF8oxMI3U0DRMWIGJtCAgN0uDBNF
zMh+wZkcwAD0gQ3l6xRi+spXvgIQKVRoDSP9NnR76elGspu1gHg2a0lRTShk
Wc4IvdzTPG4Ns+S4MbkGUJlharEOK+rYMlg7KuyqxSNbFewn2mgDyXETN/5q
cWPRtNEPLu7zy6VrzQW/Wvzuz57WeUjf3jRl/pvDjRDFTof26XLbSW3eWLAO
gDw9/d2nH9H2D8eNm8a1JMPePmGbJm78RXDj/KrpWygsYaaDflhWYkCAqTSV
yTp1UUyslqBfBued2RD2AVGZtVlGlFmWfzgQHSTsAYvmwXxrnBEZt7pdF4H/
+OOPByXyDHBpmNM63gcXUr3iaW0UmHWHPyiiV0OCT72KGquMhyGSTWXENBNb
h6sdqCfmOfE2BqaojhXNgrw847RJEgll5G84vd+TC7q4pn64qM0lo3cbNKAv
dRGptYWHJZPVUAYh0woCmFRo3bM8nnGGJu5ZYkWFhdenfIoYwsifV3oHZ4Ls
BgjbZAYBkOCenIAKgwckZHpLXiQ4P2VAt4embPHvtSCQqDOL+7cmP6VLoTAe
OpGtY1v6vIxr6bX0swXv7tOrxRzXkqBXEbYOHvKG0rT3/vvv/0pF0SOwQmi7
ADpoVsJ6z8V26qRYfV1zYUWbugIsoFZzwcMPP2y9LxApN2ex31IaMJkdQ448
GkdQBTChmxVNRVFn1EEyIyAJIMYFzLJaiS2ZJAvgXFY6txrKZaYqqT0wAHNt
AKcFALWTBFJMt8934YRo3LAiVQ5CWV/s2uv7OsMbukGxNiwZtsv8Id2OOnT/
rAW+ZdEGAzCsb2lHIRoGhcJaWAUjlmAMzCNZqJkod5re6vdH47bbQqdOnfiV
emkIEzR8bJ4tv8jXw/Zsaqp+ekgXFyIziCxgBllIzwGgXQ/HZTyzO2cTxNiY
wQQc+vTpAyZnWbEogmBnThr52Tl7/GzxFq6jr5zeaeHYltoafCuX6b40eRkx
IwPCs1EoCVa5oZBFKS2EAu65E1mqQjvPlTXKZRqNYUXjk/O70wsBIHlNKr5m
U2Aq8aWGMqc8NsgZilj1/qOOvPKkbq/Pf/dbQeyL3nnJ4PdkHmk03LFjR7gl
fIi8Gq4IFNNuaeW4PTMgwQ1jUXIZ4ByeYZXRJTxER+xQjjUmuPWzlrNs7Z1N
cZVAB1CgybRuIGXVZ98HhazpZDIj0EGZUIwtd6xLoIptF4IGoNyDDz6IvJRn
Q4ICz0M3lQJQeQBtIMw71bQoPMVUUrCI0AKNeCCAvJ3FhSzhXrmoUC7TvsE1
WYN/dNwgkK/Fdz93k4+N23bh4B2P6LljEzf+G9w45uh+l47p8czct0ph/Hjx
lp9dcPDsKSdjjXx74wZqWobixIO7PDH9rdC1Xy585xmHbf7f4Mat81pS6X+8
YNNhgwc2cePPjBtGRXplOB82CICogxMAFlgwgJAFuE+hqCEtRSH263nDSZ2+
Oq3N/7eu9+31s9718ORWVw1vO+GQ7fbZbSeLR4UZGgpJWXUhaxxEsgJeVg2y
PT5fVlBOAjiBBXBju+22I/3NBPz3FGrTpg1lkIMqCMO5njcyiS+SNszJqiTE
ceK6dHKhHANueFRDuZhv5essFkKYeEhc2IBtfnHm4D2+ML2jLpLfLX3X1xd2
XzFzGCaLvClwETkfmSQqDOpJgIgnmTJlCm7crF+mLxPaUF0tAjAMGY6CtVBe
yMKG68JU2kBM4qMHCokeEncgsjeUX7RTMEied69bPyDgIoPDNXQdDeVYtFlb
O/3A3b5x2ltRZK/N3eDYvbZissJ1sESmidC415Zsk2vumtubjSNEfTCU0AwU
iyIKAguQXr2hRx55BD+INQCz5LkmuEEz33r1aWAnAIIGQT/cEA73UJY2EYBB
CX7iySef5OtBG9PiACsbeAWmRJXAO6MdRaah02ieil/JlOnjM43OXFHBwaJ2
Vveyp5jNC5AWRAmtGUsL0cIJQMCUYU+WzLUZLhbQMPQ0F7CXhQFMukS/PnA9
ymyC9lYanzigx3UndvjS5Dbr5zX8YN67vzGt1bXHb7vgmC6nHLnTQfv2COxo
XzUiERyoV7lEOMHSYjd2Pg0UgAkBCloqbLrppptURJn0UI6pBbR5odatWwMy
HTp04HfzJEZck9d50EEHuZfxsjlAuMoBCnuQQf8pGJslYIKqxffwU5/Qd69b
Ttnp9UVvxUe9uqjtTbMOnTBqWJaPcGHrupzB4pSJYJWdUihIhVnDnjj4lNFq
WekmUerrN/fWuq9GyUrYcCwJYpykMQn8ivYxCrCHAgXsO1OnTgVCA7AcZKU3
hPQo1AX6QEu2p2MP3fO5WRs7Po9P23jvXbsoptKWK7Rq4Sjw9tK5Y2yaYGn3
zAVbQH4F+erTn/40S/LLhUhTJZQUJCF2NARi0CGLjx599NEnKnrsscfot5Wl
rWHc1AniTmnLFQrOKHgYECJuBDGQHCK0iMycySMheASgDCXFVGWYKMUPwRwr
yVg3xkAOcYPJpfol7QwUGzRiQAYkLK36VtTpT4obOdaLMXC/HRcc3eEjJ275
9dM2s6Vpw9+jUzf9/CmtPjB0y/wte3/bE3q3P7FPh/y9bXAjO+n5QzpGffOV
/+XsTT4zp+eiaaOzoDLObM1N3GBsMxEnH7z9D+e9y5CPj57YpgE38r7fOr93
i4F08RZDBg1o4safDTecQdNYchOU2WjxuDYyp8x7pkC1FE4eWsjaCEEVFg5B
QbR51TNLbNjRfXadfNT7Io3cPbHdM7M3/33pUf/l33fnbBTwCcjk3/zdMa4N
UHPZMVtM7L354D1aH7tnm222ak11QfLu29WIUh7vqRF11FVnwJDQ9ttvjz0/
YKJSU9ewsM9YHG/PdclqOZGmzh3a5eFpb5UCjmLy5bldV047Kgs/ajjqzPvf
/35cP7aUqidoEBtGHhCthRpa76mN6lkzG8hq6hQ6szJVSOjQ4mE9EOo/mOJt
KyvLhsCBGN5DJllbTS5ogAoTrQRTDzlWoQtK9Xu7deRFeMcWS2lFGQe45YJB
bd9c9I6i8G5w8oHbqF0GKBaeOecnS7ZqiURd2Dk/FOC1JEuAF1aMrs1DWjjl
3nvvBRwEEAM+Cf4MZcGisORTwvyCBo9W9NRTT3GQT1FG8imYYDfYnMHQQXsd
1r5FxkAbglpNf8NXq4KZ5+SLQR4egPrnIZOnMrkoLAaJXVO1WF1ZVQLkwEAC
dw2xhcohoI0BYCaRabszbAxAMBSZCArI5krUHCP9TeUdvT4bnzvItEKwdNRY
9s1wO5CSyUVKsYQdESBsxGzK/Q7uddrA7vm7adwON47tfNepHR6f2Zq/hpJT
f/jf9+duGGD58AntLh+2TWBq8CF7WDovMgOyUCQWMCHgQNxRx44dKXAa3MC+
+t5CYVfjWIyp5j4Rt4zAx2588N47R7q4f1LrOlx8a/57r5126Pjx48PJYIKp
qfkuDuXABfEbNGkNZbQbnK3Z3xtSlggeZu4aCstb9N7GENax0RYnkljckgOD
59lMTeOVdPe7PdmmjZrwONCNWYVdKZRBgRqe7dyqEXno+OOPZ2SsA5NB3qtH
t8+O3+I/y0jef8qmPbp1jdqSkW+pAzn4kEhuLe6nxb0i7YTlmGULqg8aNAhZ
KL/C+955553kL0ecAAEeqZFGjK8Xsgk4gsfjjz/+rYoiVAgOfGQ6rc3Eta9S
NDJkVclIPhFCCOrIV2z9xrhlCggOyXMiw1jcwyK0lL0F5y3k4nSbKsuZ3JMz
ptMaA2/1fuyo4AkfmXBxcenxRHOEvwbckCLeu7QbOg6jPgw9uEVWyd+UAd3y
N++YnSO35O+aEVtHzfnalE3y9/uQJBD0xKw2/zB520uO32lS/1369Nr7j44b
ebyLh7T/+mnr5Ic+NrvdhyfvM/7EoUZuN3Hjf4QbDPuRe3b8/ty1m0i03Xn9
twU3QudPGfS7pe/CRtrEjT8DblizlGwRQtDrxTSwoyJnBiUIF7QFp+VPtc3m
Pg354JHGQRLzpEzWxh4S0nSQkwcV0pvAkqxfY1W6IwthSaDuHGx23EFdp/br
8sGR29w1fstvztjiv6wX8Y9nbPzQpM2uGt527oCO4w/vQvirnh1KfOQYuwod
QEKU8ggRqHn2xEEfmtL7izM61dui5e/L09tdfEK3iSe0ZMHjGbQMu2kdlibI
PfEQBS7QygMvGDEy4CTB2Rc+kK4/1Hg/o1utpYzA6SINA6AdG6MYndq6ZzAJ
aThQLgAu6pliCNW5ieXpGn4upF8AD2O+LkyZ6YP78qbSlTXvAkdNmjSJsco4
4DzSV5vJzXREbfnt4rVqyzMzNjpwn5Z+K9mVIshx8saZhzCSFtyO+gwUhwlh
bBWWrGIWtQgQDMGqYNxXkAT0yGVoJU888cQzFT399NNPFOLrpLZRuJjX/9zn
PsdPAC8gDI4VdB+LiXE9/nFWPbaLPGeD1zgDqKXCgmNoHPpTmHFWvcYQzVnu
KVq0jCnVPga3fLj0qcwNNWppIbEJLMHnqKvozsaih4fZFIIhoE2+yEPqyKsX
ooGCKtpJ2G3DFYoilvgAJbKCTKarG12hdapRVWQwuY2Vqa4fioRAL6eIEJgs
ur23/bCeW11w9BY3j9zsK6e++7+USZ6ZvmE+um7YZpcPbj2v39ajDthu7CGd
xx26w9QjOy0f2uGiYZ1O7bfzipE7fmzSLl+Y3rEedMHfv5694YMzOpw3qufI
wf2JfgkDZ+t0B2wQtHLSRqtIFxkfNkdTZQPC1qNGlnArd98nsh1ltkG9zUdw
1KpCNAVj8WrqrH9KZU7jGylqEQrHsgOarRwuMpze+F7uk2+Z/cd2SekbijV5
H34uX2e7iRCLgTSIoR+cgwwRJqA+e+/69PSN1mp/i98x58h2mfRIbitHv4+T
N8w4OLwaoMAha7Jt5oKbZ1TZQ7MSkS6yrrV5IoEAHXRe46MXXnjh6Yq0eeb4
uYqCIU9WlI8wkpDahhUUIMpH/FbkBwQYQtkZnHroOAMo4Gd8zLATNxh/k1Wp
8xOihgykwABu5Nh+1lxwTa0WK2cMEg4jWZFGAHHS/65wI9pHh0I4X3rtvPUJ
+77nkve3umP0xi/N+l8aUiJmPDxr+xsn7THjxJamaZj6c9DEjT8RbmSKu3Tp
smTAW4LHV6e2GtC3pdHkp0/fmzMrpx3VxI0/HW7ohzUHwbqmWenYw4MShvQg
OUfFBmRUnSjbi1HXEET1XMTXgIyh7yg+YYnRhYiNzAoCSSLMswAHFYp2g9hZ
RxI7sO+1115kwURDATds5ROU2Laitm3bEgnWpk0b/LCbbbbZFhW1atWKMwfu
1Gpg980u7L/RxQM2uXPMJo9M2uirkzfO32NTN3pjwTt/etYGX5uyyT3jt7j2
+G3PH9IxssdhvffCxGEuhjWpIOCCa3DdAhdqJcCFkZ/RRxocE0urVpvLqq7i
SIyUHAyZMHV9rVO5YT8GAqkLy06o+dT6hnSdiBvoEXhPOAi7wr2khoXyc5aV
41fyeFbMQ2KPWI6aY5YHykso0MGL5CEx3WRPocpKUAKrTvBTDyA+l0DB2vC5
Hl2fnr5Wbnxz0TtPOrRLNqA7Z+1JUMc1px+DemLkgNHIUVhwSGVIWa1Z6Rg3
oo98oxDBpcEQ1nuOn6ooiIEfNgecCW5wJt/iYhPqyXoL0TU4ZGkvxsSSIOgp
wVKVQQD/Q6Xhl61mif7FdgFcqGhYQMaAPd2vRotZ5CFswwElFm+qehm7Eehz
0Y0LgGSyrOBhNT8Sx0LhW1a39SENj8xHXFnPpjEm2Y0PSDG8ua6CgWlkSIVs
/UlJCmLdOSAAgHoyuCyzX4QZWHfu75S5JtzCEG7MsLuVrutBEmyeW221VYND
NmBCNoTY0rZQAIdvWSldh6yeZbvFGTyQB+AAy4wh0Bj9AhcsAYv3Rpxj4ZBs
iL3CuBr3FMAZ2yY9kZEcMu+udMMAmG58c/AVM2KiU4DCDF87SUH0PHUv4HpK
a9quNBQuwlZmawyLvWcxsnBsZhd5w/Ke/Jxdh/J4GNMy0WwcgVbGKpsL+Jkx
gVtOOukk5IeM/M4777zi2HZWSL51zFYZ+c/M2g3ouG7e0DBweEaxFlLwCMux
OrK6MWx+9atfRd6oGz8RPCIzPFZRUEIAgXKxsRbIGw8++KCV7U1w48COsXl9
0RWEocAg0l3GX8mhLgqGiCcHHPhIiTFM0lDSZ1Wt35mmJyxX9AfkAqbYnAJj
SkOc+VDppp3naeJGEzf+1nEjdOie7/3+3LV279fO3GjauOH3zu4mdDRx44+O
GxoiokRYA8ryxeBGJGc07rFjx4ob6CkXFzLwzAJTOaPALOni4b8m7ZoyYwCh
TeXIYgvNnj3b54nSZCELns20iAi62OHDLTBeGMb0EHSZrH16smD9CHUu1LVr
Vx2ynKHSYIgk/RCF8kIWNwuBWtFQ4Mz8KLydjyyDmadqKONsDbQsGRZgJkJt
lDnFAB66umpoS1FcWMsu6mRmQUyu8V028oiACkddXSqYrS7d2D9RSC8AHYjk
JaNMZV2bfTCDJkmFf3haM8WydlTniZPMMmnI2Aqf4FkOljJuUUKZNRrfhGzW
E5bA4pFBRkvNjGR27j55bQzh75a8Y9bAnR88vQvQ8Ynz19ZOtKtpdhlUmMwI
vqq8IwoLPTpD0TVUPfCDfO1rXxNSnq3oueeeQ5fJxUSi0gc2lFsBCHlrVBJO
Uq2LQaa+PcdqLoaeqqeIHpkCJo6EFPjByurmMDI1tisKWbef++SyjxXizMpS
F11EIv0tlGXOtrWqKiQeyo9SqYPYQoC3XmyBlZs1y8SF4RlkZ3BF1fieWFP7
PQlTnDF1ThvaytKEmoYvIcFKR784Ru0ygMUIE6NhPSanLwTChAg4CWV7gknC
LWbhGQva0K2JHBlq3HFgmcEABVZNZQlyVEO5ufkRxtvDooTOEl47fvx4LMzO
hSOjdJHxYSrd3OkiWhcqDEoMv7EAqYfJpqbkAJ6ESzUmACzYuLBvwDzWY3dF
01RI65l8a3ki5MxlpQ2xsE9FylDYm9/9XCGq8FFUnDWVNWIAJDtR9gIkySAG
RoyMJBbmMJ4CGD+ai/ko14Dks/t20Fj6ifHbffWsFg/Lv5+z4e2XtRhCIzOz
ldRrt8Ik2QpZiRk3E9yECx2pOGQjcoAbL7/8MjKJ5UnzRVcrrx/ktGih0arW
ErR3m33i6oEcIgZbCQ4IQjuA9LpLXRM3vw57WDsI6cJaWJo1vP9l65KhvHVr
vNE+Tdxo4sbbCTcyWb17dFFn+c7C9kLHXZdOaeLGHws3Lil14ep5bZAljrMG
MfVTJZucCCtRcHOroVJhD6+udTOsoswasYyDOlQdB2x7ZFVVPcX+1rJSdNf6
VMY7aZ/JT9uWDqUmTIISYTR4lA7AIbhBMouO2qgwQAqhX9Q3tp87Zg1ayYTo
ahTKR3Za52JKF6LL2KjResh5fpek9S44gx5R92vIJGEqhVs4MBzL2gRDWJiW
3kU7uP/++5Glw8lwpt6TMBWwE5ZGuSBGtMFLe22NGO28AlpkxhlFIzPF1IQV
bZjII+WnWYlZgIRU5YdsNsSsoU2EDBjO2BIsF9Rlc9GJEDZA3Qt0MMIZ8ExZ
tMt7xq6Nwfv5wnd/c35XoGPNhRNQWILz/Eq+aO9juD2PjekmD4yl4uFCjzzy
CGaNIAZxX9FTvl1RoAPTh93nKWke+nghmiutqfq9Mi85k3dnCj5UulJqZUJV
DF1dik/qmc3FzItBem4u9LWEQ8Cr+oE9KPk6SYshNwLrZLr7W0zSqizhTAsa
ZxZYnpZwyZWMpCVZMkFIIMob9fLpZu5bdJ3wD51o4THLWipLSMCOLaVyRpCx
Wh1XUjbHy8SZBiui1RSNgM2LYPoIK+LGNZ02zAZctGvXDktp27ZtQZL27dsb
/kFjhcCC1RENKeGGdrPNt7CKUFYRIt8tlOWAQzBrAVufkTDaEMIwGhPYQWj0
Q0iAYgZc+qUvfUmt3KovBhni6cs1uBr9yM1OgLKDKlEWFtOD30i/4nrD0WHp
TBPPf2XVLhwCYXIrwY1nI+g6lOdncWUXY7oD8sT2RFSzvzlCxbhx4wgMyMwa
3AizZWaxmQfD7dy3/Jit8LP8bsk7nprbHlvHjedNCksEJayOApJruwvfspQy
bogZjz766EOFCNKImEHYRoAC+wZCSCiQ2JDEWm/HwDBqeQgy8F/m2mgZ6/kw
OKurTsq4U8GNevVdZMhcbIAHm0tOWhbVHYQztqbKHQAQi9CaDq8kkANL+oAb
YdEmbjRx4+2KGxH5Tjq0y28qc8d/Ln3HS2e2FTqauPH/iBuuMmvfEfqFZw05
P1ohnlDKZYcIIg15EEIr0bGLRwYAQSYnyxsVho+8GHGowR2svu+DeY3C8PJC
2kMurpE4w3+phR6KXMqyjTCMySLKCBGkhIeFAiCk2OckOfg5Jn4sAAImWBLE
PlDRbrxGAMlJAEcIiiDN9fvttx9Pgk8wFBGRBZgl2aCMZJUROBQGRpumil0o
Oog54F8txEcWlDDuSIUlgAMjEQJEk1NVoTBhQxlwOkwhSMOHQkqdt82Y4CC8
rZzMz1lgnESwUNYpcxSOIhDOjD+d1xkirEOZZXADaz8aMR8FcPr06QM477rr
rlEtD9hjp5/OXxsJ/MOFLQ6Xf1u68eoVc1BwSJsKRXPBMz5z5kyeJCjNQwY3
TEwDHKKqYNYwCQ7Hayi4IYDwkYGjHy1kFiHKS4PxAXNTyBjRXOYOAqZ9sNRL
WVVlG5EKBJOEW4CpnETfyRlT7SxuBm5QOSFUd+Nqr9BQ4P7LyERd0q5oibAc
IFREQmAujKCYPHky645WX6Ggimds6QI4qBb9l4iEAGAJMg8sZqh9VRNK/YwN
LgUKAVDRRYNqXkprDGRf5nAjBoqsfbyuWe/tCxHIYQWPgAkxHjlDBDs+Wcji
/yADJctCuU++CAQRKBKyXlDkHAAkEgsJetn78NVmNFiJ2S8MQVTRVukGInJw
XyEY2OzOMDzWPPdNzCCY/hBXwlT2ZdZ7S9/ekFJNji1rqevW0HH4XwjSfazF
Jmc0x7FL2mwovwjI560JTqYFWCiCB9CapY19PnsQLI09mR2BPS7AmwEkqt+O
DN132fG52WuzpH++aFOg4yMXzw635It240UWzcjD0rk/kBiYZagzqlo8vlJI
aDWonkF+rJCDjI+VGh2MQ1bunVVraby0Gr0tQ+p6t4qpoaRgsq3cbCCVB+CG
q0sb9NzH3+WNrONhhqzWVOt4RIY0Q9bMERZgkKSJG03ceNvjRuYix5+dsLbs
7b8tbvG2/PqcTQIdTdz43+EGegQ1SFm5GXxC9/VjBjfgZNPZWPuU5gABrP9g
/I9nlpamqPpYrYFscBfZ+mTu81GuB4XOLd3l1FxQXlCHfakcI96jcwFWwMXi
0gCi7uflV8KfNrsn+96i6wEQUMJSYFn4WDyicZD5skuhnQp1LBRAwGUTDQiz
Sb1UcutCVEsORbXhnrvvvjsZLiNGjICBo3Xi7LBYBHnfIQvWUc6OGrZcTCuQ
ULgd3Ih0bZCSIUkQfAvraksJGU2qRw9JWz+LzuKAjF1C9NXarsXIYaK8VPDV
ynNPGDgzjr42ePBgIN3C1DlDaF92NEBGD1TWONwS/sl3KageJbQO6aHrT9i6
BIa19J3813M2//LdaxPSsz9S7SHMANuHOfEZZQSsJWjhL1PsId0otmTSeWTT
lnyLj7R4ZITFDfS4kA7020ufSv0v5tqvrhVAYCSNzjUbSFeL/l8J5KcWullF
qlEoRDljkx31fdYRPhe7MnGQVWytaetY4sfMR0CBq3X9MHULFWomDRrY0Xj9
AAxFFG2q4pilhIQm7R6XloLwoqIBbybm8HhAGV+sB5bwkJYkGjVqFI5UW98G
QBAq6mUGCTi3ZnLAgcUeJOHifIp9I1hhlGn+BUxyBz6NEAIEIYSEWrVqBZLk
I1zDe+65J9HRGX/QMryH1+/FF1/8bkWvv/46gQSUswuFdcENthWqx8Dbzzzz
zPMVPfnkk7D9Z6tmZCE2NQiOwqOnVVZHMAdoxISkIqhg9yN22ihTyAQro0xv
Knl5eUiDq1kImS8EgKxfk4iRxIIbGDOzqNnjMiZmfrH8w95mTQY6FCaxfmdf
OG9IZ+qG/cfSFnvpL5e1vffj12bRhT1g8kAHBpZJkyZhAwmf8I4ZKHPQsC9l
VMmAQxoJ0S4hFNywY7U2KEttQDhbGQGLB+a8ZxAh6v0XjA3W6woZr07pjzVV
72mlFGY2mFaPSiV4xsAqQ5G1lFqux6Vt+ZcmbjRx4+8KN/bee+/J/bv++5K1
Tpb8+6sLtg50NHHjf4QbmiN0m9K8j3rUFgAESbJyEfJxt+FxsyOPSGIJO6BA
SKkjgKDBNVbTNe6UO6g9hbLGPQZ80Ds0/5pYZ8oDy+28QphNsJP4AMa2YU4P
cxLnGQDB8pBVj6WiU6EABSFh+F9CQYDW61KUkQ41wmCCbSS03XqUj2zywjXR
lVCdevXqheCdF2dtZuF/v6Kf/exnIEl0EJSRaNyoJxrwwzCciXaDnhIA4VuW
49aYL4DU4w9Xl3R7K3LodqkTmg5V7FZVBcG0+Qs75rZwJtfDxtSUCOVbWCqy
fslP6dmzJzMycOBAfKaZJla0vqf8imClohp1BtUjNyFOjzILoeGH9fj14ncK
HW+cu+VnVl+JNB7oILi3XngNlr6xdLq/o7RZzKiiOUZVxOdipWIb3AdAhBTT
+sB2Gq80eM0kAV/XDJBFxj3qYb4ubvBRbs4NtVYZFUwBBMhGk+atMGt62FeV
MviW6MnyBDfY3F2euFPnzJljGiyzYxJWPmW/rufauKcAILk/UODSDhQgAGR1
a9g01kK0UbRQULFdlKuea+rOX9IkCQixDrMSCGq1LmkfaVmpaqgjz2IjM2fO
RMQK52BnsNiOTbQRIbCEsMYDFJtWZEGPiBZgRd2sgXuXj5BACDMI5W5cr+00
SMKZ/Byx64MGDQLAM6cw0pOF6nVj+CibFEsyTG6wBztgriHcMdejlYepAAQ3
sob2B0YgGNVsJZ8G3TmsyLcoH3pd1TYOvjUA0motuachItpPmMeJEydi1sh6
Z/xpjBsKdGCoDye4kcH24fPMu5sCW6G5cvvvvz/C5B577DHksL3/7ex3Wnzp
X85v/8lbPpwXDAMTHZ1fGVYIi0fu2VC4LyCMCBcQZvxNkjVGxXZvISyoihy8
tUYMwOTzhWi9FKKaUCgo1FABKQ9sdDrDyIwTpKGtW2DnsY3oMKg1E2qUshVd
AJAMqeUBzTw1/9QUA4MrolbYOxgTd5YVM6IRMmhgsX3LhohOKgWihMFaJsXw
SISRE0VmGqzIIP7wLeLNRBXTbw3b8IwBYPyu8WYXVmm/9f8qeGhEDb+Bliee
eCIu/sMOOwy5lw5KoUgjiBO0YglFWjD8g1WfT3OyATdybOc4q5gCIBQaotaQ
oe/gVdYOTxKuZrTDJMjJzxQi1BmpGPZTGQlTsUuGgdkl80VEkf/SLWLeNGoI
FUeBF7USBQaq+oe8A323uRhWVHXKF22swEc5aUg8d84sk+pOZ/PQAQccgMJi
W+1AKLyxsrSZwx0ATxrbk9mEgSOzUQEsIlx2gcN77frPC94q8vazCzqtXnVl
VhDbU9CGX6GxZigbKLydcWAkgxI/qei1114DQEyxD4bYRkEAQd3IqjcQKyPG
gQtf941tGjJNhIvoviHHJ2QZZHKZsalqO1VcFLedLDNzTStQzAAbRZvcgY1Y
eaOJG03c+HvGjdAh++3x84VvNYb78QVdbr35hiZu/F9xQ9ekFf+urMqkh4IP
aJo2Dg5uACnLq/KDFPdgbV5ZutmaH6f7BserCWtAynnrklEZ+XT9KFNWNI7U
86pK+wZpaDzxwFtpxPCniVqnypCuJe+j1ZSvmyCcM+BnJGf456ijjgJAspBt
SgsOUOeHeFFsIEGGLHziN+gGhREDJNF8Gugg9NQqQ2ouuScHuRsx7eFkKrXm
2Zj3sOs/VfTss8+CCToBgxKmykIKw3VjCMxmKDKai8ZPraar1yNzPEEny9zJ
rhbnkRWNhcYMVQ+O9TmDKmTMHXPMMda3J8Gtf//+1BKcMGECvJH5AkjBIkEJ
MMlUMqezZ8/GQhKVh2DUzOBhB/V+dd5b0PFPF3b/4JUtjYoCSlRWz8+hH510
0kmY1/IpD5lxBq7/sdCLL75ICPrTTz+NNenBBx+0TinaSsYK82bGM+97TyFO
ZhAAB93uAR9wI5sC85VPbXXtwmeCBBDhGhBg8I0g5fm1XBnunhkhfkMbVK7h
zCVVWzcMmFlWLHwRmxqVIeKjQhlAdt6MmDksujMsIqovoyH3hCTZkCBzUSk0
amiHZgrDxc1AqQeEaGj1mnowOXJClpIoAWEKVmi5uGoWAIDUrbjafPg6lXMo
ngNv52IAJAvWuspYHqz31b17dyPPkUnCmfkv4BCUsIyYRgyki06dOiFv2Ogt
u6EhJboDyII59NBDyd+Pjs/Yhv1erSh8i379zW9+E2ajmxiJruwy+gXMms9J
q824E8HYIcMtTLrMMtdFAjiw5EMm2xKsTk1jMYeva3LJF0154Jo7Sn/2/BwT
ccopp2DosCZSjhE8hg0bhsEn886EIsDwtMZmX1O6LWfHwYo1evRoBjAyDMaT
75/5Vtudl8/pel7VahkPCx1OQ5lxzoRP+IlgL/Led77zHXD7u9/9rpZqyELH
1v954IEHkDEIrsDmYMx/RgnTJb2tqWLKQc5oILV2q61VwAQKLyBdAM6ZLAzU
9qG4ubSoyGUfKWQxZEQCs+Y1j3/wgx9kSWa1NnGjiRtN3Ajl5q/Nf6tb1rfO
2auJG/8Nbiicn1cSUfMVl5sqAwmtpG2G6jXSARntGytKebEL1qNlpZKPtgj9
Gi529YXzSyMh1RydthhhNFDofOFpfaN6BKmJOXwrZ1TZfEfsKgi9eHysnKar
CGwJoxJAG+UXD2kUh4YG0/1qFFanzk8ABHDAhxuKwoL/JRiCQ9bQU6sRBijI
DO1dKHCEep4fwgiQqUHgjOyKVBw2Q+OOqIzFAzs8RT7BDe3q4R+FUqs3RJq1
/TGockuNYCrjFXNGAwUHWjPU5VHDiXxmseTA9qZwO0lza6pyhYjH8+fPZ5Dt
yZU1zkIeMWIECzkzCPvlVnWPMA9gKlnQCXjJPfGxRuuhcEdmJ3f+3ry3pI4H
zu6Nnh5wJrHu6KOPxrEbfYc1kp/AxxqgeLmil156CT1Fx4qlOXDOkrOMJgI8
8r4kCQLgqB72X8BfEwpu4BHLJPKtzCne3nq5DziBiNPQbVW6cchGsVm26Jj1
qkGCg/WB9bBApMGGskZcwmr6pqaeW2p+ZpDtzsbFmEGuLAWHr656SzEjmgu0
UtYtltBFJXPEZe63zqvi0gEHLJ9KC0Z9GHleP0PoGvWmtIfURQ6Ay2dD8skX
gYvwHlCQ1/SRTOR3iAAZC6CNGTMGFTgHrN8wlU5/651a2/+II44g5yKYgATS
rl27TSrS9GFjayPVcz16veUxqU4TihBCkEOWFb7CAClsY5uw8C0GOuOO7ij9
12S2cK9JrDASIdAwsHuZzn3RQ6Yya9uwJXRtbHHmdVoE1Th2bqjXz0qY7pIZ
cEbSDNkscAUAHLKRhGG/SBd4h101mG4sdAa7ZlFgqciUKXhQXuzFOW9JHXee
dSgBCSdVRHeG0Lhx42CbLCWgNbAASgc3vlMI0wddEkKRN3TIguQE6Rm/YdVi
nj+YwAwGMQjzy1Ri38jFDGC2AOSNgLBmDageGwO221pa46exN1qrrN5gjSBz
ZjU4Z901caOJG03cqONGtM5Xz3oLOlafObCJG+vjhjU/TRkz9vvs0nXaOKss
RtZdvca+egqay0WlLKHqif7T+gG/pZlCX4may7ml3mDIBDeIrwsdmkoWFQI3
wJy6x8Tj/KJpcVwcKCA4ljasobwv988j6R4yOp102oADUaaTJk3i65Qop0o5
tVhPO+20nAeUAi/EEUUwRgfB6IHXFbuHPRpoyhDq3LkzZVEDHWhD0cfBje23
3x4bSLCFwnfBKJ4/kwJDmpv5yCOP4EbRD2jlujAVi1SrTla90chqynhJcJSo
ApiiBZcaDOmyNR9TJNFXK5NTgGJ1VZa/ITo9axyzUv/+/VH3zHQbOHCgvRJg
mzC8Ia96Ni0bYkZeVgE6bG6L6pGbY6rKOPfq1eufiofl35e88/I5I9GGsh3g
jol+RHXBrBHWVNYyrdyiqmDo+OEPf/i9ivCt4F4BB6KwmI0YtQWdkVRWSp00
RJ7neqPLiCDNZeDV3YXuKHVljc0zZ9mJwM1KdJw6iCFhDeVBbIgQVVRIR1og
xtLWwIwkGXCQmzu4oR/2sqpbMYhk4KglmMANoeD8GnFboz5oheBJYkr9Ub2o
ntGCcWGpgnheSa4/t1REPK9WL4hrtLWKZlpoLV5qLkz2ILg0ax8/oFk5Rn0s
Ka0wcw3JFLkMacf7aM7lyS1NQCBBAAcAic6O+XSnnXbCvrHNNts09HYhAzdE
0koo2yK+WkPf83WEk+zFFGEOlPG0WYwwpF7XHBvMjHmN1Eh2AbabLLrPFDKm
sb4kESEwhGpxJUSEhRCAYiusZ2Rww1yjt9dwR+4sb2OpgJi1448/HnkjI2Az
blJ4IgNQjDpcbR66iaUGOdRfhC04HMt05+ZgUaADwUPo+MXZG5+74PQwRnYB
ton8HNOXY0JSg0WYlbK6X6ko0PFaRZETsHi8WMgm1CGjOzRMOU1BEqA40wRc
6Nu1GZzDfltJLCJ2nbhfQV4Tk5hg60/D1CXQJpBiHxO+dWOpk2w9nyZuNHGj
iRsNuBGp42cL1jaR/PGSdosXzGvihrhhNTAVjcgwmk9VPZDYw/koArhUQia4
5TKMAGa2ihsXlCqgRnJeUKsByK/XmyBbltzVqkO2btNoKDmYM/pBdNZw5QW1
MqTaWHh+Fa4cGGTI70Z5sTIqvFG3xqgBNRhDfCM90WAsL5X/MoC5J3pNGI+y
/2FXXCRk14bUUyj9QfUPsm67d+++dyEqS9BDKhQwwVebJQCT513UhbG924bA
Aj44WzGqK7jeWQqhG9OoxeOuUuDUVE3bIpufFXSC//X2Gm5kmFk9WomHvKmU
WDcpJlyN5jJ9+nRQIiuadz/wwAPxzNLRIJSxXVW1tMYlZIFNHUk+CU8bdGKa
ooYQ3HXwwQfrB+970L6/XLQB0PH42d0za+in0WswWA0dOhQNNLzBj2ZFk6H8
WqEf/OAHJCG++uqr+Fx0tUR5DEoYHWrBH9y1pjbnRYDifIUsmMALmKyrS4x1
4WtEsvq9QG25nqtLE/CMs0YhLs4Z9URAhn5PZB5dVqjeWE1njUVX9NuaCN9g
6rygSnclEsMoC8DBoky6aP36hSWb1ZhwI0PyPDyYwR7aaQkFV6rxkQzbaLiD
wsxlpeSyqzuXMTgkDpNQaeg7sDNv3jwED7s/KNv4W1eXjmZWjs2kcJ+Mnk4u
yiiF8l2wKBILmnL2O0uewrdBAyQQ40XbtWtHKaHOnTsDMpEuiCCNvAFudOjQ
ASQJdGDxiDjEQ4ZtLDzF2s86stiUxbvcv+rmCANNRQlzNnXpQgZ8GglpITJX
qz3m9NK6osP59nbxqcC08ABRsrhN8ZyCG0cccQQLOdhiSnjuzz01HlJ7hyBt
PsqaYuMIX2Fi1fqa+weaBh64228Xr01/+/Tc3tiOMqRYSoMbmEciQ8LbkWGw
fAYfflDRG2+88auKcgCARGwgtCMHZMCRSIu8QZ8IcmCBdx3iQRU7S+LSJUA3
ZNY8MTCAswdKiRZGhu2vLJ0fgwb2azCiAzGDvi0hzOYUcGviRhM3mrjx3+BG
aML796XIT/6uPev4Jm6QiqK3UfvGykJaHliS2ArqiR75iOHSBhJdhtW9rLRG
EgpIxcXDCxRcVGtKqyrB0jak8+JaVpoakKYGlRGfTa+Nb6QSpNvokhqZdM+V
OFnw9fhqKBdZ5lppfFQeUjvP9TViRvJRJkUhkKkJQAFluHJCARDSt8eOHcsS
OPTQQ600iNPWch9t2rQhDT+fopX06NGDMxpD8hH8n1uhwudheAzjr/SnKOUa
vhh15vZSwcNlbpEHNRfBgcoPdSO/So0gQwY3xg0jwRqSx/MRo2dsEp6dUDgZ
B1/Q1UA4jBJZ7Kgw6GXI3joiA2soaP6KSX/W06NEYShowK2CG/sWOuvY9611
ryzdYOWys7JPATLHHXcc1qSoSPhcwi0suiggOFbefPPN31X0m9/85qcVvfji
i3hYSH/DZBGgAEAeeOABi5dq+gCugxt6bbCZBDqAYj1TRHzBbIx/Pe4Oysig
cehYCZmLxMaXj6xlarc4XV1GV2YtmNeGmIGRk3ALIzFYZUomOW6QNwi5JNOW
VWZwJtGkLFslASUWXaWihEiiMdMIdtf+xbViREaSc5lnBAflDQM5LqyVNWYc
cnMbwIk2SkR+VIejepi9pXezY1qjxlZcbhyUXqFUBbfCvRvSdhohBIEh4gQV
hIIGRKdvscUWBntQDVWriH1bInIQ8Z7dmT0x0MRbOw6WyMhDwnXWIs7ubHko
c11VfrU91tOyQIC7S6nhu6peHqFPlJJWyif1bFC+Wy99jFnPUjz5FewkuTmP
PXr0aEqBRTYjQXjQoEGMVZbwtGnTGNIsXtaUQhEmHeqQ2GWGj9ZUBbJC2YCI
wAluI28Egffaa6+PjFpbm/Rni7cIOGD4GjNmDBkHAWeSZzNxPGR+lzj/CBj/
UlEAhAOcs6Hnn39eU6eVfwyzyVPZfwHpIgeE4jz77LMvVPTYY48pOBkJY+S/
aK9N22o/5roi3dWTARkHqqNgX7JSsW37mrjRxI0mbvwhuBH65ux2QMeTS/f4
O8cNnRR1BcH1ovuSBYiCUI/6cNW7AM8vOfJETC2rVfe6vLRwVQfJSe0bpq4Y
G9YAKXVU4Sa4jHVkiHJcrOmD2FEeHiASgs4vOXdiI6uJMDkoS9sgN4Mq0UHM
ygnMMuzkwTELJo/nDnYBZr2Eb/Gs5YAlacOyPIx97ggBHT58OJXHgI4Qqgoh
pqS3bL311tTx2HXXXQGZHJPnsueeexISOWrUKNwBeIdDeX2daCDb7aVGB2YB
LPzmU2gWMPvM0NNcbLY+Z+risaGk1gO3Yh50b2m1fHdV7HRN1ZeBQaNdAs+D
CpDBoYPb4Ycfjk6hdSg6S3QHdq7MlMYTno0+BfR7wosR6DB0k4szWXw9aIAV
JdBBI6fA1BuLNgI67lgyOGuHsmChPAzaZfAZ22l4g3cMdOCZjYbys4pee+01
AkqjsNBbNhQAIRgsj6Q2B5bqalF/MXKMMOBQnhwoMP9dPyzdDWg3zDUZUgPh
UEZuLH2X3EGM7M2xhR+Zkdx8SaFza7U33d81YzaU/sO9eFlVdcdYSpekMeRe
3LC0NVT6daFpRZWZC7E2c9AQJQ5GaZZRmFECgXxsu73QYC5k7VPvWc+fBTeM
ptaqSfAzYbeCg0nEooq4XT/jF5kvFdVouBjBwszMKYUNV1RFMnnaGTNmYIWz
WUOXLl2smYzgESTBHGpmLvUMtZGGsr6ouDt79mz7WTC2biWGfWKvsEwHKEft
CNY4vI04gSUBcDB0XNvFnVXZ4U9WXSNBgPA5xkOllDo1BLffVlUTojYIo0fb
gpA9VgIgCB6BxyxeHNCZVu5gUc28y4OFeIC8VL1QSSg/xJzOnDnTZvf7FBoy
4DBrGp8/d2JEOGLghw0bxgPQMpJmDWw3+V2m+Lvf/e6PC+mlDXqQs2bBn0AB
T2h4hv0xQQw68dUDP5gXZAklB7lUPqwnCHCxltLMuwHnVmQyPdAwdTgzu0wT
N5q40cSNPxw38ouzhu6DyPGvSzb+u8UN7Rt6JZZVDesxIOjrFF5gs0tKirr2
DdUTV+J5pSGCjhX1lEtKD2vNFMtLCUFRS7eI2OI1RIJxT/NrLispdfV4M67J
S5HEdPrppxNVmAO8GEES9SMDz6zCjVSMgSIkbpgWVK+IJTJwpl7QIEzoSWYn
qwPVNdyCqptjfIXhEysvoUTkpdCmo3TjdozqYUF1agkGQPCnRDGxh7UKC/XY
AziYBUaMGEGYa+5pATe1M0ttuGDDwKRvh5nrvckAED2qmj54cYJOQ3eXVlAq
2tF3LJ0HTK0pDWf1wphEU3cKGxsGZwYDSdjp06cPI0MCID6OaGS81KdLQ4Hg
lQK/FgMWNQpCKJexXsKcxHQFi0hdCfYCU3dM3gHoeHbhe0GwoDqZMsEZQknH
jx+P9ycKi1FbqCff//73f17Rr371qygvpLGosFirLU9rvCsAnpM4YW3YZ/Pf
PDbjnxmsB1fgBPlQIfjWwo/OiGXVTXCz4jSRY6HcGWTAUKlZQIHBTDcNjAZe
riikYbP+RRagokgDIrmQLy3dTwwaURTBnFL/lr8eQPCHNJNqzTCsVLOGASQX
V1GsGB6Bi6wXk9c0fViuREjU/QTVTUbWPzG7k7E1o9MDjCEqhhaTcSuxFpwM
4MbNMsmv8AAZBKJMw59sf/RkIa4D3IgQgoxhGfbABU1e6D4Z6tWrF9aALAqA
9NzSUEC7Lq9mAQ0WPr086iZTjvkvb6S8YXk6ba26AnMsEHHDT5X2yhlDYzzg
ZL3GOosNgY4MSZhoEAPPLCV9sOeceOKJrNy8DvKG6ah0guYBEKWyJEHyTAHL
PMsKxgsm4O3t3bs3kluw9+W5WwAdn1o0cOHChQFhDKT9+vUDu+jzEgosA8XB
W6I9Ax0/rOiXv/zlm2++qdGDKHS624fyMAaTK6eZosi4BUyMARY3zByBpQ0K
VSomPKYeIXNraQF5a2msYMaihg6Tpi+vNX9s4kYTN5q48YfjRlSS3yzeAEPH
hQtn/r3hhiKNEZt1BwfjRvni86qCwKz3OtqYcsL6vbh0SzEYNdfwdU0ouazB
16ln046iWioM98r461i5sEZ6bdSPhCleRNMH7aUg3SjGtvEAWeZ2XXFA1InM
BoKuL80mCE+qh+SZOYV241dYlbmAlWhmmVlgcDW14IybMvCJ4Zo/fz7CcJQR
MMHUFWqkh0jfCAVerFJI3GngBU/BoEGDMAXkhvBYvYZ5Hh452dIQec6GWFCL
pYf0+nGNyfJrqkK45K3wjvo1yN4igUvrPfzPYJqP9smqkRB8m4cEhzM1KFwB
UlSwrO6jjz4aVMz4EIsbrmB1WM7Xvq4WDSa9HfTgTF4WhI+Gi4819yc6N6pK
jk8euNbQ8ebidwcf8N5GP8Kxkl/H0DFr1izYL4ODKhS1lJCw119//Re/+AXO
2SgsxJe+9NJLeGazm1jdixHIwQOFGLcgBttNzgAy9ZIILMAcy6WWN4E5w4f6
XKCP1mqjqXrzEUkroSuqRgaaETRruK2j/GZTZgfPScMVTNTSBuJ65Gk/UDow
GoDBZcRpc0arpiEWq0pvL32XRJKsrDos1C0ePqQ1Oiy+wS6Th+Ea39Ewjwuq
cohUQkMFtlCqsQ2Szl+twbnYwDmQxPDyjDMsWq/3uLp0AV5V+g3lU9xnWUHa
DE0H08UGk9cbeLEXZ1gI9og2DSe/733vw+IRTABJLEZKv4aQXaJ02mYDZWvO
4mIYjeigrrXVXXgX48nJaKObIQysEeOekg+rgeKTpfQoVSYQWkBLmyFaUKJu
qWsoo0GcLTZnHixPCP5n2bJa+/fvHzDEvhEwoZjSjBkziK5x2AnnDgWf7YkG
fa1QruGR8ovUVMk9gWKy3kKrxnQCOp6f3wEjNllvIcp0hE4++WQYMtzFi2Rm
qcMTrHjjjTfAjZ/85CeaTF+q6IknnkAWDQ8AxRkBDu4rja21b4CBoYwzUHB9
1XUaA6kpbwyp1U6UaVfXSNupZVp1iJvy1sSNJm40ceN/jRs5fv6MNmsjOhYd
9feDG5eVInhqKCuqeuM4O1gvi0srIrK09DhQJrrBQKESoatUx2jdFsFPuEjx
0XB/Ez2Mt/S3dHmYViNuRJicVwjbBYoVcNFQoyNf5J7WK9OO4esbCKdDJ++o
DuXTQuby5AB9ROURd4AToWuGKTD2CYdXKIoJDBBFmIzsMDArkdgn6kExlcFJ
RGgLiNG5KdSlSxeqoPfo0QNjSA7AligsZMwFOohoOvjgg0m4yBDxjnlIKz5l
xcFCeRcTJVhukbrVr43pUhkx5U09Bb9AFgJw4WWo6jQ3ROuRye8ozVhzBx0r
dgZBcwkDkPIWIA0MUpqAONJQlAXgJUwFgmnoMDUmaxnt4Nvf/jYu8kA3E5FJ
YXKDTqaugBuB5Rz/6uy1ho6L50/Nr6A6Ba+AsqANbvTgPLOWl8XlGoiInoJ9
43vf+x7KS6ADhSXqDN6T4Fu9jnHIkDBxOzMCEuYM76j7Sa/rHYVwoIRQXiD2
a1xpuONNbzFw1For+kbV4g3adFHnmDXlotbQZxSldXsuKy3YNFRKmlAMATWo
u25+bLBGYqIkNFQXrZafnORWi6sOTaG6H1lDjT3uAQQLLZrilzO/DzdwHBMr
wrZ1eSltdGmtWVVDwVVybEOEZDvg7gVM021V5x32Yu2KlrO29yuLVGOCdUHz
5AQ3jhkzhlrf3bt3x+uqgTTsjTXDyhKBC4whtJAL7bjjjnw93I7PN0Oa12SI
zNrLOgXuwpxmcapfm3PKQ9qOlhIcIe0bdGkPUSqTcJGGCPAc1CNXaYUMFBtl
arGasCLjMGrUqKOPPhoh6v2FsvVTszGXsXDyJMhCuQM3NwvVyuRBbFaiKG3O
rEUFe/bsGXHu6AO6/+daQ8eGJnjmMptlcBBYIx4g8w5qvfDCC0GMf67olVde
IZDjO9/5Dp7ZCCQKHsoSVkeph9kQacNE6CXX7pT3NWaD13cjw5AVsmYjoBSy
wwJSMdkBll5p4kYTN5q48f+IG6FrR6+N6Hh56U5/D7ih21St5PxSilw/zhUl
f9bkC62yiPqYuK070RASVnfUmkPHksTxRzglAnzuYOYLa1M1R8fKuaU0cR0c
PBNqaOmSu5lfw8VX10g9hYuXl3pfy0pLl7r3WSBVVWH0+DlrpqHKGf50S9Vp
iEoISIzmBdg+4/5C5jhneQIXRhISVhrSa5nLGK45c+YQdxR9hBKC0UfwugYl
cMhGlyE46pBDDsHiEcRoVRE1PULRZeigGsV82rRpzFemCZQzHyoPCVNlgQMg
VrcLg6mVGNOoDQTGy7FWBb4Vzmf9hvPtUwnsaFQhiBS1xcIUho0x/pMnT846
5RWOPPJI3rdfv35ocwEWxtzku3trDYx0rKCnPP/884byMmthDxZ+gAj3Ta9C
gdwX5q41dNyzbGh4JtCBryqqCjl3w4YNQ4UJJzOMGYGAA7gRAMHoEciiZWSg
g8SW+pPALeEolTien8IFeMwZpQwL3JIzvHWdD63aAW7o9b6lqhGNnmKwHKro
PaUzTj5i8V5RlftzBzfnS6nA5QZKGLxqwTELgLiV1xHArDQOstzs0tVgxMhJ
1qbiyvpfx+vKsr2iFOe5pJTQ4bYhjZY6pDBpfqAqTKRUAzZeWkpzaHG9oKoU
hK+2wVAjRmnDWV4i53MrXoQgUqI4rKkS3tPoxBmbi2UumJ1wMnOaT5m4rCAc
+tl3OMiCNYSP548oRWuGrBo4GUNoiHYJGDoIcsiawmTasWNHEmw32mgj+mLr
z831vXv3ponDmWeeCZMYhHxL1WgMS6lh2yxzWx4jV4TC8IgQYWBLecDS+QiU
yIsrpXBDXaW5TBus9djdbf0Wg5ZtZeTIkXSLiIhlGVKLvcNUPHndGoORNhTo
IEbCxtBZOMCdRQWnT5+OJBO4YEgR535dVQb7z6XvmDfj1HAXAvAJJ5zAxRYz
pLhQKGvw8ccfx5rx+uuvU9Un8gZiRqQRIjoihCB52npP24XGnzye8S3Mke+Y
54fldDo4j25eiiJrqm4XxBUYKqCAB27ksiZuNHGjiRt/LNw4deBea1NXFm/8
9sYN3a91zybSqVlgBl4a8b6+I1IRndCpECs3dElpY20WFVFhWAOEHSNIXcgW
zWBtEt26oio2qBKxvJAqw2WlvNiltaLHPK2ljfTtak5Rq1Iz0r6hmcVcGOHC
aDF9PYbCms5MQpzqGGJhPQ3EwBtWIoFe91Rlfk0DRx1WKXj44YdZOOEfFMY8
EjYcWRrnbKhLly56WFBPLGO12267gS1BjE0LWdkjqEIBimARtcgyiUxWXgpr
jBUtMF8g+Vs1HSRUW7m3VN4g5yKUL/JqACYLma/rIcXbCDTxEZK248N9WPV5
sIwA9o3gHgByVKHocRgowoRAgRXAvlCI5PqQcJdPebbMDvyTr6NxDBgwAM9s
fgsAueXkjkDHtxfvDP+fccYZOGRzMf4dOkWGsr3m5iQo/ehHP8IP++qrr+JH
i2ZKxkoQw9w3HolwYsABbuHxQnUfq0F6pkzCq3kq4gE+WjouZdz4embQWiuc
ub2Q4X85OL8UtaiXpCBsI7sMbk3aurGlGi/KCqpHO7iEDY2wzRPLdkWJMtWD
qbRwaS3OXMEAsUE3tHleF1e1enxgMY217K8oFWi3JNCCULoGeaOOn5pqhRSN
IUa3egDpm0YGo2cQdtFIU1pv8gwG+jrvzKkh6LdUnbbYUHSfsSRdHa4ydXy4
IhTogKWzu1mnFEMH5X0I7cD9Svn0UPv27SmZvskmm2xeEW3jQJVcz+oYOnQo
NYUCIAai+GwNHtUscIvd8dh3lHra1sD8TK3MoKlb2PeAjlDOIJN4H+NIbayQ
cQBb8gCZF8I2KOxDbR8sk4MHD7ZPExMhTIWQjoJUDRYbFfz8EBt3GAnvf+7D
DYNO4Eakjn+cu7bd281nnxB5Q8/ssGHDsLcEOkhMJgYeUH355Zd/VJHxG7Z+
C1yAJDnG9qIIpFCREcBAEYYxgkg5ARnvulKd8oqqWGgoW5iCB1Nzd+k5nm8Z
uGt5SQ5y5yZuNHGjiRt/XNwY0Pew31U1Ov5j6TuXLjrrbYkbwUOjK030QK3I
GazHJsIb1amyr+biGQ0jK0rum9oBsVuI9BwYL3px6dZkPr7OX1OA68FmOn1c
wh8o4anLS8W/epQXH2l78QE0fawoSXx5fW5I6Q9A0iivBqVM55E/odqlq0iT
NXU8WG7omCFrU5C/Rj6LSg3XuEz0Y95TKv0qXSO9h/LTBPdOmDCBICUcr6Ho
HYR7bb/99jZswpqRk+THRU/ZrCIaTdKDMl/EtxutB//jkCFDWAuZAl4tLwK/
aYXQ2WoX9bCcbmhEX6wWBouGVBP03uaarxdCqbm7FPFW37FM2b1VGQpcyVEN
dMiKGyadERyYJ/dXuHkQw45Inyuk6YbfXbVqFdOd1QEC9O3bF2f3PvvsE6Sa
OnB3RI6fLtzMAOxAGTNCZ9vQuHHjskHjGQk84k/5yU9+QgDYCy+8AG7kABh5
5ZVXuObxxx+3diIbhxAqFNfz+JiRsBB8q6FA8xoNa26suudwQ92v1jc2wTDs
SiHQENHX7OMNVQHduI2ayCDoq1Wv15xoLDcAUg/bEH+0D+hFNffNijpGiSuT
iDZKLAZg2LWBTLqLqurrNpDViKrvVbsuz39xqUqa51Q4EVt88XrIB7/IxSuq
mqWAFW/0gVIJBxc5+9RHq66d+MpZQWaB3VVanuUjcEMft+VWDL2WsmS0GWIh
zDWwdBYFVk29rkGAtr+H2hXashDNnkQV+i/kAq2mlC7MWiDFOAOFdKTkoP80
K85qM8BdxoHnv7dUGg9vAyB5F86YunVv1fqNKFOuUcoyANJoW2QPlkCgg+w/
M2QHFAqSkIYWzmfD9VcCXMKUnmUFEq5h7w6FbSi9GBEC2UZj7D2nbgN0fHnR
PiyEk046CftGngQAiaByyimnsO4y9dhjX331VUr6BDpACRtVixvf/va3tZBr
jjALknGze7V10fPkyLTGKmhK1YwfXnVqeNm6NYlBDis2caOJG03c+FPgRgbn
5wvXFiO9YdnUtxluBBxYOCrvLgFMOiyEBiuEGR8XlnLEJp3pjqn7KLU2NPgs
XK10RaFUV73FashsMgkrBMf1WkYmjxjApt9WwwvLv66ngAAfKJ1q8xGrlRoU
oetKMUBjw7RmGO2WO/OjFEgk5Z87MxeYeq6rShNT2gIoEAGADtCDj/IMvKMh
ZLrPDBvLnS3Tx9c/vl4jocjDrPEdd9yRvLbWrVtT1hh8wHsCIOywww56b7ct
pBaTL1qWkNz87t27H1bRpEmT2B3y5LCZYnOAgnVnjQvDRE0P+UqNuFjvST3c
CMkZnAndVzU6pHA6I0PKD78bPMcaE9xgBHJA6b+MiYYOYDZfBOV8WuoiklcI
XtWfEO0yE8p+l/tQJzBK3P6F3n/kgf9Zuq5Mm3zKxIkTKWIc1ALHgiHRmHCg
h3N4zWBCQznBAAh6yosvvsjBc889RyighTjCA7AN9dl8C+DOVpIovGRIhSxx
kAHk61reKK5yX9XH00QVZjbsl+XJ+nUvdgURlhkyqjwHDHLdGmDZDb5ldKhS
yuWlyoeRIWp8FhUUJQwXN5lueWnQUF/sl9dKDvJI9Yfko3p8qaEgijdGv2sp
AhOUhbAaseRtDMHFhuIbtYKJAyMPb3Ru6QN1TdUMy5gWixAawmeZGqt/M4MB
LkNiGr5lLy3r2NcjeJm1efPmWfoSLt17772xgnbs2BH5wc6zVu3YZZddCP/I
EojOTjlTaneE2hQK4HDG4JDevXuzKLLLM5J5SFZilh5GS2O5yfGkKia8ncXI
bhvNvaEyRlDlrkLspFkC1tgxJNLAEm0dGUmmady4cYzA4YcfjgRy/PHHkzOb
Y7AlU2kVU9bd56umDJgHWVz5XZ5fUSSrlakJxyLAZNCI2I/gkTFZeOzOiByv
nrV55A2MIRklUAvPLE+S87BQfpceBz/4wQ/EDc4EUjh4/vnnCe0IgDBKeWzd
rxqNeZF/qHWp4yOtoFaAtOyPntk1pS4rSYufq5r0cSYj3MSNJm40ceNPhxuh
h6et7bpy16zd3za4Ue+xrs2B1a1HVek6k4J+pG90ZenNhDrAfVgvqhWXlrww
nafLS4aaqkQkPXBDhcUCxfUQL26I/8WT3NxGdZTsuKpqAa9neX1fs0UI/Ugl
SGVKF0mD01bcuLy06tb2oocF4D236lGin6XucOGLdskJbqA8qmla98CgOH3T
9QrJPFuenJ/LAFK8PVIx0YlBAFSJvfbaq3tFgQJS3gIIZNZ36tQJSAlukHTf
r1+/MDY6e8+ePdFKop4AOIEaMQRdJpjDzaMOkDa+cOFCuCXgIFwg5+fAWFAX
Kc7W4MZjhQxy0zNrcT8+omJeKMzMisjPra5q6uIuZCQXLFhATYz+/fsTFJdh
AUAyOKauMKSGod5Taq3fVkou51f43W9961vUSMnzszQys6SzUbQwFNwg5S2D
+S8LNwQ6ls1oqQgdmMJTHCjLOINpAROC68I8gGr0ESJI1VNo1RT6bqEck/6f
1c0ImBEfsuwGqHtb1TCFgFI2KSulB9KZiHzEOsLZxzUmIWJ6ylu7lJbXiDO6
X8PeQBClpNnmrLkNS9ctHtzkilppjrpBFdupoeP8xEW1XkgSmiMCQ0hbyiW1
brZXVi3ScHey4WruYMVhtGz4XZFElKsbYQAH7Z+Wobi8FP0wNvWKWjPuBjPL
8pIfF7qwlGzVK62zFUNKyHwii/x4jaYnQ16BIBCMwZk/fz6OxRkzZtColADF
UBYyLsLddtuNBLcDDjgAdyonQ8EQPK2BDiCiW7du0dCJSQh0sATyKSiBrYMo
U/y2QRKcvDvttBMXH3nkkdgM8+Rs3E888YTx0mjc4UaUaEtzELBB4W7rFwE7
lPugKQPrlzZn9V5FiGqsIHO1Mh08SZCwX0W2V8syJ5hz2rRpDKlhlmtKiXVN
TwFAHoCs1VCAi4szjzBGpgBMMJi/R48eB+27+38sacGN3y7ZYMrEkzNZxIsy
RzqLeZLp06fDEkFREtxeeeWVlwsBIDkAN4IkGEgNa7H46mUlfXtVjQwTteAq
E5E7MP7hQIuRAjKfrZoFmwRBrEgTN5q40cSNPzVuZDRmD+iCyPHDhW3eBrhh
kfArqtITGC7QFBYvXsz6RZymABdLI7c1AJIVcUFVRg+zBmcuL/XAL6vV8VAF
cAE24IbmEeM2taXUYY0oULwhwAVL75aq/DIol4dkdV9Yq5HOAbWRCU7jniKb
gaM6VupJNKbS8Ngrqw6PIaLaQrpoDYXFDa3uhhFJz6z99ahugZh9YyGRsMEj
bIxupokcojlz5lDqPGIwakL4ECdCwAGTRRAAhSVcysGhhx5qEhyxYaSxhCjc
QYfZHGDo2H777bcphLu2VatWG1cU6CDQNCdxzQSOSA85+eSTef2wHAkXdABh
+cP2YV0L7ZqMA8gIICaM2CkJewgFwDE4UBMMPeXjhTLazPvo0aMZEzPrNXSM
GzcOa1jWC9+y4Ji+ISX24AYZ7k899RTLLevLdjkAeJQgDB0ZPaJzH576HqDj
S/N7EmyZ5xk0aBA+2b59+2L0GDNmDPGWUX8YnBdeeAHQeO2119BccgZ/SgZQ
byk8c3lVmfOiqhi4Ozhcd20p/JiLRQBzDwGQjBtcd3Vp+kORbQwm2HmCpbNm
zSJ+48KSf5qhwzLJSXCjIWjziqqgMdEXmhzdUtkcryjFyV1BCgyo6pg6AXlF
Ede4QReXlwzTvAjLp25OUTzIDyEL3VLqIoYB+BUlqItKHpxG0UtKZu7K0hv6
ilqZIB7Aj7K0Nb02hJRcVzqyXVsKD15Rq80uumorzhnLsvFFI1eVQAjRDxnl
ckEtI1gxg52LPtSh7HSwX7Z7pQVchFkaeGazWLTLoYznGng7iKHBM5ID1o86
XPCpBxE8iAABQ0Jt2rTBaZsvIsxQDii0ZMkSVvRDDz2EwGD/IAn1mUAOhQot
HsaBcBAwATe8T74YxjbMQLsc3JuBQgazluDw4cMZiggeMyrK1CD4WaRiTSm7
hDgUypMQ+J0Di89rYIGTyXoL0WE2FNnjLUPH1MGnnHJKrslckKsb3ABmg2kY
pjK5bC4ZBHBDs8aLL77ICHyudM0INhqHALfXRQJr6SNC3FP6UISwHQWdAOdg
L9jywapWJ7HNDOPqUrQ/M9jEjSZuNHHjz4Ybg/sfQkTH7ypDx980bpifsrSQ
LlF+d2Vp1Wp1rBW14mCmk7AiLqmVwLICmN6EBieICoIKiyK9IJO3btCSCE7j
d/OQPLOaywfWy/G/rKS8XVJLXtMhYqZJgwXj0hLkpnJRt3jwrRUly57eebRQ
F1ohcIObq44ZlapKkts2uG8MRl1eaiGqldCqMjRz5kysGVFMcBBE4kUUP+SQ
Q8CEMCTehHCp2MKZMCe1c80HjyaOfeP/b+9No3+ryjvPrk5bVkxHokYjUZSL
yKhMioqI01URQpwVEcWIGHA25YAD0+UO3IF5EiGYSFymypDKVMlKxTJNjNIG
UZGIQ9AIlOnEdFqjnUqqqruq+1Pn4/6szc/UC/Ii0bV+z7ovzj3/8ztnn332
893P/Dz84Q/fY489smboruXADizghgdASmUJK5a+0gqKu2nx4EFmjjA/miOq
DICcLAKwhtVTSr1hSQsa5eNrGLFQhnlemT4MynJ5W3d3JlasL75x40YnBw1F
9zFTZ3kuvrhfROiArDZvInlJ9w4ARqsasMYQ2NwFwMeqZLQuKmbgMY95zOnH
fdfQ8Wfv/lHR3lA0Lgvn/YJgmjs4GBhOqp7w4tVVXrE0XjDVrowj3IDev3Qm
hZgczUoF19Vw1g65EHDhLlnTn7KreBxqVC2GCy/3zNZRmXzOfs0OkDEkR+qK
qfOSUYijFNG46aKRjJardLZYtqWWzSpc5JeUxb7X/7ti450dwR7M4Rkr0tGu
payHzuhe0PskkyRLdOfzR5/cq5dq83ZnK9ijhxb4cf7UGDe7yvcm264IPIFk
0kXGT+DCZY844W4FXLjqjjvuOHd5rpFZOH7hIM/wJ31/J5988osWAmRc5Pvu
u++GDRu0VAAdChW77babZo3soogc+XYTToSUYtcLLuW27q2I6L4++rWY8IVB
CRVlv2ZVMGQaClUAnApTaAyxv6rcXRVWjV3au4zWaLos3wfx7k7XW9/6Vnmt
WNxfHj2X52pFwh0s7HPNtrP5lBezWix5Wh0hxDkD/n/t5AcJHb9+2p58BaEb
+dDLnvCEJ/gJnvjEJ/pxYUnltLCxwBWgTF5OKq5bgbtYOZJa2ouFFuUKJi+4
lOMcsl5cZneOBhb5GjfWuLHGjX9k3Hjc4x73F+/6F0LHOSc/4wcRN3J3bh7t
47VsiBsxYAb8VnsikBwx+yy8D9xRJKdfzTFA7x3djuC4AkfrKamWpNcDShco
FUWrdT8sja5B9idVGP4qyCS5xcgXjkT+dJmAMc1r+1T4S/TjDj6iKSqkM8tP
ao6aTiQ4XDjSecK9NKacSvlY/SjQG9/4RrPXYXN9dq1/qIbs/gnu+JeDbFT6
yle+0phGZGPZ53Wve91bBlnxmztrDGH1PvrRj67EsdYMQ0yh+973vvdeCDAx
hEzogPbbbz8z9IGOTB/qO3vvvbdtR1ATHAkzoMAMv4sAHKiwfPazn5VH/t1o
Slspv99fiolB2Un4lQFR6CwFjBVoWoNCVo5LwhgwCJjV0FHGCqNyBZoQVDks
PV8eMBI9HQxYxyiPW6l7Bl7Jd29/+9vNmj/qqKM0dAAgz3jSY0eNjn/28pe+
SIXxGQvV2BedxUHyvWSBj4ziYLxm9o0avOZ9LkEyF39plQ4JRvBMxYf//SjO
FiaDKjW3ytChJDDHIsIX5w6S8YsgnbdXGYElXQjlxYP8U/hTnGcWwth21ryc
kOALvBKlTdGFto/ynvG4AQw+LnCwzsb5S55s46kbbBAU8/6PJKjzR4H0Xj+h
olB2axBp5Mmfm4HXP+0YKXv83MDai5di6T7r0lFK6MLR9ypLUQhsEzoImVAx
AwHDQGXWuSW7EQ/qhep2CTho32MOnRkO9AwCFPpq3/nOd2b6NoWQy0JCn4Vi
zhqunGAlB0UAoQPiQLMG2CJuwBe1edK+UX5cFg8uU5eHX1wtrHaDNEAMTRaI
EFnqNP0ZBA5VjVy/rUGP/kou1gjAyQCn6kZ+UKZClAA35E2m1DNAiqDKR1GG
rFhKEi9cqQjEIGVkRl7juSJS5Gi+tdOObONbgwnM0qnPfKQix7fPuLeR5yI2
4O9GwPx7hs/qZ+JuvuZXvvKVlby2315aIcxpyEyUBl7ApKzhoKAy5rqYazZR
EhzHSms27DOFuW5Na9xY48YaN/5JcAP6tZO/m7py81t3/8HCjYr4ybwz7RiJ
8HFuLp5aw+tU1a8qR2yfOtTLgGlel46MufNGcb8MDuctqfQQKvw7BwVfhYkW
x9JIyrtnSJ4pB4TBeAduJRbJlT1dGMmYoIdo+ygt0lvnbL1yNIG9bCShZDkJ
f3ZNVUp6Fpjpert81PSwbvMcOLd1Se6DGKdhP7WthIv1g8BlLnLWnv07asmB
Vi44oMuod7ztbW8LM30jpsJ54ObOduGyfIgi1vyg/JXbGhOVu/aQQw7RUlFd
QXSQslTMcDn00ENd9k972tPkDk6Whq/BRL0GQtPXvMCoXJOsW2PDMh380R/9
keoGf80PWLMqFzkQIcjAUH/2Z3+m15I7+Nd8jrCSgjqrRZhlnDqSDCKF2PoN
nDv99NNdG6gnMiADcIpgJYGLsdmKkUf3rAwFWjwAHFcCgO80HnHEEQcNuvPt
3zV0XHHyd7PeAK48s7paGJJQBgf5XJ6oWgeGOEsV2dAQZDpP7a4qCKDpw5pd
+ok6cEqBIJMQbZhifWw/jQX57Xdc4ZqcpEGBUdyFN6iVe00e2x0jvyxO7MyO
qT5PVoW2e79IoR2JK1ll8wvziZWC5ogOfiJwVZyn7N02+v4EbsiJ3Sorbt7e
IjoMlDUtNztPwCXN7uPmKvFpxfIjOuXSypMbBDkVyXuMVlMDbGu4Bctb/gUx
DJPmwEXOX4UL68FCuWgtDAtdMMoNlfF3/ihREshfvASxXzGaShsAz9gUgbin
rMSjq1laxzfjzMEEU94e/vCHyxF6HiEu/slB/gokseTp/vvvb9Io272WXsag
xn3TTTe5pcKSChV22v3w0h9WJIEXlFJuHfTlL3/5jjvuqH2AuXKZEz8yCv3x
am9cCFFN3Ghz54wmYgbjBHJxeRaF1rgFw2UGviImOQAQzyHBuUoCDNs9gq+j
oQPAt0AHU8Rkjq4r/9OZb34lYgnPteASV2Z70UeMFCoLc1txknfUsMOjNbnc
fPPNAi9/9fUL0vj3o3Ws5RwVjRRFwmSgVbmFCRejfmO0ySsLW1/zGjfWuLHG
jX9C3HjJxkMMBvu7s//5DwpuXLJkfEPxy9Yl71vzfnaJlahOLo5b88OqjM9G
knhzluQvGI1RZJZsF/kgNg2ag9CMQ1tx9WpOyY+sWYDLZCUYR7EcBPAO3bOS
YmWspJ31uDMG+UMrgfgi+ZW2D7pw5BAVrJXreTbsXD76PV0wxcc2S44NjUPf
qIUaIFBCSzsiq6FEp5xyiolaLDMv5kBRlp97n2AWmFrp+mQCPnTl0t1GpU/Y
T6VieSiZ649zlmA0jQAoSrpaUE8ME733ve9dfooQsddee2nxOGiisuf2HOR9
UGeU4eEX5xYJWZcBMnNeQrMqTDEzy0z2sSSFVN+inA7AizwFE8k4vKBvdPLJ
Jz9zIRSWlVBS5lkAZ6EWeVibMM98aDTzRTuo6YmeZasEWL9RkGG2y7X3oahp
QMfjH//4S45/mNrKXe+5P+vWT4nC4pDQWdSqUD9dVDC4alEKy+c//3nfEXxQ
c3EwtgdVf2FIVduouZWYXL0vK30Z4SbuWYQQYkkIgNdddx1L2pUT4/+922ua
vt+04hg5DRMzto02Z+eMPNYMpBeOdmncKh5PuoiRZ9DQixoje82WqcNszMsP
ax7t12GXtPQlZ+TN7UuyjzfscXPIh1YOrwlSVP+14QSkAsiOUYY9Z3EJbpeO
sFX3+jZ6rw+d3vWud2nEcMAQaOB2w4J5xqDajWlh46U0YuRpZZm5X4OThZS4
yAv2qzkXC6CcRwe5ZVDGKF6ByypkoYLPlWIpI6mNtex/v/vdL9zQmoHgYa4c
sGDAOXurB4gZ2kn4oVYRZBJz6JA93O75lGrTdX+o/gbHLnvY0zo2X/ziF2Uf
ewd4ElbS+PCJpYkSVD4dvODksAZ0W9c89zmDEPA0K/GZ/HzOmHLjtYPEBLBI
tjXb1/iT+tuKLUyg9+HzadUpVRm65c0/KnTcuOlId9XXvOY1ypmVNwTlnH99
wUa/fH4hQFIIBRvFDSDUOeGti88vFteDmuKB0vX/UvCYGyJojr7++utbP2vc
WOPGGje+H3CDF/+bM7+b9favd73p+xw3ZBDJlZx8O4dCJWaXaVJwlGwbpIQk
Cf9bR3EtfSsyoLDDDMjabx+0oqSIG4Wl5anMopI1oxdhJWjNUMeHUnDSbuZo
Mc/MUV5RMV2uECS0qqC7APK6prlotNE05KTBa8Xp8VfZE+52bLy7blNYXh0W
ZbaQJJ2tqSevetWrlGDNl4eAjtxJzlvpPKEE3FGqviiRmG2yEnT5UjBk51KS
MQ2LK5Vdf2O0ngRAfHHGr8UDRtOIAQho3/ixH/sxw73MVZGMIAVAdOwGIPvt
t5+e2UwfaDH+CTHel2XBpHqXz+6yhxcUxeugCoDM+V8CiEYSrQGq/FVW56PU
pkoXFfMvcDHt5pehBroULxoduK4cpeaZVR2av/Irv6LAz81l0mqa6ZOFqjjN
ctVyxVcuyouDFxz79P92zhIMtumHrnv/1XxWB/CsZz1L2wv45mhZb0Z5oapY
CeSuu+7Si2TsHMRUqDrNJhcR+COjcyWw5oQwme4RVTivSlj9Ye2lArFs2rBO
P/10c6aEDqjgxotH+mrqeeEHF42erTlGt4ySoTk0o62jWs6OkTzLmYQEbRFJ
KVk23jNIM6xm2/NHJElywgVLDRANm1Uozb6xElKifKJEEUAV4p4f1kHOabAZ
MarFmkPWXwUgCWkhiZm8jgRYU3eGLyxnzZIo3thAcRaVWi2QopjBBnTyQmyC
HvDhBMALRieddkDIYQd3iUkZ+iwSDn1w6UGmcUNI4a/cQaawSjYEz2pGM28L
euMb36it78gjj9S1WsDGAx7wgIJLtYEAIEogyBWm33JguGnBpVxjuKmJtBAs
LMbyIaqpWKl/1Xww4ZZB8It9ixI84J3PDpKDTMWFmAFXAuypaPfUpz7VD/G8
5z3PXf6EE07QiMracAL7pq0N5spN2cFUMETbQpEVzh5I7taGyJGNFDjlZc96
wX7fDQY79/58JqNqkzyN5YCQS90LEDmUN3xfG7r1ph5YwwRCONFAykiqfFgh
FK0ZvIiSGAeiRB2dajzBJ4Ct2vEV72c+ylcyWzINUVgJnL5k6gu/knKSq6Jd
PjWn8PIoG+ZsEW33b3OPT+HcRMf29CSQtBIBpGKqjS1zaPoR1/irraOb9rwF
l3viskkZKcdfcICyGKuOJTIpVoEY2jMRMBRZ2bjd71ge2h75k9jCInHdnjYI
McP7VFa6QYISggYSfkE+rXY/FqOtLG22uy422EkzoLjBgYb0/P781sv4LjI1
o9WI97jHPU5wCAqQQExm4cAgsVpdH3TQQUogXF+vFs2qQIc+F/ZivUjMgPPP
eMKxMtwLGwM6gos/HvSpQUnmWi9hc9+RKVUpMJYDyp1hLR2IDyFrXDjVbZN/
GZJaFawnlFn+FLIqEYRipXKB7CQ3GSFTUIeend9//e5Cx62bH6s2KrzYttJJ
Lhj+Qx/6kDf/2te+dudCwKb4OUd0lL3rJAC5dd9wSGYZQwBFPqN2DWUbi2b/
ytK6eo0ba9xY48b3FW4gZ37rrO92pr7ibS/4/sSNxPvWeXHO2SUMeNCAkDVj
JYBh9jBmO01zKfIzSMms6kOLqY61+TpFcaxoN3OUCP9dKfFt8ZyrliawPc7x
p4wUtrFjJJ1lJ+n1C7O8ZJQ9Kb/p8onKGfS/5bXtGuUN8xRDKIMiAIqGS1Gr
F4SM6gFLQq3EwHJJG8jb3vY2VTCGV7x6ASHZbDVryN2GHLhK1T0hRquiDd/V
0ksdlot7o2tHg1o721p+wYMaz/Envztrww3oxBNPlO/UWVRbwo3aw1mMlGu0
CmZf5WQ1gur6pC7D5Jigx6z60VWmIBZzzZLqTF1hUjsXQHCuCg5XKrqDMzIO
r/CahVIKbFIAaSOFUAxdos6hOdpXDZLLgA5NB4xE00HFVHm6ZhkEfr8RX+RV
r3qVUABuWPR148aNJx7/wv/nbIPB/tl5Z5/O/lJmnNhy7LHHOloY0A8HNlpC
8Pbbb6+WkS/L47S9VFZRx6tUmGi1TbTGmCsnpR6KG6BNgRPnjbKigUNGgHOW
HAfoXYMyNcwBGAJITJqhYw7tyG6fEcBrSqYwIUXbSMzen8KBLBWlnBRwNXNQ
JsqsEFlT8xklJiVBZTv19d3NE2z0Qcit7u9zJbSy7HuWb5eBQhO9OSYQ60Qt
/mlPe5q57YCD0imbkWuD5erP9Xfo8nC7Z6EKlcWHXz6KsyEe+NETPILrS0dp
AqDDWOg8++wpihZ5EGxVmVPGv2p4h0wzhxiAHxQRyGE/9alP1UWCzKAIYQkg
6H73u5/SBWKGVlBww2tKwM8vA4k/+++/v3N1/PHHi8N802pgygXwJhgoFMC8
8gKIYdwXJ+Wy5JNbb71VM6a9hKCXvvSlBlewv+vGesEgnqsxkEXoirpiNMS5
cpSWZU4U4Yr3Zm59VgIAbKtZiY9iOIfWFXHjyCOPBHXf8IInKHL8x7N/mJ1C
s4ZtWXS+ODb2FL8USFheT14kTS7IFQLI5z73Oc3IyhV27akJdWDbIF0b9ri3
zX35QWvcWOPGGje+D3ED+s2fO0To+JOz9v5+w41ZOM+s4ZlYMhau2L6BzWcv
qWQZHFw2m6dEMz9uLsJCOvPVqqHMqWddLPJI+T6k+a/bRh31OaE1N1AFQPym
7xvtXLNFXDhKi+QZKXvu3KmQSFCQnSdjgl/totGTrhumjjEVKCb63V75ylcK
Dj/1Uz+lxsoCsLR4Rvs3v/nNxoJat9acNWeS2wpcwIWYUFfQmsplcgFbBIcu
BgHK+BMJOVMdBuV85NXqZOY2StWdAz8kLhM3WJxCClOhs4Dx65iojUIB5w94
wAP0z4IGGjE2bNigCgO2/MTdictUarhYXebggw/WKAS6ugwuG9X+YQSYoo5v
9ZOVlzmua61sgtCuA5eLnS6r+kD2k4Ve/OIX+9Ve8pKX+B0RAPzKTTKPFsn5
InWS8unGmUDwsupSibrMMwvGz33ccceZD1jZ+ec+97l3vecBQscvveVJQDHX
HDnIi0EzSy8yAB8HQJmiC4ConvAUXz+nEkMSZvn0QkFlQ2wIq6/KJcFfVQbL
a+OH4cbOqXhv5sf4JVuf2AKbr+Razpt1ARjZSbIYyEo5K3WbmqdZUHeyjQez
8zS04VZef86oopztIgdodpXtUwWhSpAlJCSulLTrxTtGx8asuNl4iwTTRnrx
kiDfpIlyxXGZcaCzlRXoVsK2Im4873nPUwIBLrzmpJNOUovnhy4JXtaxiRiS
YkYBSOy5ChWFuLuY7VhR/ZZqUZZ5lHCipZGtxIXE8qhOS1iUfFUoiL+F7Bdg
NLJzwnQpnSIvqcIffvjhWioyYmQFDSV2H/Swhz1MmUScgQoI4U+mySAVuBEj
A7gOGSFsUlCTQpT1M936ZaX6Wf/haBmJyKGTkc9dMo6CBwClP/RnfuZndH+/
6U1v8itnX2LmRWDnEOIp8l1b+Ve/+lUj4S0OAMGADNhZ0t9qoVcFDwtK/91Z
P6ShY+e7/3ton2IqmKboVUMHOEXgAh9Mz7nzzjuVQBiJAyh1BXFC8KyqDwMW
LmxUBxnlAnFGuOgdmeE1bqxxY40b38+48aoXbDQY7L+cc6/vH9womDxDx/mj
6HfaRGdCABBDWdQoUANB81HOXo8dS6rpikM2N0rqRkpNAedFgtVyOlVl65QG
G25UKHXnSFbNRRKA5OIpYCzXZOMvuCuFhcc5gLLhCo3L1btl9LbjV14MYlTT
j/Xmx60SzhOe8ATX5Cte8QrFVIBCFuCMuPGOd7zDmzMGocDaKVBFs3ctNUwg
FowGh4pOW9gNSoWBzb2GNaCWccmoAVvcIxrH9YMKAUqFt7+VGJX72+WawlK5
BsBZbYgJTBS3zVMWjywYoEFRpuXM6s9FMdGxwp8MJANV/NOjHvUog6YQ1ytJ
xIp12PDFHwySBWDYes6qxZv4CXFGfuGN9CzX8A7cePUgIYUP6qawfSlLBaXK
MWniD/cUtbin1gzz73QQOwzd3y4z/a0QOoh1S3gvN5drTnus2spfnv3AnD4G
BwIdBqcxJBcna0OLzRcHgQDCFO/7R4OEVouvQkbhinXqOyksjF+lRluZesqO
0dGjEFB3z52jt5rUXh9uaOUwvlQ+cuNuv75whKn3qyJINWxquJCRY/9Iw8hM
hpUqWhRzXkwIfxW3OfZTaqTNyyzUiC1l1nOfpKxydT3YvuTaCA4CVJGrjKEY
D4dUBS0+nGEwrOECQdk11Ekf//jHu00AIAYzswaEF7Tmin9q6Khf3q7RNKFO
wfWCrAxCtcjqdpF0AZv7c+6jkJBfNQMvy/6X7k4sD9aJyFMC9UylKmTrKMaj
hpV1/nIlIFMZmsJOanApkoNihin5ENBhvOgjHvEIU2gf85jHKF2AJOKGHRkg
wzwga5ZCFlb1c/NervM6FdbjHpJzi1uoDDLjd5UC+DIyUmKfxgOwXf5lLbla
EurqxKdzE4IHxQ0wREa+/fbbtTPApAxPVGfxvHKhZz/72aLrYwYhVNx8+ne7
J3xq0+NZeGCX78uK8uA5z3mOmMaSFvZtPWOlVg0+IKcoCm44CYzNKULCFFss
kaoB2QlRCIFKU+Lt1rixxo01bnz/4wby5zdHMNj15x7/T44beUtnN4S4EVak
uSe6a+JQhTem8fTTT5e5ZkOE8z8HWZ1/d8q+MaezdZx24J0DkLnSXePfsiSL
ydRZUVYUrmK6zpl6S5UNt2IeaWyz6uTBjFrCxVvf+lbnQWsGxAIw0ZJlcMQR
RyhOu7Ah8ERlJM9sZ7iJ9+T+QnEmi6tHt4WYt2i3avLo/lBxCDeU203Eu2Ap
e5hZw4PCRIMU82c9qFGXNTYNH1UZKYdFpJJEnpwv9YZgbhXvzWeBUDSsyPGQ
hzxEI4YlByGQxK4BSOP6F4AOL+avFie0PRzExfplNHro9WBNulx5O/EWHUrZ
u5YKMFGpXh5wjejKtqiHFKWgnm75ZM1Z5l18tapzNGkwo4pP9djBDXNJ7rzz
ThUWtAmLgUCM0+g+9FkTG1kw4obKyIuf/9P/7znfDQbb9o7TdPGwuowEY370
XtnIG4LTs+qIjblI6o7n+1oQSbiw/LulXCs9alAu6onLgFfbNMr1nD1K7uSH
XWF/EaBYUPmO/V2PNoxTaEdhn5kTu085aHF0AZxekyhiJMm5S5ZufljvDE9V
hhQAKbnex/XDbLZB3/mjzcGOkf8+Wy1WfMTbR1kzuzZDvGah+P4EmPL1+ViK
DTU04YOqnLrm/aYooV4GPiiNmKQGcVK1euvorZB4MNsQhIs8oZk1YIq6W5YI
L9vOibFGNmbxNuttdiMWEWq2rJhw1ehHbIMYPdrd3GJQdWHW/JK0owk3r3fZ
cG7lbJfGbyAzCBf3H4Tgofv10Y9+tDP59Kc/XcUffFBKuc997mNX6/ve977+
CgDZd9991f3BZ8Gcz+Rz4SYBhN1fNskMyGYaBzlLfGhjep85iG+qlPj85z/f
8dcIRuSEdI5LGjrgU2WbT3/60xoqwQ1z0IwekU+Z1SbHzQWh9EmD9Lq+7aSj
v9smctP/4moBwfyTzbIhfmj8Dx+3YJWiZBUzapP3h6Od978ZxLCrD7BSg5R3
CUDWuLHGjTVu/KDgBgLPv3r709VWvnn2ff8JcaNMk1gpvts2dTHOD7LiKzlv
pI8pvev0zPmSVSGHSByd5WFFG8oqsmvkd8wJI92wct9WKVdlKAbVW2WiSec6
b6pk7p/Sbs4cvRLmp/hcnlUApxUh1Eeg4MKuRhDyZJ2aXb1IuUie6iBcrxYD
UHgGQTdLi3N72ahwvm0UQqnsZ15X+FdXxUVLQ23TZH5+UAFgOZ0j78PJKjLJ
0cHFVVNPOkt522zIO5sHZDmRItCME4MHFWurAgoHec/QiRfJRSUCv/zlL1cm
R7/QUgEaPODutPvuu9uFAbldxf/www+3uiAXq6fstttupupzkLeFy7x5PaOr
4GRgJ2TEGsQrqOlr9oH4In4sNJSjB+XzcnfgwLKu2VK4lcxlmBlUrjqIYUEM
EOOOhW6//Xb+q8bEvDmlrFKXGZhg4BkvbpgoCguw8Ptv3iB03HHuXqeeeqq5
M7WlZpDCDvudaM+r+Wkqx1o/7jLrrVsubqSBin6lpdjUCUKFmQOkZai26YLA
2+i3j9YABWCcN9X1LQ7EvcyQS00HmSySHGTkXKsZIaO4Ph4/d1QWYkgZWMp6
y0C6fdTbMdJD/28Cz5ZBjvbcqUqYAMIaMGoCjvYAcaL2JTU+e+nd6ad/+qeD
fQUM9iaXFhcLLBBXalhDzDAflsf5dpbOuHZp2usXKUWu+ie5TTU2Qvw1tPfz
Zd/IXDl/YtEj12q5w+cvZUjfuzSm8fN53qeUxQYp8OTKz1Rr00CITa16ti6z
OcrUAVwy+vTx+u7piBMaP/O6IkL88EJl0W7YsMHAdfhIwaOyP/e73/0UPO51
r3tl9LDGKXTwwQcblQ1cC/h8bldyuDpDojPArGr851dGkPJZRQ84+sWDlBu5
2Jkx/wuqplYZsnCr8RsGV5S+asAqzCvy8F1ct/XOAy7qTC2AfOUd9xM6bjrr
UCERbFQqYxE+eyHwTX4BHh1S0fU8TksLqGWpkD/4gz/wq/EdhYvfHFS7TEPN
pTVurHFjjRs/cLjBAP7vs+/zXffK25/yj48bRQBeMfoaGw1lRaM0DmnH3TPZ
NR1oBEjO75oLRuOh/Jjnjnz8rVNNraCptJRwIAb34vLjTK6vhdD35rN4z3On
UqVpXpvvTsWbsYBdJOgj5YkoLp466KSTThIl7OMMbdy4UfWTlewB4qIqsNFB
kLW51GL4oXcASQQlZWbFZr8OC6+6oLUJK0m/3D05kQOnq7olFywFysQWRfH8
oQEIB0KK1QZ0WDvJ5RntWOqqlf4mOFThnAMXudChr1ZR9t8NYhFmohdkVLWs
lKIRho+lnM9EaUOAO2T2ubWTXlfjS6E5G652DFY3/ZEf+ZF/MYhj78AFaToa
mvgo7gWVRtm11HK/fKkB6/rRfGcvb9UT1E91z9zokL4bLnNK65UAc+n8rROT
EZtWBP3yIDjXKqCws+YIPrdfkBWr7QvEc3UxOcYNWvj9P5/9Q0LHB8/77xUj
dfQwvJVcez6lKwE1RCj77Gc/q8bEAKz9zpCMFrNxg22YHA+fzy+b6eb666/n
25UGJVwUOVmVnhZVgaOtLl7NuX3HO97hAijee9tUG6fo0Li1WAjP5HUtxOLM
0T9ltq96MY9LKmC6eu6KgWLzyLA7Y3RCyZ7ZU4Cdkny9YSV/ky7gepcNH8W1
XSQwG0FKZYYybXFsAeKGMobxycCF+x3T5SCZbVmJj5JtSpZsK5fjoEtHC8s4
GjTQQBGobhn9Lll4LmDuXFkSvzV/Kjq9P/mJzx6d+JQbK0NamKhQVnEP/a0z
MdrKUer3tyQvVHh/4R+AmJsL30Jwhqmd2wMOOEBMAC6q2hGAmOD2iEc8QkDg
oHj1/3UQMJLRwx8CR0o1WaqtxmNBnuzqRSAXbCA4cH17usJGuwMLRvaxDaLW
YCP2wY3/bZDGhGqQfuITn/jMZz6jEIIMoFgSzHIH1zP3V4Q48sgjFTyAjmOO
OeZlz934X4dn9trz3uJyVT6BuNjdjVlVumPmNdV+/OMfN+Ac6FDs0UgLaevQ
UOz4c78yJHGDk2vcWOPGGjd+QHED2vLG4/+/JXvlv53zP7/tta/4R8MN1WdT
ztOms8MXZ5h9IIemy6zcjdkfmodF3sxkkTIiL0OnD3r3oPoCBET2WRNS0jtg
cM1BKhQQ18v+ML4I0G056J5iAr8yY2JuJeANOekigd8VRLNdGPAp6TR5yUte
ogJijjyUp5X7aMp43vOex+ryuRYKOHspRViCjKpHFn5YMrNAqXYlkXkGoFAr
/8VRGYM/rdTfMKPtfUuXHIGIg/YIFRbrU0EwtRBx8eipt2spDhk65cfxuSaM
m8WfazivjXBnMBWUymx8GlSQGD90JNuWggNnLT2ztHg861nPMupp77331tWC
5lJmfQ3gNgyqoxOKjDgDXNxnoXvd6142lUNnUdN5+MMfbsAqUr0IwCdTUT1j
6qPhwmC1GIp53HHHiRtwpWzL59a+gT4r3gKkVTZwZsxxg8qsNwYMAjpQT1QZ
UBbK6DdODADx48JERnmxZxlACPSpsAALV73lGLUV/p35c6eyYlWmuMaLgTsH
CeOoAgMLOnGADj3CWlqgG2+80UGCG67DtjNUFQGE4yxUqv9Qrj1WQhpfLs5M
ptlFM3WWMpbtIrTJQlIEZru84FAvaVsDQBxX6yMckOmEoJUAkrcMYjevs0AF
9wrmdFMrqJv16ZI4/vjjXT+wuUti48aNzj97n+6/KkCyfvy5+AAVHYpM4rJ/
1SDjk33NJpmpEKUvHI2tLxwd3+ApNwXYWTav3MfVS011LZxZKkrslbVrmBKT
WuHQSjtefNlo3Fl0uglZUBbXiycSst63VA6ssn05tsJd5RmvWroDzBKUjYwh
L1POKabUO7vMoE2j+TVbpxlbTLt934AOuR7oWMmiNS4d2n///R/1qEfphy0a
5Id/+IfvvZBGjxlAwBnRic9d14Na0mgfABz83OwgcuKhhx7qSuB6hVI+seuZ
l/Ktg2LOKHdVnxNAEEnAjU9+8pPaKhE5vrYQB0ah8yeBl1kSVIXTEBViL2NU
F//MweLG597zSJa9opQ10qEqtPMusiSfW3BA8hG17rjjDjtH8FxRq8xo3qVy
PbqYOV7jxho31rjxg44b0AVv+KkPnn4Mw/7HwY00jtkPoqSqQKtjzsdtGaW3
ChzN5nDeKG8144YHBW6dO5Lfc3qqRaqedCZHiThgmyH7n6prqKqoBPHfcEM/
CJepKdRtBOY9aZBWCFaj4ICuoTKosdo+v7X28NOAG+opxx57rNjCQso/ogp5
zKDnP//5wgXj+blBDNLRnjuKPzPtFTPMe9W0y1NAh44wbR16Py8fFID4q1oC
XTt6v75/EFDgxdmy+rJqMfpcxA2O5X2rIKaxlr1Stv5KfCkoUVTq98aGlS43
B6Ma5uqrXbUUord4clHBzt7LXvYyw5/4KCahgBIW4rAoh34WdRl7w1lejOOH
LwSACBf/fNCP/uiP6qs1rgyqmy0bhJwIULhmOBBS9FZA++yzj3YSvrjXwNEG
ifEi2gdgriJIxQ34tP53upxQVaxXDN10002qDECHBTQ+//nPCylofEIQW4/b
E6vRvay8Nla1Gy7LzBVorWPLHec+dptj+ekXYwxaWm677TbbNqEoVTZEYrSG
jeUp49W2j2TVLVOJ7Iq6uN4KL9w62iSVRrptJH9tnop/Fj6RFTTZoODMOZzD
GI/ixj0ouhsc8GXZCDxAcoAr6xGQdKESVy0+PrQw++xnP3vjIBEAlHDaAQrB
AZTQtVdLIIBaA12uVe7pvsPxcQvxacQNHa8QwxPHckxrlhFUK5cBSsgmxmxb
CacyF7I2rKc6WQEHa/1Z7s9rus9FU584mb1Mq0IUqoUY7CSKFC3JI5IERA9L
9PjcanoUQ15IRhVgyqK14I91WYuTLzpdmGJN+o4ZeIsaytDNgvG7g/Zi+377
7adNY88996zdW3m1nO9TmhkHqphI++M//uP3XQgM0W+72267lWOrcPLABz5Q
0QWWrCGCC4C1pF1LFzDEiiqQw02qQI4CR2uYaCwHVNWg+kbVJBoCMRQ8qvNz
8803uwBgT6eCLczEQNtSa3BT0C3F8qUvfamjZSV7Mcf6amEfOdrW9pAN5upf
b3tKcaPKihwrJrEg17ixxo01bqxx457iRlFSW6cuS37B2Yzv+ikRe47ALHCr
mKssISv5Kdk0qs117qi/YRqIlIO1ZkMCAqKXYTAACDrIKYN0hMnOEFNa6Kbg
cNhhh7neOPZPQIFLgqUotsD7urrqL8xf6+l8/CDzqfmTuGE4KAS4CXdnj7ZN
20ctwbnkYMG054/uVJBcPyeYyG5W8TJ8S70YvpapjSa1xkjmkQ587qWjC3aO
9ZSXtBs9MkY5aoLgEfXWAQpScErSX6nXkcmiXHtzHKBfGI1mrhzdVP0hxM1V
me0eqC7mny4YRSk3j74zeejgFz9WUnptIoEOPa1qLoLJIx/5SBGAY3EGnUWz
RhU8UFVEEhDDIDHhxaw6f87K0Y0C62nfaJep5rmGEQi21ecIS8p34IOcCDLo
h/29QUaFmWv2sUEoLNoc0BpsifKnf/qnFjS+/vrrnZy6XLFcVZ04EBMMQtPu
V3tZcSOFBdVPbGENqDqhfQRuNwxSYWH8al4WWzZLbg7w9n0LSrx4tCZPp754
acxaNR4likIxM2uUsJatI5OpC8Cmz/Z9LqBC0MhVam0KiAP1tZdNlGGB6UqE
cHKOOuoo5YRyUeH9nx7kwmMyXz6oWHE1R/7qF2G2M1l4ASpkdRiULgAxR8sr
BKQVLI3Xsl3MUfReH8zWZyED4xWjxn7hFvBmhVMKFC+CV9yYhYqV3Ldqy3DD
DFlKO/XW6YBHFLl65WhUF14FINeO3kwwvvbAwjaSjvhhdhIHUFA6iJHxTY37
faNEvJHeW0b5eoN8tHiceOKJfhq+ssIhEFHA+Y8P2n333Q3zQD5RqmRJuDYO
PfRQ/bYPetCDxI173/veBXsY3440IrZYSh3iepGEAyWZI444Qkhhabndv/a1
r5UjeE23aRjtE3cniwfKifCg9o0MpBY7hT796U9rc7jjjjt0kvJDbSZnnHGG
BUB4roI069ytEBBzYWsShFi6MgKIV9moBA9nOyM2H8VU2XrpMjbhorLwnFnj
xho31rixxo1/AG6kYriAWRWuyUKAWHulvKXRrNTC+l4/7Ez+qWw4Li5EU/G+
ZkNFZCHyVQzWL4JOoSqBoMUkOAM5pJgTrce27YbidxhcbYKbOKUvGQQIOO21
1+Gk0ARKeE1VrIMaVCdtL1U5K6knCwbHoe7Fo1Zz6Gre385RQ15ytquOVXDX
L0xUcS2R5MpRRblHpJUUJDZXgPRPQVMBwJxUTeARuWNKqb56aTU1a6zWUdy+
dJbxenBGPQWNPgXZM3MzRM0assycRVUxZI5VlDj26byjc7V5qmKtUYsv65JA
hTdwFO7Ot/LQhz5Uf8q+++6r+wP107UBu5WirtMWfBBAgAudtkCHZ35sEFpM
iNSdVYG5oYzMTiduiMYQL2uwKHpKuKEK42vqpJgb2VeLzP+WB/e5z31OvOXm
evZ5ojPAGq6Bl5sjKrw8xcr3rd1eIaZL7YYFr8LC9Lqi+CJm/YMbRpAyABUo
dBa/LMcXjP6wm0ejtHyslcKAslBVKM8DJAQjP7eOcuVlinWQgWvbyJktcNSE
MsjqFhAoUeRDJgWVsppVIVSA8FoY+F7CrIYICH4XLkCJBAkPTjjhBD+uVlOI
Pz1/kGd4rigNgr1hkGfMUIOYZ18/22+ZejuX0u6aF2aOLrzWuc3yXEbqLJ4l
sRRSLlywrZePFpsrEnCNwGW9Dnk8g0lBnisFAGHJgL2BZaftDkWJdKsCPCwY
YjKvdlEYX+Wd1aUZDaFCmUTTKJTNsJypoIMz6f7q15zxV4m7u0aXQD6BNq4i
wA877LADDzxQKEAwkLvr7sRJXbQFiqv+Q/C+ppIHP/jBWkqRPcyPu8997pME
og0EkDFpl0doaTFkHWLZCG7muEG/PYiXUrRgy87QXXmc2iVYHwPKUAlcfG2Q
dTO42A8BeCoDt5MyCWZDcNIdENxw2Wsaguz4BnFskIy2Dgi5UZTjufVpEsey
wABxa9xY48YaN9a4cU9x48LRl3DHUkNjjt2qt8iu0UsIlMiRqjmiwuDljnFg
kGeRn5DXlGDSz63oC6GVyJKVtuCtfcf6dCNSasEAIlQfINhcryvvLm7kG33O
RGICjG9wTtnxHL9xkAKboarWJ1eZ4l2UigEQr7San1jhIsmznD+6IDoAJPvA
BaNTZH4Qp1cNTl5IbamaH1Q6iXJ+btAiqVIleJwrynSSuRZHTVLMlYMqxJEx
JDeudoY8wnOxwZAKyoxT8KpeXQg1RDYBAXTyvndQ1QXn0nOVGaycb/WyDKAt
YWfnaJED2Lrq+HCuh7mtZHFfKSxQYaVeg4TvrsGiku8AEK8BHHZbyBQ5CJ3F
eDPLJkMHHHCAkj/3cSNjKbq2mXBfRyNGdcItTqgKIybX+UiGNWkFgmHNuwco
VBlQWEx7v+mmmzSesDZc0mygpbOJCRzLEaCZejpcI6QcMQhVRT39RS96kWzL
kLyznXYhAMQDBlZd9ItGY9OS17JUBO8FjZfiWqppzaaRGTyYs9XkRBhNPauI
8XoS6WaF5iQybTgar6TaV6nKIVEUmwG81PPXHYQ7CKEcC7NowQoMda+ew00L
WK24RzJVfmHNcRwYsJoVNB7Prnv2aMnUpMn14UataTNaFu4SgCfmFemdI9U1
ltt0lkBWavoVPlGMKMMottMlDf/mV62gR2JSItPVSx9YC6SLHsZpQJwsLj3j
SS2cxAQWoY8L3N4/dTdzlbL5VuRBz2CFtcur4livMbPnRnbmaJaxdRSl5Otk
BjzkkEMUPApQn/vECQ6sLl2rXC+XwfuGZz/qUY/Se8tlHuy+++7eZK+99iqW
WK99sMOxOyBrwCkC8YSLG264QQDJ8sNcXTGKQPLK1euQAAcFj9tuu62e0RUm
VRhjC5Al2QS1/DMAxXKkIBkH7jAYHsFMcHvqoAzF5fextl0kDLsy7HqK3QK0
jq5xY40ba9xY48Y9xY3crHN1L3mhLLbK+pXMkhemihZ/byK87FbApzkjpo2U
8+VoUTD9fI8dxFsX5CZcIEyKFWgiyFrKV/xQ/a6AvdJYVDEgm8xamEL5Nj8C
r6l+UaHjkKQKIaXXlX/H9c5DDM6tfEThss3e1qmdZTPJbFc6T+5uJFzj2OLE
PCzBSKGksRJnPjTIM+9buqJcNWpuXDGV3fjA6FBfcSr9v9DlI7TPyVGZKiU8
fueHJaoUlVqqXclreX+qKNJIfH1w73+ksBh7ZmVCbxhYcWcHabV5ydlmcti5
VEJhIo0PBx54oChht1koh8g+++xjBNdBBx0ku8FKtVD0jCUUoGKJ7dwKaSGB
2KfEDXjQP7Eb+h3r/AgPyuwc6H1W73PeeEH916gq8qkF/SDUE/2wtw0CQ/TV
greqhyxU139lHwyHhvK6Mk6VejZobYaM1oqLHAi2oK4WS1ZOBQNVGD/ykY8I
gIw/d+H5ozxaBlIdptowC8kQUubaJnPRm0rfWP1Gs4A9UqHq7PEKzi3fyE8D
Yoh74Hx+VT1lOl6h0secAeUTxAkVW+Ci+gnZB1akgtn2WLCKnLhjKVlz9lJ0
PSOMKMErGG2iNKUlx2t2LHVBDchXipiNEkFTlVHL4ztvVFY35txhdL2UQ9yy
n5ctdc6zvvonC2hDQoeJZhohSzQrIiLYKbhd+cSIDuHrqlF0xTBXif8WH+7N
y0e7ZnRkuGaqtV7qXDYT0cYdFsrQUdwp67Oo5gJWpTkvTySskh7z4Ifgu1cm
kSc6/yxC/eZIEQLIvvvuqwSisRQCSQzkMCHOnDgvds+CDCd2+WVFd+NmBbq2
WYfiBj/M4qGlVB6EgA4ZsA5o1iQpmFbjVW1tTZKF7rrrLpNVgQ7touCGFo8b
b7xRgY2fu7TgBUcbJjAkx8Y8GFrA3u3M2N3Jeq2+NZeZ+8ku6SKpKzFwUQe3
NW6scWONG2vcuKe4ASxUvbnkkVqd5j3JJpA+okhfmSzYtgJcSomGekJMnWIS
0668x6dR3jvggAMUpVA3sldIZY7obJX0K3FPQClTiUzNkNRwtw/aOTVSydes
BmGpQwMmi86KX8RPbigQ8TitMTxOpax0vLSS2fcUqcIo83vPACQzS3Vxja+r
brkxmStOz9Sr0CmTRdzK9ZXy0yxgEKaO2jBtpbZblocgwmz38pIEhzqSV8pD
DfeSpXGkMAWY5KJ1cpgl51YXcEFrZslV+Cu4EzfqF1khkatGb5erBzFXftm+
OyjHSTGNC3xNPpzczTKTlVh4wsXDBlUxDCRRqWF9uoUBAs8YpOmMxaz3Vlem
hSLd+A455BCNcqozEDyooY85UfKvEhpKWUFxqaVMr/DyiU98QnC48847/3yh
r371q2ou4cYtt9yij4PP7eJh3YaWGmp4X70nqCGCHkwq+9R+BXh0/OVwAS9e
w8d1PhmYcPfRj360Cp+GZ9gIQLsEcF29PndemMg/Wffb8E4NmwKFRU60RgLF
4h5DWskGSqlkkM5/eiKT7Ito/ISMu4BMHzODrGxT7beGtpYWumJhyHSQs7jk
334V47en63eGXve61/lc0Enc2DZV/86AmUgQX3tG36gnGUMA4oGwbIqfY+5W
WVNDkgtHe4LLR0eDXKU5UivFU/V79GgNjPkxeUSGbmHkfaPC+RWjRA8bfS3Y
KiJqoyLLijqA2czrSMp+VR5Qai13b6WVm0ChTUYArE4pf/KasmizpdS7uTpC
TbsYHspVGNPXhHkVU+EgMQExw1h0oEMJ5EEPepBBoYki+m0hoMBtjh1QeYO1
rVmg+i0ghnU8uLNdGxCnlZPZgEQ5Jvb3ByEqiKWlLZcQV45q5lDIKujARTEe
Okl/53d+x8lhEmRkOFGsYwCipR2KITZfl3SVfmEuX8TLoCc/+cm+I8N2tTDb
RcCucWONG2vcWOPGPcWNugtVvNdOQzYbevPdqeAoEEMXSbW+YXz5vTR29BE1
psdM5JAMODHmRK2ET+kBP9eawYDVxV796lf7rFoiqin4CbQDKNXn2RRSLGm+
eaqQjBYm3HGrSg5KhWnlM+KkqkRAyszk8vCgpJLYNg0osVOm9uSOkVA/KzuZ
lfLRlKF22d3JFLlLlu5Lssblo5JGOshlo4AYf3JBghsmg4AhcmIFVfKYVKyj
SFQLjrmALZKsCSV/imcYUm6j3PeXD/LmRcEVeFZwqQkaAtSH7k51vP3Fqa+9
mHbdRN6Qv+aWKnZ39gioXnFGZZx9zQ0Lfj9ooUc+8pE5W8WNudek4V4PechD
BBBWcqHLLlcAxNUOthh3CuAUaSbbPvOZz3RLhcucbWNiVScNw7PMo4D/sY99
zHBNc+qh0OO2224rh0XiM/mOTQXbq+FeFkK3CICaCyN32MgGYjtrW0YGOryG
OfFXsKSWB6bUtcHY2kxrXVr9f8Mp/W+yhHmgRXXaewgCCkwdAmD9EExU4GCU
GtDnQSGdDEkjBrDjsJErvLMJfVDRIDC+LJbpADIe+5KlXk0u0aJbC2HNninN
QfUVCWnf3zRIbClGJZFg29S/Keki92Wmy0SRrJ3bpq7ZFTZ3JLumhLhiNrIH
JhX8wt0JBpSVLh5JiNlYOBBbYEBX5lzQXr7mMtfYNaOv9FWjVQE3BxwKAtdk
lwxQZi4/8XFlRodF4V7y0mWjJ12BrEVrQPI4T/HV6k8K+awEjwLgOdPAhJHL
ll5OAr5uWW04TZdj45vKC6w01ySsZCke63VoMq1Gh2RuLDRbU+Uy215DyBua
XrlMny/QYZQ7AnbNuWQ63mVubC2W5r/mTwoVX/ziFw0TRdLQUsoZ/3TDDTcY
U2F/K4gp1SrFiysJVGiRdyzOQYsHu7O2u9bzKaecYtjDE5/4RLERJHFPByJc
/0z4GjfWuLHGjTVu3FPcgGFVB9AU9Hqga3jAGT0y+Z7gdMUb0MCnAw4qIHWg
Y1qUALneO7/iFa/woBQSSP+IniydWX7HN73pTbpxeV+NKueOHrKxmNU/cg27
NiqvF4DAldUeFBPSR1RnlO29Z17XglqrkV5+TbaUOYA2o0RqvvybO9WL5anq
K24e7SzzdQaA3SoXT3x31SjPlYkgl8eloyVTdoY5u6SMMwOQrMv380thsSJR
Y0m1bACnBZyTN4atdJhGBgPGnHZDZNWYigSrQrIX90Y8RaeJAaJQhZGvWPrS
QmgZ6lmmqOgoKWquYRQBe/moZta0M+HOZI4Ybq6pCubVj1/zd1ayykjVCB/8
4AerudRokjOVJUxzqQ6M+GPHKKgoU84IIHCNvMmmzPz4UX73d3+3YDAHycyr
J95yyy22c9WTYl97A8DQYmooX6qg88a0Ow8V/rJuAJTdAEaWtVHDq1GpLQJu
1eJhvQ4oxxAzDJ7I79xE/xEHOkm7eTEVqXVdzGXlmpWgqhsIlBMTGJUHYFRn
fBHkFvMZYc+6s62Q23TlbnaOmhWeKSq+5C/rYV6xtA9QbCghd+dUJaNNuVj6
ApW1ZoCuSlnIPEKKBknZOW9mQsWcDuZWLrZYcKaR+FIFkOSsDC4y1Xbz80fx
89nmmS4cB8luQUFe3VyrVRHXILBCSQLZTq8cvRWMFLXAoJN81SDrdRsrUqZb
8lKuYX9eFp6GCEG1lD0Zv+LtCQkwgrgBgAQOWTx8hMHz+nANKIVcA5rKi1Mt
WMJpR/Bwd7AQJcT6TALRwrnnnntqqQBDTGerwwIktuyzzz7aNxA55Aigw0rp
Ao69GwQQpBRZDJx59atf7XTxXgV1ZNhR3kOosJbOTTfdpB8WeaMGr5YQtL+V
FZCU38IfXlOJnR1cC62xEBDagaEdsKQiUB0KdFtDtgKxqr/8y966xo01bqxx
Y40b9xQ3GLx2CQ60SwQRxbfbcsiuQ9XsrfTWCwZV4PfYuxNnjJZBl9Rygj5V
kJjqFQKbr7ZtlCssl2TnUuhJt0hRZ5X/Ta2WGfVHFCU1Kwuyat7Pktdmp4YF
2w33Ai7ENIYXbggO5n/NNMvkBTX5p11Lg12HkdNhTmxp2F7PHXLNFMCW1yYX
rReXRFaKPWMrNT6HTsGZqTkllciARR/lsmE8vRRPyf3qUgyCslSozogwninD
Lu2goV4zWnrNaXc5T2s7VXpL2TTVBMsPG475IpazEF4+NJV/z8BSqKpTyszX
X7LwZqvMsc1pu4O/ZI2ixYCOihgLDmCLbhQzXCB2W8/sOajcOlSVAwehCOj1
YAH7dqX4cexUgJwGan7iE5/QrAF02OD11ltvFUBuvPFGk+bmfkkuCWbVZVNI
GCwpuFWyG+4WLYGLAr81b6KeCCDAixPCjl9ULVQ1TiWHrBAZLS2sB3FS3OCg
8E5RwghPf16BZcHBwno6fD3Q2wtpRrBrTJVw4npFkfopwPXWx9DU6UFVKKsg
VFR5Zsxqtm8f9Xbyh2Zq4POJEu5BEEDnII3qTLCRef0i7WiXj1qasI/oYShg
8kliRp7Qok2EuytGWdEyDXeMBLrCNqqfk2kC/tKE6HZsTGZBF/JvYkPZr78w
+krn0OzOYleSg3dwE9TCUBWOgtgdtvEVps7VF3vFPBIUFAfiD7VUyD6/9Vu/
5RsVVV4ArbGLVnfPRFxhdjhOxoGJ1Pc5n1/Yg2tHdyqFFiP5FQVZli5FNg4B
hL1YxmHPtRohskcFfGp1rSgCFGTxkwCcPLOaTAvtcNN3x4e5XMlae2zMKm7w
RooiQIdWUFBCwePmm2/O9GGmmzEhkvNQxgEvrqGPJS1rm3hu7rmqBOyvY4J5
cELY3LWBIHiINggea9xY48YaN9a4cU9xo3R1Sweog4gAc0y+4AAaeKZcYyv6
Qlyj08R2qAZrKfjBcfkx80KuqB7vnCivq3CRYxTEUKS0Y3jlPjwZgFgdHSr+
Z/tSNtz/FlSZMUGezUHDz70zI/dFTjrpJAU2RlWQauGmUjqFyWtQLk6Vlzyq
OU1UvUs5yeKhT0QB3l9dOpUoT63QmOBfzUcrkiqHpq4KWDi08VcpBe8fzWRn
f2i56iWGpEpwhwqOxcvSJaNme+Ga142m8x8cPWTLtefniuI2PYR4lgicz6hE
ldSN2XJSbTFH24N4ce6pPeRjH/uYwVG//du/LZTl7eLFC6ZtllJq/JRV3WfL
0/SBxO7eCtcIBQCIzlaLFUO6SyATQwy/1ISILiBQ6H/RWmiWFsSx7kvWtt8L
DHRy0Fz+7SABAQApXtQqYRbmgj7+8Y975vd+7/f08HK9jvhQGh6s1ICuYY2W
EANWGeGtW6KaF2B/QcYq7kLB0UcfXZshjSe2LircFOIaYWp2zmrhtCkAVPkL
OdeKmrFGjFz0hWdgN+Ei3Srn6eapeEWCR1CD7FEAhl85T24h9OdNVdbl92LL
jQzXiuIjcsjaWdiKgitx5gEgv2q7FH8YxgoAgni7RiurmXIfJ7EU7u6eaL6q
KJHBJM9stlOfq09Tt6YcVEgDd8jp7Mum5hd7GW7ARx6YWaZ4kLVEiwoUKHFc
nL9f2eoikEYPCMFAKCv38xeXdmYQjzPDiwOfdflIWzMq1dYMglsf66Klz53k
nxitN2RgpV/dcMMNbsGwkgxoVIOR/M5tyOO7CJUZiJxbdgH9j/COezGStg5N
EMBgj/vf//51a9p3If4kIIAY2vdgE3218KYAYsEZhRCud8dng3blMFpFL96l
GoO/M0iLxyc/+Umx0fJ9Vh1XJmFWS7+VgA6ni1eTlU4++WT3/eJmzf6A4HeX
8c8vzbAgXl+5i2GvcWONG2vcWOPGPcUNEEDfytyKyCh6zmjWQELT5FuxC1jJ
maw8IHyqG6JKWTDXimek3I1yxzrI07p5aaiqepJBwzOZIAzyrLV9wV0elITC
kFJYckyIV5eM0hZXLm1iDOUKmirzpVkj9aRBpoxApUK42q8aqV4M0pkx5d+R
ZLHZNRLhZxbOA+KZRli4FMcFla2EjcmnXilHlKqWhyUH9IWjF+Rlo3r5NUtt
jetGQ8ky2bU56F6BBCjoulHCi0XokLaN1p8pcaVBFW8GC+QI/qVBRT350KtH
5TEuK7Peg3Lf0lOypWTT0NXiPWEr+67CTSIJX8fRXrXUbfYpAk7eT36uLsaD
RDlePNOHMcynnHKKAc9x/QMf+EBrF+dhefCDH5zX1f1Xl6IRqnV3rRbZhg0b
NJ6AM96ctacOyPAEDXi/Zve1SbI4WE0kQQx1md/4jd/wYl7cin+gTbkwTiB8
5HaPnCASgmaqV0cddZSjZeNzkvn6hosDHZbphv7lINjt5waVxeaGy3R5MYxQ
YmmOzpUSExk2M+sVepEEsnNqPDRLI5o0vea8idrRZsOm7Fl8Kcf5WIsAyQ8r
XTSqFbWD7xi95DK5zOlsxS1LvFoJtj7UJFnI+GqtE7KPNdu9lTUGoe2jmmgA
cuXS5VnpIiuiAHLVqPVn4qcyRnjrnshliRkZJYr6KOxErt81QvF3LFXrnQ0X
Erwp19h0SYbVtCvO5DOVy0SVS5aCn2cNcmwMyZ/PerrrFsBZaQ9n9DsUAl8z
kuCuG0m4lWEvaiU3NKOtTmk3h18UZuAdR6K2DnXzOVgiM3JnPMh6zEy6SFhs
WjxgN0MU4HqDNMANg9J32203baeWPYcACgUPJIoKD9YDbsOgukRxcxmQ7+4b
2dxZqePXBilUIGYIkkWe144cUt6o0B/38YZ8SrkV1jYUvBYJiBx6ZpETXP98
GtnQOIo1bqxxY40ba9y4R7hx5kTK50ngHNcavuisimtViSJlxHum+2fEOG9p
tOQZpz20KSBqx+gFuWXpaA9tGV3Iu08JXyr46T5eln4kYljpQp7KtFIsXC7a
+U+V8hMKgk1rD0JlXuycCog5dWlJPN0JyWfKgJmTCrzXUMYfpotV6zhLRQCS
7nP+aMubnqLytXPpl5Q/RY64alTHmgPA8rGKG1UbY8DiZyFeejnjoNyduVFy
YvohGH8eLl/EdDmo6uu2VYKqQlzzetFADvVXPz+aNP3iqAlmfULL1q1EnZnG
YgXdX/3VX1WH4v7yC4/zVuGeCAkxAPWjjDDGrBp1Vg1DbT7pWUy4awPlPR+l
WsZP/uRPmnSfxaNmKzWFRAWQN1FS9txzTy0kD3vYw1R59t57b501KAuaE+E4
4Z1R+UY2b4LARm0gnNSYk2PlxhtvrKyfekq95gsu5R3VYVmKVjVMh0JhcbRP
ecpT/BOLxGfpNywEWiiYC3pXDFB5w1p5Gi1dJHNbgYyWBXUXt5ldoloTK1JK
O3hCQmVzkh+6UiiQhbl5Ngcv2zJqhhcakdAyg5IHMeCc4ir+6MGHEMnEBK7P
D+jTuU8w6+vXT2HXyG/V4OkMaJA5Y7SmgrhtQSmNX5zMtcrSVRjIHJqB95LR
TyGLTcGZWQ5zlV45WiNx7CvX9IFXWwlAlc3loDb660ajt8Larxg1DBO0Lhmd
mDKwfGCUT+dWMumHB1V4MLPk+wflxm27b2yVQPylpQecASHCHRCR7l/36nJF
C6GsuAe3qp+ayJMFUnFo9lBrN4YYsAuAr2YrrhNOOMEwUfs9QQBFdTwURer6
hJhRBT/LWM3RHY8eVEgVuOR2w9d0bMCCLZkAAaUOAEQDaV1oP/vZzxqCDsjo
mf34oOJAbE4B8dXcyKzXYT6sxlvTZiEYQbDlxatpA5/GAvJvgROcqUFAsqir
3fYikOoMBCPIQW2FyRLbpxYhVd3xEdY1FawCkKI1SqWXo0WnxCRHcubU4Vrc
4O3kBVZ10JTmknSUi2RFzjGEw9KpSlk8RR5Jbuf6rLjekB9my/WGcHc7/q6l
5JfvKxYVf5LbqHJDCi3GXPlxLxrNVoJEY6dNJ0nrSc4XJa4e2aPZWnNM8Amc
UoYk189myYoe//LoeuDubyGdbl7sfVFe6RdFswcgCUUZ6Lx4TrQJNwot8+nc
vNiwcECRIHGIy2Qi89PlMrZXd154qozRbLa6J4ILBH65rK2c64WLDpDzhTtm
zM/HytfAiBqiP2L//fevhKkGUoUK5YpKgVnKGEKRUT1hizeUouKlcLEl71hU
DsDmj8Z6iQC8gm+dz+VjH/vYSk0wXr8Oeio1XOwH1WwOwUf6Po499ljNuQZ6
2RHSSEjDnNa4scaNNW6sceMe4UaCumteSvuY47r1dcabLWCX68xBKT4q0bFS
uszW0V3rnJGpmuKTuD77On06wFWtm1nlWSnOc9YIHWeQcvcs3vurOdEsTX/W
kow215iJqiJs8ldvGAPqf9y21NOWZkDzhrOJJnWsKc2sxA/DjewzmZHTBcrG
mvNktV2U+ynjzzX3iiGXf9OzoCZE3CiCVOtKIdz5T3/h7mRuqchQnGcAIptn
nylenb+WeyWSfGCpJaJxI6tOEeDeR+ODOKYtQmXEUOoCWcWloAmCzdVE4Bc1
F/6qyq9eY1C6RlRwI4dmneNkSbQYYaeACsaQwuLmwmoxuBqut4guiomeWUtw
2KxWXQYtAMbU/Lhx40Y1HVs+Gb/tGQ7UFE499VQ/E6NVB/njP/5jFZZMFrys
NhDGr8XjlltuMZ0WDaVXE0iZgWrP5qx3ZQJTFds5cpB2Xf6aVT8T/fbRiy1e
gBmdk9msl4Ex3izqwBsGF22gmSDOnahoK+9se7Wq9c5U+xJjOcKNYshXzBQx
4OZR8CcRKLvo9tFdJStH0WU8rpVQIJncmtFARwyU2JM8VkDa9qmBS6hy1ugx
wUwm1EmJQ4HM1qXEmcFjGSs0L1RmZ3aayIC2QnC7lMuum6itvKizZBsZ2dRa
hQr++6++h0q/LZRLKlXkmpH0anzaBXdvu+AwLHpsbEZZLeXai3Jl0wgUUOaR
DA45DgSiIjE0enBeNom56nrPGR0xc3yUF99www1u3EFQhXFqYcbFzgPv6AJA
9l6xeCBCWK6nfPz6XO+zzz4HH3yw9oSXDbKUN8QWbygmqGLA1THHHGOtXWZD
McPmjxDihLhnK3kIoLBFAiKHTRM+85nPiDZc4885KCTM786qEJpYmZUnFccq
yYXIscaNNW6scWONG/cUN+ZgTjlLDJkpN2JMLVfK9f7qgtExmSf6qzSXJP/i
KFLPt04Jqufcnc4agRnGoFpzI30nYAk3jFpXhs+Kkpy/4pCNlxtkHknGmelG
X9tpp53mSgBDZORyPwvg3DIqnJ8z6pQawZLLxnecNZrMKTmknGSgwz/lBgrl
LMFhQGlB6SGYZ9IFKmWTeD9rLtXt9OL3joI2Vy11+M0piyuthgEl8HNQUdBg
pBod5czm9i0NsPELXGWT5XOphGlh9nOCns/iXWRkBvb3uk5W6qnC5gWOFsAg
JvzuIFQPD3g7WYmLNXSknlTMMMsJ8OIBTxFj9VFCCPM2e0KwNxTzwAMPrHyH
tMcee2zYsEEzwotf/GJjQl7ykpcUzi3DmnZq81mVINBJbGR4tw76w0GCAyhh
jY5PfepT1kW/7bbbLE/6uc99riS4DB3l3jrbrChNl8cff7yaVIknvNGcbN7O
mywRT2WrzBgSS5Zw4V5c6HiGvs2j4FXGkNhnDrHIiFr8mBt3po9NI0KAd0n2
qK0wxw67MI+LRwWtywZdvLRHcQH7uPj9zCmdVsbnKdpF7Q4DVfiL0bbvt6Um
Ucj+xnKcNVo2NF0ljZaQ63SBhIW1ZwXyT+3X/Dxf5woCV92r9712lP8txqmN
GO6W61knMnuGi+TG65aYc9kErqwYV4yT7dGNPskBEhOyxya3+Anm+LHEpKtG
PeTi3z4wKhExDJd0YhIDDjdEG37u+BmJ0V/Qrw/izEcHCRfhRr0LYZyQp0gq
zYkIHr5sI+E+GRjd5eM7xhaA+B0RD7ROwP5aPvfdd99Mpkgd2kjhSitfgRte
z/5eVS5DKQ4//HA9s694xStct+C2QgUoIRRk1wUubAqJvCGSIJZY3/grX/mK
jar5kzYQ3qXXd2tg5l1arHwHZvlxiIM1bqxxY40ba9z4B+BGekSYIOcmcueZ
3Txyu7pmZvw4ooisECkAyXkRv+d6SEsqmNyLN02l/BpPbojaWMens+7TCOUp
Q55kdhcwzChHh061oqsvtqV7IANlbUTrILlVcUo+YueSPqnnOkPNbFcpI9WR
vHf0jN45WiTXn7fY3bw8zU/ekBJ752MfUdWdOffWJZ0RI/apJVOIxHiYJZmx
wNFrR78keFb7ABxXKJT83tw2yMtHVdL8UL11CL9rKoroTPas66+/3kdwUKbb
SnT61aMIoTaQyuvJAiomUFUs8p7wCpk1VtJIAweEeV/210fnu9wZOikguPWG
QT5CowfEFzTc+vnPf74OTRDAyPNHPvKRj3jEI8QQtBjVGRDjxQuZN+fFBqPa
9hqCczU+sHQdLdBR3R5fpKKClj2HQBLLod8xCOjwT1wm/vhSEJPm12f8VRfU
ZQx8hQDbpoJXcxSoBkkP5n1TXs4zu2lU+N8+CuB4vH3q79yfuLM8kp0wL+SO
KdXdVVd0emS0ZzbblQR8GNZ7xnfaUaH2MgPklJF8/SqXVu7p9a9/vfGiNci2
5JehsKGcjFCJm0tHxd05fnXXSAQucDTB47KJCth28vPVBs65Xy8cTRNKnr10
6oNQNtCuuxMDDmR8IjyYIKE1lR8mW2aPvWI0fyw1HqZQ8IjL4BR5+X2j/H6R
MPmRrxyFjt8/lTPtQLiYEbXiPEoXFd780NIXUu+w42ck5aeEGxwHbqWIipM5
Iot24NgX4Xov5qQbt0kfENcoyYBFmgXa5a2cA8F3HoAtykLmKEFs3Na2Ovro
o43Q2HvvvSs6iuAhmDz5yU+2UN4JJ5zgAYKKSe6m50OHHXaYxS64pwKbApIk
3DE8keTWW28VLpJAvvCFLyR4WJ7084MAGUWRm2++WdMNn8A4BEaupZenr3Fj
jRtr3Fjjxj3FjZSIOJcPXZxVGbK+eHJyFQlSPUKJtJ6k6xltXNJ5OnaMLNSU
kW0TpdRn8fBXuUv8uYs86DC1BPJYX6c3V3o3DKycu2BTtHnn0nrJ4hviBtKg
eT2vfvWrY+TsJDloVnJ+MxPpdcrZIcNeONUnlBLsA0z+GtpI5bXlvbpiVPy7
ZjQyqKLI+YNyJ+2YEpNX9KwSPfhTnuJNowt2kbfXjpqlOjdNtJQBYTSZuop/
RZc1J4zKx1072syluZQG+4FBQXHqUm7Q1JPyVsIx/Sm5ZYWCGF9bh5FRCvOg
RKUtJOFFIPLVYD21EsT4ivX5cyOvIA5SCvRZ3HLLLapCvK+vz3xqwgIQdEzo
YTGIFNwwP+Xggw+WPWukjuZiPsujBgEvKjXPfe5zdfbxddTmeCNfNvcKsJYy
0oHhpl8Y9LWvfe1PF/rqV7+qCsOxr8ac+PVf97rXCVY8tyCHM0ec9rkj4Pwd
g3QOanh0BbaAZwvnjkFyfeBQHMLmKZ0ts+RKVPau0arg3CnudCUORGacvZzb
7l5LJ8NCZwqliDfnoc6W3q1L02eIt9ZXjrzhQYGjhbkGpL1INuRtU1GdLBKF
d1YXNOQJJS4fibRGZVw5VT8OLbs50FH2qAelwV45eiVcOHrSzeMpLW5lPM7k
2UvH7SS9ULHQTZ2bWUQh41GhRnvt6JXAzd1BmFulI2uI+dASVMtc0xyqZfXq
pYa/IMkZzQs1hfzAKJ3KrUQSxIwYHyYSEwxUgIrWYNjdqrw2MSHvrUZC6OMf
/7gxmeBGNhAhBZa0QTysp9MTZrT181133SWT8qzSEl0GLCGzaJ/4xCdWt6fo
jn322UfpwkgJ6GUve5mGkUJBgJeSzsyZBTqc0sLsGaSCB8LPpxbiFfTYfnoQ
x0oXX//61/9qoW984xt/uVAHd955pwDIkjDcnYGtcWONG2vcWOPGPcWNFI1N
I48s48OZS1kJzfvljMhluU3ju9nVEjgUiVqQ2Aq2bBrtlQsincO3HEblOt8z
+jtbvCKUa7QrmWKbRhCmqXBB09YlynQl0SYdKvcZao5wcfLJJ3uQvtY7bhth
q2bxCFYrSLhjideSLh5lzOMXeFamaGbOnxowyRQJ8ykseR8uXJpNQ3HZ1VP5
8UwfeWGK20yX8UXC5ExbYosfRd83xIw5WvQUeRPFpLoc3txKKSplOWQDyRJ8
HGoVR69ayq0brlYujD+/ZrQqYAb8k7YLeb8EHHHjw0vXM00WxqfZDkALSVoJ
12gDMarNG/qrktfSXJD5NWLAehXzVBdAPVHOR54XJT7zmc/YuTXTAZwrEJUD
yCy5oo4++ujHPvax5qqksEAiiUU+oVe96lV6WFBtbPQG2uhhAUD0cRx//PFy
B3PoW39sEKpKXWW/OCizhqO9/fbbv7nQX//1X397oW9961v/caG//du/Valh
krUAnHjiiTkrMxSEG1XCiUmzQhQ2kEHD0MfZmjFvuFk8ghRxg1ulTXfnlRtu
HvHqCRJW99IcmmGWA4WBUmtnb6+80NgMBzXG2xGeN2JZeaJ/sg4t9PKXv9yy
inxo75aBERaQf2fUCsccNseBUrHT1fLKaznLEs5txTSKgijaIbTJlZmBtHSw
S5cWDLPT89KJih5JuhM3zh7lU4Qap8tqqxAT7mxbQ8Z6GvL7xUuN1h2LWTtc
Er6sj3HdUiF5JVqjoPQS5TjW2XrdqMFVJR/fxcpmmSASG+RNwAG4KDZDDirB
raBQ3ayQIdYGlxZDXjVgfawihvu1AHLTIM5oacyuiMghtsCwejY5EOWYrmK5
nV5E2WOOOUYbKQhgWzfjSKEDDjjAvgMghhY2LtYwcvjhh1dG2HKgz3jGM/SW
8u0cP7DmsD/5yU+KaUCZRgxkoa8txICVQICFP1kIkePbg7610F/8xV8INUyI
ywbBe40ba9xY48YaN+4pbmwdpfPOGfW+zlpKXpyxZK8b/lThi5jivFGzunJb
6TvpwsnSaQdbRsZWPLJj+FO2TJW4smYk5wsg2hxq95bOUjqJsjTLu/jSvKsO
O89gYaLbpjqHqU6+Pgqj1mygoxYPgkOvH+WOCS7yw85Pgd2UyS2ZpU6R6tEM
xLn+KQDJiJGP8rrRYXkOhS3uLrYtXNM/pWZ2sGWqSdLMXDSqsM4an/PJ9SKA
GKjynrOsEFYHUEmN9969+BgELBi5Wjvp60al9MCkImCpQvy8hDV5ROcsJIZI
OkyNaF2JBAMu8lrqq009sWYgVGxb/gjwQShIc6mm1ucGcY2IVFZLruocPSWR
McNvetObVEZQWFQ90FBqY60Kc8ghh1jh/LnPfa6pIoWeorDomX3CE57gNaed
dproyoO0S4AbOmTh/T9bCHD4i4UMGdXQ4fi//vWv/58LobD8Hwuhwogb3Mfx
G6NYtIBU4w/YU04sONMyEVo5Cj9wZ4m7t4xMt7xvRaLmmjxvaR8vdT6zpPiT
rh2aFc9g0RsHybEHNWKwToh4siJBZbEpboSn5K/Mvuo13FDY5EMIIKX1nTNK
i7RN53T2KWfevR5Ito7zR8/r946GzrHSpaNIyGyFKLTDa3JWulNDqJyyG2xV
1ERyjvep2A4MqLBx3qi10szw4jmmw9hdo3BQYsnmqUtFW0B4VQEQx1y0BpQI
lCnjfYN8kdJsrxsdJ83JrZQH9ItLk3pz4kpYy9Axp7xl1sgKmltWVrL0hKQR
AzCRzbOZ/PJoY8318p17tzGi4ob1PDU8ahflpLgRSvAI7ZMc1K7RgfEUvrJh
yc95znPsnwIIaOVA5NDQgSiiHxahohbPGjr22muvsEXb6fHHHy9HMEuKUmXI
Mjx9rN/85je1giJg+CegQxsIooiQ8o1vfOPPF0IsETfAFgUwZmaNG2vcWOPG
GjfuKW7k2Zz5xfzx6vGeOUpXtcyKYMx4vmMq/Zfkn89lxWeaqyUX4cyGPSuX
a45R49DSm6DCvUA5+TSzTL4S7u89z1qqLmcb8T5xdyMpStY7V9icOzd+D9Se
xDQZ6uzRJSq/8DlLJQGVslLtwoRyN7JjzKle7x2UiSPcSHOR+/JZbFvCcWVt
J5CTpZmUoi6zp0XOmUEBeL71C0YX7FnB6bJcbK6EQtHmCmA+1yCuy5fqZA67
UmAfGB1jWZONth6yokSBXnCEfzJOFSpe9N8sBdL9a3ltpdtzvQ5Za3pb3UsP
y2+OHg1Fl1nA3A7XBlBlzTAGDOKk9wEWxA0YUC+GN4fAFtWcUj8sjgExEu4v
4L/mNa+xEMehhx6aoUPae++9tWagywgO4IZnRBUIBcczGzdutNAfn1685a0F
B/BNcPjWt771nxdCH3HYxa196UtfCjckcMNf8Vf90cDs5lHThmWW1VFvC7gh
l2lt0JHqItk6SthpEJghJcpkESbo95SJVtx/cVn+3HNHR7bNo8LGrGVr/7Su
YObQ+F24i1vT+s+dCon4q7LYvF6BwXngT8LUGwfx6HgkG0K/ysySO7t9Pwbc
NYqcF0CyY8RwXjYatxlx4fZdcIXEcYbNBLZkkri+gJAieOVoYKe64jGyALJr
9EEo3HR2ss/e6gI/SgzsuV5ccKneYSixwbqCV00NGpI6quTzy4M+OBrTV70c
6FgpWCp0GBwu+wMR8bvVJEQeDzhp3EUlvuFrGb8So3Oua37YAi9lnNJI+Xnu
WuGCk1kMZEkOdHrCkm737PJxIndwcvhSRmsACwaFbtiwQdzIM3vAAQfodbUj
PIS8YWPryqHzQ+v7veENb/Cbgpx6jQ2Dh5A3/stCf/M3f/OVhRhJsaPaQICU
ry/EX6vjEf6scWONG2vcWOPGPcWNYkE3jbgvVn5pKZ7ZPqpjlUzRmgwB8pbm
joHyjPSnFZdBJohZuQiaQqRCUoMv9ZHZ2ardo1ocPr1sDhmHYftGQGKZ8mW1
ZDApXLZ6X/WVFsqS6pPnsyrMnl8hJQDUESz3hRs5m4QOvaXyZjdPBZhLncTv
RZT5p3SE0kP6ahcuXeEgVqmcyIGS//tGHyK4VYXIaDFHu3mUUskMko+1uitb
RjpkIHPl0tlWTSqtKsYv5b/8FC+2XLnGjdqupYx4pnBTLs6GICDA/qkn6hqW
GfEAzFTlic1hAXX2ShbXpYg/qU18atBNE4US/qkmRxzokIXj9EeY66H3sxyQ
2weh9QhcgLlL6Pjjj7cIMKqHHdyADsEBhUU3Cn+1FAZA4TUPH7TPPvvoqz3x
xBNdyWh8epHKdAMK9LF+5zvf+Q8LffnLX75rIY7/r4XUUPTVioQApgoX71hQ
RJo+/GI+F3q9XMaycZGnDsfdrfw5xbV9VnAoiypPX9GVZ41+ChkSN49Q9owe
4UbLWANdYokAkpgxN1V0bHNEgRz0non8OdJFdhIZP7fvqaeeWryo7xhsxlDN
Q3bahBMv8ykCo05Pr982SghmQ2hPzyyTuLJzIlGiBD2NJ5ANCKD3jUbVF44c
uh0jcjWLh80T5dBsCOHGbDEON+T3AjAuWbpG6kRu33HYnFQ00qBxxdLiTZiy
MiF0yaiYmrOVg+wbig2MKi+qYkMNEd476g1yjdZItm8rgkKV7gk38vZy2+yZ
mizYRoWLapXzV7kMfqnpQKmmog2yxJ8M8hq4THb7y7/8S6Mg/uqv/sod/M//
/M/lzTvvvNOtnDPwqTgDMxo8z8oxbfZJT3qSIgSIYUX0PfbYwzjz/fffX0sp
Iodlf7KH7LvvvkLKC17wAutNsZCcSSZHBEB4cJDAmgdAmQDCaP96IWQSR8vY
nCJ+VZTpGjfWuLHGjTVu3FPc2DoK854zqm3IelAF684dVcc5LmMlfo8j0kpc
NrMjMlFc3Mixu2lkasNZXmy81qYpRivHyo6ph+yOUaajyLE8tlk8gkQeJ99d
NPoW5S1NmzhrtJN+91KCQxuIZKtHNRoHOev7Dik39JzUM3O9xzl9impLibho
VBrMw7Xpe2oLnDeVNMl0UxhVBop8LuJGpTkuGNn3oeg1S/NWy+7JUHlwRDBR
ov2igLc5cjVtyPnXAXfm0snLP83+IPWL942aw1VLK3cjV4vFu2w36UFlvmrY
+sGlD7XV1NVl4GihQ3uFTpY6xgIg3grkqYSvJgsORJ58tagh3xsvmkdVf0ph
lqkeHGvEABMU+P96EJK/Z+BNU8Y0I0j8UJjiNeU7FBaT5VFYKoSuoQPcMK/t
8Y9/vIaOSnnstddeRpA+85nPPHEh1rA6YGVDeBHT8VCainTV68rwSlTRV9s1
X/rSl0xm4UyWvSKl88OizrsAMnUWcJ7R7+xRtaMlHUtqonT/XbF5bh1BqjMD
9ojEgB7hNG6aYiRYkxkKXJyKQ1lddJVmbfCe20bcZlEKGis04MStK35YM2Gh
cKO3ZvbkxEtHFfctU/8IX3bn1HZh24i93zbSTmOuy5ZSgd6hASSVBSYrCLxz
qeZnBpliBkwUgAQCNVFd6XQfOxfdnT939hFfPpVVLGetyM/stG0uBfk4Od7f
AJJwo7ofCjz8dcVkykiqE6j8ULnCypwablH9QAis0NqpwVPJoRrd149usACI
2AIsiAAcaDwEN/xTDZhym3IgbgBQ1d+Qle4cpPkCgge1b3AgSnAsRCCEeOBe
r9+Tn2gsZSS+JruMhT0f+9jHKngAHbpoESq0nYIPYstjHvOY8uMOXOioo46y
+Pkpp5zigmSeRddcw4xcCYS3M0ijQSpyQIBbGb4aUQGQNW6scWONG2vcuKe4
cdFUiFvx/rWvfe1pCyGZK6i/Z+qClA6b6aO4wSjnXRyUVUQmPX9U59syKENB
/Pue0Si2WNb4SC3AOyTWmuKhol3ujNdkqZhDSb+Xu32RWd/x9V//+tdbVxZE
dWzbR53h1PPvjYzaNpWF/173x+w0Ce66g1NtHpnBaZ7JJsPF8awcDUv+60EB
SOYFpyhw4GAlEhXWrtGqSKITRF6+ZjRXKje/4h4BCLdy/Cm8DNIB8MNS47Vd
cMMMLLqG9dKa1+YAmFuH/eEPf1hmh+vVU+ruqtFDP4ueZYsK1gml8lz+lZsL
QabSQ1XVA210iPArrSL9HK1ElABVVrJakPlLGfsPg3SafP3rXzduCr7zPGeE
CLhSJOFMKe0wpj/kjI5dPqvFh0ufn50mpqUccsghtlbZuHGj6gknvbi+riCP
GZp8HSdQdIUETCi/EsCl7eU73/nO3y0EdHx9kCoYaLNlRFlsHuUBC4+0Q5mG
i4wVBUNmhUj7dvHPeZ0ZQjP97bo7te8nVJw5eshumYp1ZMFoR4P808VLRU2p
/Tooy8TqT6z+B1VCsIsTVzaPUGrgxbANIRQCuFLzHT/MUrh4aa1BorikVOD1
xWDP23Q1ADM+ZyASyYO7jD/nj86wRZDaoA1iVajLI1cEDuXArlT2KA4k4USU
gJJMtEV4UB5uOWsBSHJOohTk/GdFgdMVM6pTavaZgeIKHgW1ZrEBcFb6KAUy
BZwXHP7+pb+t9wQEEjw8U410GKd+bSXG1iKh7gkJJ1KtV9mdNRWycRvSALtp
6EB+SPAQN741SCsoZGYZ5G6uqcFqn9DnP/95WZgtwC3sRS96kUIFmKC8scce
e4Qb/unZz372kxZCCKlpgpm2T3nKU164EBqEU8ryEDey9CJWZbpR7mJIyku8
gqMti5Y/rXFjjRtr3Fjjxj3FjRi2AKoKerNii61KTs7HGoAUi5Vj0TPdecaW
FSfCjpHokVKcU+OMUdyv3+4cNcBlsRW9YAYlz/hX0cn5543eNEiW3DyVLsyh
GW54JdBRecD8ofkoC+lsbI62GLAzlnrOXlwsZZkagV4eigtGla13j4oiuWbe
M3rOXjaawFa2In/EXK+jEh8r0ATj+yfuk3mneRAAL10aMKWepIyoXnG3jCfZ
QHzHC0ZLmsKD+avaAVxZJYosFcV0pbCstJdlJL4OF6uIaSqRRKTMHXY+Ekxg
Ae0S9k6C+Ku4oZcWsp6eVHNY2bbeKECHz2UAXnPzzTen6WsfMDUMQssQB9A7
NBT8p//0n0wG+fa3v620D7wIIHpbdGRwN00lNWFkJH7ct7zlLRYERg1RT9l9
991XDB1AR81ZpAMPPFCLBzqL2fcnnXSSaxJ09UVST3xfiHlwSlH09CyDgQII
B7119SKKwCwQ4oylvdGc2hlKbBrB2HNY9exAXCF/1VYePpwxmqxtGtGq/Qn4
ylXqTbIKzpJMwsyukZgZgGwbGV5FwIIArxuk4FFARTEqF4x+c4zEa/ihr8+j
K5JT3ZtCI1bMO+XQ8Qrnj+KHXWOpwEtHczT5XSbl/t7hPSP/l1sVuCLx6OwD
7s4JHtyhUoQhQDnLmaMTnLLGZHz2jEaYCpwmZhRk4j3ngHM/RDifb53nihIs
RS2NbPd1UNKjCiN7DSdlbfPvrOzRXHmmSWP9izbJLfC4cbBm0XoSxJA1AC6f
UqvojCF6JwuJrFERZItYhSIP2Je94Atf+IKCR0X5YHYDSuEvrRngxn9d6G//
9m9lQHBDpy3CBiKHuAHg6O5kDFX+EQxZMLaOhfe1eYIY5sxu2LBhn4UOOOAA
5Y2nP/3pihn77befMgkHmj6OO+44IzpYHspURszaockhgQm6gzUIQ1Y7h+64
446KIq5xY40ba9xY48Y9xY0iuAp01O9guoe8HLZsHTkjcXc+jjOXWhaytuy8
danWq7aSV0UmneNFg4KUkbjDG5bfIToFUI5tdou4bnvKmaPDe1QW2xve8AZ1
sYqDlZt/7ki140+vHeTPcyymeheAOruhw2F/xfGukTWWPSG30c4R+WnwJNQM
pN/tGtlwF47i52kTFvJV00+nkLVz+syoVdydb10zyjMmcpIFN4d94SgJEvRt
nspQV6/MaS/wb/5w/gpMUDwGN/SflsWWjzjcyLFSWl95LleMkumcSe+oEmBq
RV2lzE2D0Fwq9FHGirYLoEDcgH8LAbWGHidlpcqhgzPeEFRRmDfbay4PqE8T
Ahm0bxRJhYbylUF33XVX6WNybmUuIK0QDNLP9NKXvtTUFaBDhWWPPfYwlJRj
A8Ce8YxnWF3wkEMOMbOeiz148pOfbCQqX1n8LIANNDA6lAHrdbV2GcR4tNjw
Jz0+gFuu1cJE3/zmN5vGxVarI7JU07NH0+TYLQNphoi4/txRN6O4i50jPDvW
DmQSIaracd5UaLSA82wghYU3toJaZ3/lSvxGhppodrYapPHmQQgnr1notNNO
q5q373j+REVL9iIZeGPDwixLTMt82gy0U8/z5lQYSqGmLwOGTolJWVzPn0qU
Z4zq0zhFBcdWmgmZqgqizpWWn75XUJbN0+vfvdQMFOKaf+f83aPlbgZ24KX6
fjUdkOpGzWIWCq4bXaRrkA1iiJZNu5UGoSJILaBR/qzo9JujcVuMXztsy2tY
YUMDBUwhd8DC5oEWZw4TCQ5w9P8+SGz58pe/bPQFZ+REflUoqfs1rCdvsnEL
Grfddhs/kU+RTGRPbiWCWScEYnjal1ifFRVUzAAuHrQQEohiBuCgZ9agDuM6
jE7nWDsJW6EzicghQIUbDCN3cGm8jtZwdIhhr3FjjRtr3Fjjxj3FjXeN6t9l
ZCjGm9fW2ogT83cEBfk6W/b+KZ9LuJEBpONNI/ctRj57VPBr1Z01OhnFLDMg
vHsqup7xZA4PUxHzTylEsXk6OBwkWp5yyimvHqRS+bM/+7MiCdfE0SuGguJX
L1hqFKvdh12bRiH3iwbxyTwz+8F9x7MG5b4ptuqS0WalGZs9UJmDvGF6Rxro
HIJbaFkgqfMIHtcWJNw1pFDFA0uXQFwfMmcNa7Wo8HI30Yl7+iJggmwOdKyU
5Cq28wMf+IAgY9V0z7vaC9IDJ9Vc0NQq8QGMqIn85qhLnCO1dPuPfvSjNVLR
mVJzIsBBlDA7HqoG4E033bRSVY+LNXTAU/IdP/RXJsRB/NCLc6MADiXRV68D
VUV44TINHSCGgwQ3nApWi6X1jz76aPNTwATTUh760IdqzeCk3hPgxYT6ww47
zIrHBxxwgK6WF77whX41plRViMcZ08Ur6A+qKWQtpQRV6axRLqMgjerViBhy
X1pwVoViKmKTdsAVanfrr/08js4q2w5YaR0ttOndKwEk54xUu6wxGT2ST2Yx
oy04w0gvkq9WmwaIcfJCr3zlKw2ghbm0lFZpsMiK94zo1iQublib3XePFNEd
Ix1v5+hFNRttsuL6w+SNWbzxzOZRPb5hM11Gm8ypcwon7Mu+YxgbtmRLyef7
7tFL1wgT2XPT0n7XkozChZIeVEgMABJ89SGyHbmi+JXXFO9qFUEIWNAWwUGp
Z2JLNQBhfLXygpyrN5Jn1tIcWk2r3eFvjS2v+3PlerSLwqQ1ZcsvKUeLIVAF
fCo0GqTAcVozYPycvxXr0FBQjQsgoj1dHy6UAxeEkTf5k7EloStv5Pdid3va
QgcddJD1N37iJ35CAAE6bC8LOBy70FOf+lQjSAEZAeSII44wEpUVpemVt1Zw
AiWEzTL+eDsBpHj7NW6scWONG2vc+Afgxv8PMM9Wng==
    "], {{0, 341}, {360, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  DefaultBaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{360, 341},
  PlotRange->{{0, 360}, {0, 341}}]], "Output",
 CellChangeTimes->{3.7069482745431314`*^9},
 ImageSize->{364, 341},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 
  1}},ExpressionUUID->"0e942896-1f80-426d-9ece-581b9af75be0"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Interactive backtracking", "Subsection",
 CellChangeTimes->{{3.706940205802808*^9, 3.7069402083796697`*^9}, {
  3.706941100460916*^9, 3.7069411034518733`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"Function", " ", "for", " ", "coordinate", " ", "conversion"}], 
   "*)"}], "\n", 
  RowBox[{
   RowBox[{
    RowBox[{"SaveElement", "[", 
     RowBox[{"xReal_", ",", "\[Theta]Real_", ",", 
      RowBox[{"{", 
       RowBox[{"dimx_", ",", "dimy_"}], "}"}], ",", "s\[Theta]_", ",", 
      "periodicity_"}], "]"}], ":=", 
    RowBox[{"{", "\n", "\t", 
     RowBox[{"(*", 
      RowBox[{"Real", " ", "coordinates"}], "*)"}], "\n", "\t", 
     RowBox[{
      RowBox[{"Flatten", "@", 
       RowBox[{"{", 
        RowBox[{"xReal", ",", "\[Theta]Real"}], "}"}]}], ",", "\n", "\t", 
      RowBox[{"(*", 
       RowBox[{"Array", " ", "coordinates"}], "*)"}], "\n", "\t", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Mod", "[", 
           RowBox[{
            RowBox[{"Round", "[", 
             RowBox[{"#", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "]"}], ",", "dimx", ",", "1"}], 
           "]"}], ",", 
          RowBox[{"Mod", "[", 
           RowBox[{
            RowBox[{"Round", "[", 
             RowBox[{"#", "[", 
              RowBox[{"[", "2", "]"}], "]"}], "]"}], ",", "dimy", ",", "1"}], 
           "]"}], ",", 
          RowBox[{
          "#", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]}], 
         "}"}], "&"}], "@", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"dimx", "-", 
          RowBox[{"xReal", "[", 
           RowBox[{"[", "2", "]"}], "]"}], "+", "0.5"}], ",", 
         RowBox[{
          RowBox[{"xReal", "[", 
           RowBox[{"[", "1", "]"}], "]"}], "+", "0.5"}], ",", 
         "\[Theta]Real"}], "}"}]}]}], "\n", "\t", "}"}]}], "\n", "\n", 
   RowBox[{"(*", 
    RowBox[{"Interactive", " ", "tracking"}], "*)"}], "\n", 
   RowBox[{"Manipulate", "[", "\n", "\t", 
    RowBox[{
     RowBox[{
      RowBox[{"(", "\n", "\t\t", 
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{"g1", ",", "g1d"}], "}"}], "=", 
         RowBox[{"SaveElement", "[", 
          RowBox[{"xtemp", ",", "\[Theta]temp", ",", 
           RowBox[{"Dimensions", "[", "im", "]"}], ",", "s\[Theta]", ",", 
           RowBox[{"(", "periodicity", ")"}]}], "]"}]}], ";", "\n", "\t\t", 
        RowBox[{"curved", "=", 
         RowBox[{"BackTracking", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"g1d", ",", "g0d"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"A1WInt", ",", "A2WInt", ",", "A3WInt"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"prms", "[", "\"\<xi\>\"", "]"}], ",", 
             RowBox[{"prms", "[", "\"\<eps\>\"", "]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"W", "[", "\"\<AngularResolution\>\"", "]"}], ",", 
             RowBox[{"prms", "[", "\"\<gridScale\>\"", "]"}]}], "}"}], ",", 
           "periodicity"}], "]"}]}], ";"}], "\n", "\t", ")"}], ";", "\n", 
      "\t", 
      RowBox[{"Framed", "@", 
       RowBox[{"Show", "[", "\n", "\t\t", 
        RowBox[{
         RowBox[{"Image", "[", "im", "]"}], ",", "\n", "\t\t", 
         RowBox[{"Graphics", "[", 
          RowBox[{"{", 
           RowBox[{"Red", ",", "Thick", ",", 
            RowBox[{"Arrow", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{
                  RowBox[{"#", "[", 
                   RowBox[{"[", "2", "]"}], "]"}], "-", "0.5"}], ",", 
                 RowBox[{"Nx", "-", 
                  RowBox[{"#", "[", 
                   RowBox[{"[", "1", "]"}], "]"}], "+", "0.5"}]}], "}"}], 
               "&"}], "/@", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"curved", "[", 
                 RowBox[{"[", 
                  RowBox[{
                   RowBox[{"-", "1"}], ",", 
                   RowBox[{"1", ";;", "2"}]}], "]"}], "]"}], ",", 
                RowBox[{
                 RowBox[{"curved", "[", 
                  RowBox[{"[", 
                   RowBox[{
                    RowBox[{"-", "1"}], ",", 
                    RowBox[{"1", ";;", "2"}]}], "]"}], "]"}], "+", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"Length", "[", "cost", "]"}], "/", "10"}], "*", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"curved", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"-", "1"}], ",", "3"}], "]"}], "]"}], "]"}], ",", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"curved", "[", 
                    RowBox[{"[", 
                    RowBox[{
                    RowBox[{"-", "1"}], ",", "3"}], "]"}], "]"}], "]"}]}], 
                   "}"}]}]}]}], "}"}]}], "]"}]}], "}"}], "]"}], ",", "\n", 
         "\t\t", 
         RowBox[{"Graphics", "[", 
          RowBox[{"{", 
           RowBox[{"Blue", ",", "Thick", ",", 
            RowBox[{"Arrow", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{
                  RowBox[{"#", "[", 
                   RowBox[{"[", "2", "]"}], "]"}], "-", "0.5"}], ",", 
                 RowBox[{"Nx", "-", 
                  RowBox[{"#", "[", 
                   RowBox[{"[", "1", "]"}], "]"}], "+", "0.5"}]}], "}"}], 
               "&"}], "/@", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"curved", "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", 
                   RowBox[{"1", ";;", "2"}]}], "]"}], "]"}], ",", 
                RowBox[{
                 RowBox[{"curved", "[", 
                  RowBox[{"[", 
                   RowBox[{"1", ",", 
                    RowBox[{"1", ";;", "2"}]}], "]"}], "]"}], "+", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"Length", "[", "cost", "]"}], "/", "10"}], "*", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{"curved", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "3"}], "]"}], "]"}], "]"}], ",", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"curved", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "3"}], "]"}], "]"}], "]"}]}], 
                   "}"}]}]}]}], "}"}]}], "]"}]}], "}"}], "]"}], ",", "\n", 
         "\t\t", 
         RowBox[{"Graphics", "[", 
          RowBox[{"{", 
           RowBox[{"Green", ",", "Thick", ",", 
            RowBox[{"Line", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{
                  RowBox[{"#", "[", 
                   RowBox[{"[", "2", "]"}], "]"}], "-", "0.5"}], ",", 
                 RowBox[{"Nx", "-", 
                  RowBox[{"#", "[", 
                   RowBox[{"[", "1", "]"}], "]"}], "+", "0.5"}]}], "}"}], 
               "&"}], "/@", "curved"}], "]"}]}], "}"}], "]"}], ",", "\n", 
         "\t\t", 
         RowBox[{"ImageSize", "->", "600"}], ",", 
         RowBox[{"Frame", "->", "False"}]}], "]"}]}]}], ",", "\n", "\t", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"xtemp", ",", 
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"#", "[", 
               RowBox[{"[", "2", "]"}], "]"}], "-", "0.5"}], ",", 
             RowBox[{"Nx", "-", 
              RowBox[{"#", "[", 
               RowBox[{"[", "1", "]"}], "]"}], "+", "0.5"}]}], "}"}], "&"}], 
          "@", 
          RowBox[{"g1dListForward", "\[LeftDoubleBracket]", 
           RowBox[{"1", ",", 
            RowBox[{"1", ";;", "2"}]}], "\[RightDoubleBracket]"}]}]}], "}"}], 
       ",", "Locator"}], "}"}], ",", "\n", "\t", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\[Theta]temp", ",", 
         RowBox[{"g1dListForward", "\[LeftDoubleBracket]", 
          RowBox[{"1", ",", "3"}], "\[RightDoubleBracket]"}]}], "}"}], ",", 
       "0", ",", 
       RowBox[{"periodicity", "-", "s\[Theta]"}], ",", "s\[Theta]"}], "}"}]}],
     "\n", "\t", 
    RowBox[{"(*", 
     RowBox[{",", 
      RowBox[{"SaveDefinitions", "\[Rule]", "True"}]}], "*)"}], 
    RowBox[{"(*", 
     RowBox[{"<", 
      RowBox[{
       RowBox[{"--", 
        RowBox[{"--", 
         RowBox[{"--", 
          RowBox[{"--", "Save"}]}]}]}], " ", "definitions", " ", "and", " ", 
       "save", " ", "selection", " ", "as", " ", "cdf", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"File", ">", 
          RowBox[{"CDF", " ", "Export"}], ">", "Standalone"}], ".."}], 
        ")"}]}]}], "*)"}], "\n", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.7069402203003983`*^9, 3.706940222475156*^9}, {
   3.7069402807191415`*^9, 3.706940286395206*^9}, {3.706946601393757*^9, 
   3.706946608161796*^9}, {3.706946649970992*^9, 3.7069466600016766`*^9}, {
   3.7069467648716745`*^9, 3.7069467728188105`*^9}, {3.7069468115217752`*^9, 
   3.7069468340346675`*^9}, {3.7069468822960663`*^9, 3.706946918676852*^9}, {
   3.706946970967965*^9, 3.706946980967568*^9}, {3.706947456225922*^9, 
   3.706947460562459*^9}, {3.706947798399227*^9, 3.7069478425165977`*^9}, 
   3.7069478763262367`*^9, 3.7069480307301893`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["---End of notebook", "Title",
 CellChangeTimes->{{3.7069391480582695`*^9, 3.7069391494339*^9}, {
  3.706953704260953*^9, 3.7069537045968466`*^9}}],

Cell[CellGroupData[{

Cell["Convert output to bitmap to reduce notebook size", "Section",
 CellChangeTimes->{{3.631265495696987*^9, 3.6312654995601997`*^9}, {
  3.706939152123087*^9, 3.706939156026475*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "Run", " ", "to", " ", "convert", " ", "all", " ", "image", " ", "output", 
    " ", "to", " ", "bitmap"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"NotebookFind", "[", 
     RowBox[{
      RowBox[{"InputNotebook", "[", "]"}], ",", "\"\<Output\>\"", ",", "All", 
      ",", "CellStyle"}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"FrontEndTokenExecute", "[", 
     RowBox[{
      RowBox[{"InputNotebook", "[", "]"}], ",", "\"\<SelectionConvert\>\"", 
      ",", "\"\<BitmapConditional\>\""}], "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.615614680193201*^9, 3.615614720877468*^9}},
 CellID->133026008]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1920, 1117},
WindowMargins->{{-8, Automatic}, {Automatic, -8}},
ShowSelection->True,
InputAliases->{"intt" -> RowBox[{"\[Integral]", 
     RowBox[{"\[SelectionPlaceholder]", 
       RowBox[{"\[DifferentialD]", "\[Placeholder]"}]}]}], "dintt" -> RowBox[{
     SubsuperscriptBox[
     "\[Integral]", "\[SelectionPlaceholder]", "\[Placeholder]"], 
     RowBox[{"\[Placeholder]", 
       RowBox[{"\[DifferentialD]", "\[Placeholder]"}]}]}], "sumt" -> RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"\[SelectionPlaceholder]", "=", "\[Placeholder]"}], 
      "\[Placeholder]"], "\[Placeholder]"}], "prodt" -> RowBox[{
     UnderoverscriptBox["\[Product]", 
      RowBox[{"\[SelectionPlaceholder]", "=", "\[Placeholder]"}], 
      "\[Placeholder]"], "\[Placeholder]"}], "dt" -> RowBox[{
     SubscriptBox["\[PartialD]", "\[Placeholder]"], " ", 
     "\[SelectionPlaceholder]"}], "ia" -> 
  TemplateBox[{"\[SelectionPlaceholder]"}, "Inactive"], "cbrt" -> 
  RadicalBox[
   "\[SelectionPlaceholder]", "3", SurdForm -> True, MultilineFunction -> 
    None], "surd" -> 
  RadicalBox[
   "\[SelectionPlaceholder]", "\[Placeholder]", SurdForm -> True, 
    MultilineFunction -> None], "ket" -> 
  TemplateBox[{"\[SelectionPlaceholder]"}, "Ket"], "bra" -> 
  TemplateBox[{"\[SelectionPlaceholder]"}, "Bra"], "braket" -> 
  TemplateBox[{"\[SelectionPlaceholder]", "\[Placeholder]"}, "BraKet"], 
  "delay" -> TemplateBox[{"\[SelectionPlaceholder]"}, "SystemsModelDelay"], 
  "grad" -> RowBox[{
     SubscriptBox["\[Del]", "\[SelectionPlaceholder]"], "\[Placeholder]"}], 
  "del." -> RowBox[{
     SubscriptBox["\[Del]", "\[SelectionPlaceholder]"], ".", 
     "\[Placeholder]"}], "delx" -> RowBox[{
     SubscriptBox["\[Del]", "\[SelectionPlaceholder]"], "\[Cross]", 
     "\[Placeholder]"}], "del2" -> RowBox[{
     SubsuperscriptBox["\[Del]", "\[SelectionPlaceholder]", 2], 
     "\[Placeholder]"}], "notation" -> RowBox[{"Notation", "[", 
     RowBox[{
       TemplateBox[{"\[SelectionPlaceholder]"}, "NotationTemplateTag"], " ", 
       "\[DoubleLongLeftRightArrow]", " ", 
       TemplateBox[{"\[Placeholder]"}, "NotationTemplateTag"]}], "]"}], 
  "notation>" -> RowBox[{"Notation", "[", 
     RowBox[{
       TemplateBox[{"\[SelectionPlaceholder]"}, "NotationTemplateTag"], " ", 
       "\[DoubleLongRightArrow]", " ", 
       TemplateBox[{"\[Placeholder]"}, "NotationTemplateTag"]}], "]"}], 
  "notation<" -> RowBox[{"Notation", "[", 
     RowBox[{
       TemplateBox[{"\[SelectionPlaceholder]"}, "NotationTemplateTag"], " ", 
       "\[DoubleLongLeftArrow]", " ", 
       TemplateBox[{"\[Placeholder]"}, "NotationTemplateTag"]}], "]"}], 
  "symb" -> RowBox[{"Symbolize", "[", 
     TemplateBox[{"\[SelectionPlaceholder]"}, "NotationTemplateTag"], "]"}], 
  "infixnotation" -> RowBox[{"InfixNotation", "[", 
     RowBox[{
       TemplateBox[{"\[SelectionPlaceholder]"}, "NotationTemplateTag"], ",", 
       "\[Placeholder]"}], "]"}], "addia" -> RowBox[{"AddInputAlias", "[", 
     RowBox[{"\"\[SelectionPlaceholder]\"", "\[Rule]", 
       TemplateBox[{"\[Placeholder]"}, "NotationTemplateTag"]}], "]"}], 
  "pattwraper" -> 
  TemplateBox[{"\[SelectionPlaceholder]"}, "NotationPatternTag"], 
  "madeboxeswraper" -> 
  TemplateBox[{"\[SelectionPlaceholder]"}, "NotationMadeBoxesTag"], "=<" -> 
  OverscriptBox["=", "\:02c2"], ":=<" -> OverscriptBox[":=", "\:02c2"]},
FrontEndVersion->"11.1 for Microsoft Windows (64-bit) (April 18, 2017)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 147, 2, 101, "Title", "ExpressionUUID" -> \
"91e2a727-6465-4d04-b707-faf811f61be4"],
Cell[CellGroupData[{
Cell[752, 28, 124, 1, 70, "Section", "ExpressionUUID" -> \
"d0a434eb-6ecf-4124-b04a-eed684431faa"],
Cell[CellGroupData[{
Cell[901, 33, 694, 16, 50, "Input", "ExpressionUUID" -> \
"c74ddb60-7cb7-46d5-b769-75ebf2a4d71d"],
Cell[1598, 51, 240, 5, 30, "Output", "ExpressionUUID" -> \
"ace685c1-c5dc-496c-a85a-d114f0e84d94"],
Cell[1841, 58, 265, 5, 30, "Output", "ExpressionUUID" -> \
"cb746608-3bcc-480d-b41c-0fba9a1efa33"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2155, 69, 115, 1, 70, "Section", "ExpressionUUID" -> \
"a3c78841-9f24-4898-aca6-76a0f2431b96"],
Cell[2273, 72, 590, 11, 50, "Input", "ExpressionUUID" -> \
"9a5762b5-ddde-416d-a240-8cb9700db63a"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2912, 89, 150, 2, 101, "Title", "ExpressionUUID" -> \
"31ff36cc-41be-41c5-ae6b-6e8552df1777"],
Cell[CellGroupData[{
Cell[3087, 95, 186, 2, 70, "Section", "ExpressionUUID" -> \
"93ed32c0-1321-47fb-b49a-e194ba740eb9"],
Cell[CellGroupData[{
Cell[3298, 101, 114, 1, 49, "Subsection", "ExpressionUUID" -> \
"bd235899-9c08-4ce8-bddf-ba9a6a4b4ef6"],
Cell[3415, 104, 16927, 399, 1422, "Input", "ExpressionUUID" -> \
"4381359d-5bd3-4489-b142-38e66ec6c3d0"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[20391, 509, 231, 4, 70, "Section", "ExpressionUUID" -> \
"af2ed22b-e140-46b4-b7ea-712e0e24d1aa"],
Cell[CellGroupData[{
Cell[20647, 517, 48, 0, 49, "Subsection", "ExpressionUUID" -> \
"b8a47c5c-3742-4ce5-923a-15b110012e7c"],
Cell[20698, 519, 10032, 234, 1152, "Input", "ExpressionUUID" -> \
"57521683-54b3-4d78-8450-88f5d50fdb5b"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[30779, 759, 119, 1, 70, "Section", "ExpressionUUID" -> \
"eb444fe0-b40f-451f-a145-f1e84f890d24"],
Cell[CellGroupData[{
Cell[30923, 764, 94, 1, 49, "Subsection", "ExpressionUUID" -> \
"789efbba-223e-43de-b201-ebe476174ebb"],
Cell[31020, 767, 9069, 224, 935, "Code", "ExpressionUUID" -> \
"cbb51ead-4986-47b8-b217-b6cdff402802",
 InitializationCell->False]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[40150, 998, 264, 3, 101, "Title", "ExpressionUUID" -> \
"6d14a17a-be23-49fb-8412-49ca3b33eab7"],
Cell[CellGroupData[{
Cell[40439, 1005, 166, 2, 70, "Section", "ExpressionUUID" -> \
"adba42ce-3a76-4d06-88ec-d41c48054529"],
Cell[CellGroupData[{
Cell[40630, 1011, 491, 11, 50, "Input", "ExpressionUUID" -> \
"e6802f67-e596-4c5b-82c7-652d6e9fb527"],
Cell[41124, 1024, 222, 5, 30, "Output", "ExpressionUUID" -> \
"a047a282-6b7b-4dda-9a11-8e35b29da6b2"],
Cell[41349, 1031, 372, 9, 30, "Output", "ExpressionUUID" -> \
"2f710f96-07a3-4012-ba06-91d9c88eefde"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[41770, 1046, 154, 2, 70, "Section", "ExpressionUUID" -> \
"00130c3e-693e-4bcc-9be4-c66e36c7a477"],
Cell[CellGroupData[{
Cell[41949, 1052, 2614, 47, 107, "Input", "ExpressionUUID" -> \
"f603a18f-f2b6-4dff-b655-b3b55790d7df"],
Cell[44566, 1101, 176609, 2902, 355, "Output", "ExpressionUUID" -> \
"b426273f-1635-4cb7-a0bb-367563f11863"]
}, Open  ]],
Cell[CellGroupData[{
Cell[221212, 4008, 166, 2, 49, "Subsection", "ExpressionUUID" -> \
"d4f40748-07f5-4804-be74-3775368c8907"],
Cell[221381, 4012, 2699, 93, 169, "Text", "ExpressionUUID" -> \
"1fd617c4-de42-4dc3-8604-a1a5cc6353c9"],
Cell[CellGroupData[{
Cell[224105, 4109, 1288, 32, 69, "Input", "ExpressionUUID" -> \
"a03b58b9-563c-4ecd-a7e0-0ed9a71321ab"],
Cell[225396, 4143, 159, 4, 30, "Output", "ExpressionUUID" -> \
"eaec5736-2b81-4aa3-9512-06eb8c7df4fe"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[225604, 4153, 105, 1, 49, "Subsection", "ExpressionUUID" -> \
"f22b287d-bf6b-455b-80af-967aa7a2efde"],
Cell[225712, 4156, 580, 12, 87, "Text", "ExpressionUUID" -> \
"5e9cdb8a-54b1-4530-965e-93376a34d66f"],
Cell[226295, 4170, 3370, 78, 276, "Input", "ExpressionUUID" -> \
"e3c71546-c273-436e-b764-9832fd3651d3"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[229714, 4254, 313, 4, 70, "Section", "ExpressionUUID" -> \
"f5264e6f-3a7a-47b2-8dac-4cda4f9cc051"],
Cell[230030, 4260, 701, 14, 68, "Text", "ExpressionUUID" -> \
"9f406563-92a5-49f3-8d73-e0617bbd401f"],
Cell[230734, 4276, 1926, 40, 107, "Input", "ExpressionUUID" -> \
"9062a3a3-f0b8-4ade-8300-f6845285084a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[232697, 4321, 232, 3, 70, "Section", "ExpressionUUID" -> \
"0bce1487-c2ab-4e2a-b0e5-c9aaaa6a1c24"],
Cell[232932, 4326, 1470, 40, 109, "Text", "ExpressionUUID" -> \
"f94c8810-5b25-43d9-bf1e-a7a513425c8e"],
Cell[CellGroupData[{
Cell[234427, 4370, 3031, 78, 172, "Input", "ExpressionUUID" -> \
"aec02a82-5d62-4b8b-a60e-33a7cf1b4440"],
Cell[237461, 4450, 226, 6, 30, "Output", "ExpressionUUID" -> \
"b0895f41-6dba-4472-8c8f-072942ed4e66"],
Cell[237690, 4458, 198656, 3263, 433, "Output", "ExpressionUUID" -> \
"50487aab-fabf-4fd8-b5d5-5e48eb6aa9d5"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[436395, 7727, 231, 5, 70, "Section", "ExpressionUUID" -> \
"c56a056c-ce00-4bc6-b2bc-512454e07f5a"],
Cell[436629, 7734, 980, 23, 192, "Text", "ExpressionUUID" -> \
"afdb989b-8e18-4c4a-b226-27d605e13c4c"],
Cell[CellGroupData[{
Cell[437634, 7761, 3389, 82, 337, "Input", "ExpressionUUID" -> \
"6a90b452-52c6-4cd3-bc13-ae8672677bfc"],
Cell[441026, 7845, 76550, 1261, 244, "Output", "ExpressionUUID" -> \
"563c669c-7f36-4130-adff-ae63471133a1"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[517625, 9112, 311, 4, 70, "Section", "ExpressionUUID" -> \
"3a650039-1fca-4b93-bfd1-3996d2e9be6e"],
Cell[CellGroupData[{
Cell[517961, 9120, 156, 3, 49, "Subsection", "ExpressionUUID" -> \
"b8d5dc4f-760e-466c-8fa4-c8f67b29a5f2"],
Cell[518120, 9125, 220, 4, 30, "Text", "ExpressionUUID" -> \
"429899cf-c11f-4103-a27d-379dbd6f6b79"],
Cell[518343, 9131, 1496, 42, 107, "Input", "ExpressionUUID" -> \
"2bcfebef-ef29-4ec1-a0c3-42cf6da62112"]
}, Open  ]],
Cell[CellGroupData[{
Cell[519876, 9178, 153, 2, 49, "Subsection", "ExpressionUUID" -> \
"4a8644a2-fb29-4756-b373-b7d15d52c137"],
Cell[520032, 9182, 738, 13, 68, "Text", "ExpressionUUID" -> \
"897173e6-9e50-4925-b0e7-cdf9e881a524"],
Cell[CellGroupData[{
Cell[520795, 9199, 6802, 174, 369, "Input", "ExpressionUUID" -> \
"e6c77333-0626-404c-9e09-4e52c1b42cac"],
Cell[527600, 9375, 118402, 1947, 394, "Output", "ExpressionUUID" -> \
"0fc5de22-d201-49eb-983a-611606367ad8"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[646063, 11329, 107, 1, 70, "Section", "ExpressionUUID" -> \
"9db5857c-2646-4103-ac0c-8181a8d3a678"],
Cell[CellGroupData[{
Cell[646195, 11334, 110, 1, 49, "Subsection", "ExpressionUUID" -> \
"770b2d52-f769-4a15-8655-aeee36e181cd"],
Cell[646308, 11337, 11978, 239, 506, "Input", "ExpressionUUID" -> \
"888b7875-0f7b-4d6c-b34d-9948a8a3b28f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[658323, 11581, 110, 1, 49, "Subsection", "ExpressionUUID" -> \
"b745ba36-f9ef-40ac-97c6-6d67879a58a1"],
Cell[CellGroupData[{
Cell[658458, 11586, 3458, 97, 392, "Input", "ExpressionUUID" -> \
"40e3588b-3808-4bdb-83dc-5fd929d61193"],
Cell[661919, 11685, 226, 6, 30, "Output", "ExpressionUUID" -> \
"94e62ce5-4ee4-4d77-b5e7-e8c602e953f9"],
Cell[662148, 11693, 226, 6, 30, "Output", "ExpressionUUID" -> \
"19c94b8a-a58e-49dd-bad4-67ca36380871"],
Cell[662377, 11701, 224, 6, 30, "Output", "ExpressionUUID" -> \
"c9773b76-bdab-409f-b625-22d66131d63b"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[662650, 11713, 104, 1, 49, "Subsection", "ExpressionUUID" -> \
"8fa39cc2-6d72-4e95-89fd-5ed276c18efc"],
Cell[CellGroupData[{
Cell[662779, 11718, 2151, 45, 88, "Input", "ExpressionUUID" -> \
"79c8d401-3567-4b8b-ae2d-66abbf72de4f"],
Cell[664933, 11765, 123789, 2036, 394, "Output", "ExpressionUUID" -> \
"d83bce49-549d-4309-874c-fd0c6224f17c"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[788795, 13809, 173, 2, 101, "Title", "ExpressionUUID" -> \
"d61a01f9-2fa9-456f-94b3-550f15f9a21d"],
Cell[788971, 13813, 216, 4, 70, "Section", "ExpressionUUID" -> \
"8ae617fd-032c-4c34-b0bd-8cc6f06ef213"],
Cell[789190, 13819, 344, 6, 56, "Section", "ExpressionUUID" -> \
"ce0a2da2-59d1-48ec-8785-25df0ec83672"],
Cell[CellGroupData[{
Cell[789559, 13829, 229, 5, 56, "Section", "ExpressionUUID" -> \
"4145da55-f8c4-4df5-8857-e2e9c6ca20d9"],
Cell[CellGroupData[{
Cell[789813, 13838, 159, 3, 49, "Subsection", "ExpressionUUID" -> \
"19faee24-19ae-4a67-bcf1-86921e969dc5"],
Cell[CellGroupData[{
Cell[789997, 13845, 131, 1, 39, "Subsubsection", "ExpressionUUID" -> \
"2867c4cd-49c4-4270-a00c-e23b24f233cb"],
Cell[CellGroupData[{
Cell[790153, 13850, 2713, 69, 164, "Input", "ExpressionUUID" -> \
"e556e869-ff8d-496a-8319-fbc2376350de"],
Cell[792869, 13921, 183, 5, 30, "Output", "ExpressionUUID" -> \
"aa5a07ff-756b-4f2f-a1bc-42bfc0d8ebbe"],
Cell[793055, 13928, 182, 5, 44, "Output", "ExpressionUUID" -> \
"782ab519-4355-4585-ab74-e2fe96ff6be0"],
Cell[793240, 13935, 163, 4, 30, "Output", "ExpressionUUID" -> \
"96cf1387-623c-40d8-9e56-01eadc9640c6"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[793452, 13945, 168, 3, 39, "Subsubsection", "ExpressionUUID" -> \
"06d4ba6b-0a2a-43fc-9ec2-97120f06605b"],
Cell[793623, 13950, 11288, 298, 323, "Code", "ExpressionUUID" -> \
"e2f34879-3cf7-47dd-814e-9e654704c9b8",
 InitializationCell->False]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[804960, 14254, 174, 3, 49, "Subsection", "ExpressionUUID" -> \
"cff29dd7-f216-4191-b787-9c71add25ca4"],
Cell[CellGroupData[{
Cell[805159, 14261, 2466, 63, 125, "Code", "ExpressionUUID" -> \
"5afd1a33-2e67-4d5f-ac32-a4d2f7a53c46",
 InitializationCell->False],
Cell[807628, 14326, 119552, 1966, 356, "Output", "ExpressionUUID" -> \
"0e942896-1f80-426d-9ece-581b9af75be0"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[927229, 16298, 165, 2, 49, "Subsection", "ExpressionUUID" -> \
"c82a887f-c649-4381-a6a5-b8bf7212a271"],
Cell[927397, 16302, 9443, 239, 468, "Input", "ExpressionUUID" -> \
"185fedd8-0787-4e99-aeb5-a3840507c086"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[936901, 16548, 152, 2, 101, "Title", "ExpressionUUID" -> \
"210616fb-342f-41ec-8b67-01e524d4eb1e"],
Cell[CellGroupData[{
Cell[937078, 16554, 184, 2, 70, "Section", "ExpressionUUID" -> \
"a709db74-aec5-4291-a127-df1e98cea7da"],
Cell[937265, 16558, 693, 18, 69, "Input", "ExpressionUUID" -> \
"26d2de71-7e90-46e2-bdd1-7414fdf7d92f",
 CellID->133026008]
}, Open  ]]
}, Open  ]]
}
]
*)

